(function(){const a=document.createElement("link").relList;if(a&&a.supports&&a.supports("modulepreload"))return;for(const o of document.querySelectorAll('link[rel="modulepreload"]'))r(o);new MutationObserver(o=>{for(const u of o)if(u.type==="childList")for(const c of u.addedNodes)c.tagName==="LINK"&&c.rel==="modulepreload"&&r(c)}).observe(document,{childList:!0,subtree:!0});function l(o){const u={};return o.integrity&&(u.integrity=o.integrity),o.referrerPolicy&&(u.referrerPolicy=o.referrerPolicy),o.crossOrigin==="use-credentials"?u.credentials="include":o.crossOrigin==="anonymous"?u.credentials="omit":u.credentials="same-origin",u}function r(o){if(o.ep)return;o.ep=!0;const u=l(o);fetch(o.href,u)}})();function sd(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,"default")?t.default:t}var lf={exports:{}},Lr={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var fg;function U1(){if(fg)return Lr;fg=1;var t=Symbol.for("react.transitional.element"),a=Symbol.for("react.fragment");function l(r,o,u){var c=null;if(u!==void 0&&(c=""+u),o.key!==void 0&&(c=""+o.key),"key"in o){u={};for(var h in o)h!=="key"&&(u[h]=o[h])}else u=o;return o=u.ref,{$$typeof:t,type:r,key:c,ref:o!==void 0?o:null,props:u}}return Lr.Fragment=a,Lr.jsx=l,Lr.jsxs=l,Lr}var dg;function H1(){return dg||(dg=1,lf.exports=U1()),lf.exports}var d=H1(),rf={exports:{}},Ie={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var mg;function F1(){if(mg)return Ie;mg=1;var t=Symbol.for("react.transitional.element"),a=Symbol.for("react.portal"),l=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),o=Symbol.for("react.profiler"),u=Symbol.for("react.consumer"),c=Symbol.for("react.context"),h=Symbol.for("react.forward_ref"),g=Symbol.for("react.suspense"),p=Symbol.for("react.memo"),b=Symbol.for("react.lazy"),x=Symbol.for("react.activity"),_=Symbol.iterator;function v(M){return M===null||typeof M!="object"?null:(M=_&&M[_]||M["@@iterator"],typeof M=="function"?M:null)}var S={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},T=Object.assign,A={};function w(M,B,N){this.props=M,this.context=B,this.refs=A,this.updater=N||S}w.prototype.isReactComponent={},w.prototype.setState=function(M,B){if(typeof M!="object"&&typeof M!="function"&&M!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,M,B,"setState")},w.prototype.forceUpdate=function(M){this.updater.enqueueForceUpdate(this,M,"forceUpdate")};function O(){}O.prototype=w.prototype;function R(M,B,N){this.props=M,this.context=B,this.refs=A,this.updater=N||S}var q=R.prototype=new O;q.constructor=R,T(q,w.prototype),q.isPureReactComponent=!0;var Y=Array.isArray;function L(){}var X={H:null,A:null,T:null,S:null},oe=Object.prototype.hasOwnProperty;function he(M,B,N){var ce=N.ref;return{$$typeof:t,type:M,key:B,ref:ce!==void 0?ce:null,props:N}}function U(M,B){return he(M.type,B,M.props)}function re(M){return typeof M=="object"&&M!==null&&M.$$typeof===t}function ae(M){var B={"=":"=0",":":"=2"};return"$"+M.replace(/[=:]/g,function(N){return B[N]})}var le=/\/+/g;function W(M,B){return typeof M=="object"&&M!==null&&M.key!=null?ae(""+M.key):B.toString(36)}function H(M){switch(M.status){case"fulfilled":return M.value;case"rejected":throw M.reason;default:switch(typeof M.status=="string"?M.then(L,L):(M.status="pending",M.then(function(B){M.status==="pending"&&(M.status="fulfilled",M.value=B)},function(B){M.status==="pending"&&(M.status="rejected",M.reason=B)})),M.status){case"fulfilled":return M.value;case"rejected":throw M.reason}}throw M}function C(M,B,N,ce,pe){var xe=typeof M;(xe==="undefined"||xe==="boolean")&&(M=null);var Be=!1;if(M===null)Be=!0;else switch(xe){case"bigint":case"string":case"number":Be=!0;break;case"object":switch(M.$$typeof){case t:case a:Be=!0;break;case b:return Be=M._init,C(Be(M._payload),B,N,ce,pe)}}if(Be)return pe=pe(M),Be=ce===""?"."+W(M,0):ce,Y(pe)?(N="",Be!=null&&(N=Be.replace(le,"$&/")+"/"),C(pe,B,N,"",function(lt){return lt})):pe!=null&&(re(pe)&&(pe=U(pe,N+(pe.key==null||M&&M.key===pe.key?"":(""+pe.key).replace(le,"$&/")+"/")+Be)),B.push(pe)),1;Be=0;var ve=ce===""?".":ce+":";if(Y(M))for(var qe=0;qe<M.length;qe++)ce=M[qe],xe=ve+W(ce,qe),Be+=C(ce,B,N,xe,pe);else if(qe=v(M),typeof qe=="function")for(M=qe.call(M),qe=0;!(ce=M.next()).done;)ce=ce.value,xe=ve+W(ce,qe++),Be+=C(ce,B,N,xe,pe);else if(xe==="object"){if(typeof M.then=="function")return C(H(M),B,N,ce,pe);throw B=String(M),Error("Objects are not valid as a React child (found: "+(B==="[object Object]"?"object with keys {"+Object.keys(M).join(", ")+"}":B)+"). If you meant to render a collection of children, use an array instead.")}return Be}function K(M,B,N){if(M==null)return M;var ce=[],pe=0;return C(M,ce,"","",function(xe){return B.call(N,xe,pe++)}),ce}function ne(M){if(M._status===-1){var B=M._result;B=B(),B.then(function(N){(M._status===0||M._status===-1)&&(M._status=1,M._result=N)},function(N){(M._status===0||M._status===-1)&&(M._status=2,M._result=N)}),M._status===-1&&(M._status=0,M._result=B)}if(M._status===1)return M._result.default;throw M._result}var ie=typeof reportError=="function"?reportError:function(M){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var B=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof M=="object"&&M!==null&&typeof M.message=="string"?String(M.message):String(M),error:M});if(!window.dispatchEvent(B))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",M);return}console.error(M)},k={map:K,forEach:function(M,B,N){K(M,function(){B.apply(this,arguments)},N)},count:function(M){var B=0;return K(M,function(){B++}),B},toArray:function(M){return K(M,function(B){return B})||[]},only:function(M){if(!re(M))throw Error("React.Children.only expected to receive a single React element child.");return M}};return Ie.Activity=x,Ie.Children=k,Ie.Component=w,Ie.Fragment=l,Ie.Profiler=o,Ie.PureComponent=R,Ie.StrictMode=r,Ie.Suspense=g,Ie.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=X,Ie.__COMPILER_RUNTIME={__proto__:null,c:function(M){return X.H.useMemoCache(M)}},Ie.cache=function(M){return function(){return M.apply(null,arguments)}},Ie.cacheSignal=function(){return null},Ie.cloneElement=function(M,B,N){if(M==null)throw Error("The argument must be a React element, but you passed "+M+".");var ce=T({},M.props),pe=M.key;if(B!=null)for(xe in B.key!==void 0&&(pe=""+B.key),B)!oe.call(B,xe)||xe==="key"||xe==="__self"||xe==="__source"||xe==="ref"&&B.ref===void 0||(ce[xe]=B[xe]);var xe=arguments.length-2;if(xe===1)ce.children=N;else if(1<xe){for(var Be=Array(xe),ve=0;ve<xe;ve++)Be[ve]=arguments[ve+2];ce.children=Be}return he(M.type,pe,ce)},Ie.createContext=function(M){return M={$$typeof:c,_currentValue:M,_currentValue2:M,_threadCount:0,Provider:null,Consumer:null},M.Provider=M,M.Consumer={$$typeof:u,_context:M},M},Ie.createElement=function(M,B,N){var ce,pe={},xe=null;if(B!=null)for(ce in B.key!==void 0&&(xe=""+B.key),B)oe.call(B,ce)&&ce!=="key"&&ce!=="__self"&&ce!=="__source"&&(pe[ce]=B[ce]);var Be=arguments.length-2;if(Be===1)pe.children=N;else if(1<Be){for(var ve=Array(Be),qe=0;qe<Be;qe++)ve[qe]=arguments[qe+2];pe.children=ve}if(M&&M.defaultProps)for(ce in Be=M.defaultProps,Be)pe[ce]===void 0&&(pe[ce]=Be[ce]);return he(M,xe,pe)},Ie.createRef=function(){return{current:null}},Ie.forwardRef=function(M){return{$$typeof:h,render:M}},Ie.isValidElement=re,Ie.lazy=function(M){return{$$typeof:b,_payload:{_status:-1,_result:M},_init:ne}},Ie.memo=function(M,B){return{$$typeof:p,type:M,compare:B===void 0?null:B}},Ie.startTransition=function(M){var B=X.T,N={};X.T=N;try{var ce=M(),pe=X.S;pe!==null&&pe(N,ce),typeof ce=="object"&&ce!==null&&typeof ce.then=="function"&&ce.then(L,ie)}catch(xe){ie(xe)}finally{B!==null&&N.types!==null&&(B.types=N.types),X.T=B}},Ie.unstable_useCacheRefresh=function(){return X.H.useCacheRefresh()},Ie.use=function(M){return X.H.use(M)},Ie.useActionState=function(M,B,N){return X.H.useActionState(M,B,N)},Ie.useCallback=function(M,B){return X.H.useCallback(M,B)},Ie.useContext=function(M){return X.H.useContext(M)},Ie.useDebugValue=function(){},Ie.useDeferredValue=function(M,B){return X.H.useDeferredValue(M,B)},Ie.useEffect=function(M,B){return X.H.useEffect(M,B)},Ie.useEffectEvent=function(M){return X.H.useEffectEvent(M)},Ie.useId=function(){return X.H.useId()},Ie.useImperativeHandle=function(M,B,N){return X.H.useImperativeHandle(M,B,N)},Ie.useInsertionEffect=function(M,B){return X.H.useInsertionEffect(M,B)},Ie.useLayoutEffect=function(M,B){return X.H.useLayoutEffect(M,B)},Ie.useMemo=function(M,B){return X.H.useMemo(M,B)},Ie.useOptimistic=function(M,B){return X.H.useOptimistic(M,B)},Ie.useReducer=function(M,B,N){return X.H.useReducer(M,B,N)},Ie.useRef=function(M){return X.H.useRef(M)},Ie.useState=function(M){return X.H.useState(M)},Ie.useSyncExternalStore=function(M,B,N){return X.H.useSyncExternalStore(M,B,N)},Ie.useTransition=function(){return X.H.useTransition()},Ie.version="19.2.4",Ie}var hg;function od(){return hg||(hg=1,rf.exports=F1()),rf.exports}var F=od(),sf={exports:{}},jr={},of={exports:{}},cf={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var pg;function $1(){return pg||(pg=1,(function(t){function a(C,K){var ne=C.length;C.push(K);e:for(;0<ne;){var ie=ne-1>>>1,k=C[ie];if(0<o(k,K))C[ie]=K,C[ne]=k,ne=ie;else break e}}function l(C){return C.length===0?null:C[0]}function r(C){if(C.length===0)return null;var K=C[0],ne=C.pop();if(ne!==K){C[0]=ne;e:for(var ie=0,k=C.length,M=k>>>1;ie<M;){var B=2*(ie+1)-1,N=C[B],ce=B+1,pe=C[ce];if(0>o(N,ne))ce<k&&0>o(pe,N)?(C[ie]=pe,C[ce]=ne,ie=ce):(C[ie]=N,C[B]=ne,ie=B);else if(ce<k&&0>o(pe,ne))C[ie]=pe,C[ce]=ne,ie=ce;else break e}}return K}function o(C,K){var ne=C.sortIndex-K.sortIndex;return ne!==0?ne:C.id-K.id}if(t.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var u=performance;t.unstable_now=function(){return u.now()}}else{var c=Date,h=c.now();t.unstable_now=function(){return c.now()-h}}var g=[],p=[],b=1,x=null,_=3,v=!1,S=!1,T=!1,A=!1,w=typeof setTimeout=="function"?setTimeout:null,O=typeof clearTimeout=="function"?clearTimeout:null,R=typeof setImmediate<"u"?setImmediate:null;function q(C){for(var K=l(p);K!==null;){if(K.callback===null)r(p);else if(K.startTime<=C)r(p),K.sortIndex=K.expirationTime,a(g,K);else break;K=l(p)}}function Y(C){if(T=!1,q(C),!S)if(l(g)!==null)S=!0,L||(L=!0,ae());else{var K=l(p);K!==null&&H(Y,K.startTime-C)}}var L=!1,X=-1,oe=5,he=-1;function U(){return A?!0:!(t.unstable_now()-he<oe)}function re(){if(A=!1,L){var C=t.unstable_now();he=C;var K=!0;try{e:{S=!1,T&&(T=!1,O(X),X=-1),v=!0;var ne=_;try{t:{for(q(C),x=l(g);x!==null&&!(x.expirationTime>C&&U());){var ie=x.callback;if(typeof ie=="function"){x.callback=null,_=x.priorityLevel;var k=ie(x.expirationTime<=C);if(C=t.unstable_now(),typeof k=="function"){x.callback=k,q(C),K=!0;break t}x===l(g)&&r(g),q(C)}else r(g);x=l(g)}if(x!==null)K=!0;else{var M=l(p);M!==null&&H(Y,M.startTime-C),K=!1}}break e}finally{x=null,_=ne,v=!1}K=void 0}}finally{K?ae():L=!1}}}var ae;if(typeof R=="function")ae=function(){R(re)};else if(typeof MessageChannel<"u"){var le=new MessageChannel,W=le.port2;le.port1.onmessage=re,ae=function(){W.postMessage(null)}}else ae=function(){w(re,0)};function H(C,K){X=w(function(){C(t.unstable_now())},K)}t.unstable_IdlePriority=5,t.unstable_ImmediatePriority=1,t.unstable_LowPriority=4,t.unstable_NormalPriority=3,t.unstable_Profiling=null,t.unstable_UserBlockingPriority=2,t.unstable_cancelCallback=function(C){C.callback=null},t.unstable_forceFrameRate=function(C){0>C||125<C?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):oe=0<C?Math.floor(1e3/C):5},t.unstable_getCurrentPriorityLevel=function(){return _},t.unstable_next=function(C){switch(_){case 1:case 2:case 3:var K=3;break;default:K=_}var ne=_;_=K;try{return C()}finally{_=ne}},t.unstable_requestPaint=function(){A=!0},t.unstable_runWithPriority=function(C,K){switch(C){case 1:case 2:case 3:case 4:case 5:break;default:C=3}var ne=_;_=C;try{return K()}finally{_=ne}},t.unstable_scheduleCallback=function(C,K,ne){var ie=t.unstable_now();switch(typeof ne=="object"&&ne!==null?(ne=ne.delay,ne=typeof ne=="number"&&0<ne?ie+ne:ie):ne=ie,C){case 1:var k=-1;break;case 2:k=250;break;case 5:k=1073741823;break;case 4:k=1e4;break;default:k=5e3}return k=ne+k,C={id:b++,callback:K,priorityLevel:C,startTime:ne,expirationTime:k,sortIndex:-1},ne>ie?(C.sortIndex=ne,a(p,C),l(g)===null&&C===l(p)&&(T?(O(X),X=-1):T=!0,H(Y,ne-ie))):(C.sortIndex=k,a(g,C),S||v||(S=!0,L||(L=!0,ae()))),C},t.unstable_shouldYield=U,t.unstable_wrapCallback=function(C){var K=_;return function(){var ne=_;_=K;try{return C.apply(this,arguments)}finally{_=ne}}}})(cf)),cf}var gg;function q1(){return gg||(gg=1,of.exports=$1()),of.exports}var uf={exports:{}},an={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var bg;function G1(){if(bg)return an;bg=1;var t=od();function a(g){var p="https://react.dev/errors/"+g;if(1<arguments.length){p+="?args[]="+encodeURIComponent(arguments[1]);for(var b=2;b<arguments.length;b++)p+="&args[]="+encodeURIComponent(arguments[b])}return"Minified React error #"+g+"; visit "+p+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function l(){}var r={d:{f:l,r:function(){throw Error(a(522))},D:l,C:l,L:l,m:l,X:l,S:l,M:l},p:0,findDOMNode:null},o=Symbol.for("react.portal");function u(g,p,b){var x=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:o,key:x==null?null:""+x,children:g,containerInfo:p,implementation:b}}var c=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function h(g,p){if(g==="font")return"";if(typeof p=="string")return p==="use-credentials"?p:""}return an.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,an.createPortal=function(g,p){var b=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!p||p.nodeType!==1&&p.nodeType!==9&&p.nodeType!==11)throw Error(a(299));return u(g,p,null,b)},an.flushSync=function(g){var p=c.T,b=r.p;try{if(c.T=null,r.p=2,g)return g()}finally{c.T=p,r.p=b,r.d.f()}},an.preconnect=function(g,p){typeof g=="string"&&(p?(p=p.crossOrigin,p=typeof p=="string"?p==="use-credentials"?p:"":void 0):p=null,r.d.C(g,p))},an.prefetchDNS=function(g){typeof g=="string"&&r.d.D(g)},an.preinit=function(g,p){if(typeof g=="string"&&p&&typeof p.as=="string"){var b=p.as,x=h(b,p.crossOrigin),_=typeof p.integrity=="string"?p.integrity:void 0,v=typeof p.fetchPriority=="string"?p.fetchPriority:void 0;b==="style"?r.d.S(g,typeof p.precedence=="string"?p.precedence:void 0,{crossOrigin:x,integrity:_,fetchPriority:v}):b==="script"&&r.d.X(g,{crossOrigin:x,integrity:_,fetchPriority:v,nonce:typeof p.nonce=="string"?p.nonce:void 0})}},an.preinitModule=function(g,p){if(typeof g=="string")if(typeof p=="object"&&p!==null){if(p.as==null||p.as==="script"){var b=h(p.as,p.crossOrigin);r.d.M(g,{crossOrigin:b,integrity:typeof p.integrity=="string"?p.integrity:void 0,nonce:typeof p.nonce=="string"?p.nonce:void 0})}}else p==null&&r.d.M(g)},an.preload=function(g,p){if(typeof g=="string"&&typeof p=="object"&&p!==null&&typeof p.as=="string"){var b=p.as,x=h(b,p.crossOrigin);r.d.L(g,b,{crossOrigin:x,integrity:typeof p.integrity=="string"?p.integrity:void 0,nonce:typeof p.nonce=="string"?p.nonce:void 0,type:typeof p.type=="string"?p.type:void 0,fetchPriority:typeof p.fetchPriority=="string"?p.fetchPriority:void 0,referrerPolicy:typeof p.referrerPolicy=="string"?p.referrerPolicy:void 0,imageSrcSet:typeof p.imageSrcSet=="string"?p.imageSrcSet:void 0,imageSizes:typeof p.imageSizes=="string"?p.imageSizes:void 0,media:typeof p.media=="string"?p.media:void 0})}},an.preloadModule=function(g,p){if(typeof g=="string")if(p){var b=h(p.as,p.crossOrigin);r.d.m(g,{as:typeof p.as=="string"&&p.as!=="script"?p.as:void 0,crossOrigin:b,integrity:typeof p.integrity=="string"?p.integrity:void 0})}else r.d.m(g)},an.requestFormReset=function(g){r.d.r(g)},an.unstable_batchedUpdates=function(g,p){return g(p)},an.useFormState=function(g,p,b){return c.H.useFormState(g,p,b)},an.useFormStatus=function(){return c.H.useHostTransitionStatus()},an.version="19.2.4",an}var xg;function q0(){if(xg)return uf.exports;xg=1;function t(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(t)}catch(a){console.error(a)}}return t(),uf.exports=G1(),uf.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var yg;function P1(){if(yg)return jr;yg=1;var t=q1(),a=od(),l=q0();function r(e){var n="https://react.dev/errors/"+e;if(1<arguments.length){n+="?args[]="+encodeURIComponent(arguments[1]);for(var i=2;i<arguments.length;i++)n+="&args[]="+encodeURIComponent(arguments[i])}return"Minified React error #"+e+"; visit "+n+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function o(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function u(e){var n=e,i=e;if(e.alternate)for(;n.return;)n=n.return;else{e=n;do n=e,(n.flags&4098)!==0&&(i=n.return),e=n.return;while(e)}return n.tag===3?i:null}function c(e){if(e.tag===13){var n=e.memoizedState;if(n===null&&(e=e.alternate,e!==null&&(n=e.memoizedState)),n!==null)return n.dehydrated}return null}function h(e){if(e.tag===31){var n=e.memoizedState;if(n===null&&(e=e.alternate,e!==null&&(n=e.memoizedState)),n!==null)return n.dehydrated}return null}function g(e){if(u(e)!==e)throw Error(r(188))}function p(e){var n=e.alternate;if(!n){if(n=u(e),n===null)throw Error(r(188));return n!==e?null:e}for(var i=e,s=n;;){var f=i.return;if(f===null)break;var m=f.alternate;if(m===null){if(s=f.return,s!==null){i=s;continue}break}if(f.child===m.child){for(m=f.child;m;){if(m===i)return g(f),e;if(m===s)return g(f),n;m=m.sibling}throw Error(r(188))}if(i.return!==s.return)i=f,s=m;else{for(var y=!1,E=f.child;E;){if(E===i){y=!0,i=f,s=m;break}if(E===s){y=!0,s=f,i=m;break}E=E.sibling}if(!y){for(E=m.child;E;){if(E===i){y=!0,i=m,s=f;break}if(E===s){y=!0,s=m,i=f;break}E=E.sibling}if(!y)throw Error(r(189))}}if(i.alternate!==s)throw Error(r(190))}if(i.tag!==3)throw Error(r(188));return i.stateNode.current===i?e:n}function b(e){var n=e.tag;if(n===5||n===26||n===27||n===6)return e;for(e=e.child;e!==null;){if(n=b(e),n!==null)return n;e=e.sibling}return null}var x=Object.assign,_=Symbol.for("react.element"),v=Symbol.for("react.transitional.element"),S=Symbol.for("react.portal"),T=Symbol.for("react.fragment"),A=Symbol.for("react.strict_mode"),w=Symbol.for("react.profiler"),O=Symbol.for("react.consumer"),R=Symbol.for("react.context"),q=Symbol.for("react.forward_ref"),Y=Symbol.for("react.suspense"),L=Symbol.for("react.suspense_list"),X=Symbol.for("react.memo"),oe=Symbol.for("react.lazy"),he=Symbol.for("react.activity"),U=Symbol.for("react.memo_cache_sentinel"),re=Symbol.iterator;function ae(e){return e===null||typeof e!="object"?null:(e=re&&e[re]||e["@@iterator"],typeof e=="function"?e:null)}var le=Symbol.for("react.client.reference");function W(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===le?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case T:return"Fragment";case w:return"Profiler";case A:return"StrictMode";case Y:return"Suspense";case L:return"SuspenseList";case he:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case S:return"Portal";case R:return e.displayName||"Context";case O:return(e._context.displayName||"Context")+".Consumer";case q:var n=e.render;return e=e.displayName,e||(e=n.displayName||n.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case X:return n=e.displayName||null,n!==null?n:W(e.type)||"Memo";case oe:n=e._payload,e=e._init;try{return W(e(n))}catch{}}return null}var H=Array.isArray,C=a.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,K=l.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ne={pending:!1,data:null,method:null,action:null},ie=[],k=-1;function M(e){return{current:e}}function B(e){0>k||(e.current=ie[k],ie[k]=null,k--)}function N(e,n){k++,ie[k]=e.current,e.current=n}var ce=M(null),pe=M(null),xe=M(null),Be=M(null);function ve(e,n){switch(N(xe,n),N(pe,e),N(ce,null),n.nodeType){case 9:case 11:e=(e=n.documentElement)&&(e=e.namespaceURI)?Dp(e):0;break;default:if(e=n.tagName,n=n.namespaceURI)n=Dp(n),e=Lp(n,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}B(ce),N(ce,e)}function qe(){B(ce),B(pe),B(xe)}function lt(e){e.memoizedState!==null&&N(Be,e);var n=ce.current,i=Lp(n,e.type);n!==i&&(N(pe,e),N(ce,i))}function Yt(e){pe.current===e&&(B(ce),B(pe)),Be.current===e&&(B(Be),Or._currentValue=ne)}var mn,se;function Me(e){if(mn===void 0)try{throw Error()}catch(i){var n=i.stack.trim().match(/\n( *(at )?)/);mn=n&&n[1]||"",se=-1<i.stack.indexOf(`
    at`)?" (<anonymous>)":-1<i.stack.indexOf("@")?"@unknown:0:0":""}return`
`+mn+e+se}var et=!1;function we(e,n){if(!e||et)return"";et=!0;var i=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var s={DetermineComponentFrameRoot:function(){try{if(n){var te=function(){throw Error()};if(Object.defineProperty(te.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(te,[])}catch(V){var P=V}Reflect.construct(e,[],te)}else{try{te.call()}catch(V){P=V}e.call(te.prototype)}}else{try{throw Error()}catch(V){P=V}(te=e())&&typeof te.catch=="function"&&te.catch(function(){})}}catch(V){if(V&&P&&typeof V.stack=="string")return[V.stack,P.stack]}return[null,null]}};s.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var f=Object.getOwnPropertyDescriptor(s.DetermineComponentFrameRoot,"name");f&&f.configurable&&Object.defineProperty(s.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var m=s.DetermineComponentFrameRoot(),y=m[0],E=m[1];if(y&&E){var z=y.split(`
`),G=E.split(`
`);for(f=s=0;s<z.length&&!z[s].includes("DetermineComponentFrameRoot");)s++;for(;f<G.length&&!G[f].includes("DetermineComponentFrameRoot");)f++;if(s===z.length||f===G.length)for(s=z.length-1,f=G.length-1;1<=s&&0<=f&&z[s]!==G[f];)f--;for(;1<=s&&0<=f;s--,f--)if(z[s]!==G[f]){if(s!==1||f!==1)do if(s--,f--,0>f||z[s]!==G[f]){var Q=`
`+z[s].replace(" at new "," at ");return e.displayName&&Q.includes("<anonymous>")&&(Q=Q.replace("<anonymous>",e.displayName)),Q}while(1<=s&&0<=f);break}}}finally{et=!1,Error.prepareStackTrace=i}return(i=e?e.displayName||e.name:"")?Me(i):""}function zt(e,n){switch(e.tag){case 26:case 27:case 5:return Me(e.type);case 16:return Me("Lazy");case 13:return e.child!==n&&n!==null?Me("Suspense Fallback"):Me("Suspense");case 19:return Me("SuspenseList");case 0:case 15:return we(e.type,!1);case 11:return we(e.type.render,!1);case 1:return we(e.type,!0);case 31:return Me("Activity");default:return""}}function de(e){try{var n="",i=null;do n+=zt(e,i),i=e,e=e.return;while(e);return n}catch(s){return`
Error generating stack: `+s.message+`
`+s.stack}}var Re=Object.prototype.hasOwnProperty,rt=t.unstable_scheduleCallback,kt=t.unstable_cancelCallback,Wn=t.unstable_shouldYield,Fa=t.unstable_requestPaint,Tt=t.unstable_now,$a=t.unstable_getCurrentPriorityLevel,Z=t.unstable_ImmediatePriority,me=t.unstable_UserBlockingPriority,Ce=t.unstable_NormalPriority,Ge=t.unstable_LowPriority,tt=t.unstable_IdlePriority,sn=t.log,Vn=t.unstable_setDisableYieldValue,Kt=null,Mt=null;function en(e){if(typeof sn=="function"&&Vn(e),Mt&&typeof Mt.setStrictMode=="function")try{Mt.setStrictMode(Kt,e)}catch{}}var st=Math.clz32?Math.clz32:os,ei=Math.log,on=Math.LN2;function os(e){return e>>>=0,e===0?32:31-(ei(e)/on|0)|0}var ma=256,qa=262144,ha=4194304;function hn(e){var n=e&42;if(n!==0)return n;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return e&261888;case 262144:case 524288:case 1048576:case 2097152:return e&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function D(e,n,i){var s=e.pendingLanes;if(s===0)return 0;var f=0,m=e.suspendedLanes,y=e.pingedLanes;e=e.warmLanes;var E=s&134217727;return E!==0?(s=E&~m,s!==0?f=hn(s):(y&=E,y!==0?f=hn(y):i||(i=E&~e,i!==0&&(f=hn(i))))):(E=s&~m,E!==0?f=hn(E):y!==0?f=hn(y):i||(i=s&~e,i!==0&&(f=hn(i)))),f===0?0:n!==0&&n!==f&&(n&m)===0&&(m=f&-f,i=n&-n,m>=i||m===32&&(i&4194048)!==0)?n:f}function J(e,n){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&n)===0}function be(e,n){switch(e){case 1:case 2:case 4:case 8:case 64:return n+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return n+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function je(){var e=ha;return ha<<=1,(ha&62914560)===0&&(ha=4194304),e}function vt(e){for(var n=[],i=0;31>i;i++)n.push(e);return n}function gt(e,n){e.pendingLanes|=n,n!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function Ee(e,n,i,s,f,m){var y=e.pendingLanes;e.pendingLanes=i,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=i,e.entangledLanes&=i,e.errorRecoveryDisabledLanes&=i,e.shellSuspendCounter=0;var E=e.entanglements,z=e.expirationTimes,G=e.hiddenUpdates;for(i=y&~i;0<i;){var Q=31-st(i),te=1<<Q;E[Q]=0,z[Q]=-1;var P=G[Q];if(P!==null)for(G[Q]=null,Q=0;Q<P.length;Q++){var V=P[Q];V!==null&&(V.lane&=-536870913)}i&=~te}s!==0&&ye(e,s,0),m!==0&&f===0&&e.tag!==0&&(e.suspendedLanes|=m&~(y&~n))}function ye(e,n,i){e.pendingLanes|=n,e.suspendedLanes&=~n;var s=31-st(n);e.entangledLanes|=n,e.entanglements[s]=e.entanglements[s]|1073741824|i&261930}function De(e,n){var i=e.entangledLanes|=n;for(e=e.entanglements;i;){var s=31-st(i),f=1<<s;f&n|e[s]&n&&(e[s]|=n),i&=~f}}function Rt(e,n){var i=n&-n;return i=(i&42)!==0?1:Nt(i),(i&(e.suspendedLanes|n))!==0?0:i}function Nt(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function di(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function Ga(){var e=K.p;return e!==0?e:(e=window.event,e===void 0?32:ag(e.type))}function Pa(e,n){var i=K.p;try{return K.p=e,n()}finally{K.p=i}}var ti=Math.random().toString(36).slice(2),Dt="__reactFiber$"+ti,tn="__reactProps$"+ti,ji="__reactContainer$"+ti,$l="__reactEvents$"+ti,cs="__reactListeners$"+ti,Ya="__reactHandles$"+ti,us="__reactResources$"+ti,pa="__reactMarker$"+ti;function ql(e){delete e[Dt],delete e[tn],delete e[$l],delete e[cs],delete e[Ya]}function cn(e){var n=e[Dt];if(n)return n;for(var i=e.parentNode;i;){if(n=i[ji]||i[Dt]){if(i=n.alternate,n.child!==null||i!==null&&i.child!==null)for(e=$p(e);e!==null;){if(i=e[Dt])return i;e=$p(e)}return n}e=i,i=e.parentNode}return null}function mi(e){if(e=e[Dt]||e[ji]){var n=e.tag;if(n===5||n===6||n===13||n===31||n===26||n===27||n===3)return e}return null}function Bi(e){var n=e.tag;if(n===5||n===26||n===27||n===6)return e.stateNode;throw Error(r(33))}function Ii(e){var n=e[us];return n||(n=e[us]={hoistableStyles:new Map,hoistableScripts:new Map}),n}function It(e){e[pa]=!0}var fs=new Set,ga={};function hi(e,n){ue(e,n),ue(e+"Capture",n)}function ue(e,n){for(ga[e]=n,e=0;e<n.length;e++)fs.add(n[e])}var ke=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Pe={},ot={};function Lt(e){return Re.call(ot,e)?!0:Re.call(Pe,e)?!1:ke.test(e)?ot[e]=!0:(Pe[e]=!0,!1)}function nn(e,n,i){if(Lt(n))if(i===null)e.removeAttribute(n);else{switch(typeof i){case"undefined":case"function":case"symbol":e.removeAttribute(n);return;case"boolean":var s=n.toLowerCase().slice(0,5);if(s!=="data-"&&s!=="aria-"){e.removeAttribute(n);return}}e.setAttribute(n,""+i)}}function wn(e,n,i){if(i===null)e.removeAttribute(n);else{switch(typeof i){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(n);return}e.setAttribute(n,""+i)}}function pn(e,n,i,s){if(s===null)e.removeAttribute(i);else{switch(typeof s){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(i);return}e.setAttributeNS(n,i,""+s)}}function yt(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function kn(e){var n=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(n==="checkbox"||n==="radio")}function ds(e,n,i){var s=Object.getOwnPropertyDescriptor(e.constructor.prototype,n);if(!e.hasOwnProperty(n)&&typeof s<"u"&&typeof s.get=="function"&&typeof s.set=="function"){var f=s.get,m=s.set;return Object.defineProperty(e,n,{configurable:!0,get:function(){return f.call(this)},set:function(y){i=""+y,m.call(this,y)}}),Object.defineProperty(e,n,{enumerable:s.enumerable}),{getValue:function(){return i},setValue:function(y){i=""+y},stopTracking:function(){e._valueTracker=null,delete e[n]}}}}function Va(e){if(!e._valueTracker){var n=kn(e)?"checked":"value";e._valueTracker=ds(e,n,""+e[n])}}function Gl(e){if(!e)return!1;var n=e._valueTracker;if(!n)return!0;var i=n.getValue(),s="";return e&&(s=kn(e)?e.checked?"true":"false":e.value),e=s,e!==i?(n.setValue(e),!0):!1}function Ka(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var ic=/[\n"\\]/g;function gn(e){return e.replace(ic,function(n){return"\\"+n.charCodeAt(0).toString(16)+" "})}function Pl(e,n,i,s,f,m,y,E){e.name="",y!=null&&typeof y!="function"&&typeof y!="symbol"&&typeof y!="boolean"?e.type=y:e.removeAttribute("type"),n!=null?y==="number"?(n===0&&e.value===""||e.value!=n)&&(e.value=""+yt(n)):e.value!==""+yt(n)&&(e.value=""+yt(n)):y!=="submit"&&y!=="reset"||e.removeAttribute("value"),n!=null?Xa(e,y,yt(n)):i!=null?Xa(e,y,yt(i)):s!=null&&e.removeAttribute("value"),f==null&&m!=null&&(e.defaultChecked=!!m),f!=null&&(e.checked=f&&typeof f!="function"&&typeof f!="symbol"),E!=null&&typeof E!="function"&&typeof E!="symbol"&&typeof E!="boolean"?e.name=""+yt(E):e.removeAttribute("name")}function ba(e,n,i,s,f,m,y,E){if(m!=null&&typeof m!="function"&&typeof m!="symbol"&&typeof m!="boolean"&&(e.type=m),n!=null||i!=null){if(!(m!=="submit"&&m!=="reset"||n!=null)){Va(e);return}i=i!=null?""+yt(i):"",n=n!=null?""+yt(n):i,E||n===e.value||(e.value=n),e.defaultValue=n}s=s??f,s=typeof s!="function"&&typeof s!="symbol"&&!!s,e.checked=E?e.checked:!!s,e.defaultChecked=!!s,y!=null&&typeof y!="function"&&typeof y!="symbol"&&typeof y!="boolean"&&(e.name=y),Va(e)}function Xa(e,n,i){n==="number"&&Ka(e.ownerDocument)===e||e.defaultValue===""+i||(e.defaultValue=""+i)}function Xt(e,n,i,s){if(e=e.options,n){n={};for(var f=0;f<i.length;f++)n["$"+i[f]]=!0;for(i=0;i<e.length;i++)f=n.hasOwnProperty("$"+e[i].value),e[i].selected!==f&&(e[i].selected=f),f&&s&&(e[i].defaultSelected=!0)}else{for(i=""+yt(i),n=null,f=0;f<e.length;f++){if(e[f].value===i){e[f].selected=!0,s&&(e[f].defaultSelected=!0);return}n!==null||e[f].disabled||(n=e[f])}n!==null&&(n.selected=!0)}}function ms(e,n,i){if(n!=null&&(n=""+yt(n),n!==e.value&&(e.value=n),i==null)){e.defaultValue!==n&&(e.defaultValue=n);return}e.defaultValue=i!=null?""+yt(i):""}function Za(e,n,i,s){if(n==null){if(s!=null){if(i!=null)throw Error(r(92));if(H(s)){if(1<s.length)throw Error(r(93));s=s[0]}i=s}i==null&&(i=""),n=i}i=yt(n),e.defaultValue=i,s=e.textContent,s===i&&s!==""&&s!==null&&(e.value=s),Va(e)}function ze(e,n){if(n){var i=e.firstChild;if(i&&i===e.lastChild&&i.nodeType===3){i.nodeValue=n;return}}e.textContent=n}var hs=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Ut(e,n,i){var s=n.indexOf("--")===0;i==null||typeof i=="boolean"||i===""?s?e.setProperty(n,""):n==="float"?e.cssFloat="":e[n]="":s?e.setProperty(n,i):typeof i!="number"||i===0||hs.has(n)?n==="float"?e.cssFloat=i:e[n]=(""+i).trim():e[n]=i+"px"}function ct(e,n,i){if(n!=null&&typeof n!="object")throw Error(r(62));if(e=e.style,i!=null){for(var s in i)!i.hasOwnProperty(s)||n!=null&&n.hasOwnProperty(s)||(s.indexOf("--")===0?e.setProperty(s,""):s==="float"?e.cssFloat="":e[s]="");for(var f in n)s=n[f],n.hasOwnProperty(f)&&i[f]!==s&&Ut(e,f,s)}else for(var m in n)n.hasOwnProperty(m)&&Ut(e,m,n[m])}function Ui(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var pi=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Yl=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Hi(e){return Yl.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}function ge(){}var Se=null;function Ue(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var Xe=null,At=null;function Bn(e){var n=mi(e);if(n&&(e=n.stateNode)){var i=e[tn]||null;e:switch(e=n.stateNode,n.type){case"input":if(Pl(e,i.value,i.defaultValue,i.defaultValue,i.checked,i.defaultChecked,i.type,i.name),n=i.name,i.type==="radio"&&n!=null){for(i=e;i.parentNode;)i=i.parentNode;for(i=i.querySelectorAll('input[name="'+gn(""+n)+'"][type="radio"]'),n=0;n<i.length;n++){var s=i[n];if(s!==e&&s.form===e.form){var f=s[tn]||null;if(!f)throw Error(r(90));Pl(s,f.value,f.defaultValue,f.defaultValue,f.checked,f.defaultChecked,f.type,f.name)}}for(n=0;n<i.length;n++)s=i[n],s.form===e.form&&Gl(s)}break e;case"textarea":ms(e,i.value,i.defaultValue);break e;case"select":n=i.value,n!=null&&Xt(e,!!i.multiple,n,!1)}}}var Vl=!1;function ps(e,n,i){if(Vl)return e(n,i);Vl=!0;try{var s=e(n);return s}finally{if(Vl=!1,(Xe!==null||At!==null)&&(no(),Xe&&(n=Xe,e=At,At=Xe=null,Bn(n),e)))for(n=0;n<e.length;n++)Bn(e[n])}}function Kl(e,n){var i=e.stateNode;if(i===null)return null;var s=i[tn]||null;if(s===null)return null;i=s[n];e:switch(n){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(s=!s.disabled)||(e=e.type,s=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!s;break e;default:e=!1}if(e)return null;if(i&&typeof i!="function")throw Error(r(231,n,typeof i));return i}var gi=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),ac=!1;if(gi)try{var Xl={};Object.defineProperty(Xl,"passive",{get:function(){ac=!0}}),window.addEventListener("test",Xl,Xl),window.removeEventListener("test",Xl,Xl)}catch{ac=!1}var Fi=null,lc=null,gs=null;function Ld(){if(gs)return gs;var e,n=lc,i=n.length,s,f="value"in Fi?Fi.value:Fi.textContent,m=f.length;for(e=0;e<i&&n[e]===f[e];e++);var y=i-e;for(s=1;s<=y&&n[i-s]===f[m-s];s++);return gs=f.slice(e,1<s?1-s:void 0)}function bs(e){var n=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&n===13&&(e=13)):e=n,e===10&&(e=13),32<=e||e===13?e:0}function xs(){return!0}function jd(){return!1}function bn(e){function n(i,s,f,m,y){this._reactName=i,this._targetInst=f,this.type=s,this.nativeEvent=m,this.target=y,this.currentTarget=null;for(var E in e)e.hasOwnProperty(E)&&(i=e[E],this[E]=i?i(m):m[E]);return this.isDefaultPrevented=(m.defaultPrevented!=null?m.defaultPrevented:m.returnValue===!1)?xs:jd,this.isPropagationStopped=jd,this}return x(n.prototype,{preventDefault:function(){this.defaultPrevented=!0;var i=this.nativeEvent;i&&(i.preventDefault?i.preventDefault():typeof i.returnValue!="unknown"&&(i.returnValue=!1),this.isDefaultPrevented=xs)},stopPropagation:function(){var i=this.nativeEvent;i&&(i.stopPropagation?i.stopPropagation():typeof i.cancelBubble!="unknown"&&(i.cancelBubble=!0),this.isPropagationStopped=xs)},persist:function(){},isPersistent:xs}),n}var xa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},ys=bn(xa),Zl=x({},xa,{view:0,detail:0}),Bx=bn(Zl),rc,sc,Ql,_s=x({},Zl,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:cc,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==Ql&&(Ql&&e.type==="mousemove"?(rc=e.screenX-Ql.screenX,sc=e.screenY-Ql.screenY):sc=rc=0,Ql=e),rc)},movementY:function(e){return"movementY"in e?e.movementY:sc}}),Bd=bn(_s),Ix=x({},_s,{dataTransfer:0}),Ux=bn(Ix),Hx=x({},Zl,{relatedTarget:0}),oc=bn(Hx),Fx=x({},xa,{animationName:0,elapsedTime:0,pseudoElement:0}),$x=bn(Fx),qx=x({},xa,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),Gx=bn(qx),Px=x({},xa,{data:0}),Id=bn(Px),Yx={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Vx={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Kx={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Xx(e){var n=this.nativeEvent;return n.getModifierState?n.getModifierState(e):(e=Kx[e])?!!n[e]:!1}function cc(){return Xx}var Zx=x({},Zl,{key:function(e){if(e.key){var n=Yx[e.key]||e.key;if(n!=="Unidentified")return n}return e.type==="keypress"?(e=bs(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?Vx[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:cc,charCode:function(e){return e.type==="keypress"?bs(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?bs(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),Qx=bn(Zx),Jx=x({},_s,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Ud=bn(Jx),Wx=x({},Zl,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:cc}),ey=bn(Wx),ty=x({},xa,{propertyName:0,elapsedTime:0,pseudoElement:0}),ny=bn(ty),iy=x({},_s,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),ay=bn(iy),ly=x({},xa,{newState:0,oldState:0}),ry=bn(ly),sy=[9,13,27,32],uc=gi&&"CompositionEvent"in window,Jl=null;gi&&"documentMode"in document&&(Jl=document.documentMode);var oy=gi&&"TextEvent"in window&&!Jl,Hd=gi&&(!uc||Jl&&8<Jl&&11>=Jl),Fd=" ",$d=!1;function qd(e,n){switch(e){case"keyup":return sy.indexOf(n.keyCode)!==-1;case"keydown":return n.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Gd(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var Qa=!1;function cy(e,n){switch(e){case"compositionend":return Gd(n);case"keypress":return n.which!==32?null:($d=!0,Fd);case"textInput":return e=n.data,e===Fd&&$d?null:e;default:return null}}function uy(e,n){if(Qa)return e==="compositionend"||!uc&&qd(e,n)?(e=Ld(),gs=lc=Fi=null,Qa=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(n.ctrlKey||n.altKey||n.metaKey)||n.ctrlKey&&n.altKey){if(n.char&&1<n.char.length)return n.char;if(n.which)return String.fromCharCode(n.which)}return null;case"compositionend":return Hd&&n.locale!=="ko"?null:n.data;default:return null}}var fy={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Pd(e){var n=e&&e.nodeName&&e.nodeName.toLowerCase();return n==="input"?!!fy[e.type]:n==="textarea"}function Yd(e,n,i,s){Xe?At?At.push(s):At=[s]:Xe=s,n=co(n,"onChange"),0<n.length&&(i=new ys("onChange","change",null,i,s),e.push({event:i,listeners:n}))}var Wl=null,er=null;function dy(e){Ap(e,0)}function vs(e){var n=Bi(e);if(Gl(n))return e}function Vd(e,n){if(e==="change")return n}var Kd=!1;if(gi){var fc;if(gi){var dc="oninput"in document;if(!dc){var Xd=document.createElement("div");Xd.setAttribute("oninput","return;"),dc=typeof Xd.oninput=="function"}fc=dc}else fc=!1;Kd=fc&&(!document.documentMode||9<document.documentMode)}function Zd(){Wl&&(Wl.detachEvent("onpropertychange",Qd),er=Wl=null)}function Qd(e){if(e.propertyName==="value"&&vs(er)){var n=[];Yd(n,er,e,Ue(e)),ps(dy,n)}}function my(e,n,i){e==="focusin"?(Zd(),Wl=n,er=i,Wl.attachEvent("onpropertychange",Qd)):e==="focusout"&&Zd()}function hy(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return vs(er)}function py(e,n){if(e==="click")return vs(n)}function gy(e,n){if(e==="input"||e==="change")return vs(n)}function by(e,n){return e===n&&(e!==0||1/e===1/n)||e!==e&&n!==n}var Tn=typeof Object.is=="function"?Object.is:by;function tr(e,n){if(Tn(e,n))return!0;if(typeof e!="object"||e===null||typeof n!="object"||n===null)return!1;var i=Object.keys(e),s=Object.keys(n);if(i.length!==s.length)return!1;for(s=0;s<i.length;s++){var f=i[s];if(!Re.call(n,f)||!Tn(e[f],n[f]))return!1}return!0}function Jd(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function Wd(e,n){var i=Jd(e);e=0;for(var s;i;){if(i.nodeType===3){if(s=e+i.textContent.length,e<=n&&s>=n)return{node:i,offset:n-e};e=s}e:{for(;i;){if(i.nextSibling){i=i.nextSibling;break e}i=i.parentNode}i=void 0}i=Jd(i)}}function em(e,n){return e&&n?e===n?!0:e&&e.nodeType===3?!1:n&&n.nodeType===3?em(e,n.parentNode):"contains"in e?e.contains(n):e.compareDocumentPosition?!!(e.compareDocumentPosition(n)&16):!1:!1}function tm(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var n=Ka(e.document);n instanceof e.HTMLIFrameElement;){try{var i=typeof n.contentWindow.location.href=="string"}catch{i=!1}if(i)e=n.contentWindow;else break;n=Ka(e.document)}return n}function mc(e){var n=e&&e.nodeName&&e.nodeName.toLowerCase();return n&&(n==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||n==="textarea"||e.contentEditable==="true")}var xy=gi&&"documentMode"in document&&11>=document.documentMode,Ja=null,hc=null,nr=null,pc=!1;function nm(e,n,i){var s=i.window===i?i.document:i.nodeType===9?i:i.ownerDocument;pc||Ja==null||Ja!==Ka(s)||(s=Ja,"selectionStart"in s&&mc(s)?s={start:s.selectionStart,end:s.selectionEnd}:(s=(s.ownerDocument&&s.ownerDocument.defaultView||window).getSelection(),s={anchorNode:s.anchorNode,anchorOffset:s.anchorOffset,focusNode:s.focusNode,focusOffset:s.focusOffset}),nr&&tr(nr,s)||(nr=s,s=co(hc,"onSelect"),0<s.length&&(n=new ys("onSelect","select",null,n,i),e.push({event:n,listeners:s}),n.target=Ja)))}function ya(e,n){var i={};return i[e.toLowerCase()]=n.toLowerCase(),i["Webkit"+e]="webkit"+n,i["Moz"+e]="moz"+n,i}var Wa={animationend:ya("Animation","AnimationEnd"),animationiteration:ya("Animation","AnimationIteration"),animationstart:ya("Animation","AnimationStart"),transitionrun:ya("Transition","TransitionRun"),transitionstart:ya("Transition","TransitionStart"),transitioncancel:ya("Transition","TransitionCancel"),transitionend:ya("Transition","TransitionEnd")},gc={},im={};gi&&(im=document.createElement("div").style,"AnimationEvent"in window||(delete Wa.animationend.animation,delete Wa.animationiteration.animation,delete Wa.animationstart.animation),"TransitionEvent"in window||delete Wa.transitionend.transition);function _a(e){if(gc[e])return gc[e];if(!Wa[e])return e;var n=Wa[e],i;for(i in n)if(n.hasOwnProperty(i)&&i in im)return gc[e]=n[i];return e}var am=_a("animationend"),lm=_a("animationiteration"),rm=_a("animationstart"),yy=_a("transitionrun"),_y=_a("transitionstart"),vy=_a("transitioncancel"),sm=_a("transitionend"),om=new Map,bc="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");bc.push("scrollEnd");function Kn(e,n){om.set(e,n),hi(n,[e])}var Es=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var n=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(n))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}console.error(e)},In=[],el=0,xc=0;function Ss(){for(var e=el,n=xc=el=0;n<e;){var i=In[n];In[n++]=null;var s=In[n];In[n++]=null;var f=In[n];In[n++]=null;var m=In[n];if(In[n++]=null,s!==null&&f!==null){var y=s.pending;y===null?f.next=f:(f.next=y.next,y.next=f),s.pending=f}m!==0&&cm(i,f,m)}}function Ns(e,n,i,s){In[el++]=e,In[el++]=n,In[el++]=i,In[el++]=s,xc|=s,e.lanes|=s,e=e.alternate,e!==null&&(e.lanes|=s)}function yc(e,n,i,s){return Ns(e,n,i,s),ws(e)}function va(e,n){return Ns(e,null,null,n),ws(e)}function cm(e,n,i){e.lanes|=i;var s=e.alternate;s!==null&&(s.lanes|=i);for(var f=!1,m=e.return;m!==null;)m.childLanes|=i,s=m.alternate,s!==null&&(s.childLanes|=i),m.tag===22&&(e=m.stateNode,e===null||e._visibility&1||(f=!0)),e=m,m=m.return;return e.tag===3?(m=e.stateNode,f&&n!==null&&(f=31-st(i),e=m.hiddenUpdates,s=e[f],s===null?e[f]=[n]:s.push(n),n.lane=i|536870912),m):null}function ws(e){if(50<Nr)throw Nr=0,Au=null,Error(r(185));for(var n=e.return;n!==null;)e=n,n=e.return;return e.tag===3?e.stateNode:null}var tl={};function Ey(e,n,i,s){this.tag=e,this.key=i,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=n,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=s,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function An(e,n,i,s){return new Ey(e,n,i,s)}function _c(e){return e=e.prototype,!(!e||!e.isReactComponent)}function bi(e,n){var i=e.alternate;return i===null?(i=An(e.tag,n,e.key,e.mode),i.elementType=e.elementType,i.type=e.type,i.stateNode=e.stateNode,i.alternate=e,e.alternate=i):(i.pendingProps=n,i.type=e.type,i.flags=0,i.subtreeFlags=0,i.deletions=null),i.flags=e.flags&65011712,i.childLanes=e.childLanes,i.lanes=e.lanes,i.child=e.child,i.memoizedProps=e.memoizedProps,i.memoizedState=e.memoizedState,i.updateQueue=e.updateQueue,n=e.dependencies,i.dependencies=n===null?null:{lanes:n.lanes,firstContext:n.firstContext},i.sibling=e.sibling,i.index=e.index,i.ref=e.ref,i.refCleanup=e.refCleanup,i}function um(e,n){e.flags&=65011714;var i=e.alternate;return i===null?(e.childLanes=0,e.lanes=n,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=i.childLanes,e.lanes=i.lanes,e.child=i.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=i.memoizedProps,e.memoizedState=i.memoizedState,e.updateQueue=i.updateQueue,e.type=i.type,n=i.dependencies,e.dependencies=n===null?null:{lanes:n.lanes,firstContext:n.firstContext}),e}function ks(e,n,i,s,f,m){var y=0;if(s=e,typeof e=="function")_c(e)&&(y=1);else if(typeof e=="string")y=T1(e,i,ce.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case he:return e=An(31,i,n,f),e.elementType=he,e.lanes=m,e;case T:return Ea(i.children,f,m,n);case A:y=8,f|=24;break;case w:return e=An(12,i,n,f|2),e.elementType=w,e.lanes=m,e;case Y:return e=An(13,i,n,f),e.elementType=Y,e.lanes=m,e;case L:return e=An(19,i,n,f),e.elementType=L,e.lanes=m,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case R:y=10;break e;case O:y=9;break e;case q:y=11;break e;case X:y=14;break e;case oe:y=16,s=null;break e}y=29,i=Error(r(130,e===null?"null":typeof e,"")),s=null}return n=An(y,i,n,f),n.elementType=e,n.type=s,n.lanes=m,n}function Ea(e,n,i,s){return e=An(7,e,s,n),e.lanes=i,e}function vc(e,n,i){return e=An(6,e,null,n),e.lanes=i,e}function fm(e){var n=An(18,null,null,0);return n.stateNode=e,n}function Ec(e,n,i){return n=An(4,e.children!==null?e.children:[],e.key,n),n.lanes=i,n.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},n}var dm=new WeakMap;function Un(e,n){if(typeof e=="object"&&e!==null){var i=dm.get(e);return i!==void 0?i:(n={value:e,source:n,stack:de(n)},dm.set(e,n),n)}return{value:e,source:n,stack:de(n)}}var nl=[],il=0,Ts=null,ir=0,Hn=[],Fn=0,$i=null,ni=1,ii="";function xi(e,n){nl[il++]=ir,nl[il++]=Ts,Ts=e,ir=n}function mm(e,n,i){Hn[Fn++]=ni,Hn[Fn++]=ii,Hn[Fn++]=$i,$i=e;var s=ni;e=ii;var f=32-st(s)-1;s&=~(1<<f),i+=1;var m=32-st(n)+f;if(30<m){var y=f-f%5;m=(s&(1<<y)-1).toString(32),s>>=y,f-=y,ni=1<<32-st(n)+f|i<<f|s,ii=m+e}else ni=1<<m|i<<f|s,ii=e}function Sc(e){e.return!==null&&(xi(e,1),mm(e,1,0))}function Nc(e){for(;e===Ts;)Ts=nl[--il],nl[il]=null,ir=nl[--il],nl[il]=null;for(;e===$i;)$i=Hn[--Fn],Hn[Fn]=null,ii=Hn[--Fn],Hn[Fn]=null,ni=Hn[--Fn],Hn[Fn]=null}function hm(e,n){Hn[Fn++]=ni,Hn[Fn++]=ii,Hn[Fn++]=$i,ni=n.id,ii=n.overflow,$i=e}var Zt=null,Et=null,Je=!1,qi=null,$n=!1,wc=Error(r(519));function Gi(e){var n=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw ar(Un(n,e)),wc}function pm(e){var n=e.stateNode,i=e.type,s=e.memoizedProps;switch(n[Dt]=e,n[tn]=s,i){case"dialog":Ve("cancel",n),Ve("close",n);break;case"iframe":case"object":case"embed":Ve("load",n);break;case"video":case"audio":for(i=0;i<kr.length;i++)Ve(kr[i],n);break;case"source":Ve("error",n);break;case"img":case"image":case"link":Ve("error",n),Ve("load",n);break;case"details":Ve("toggle",n);break;case"input":Ve("invalid",n),ba(n,s.value,s.defaultValue,s.checked,s.defaultChecked,s.type,s.name,!0);break;case"select":Ve("invalid",n);break;case"textarea":Ve("invalid",n),Za(n,s.value,s.defaultValue,s.children)}i=s.children,typeof i!="string"&&typeof i!="number"&&typeof i!="bigint"||n.textContent===""+i||s.suppressHydrationWarning===!0||zp(n.textContent,i)?(s.popover!=null&&(Ve("beforetoggle",n),Ve("toggle",n)),s.onScroll!=null&&Ve("scroll",n),s.onScrollEnd!=null&&Ve("scrollend",n),s.onClick!=null&&(n.onclick=ge),n=!0):n=!1,n||Gi(e,!0)}function gm(e){for(Zt=e.return;Zt;)switch(Zt.tag){case 5:case 31:case 13:$n=!1;return;case 27:case 3:$n=!0;return;default:Zt=Zt.return}}function al(e){if(e!==Zt)return!1;if(!Je)return gm(e),Je=!0,!1;var n=e.tag,i;if((i=n!==3&&n!==27)&&((i=n===5)&&(i=e.type,i=!(i!=="form"&&i!=="button")||qu(e.type,e.memoizedProps)),i=!i),i&&Et&&Gi(e),gm(e),n===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(317));Et=Fp(e)}else if(n===31){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(317));Et=Fp(e)}else n===27?(n=Et,aa(e.type)?(e=Ku,Ku=null,Et=e):Et=n):Et=Zt?Gn(e.stateNode.nextSibling):null;return!0}function Sa(){Et=Zt=null,Je=!1}function kc(){var e=qi;return e!==null&&(vn===null?vn=e:vn.push.apply(vn,e),qi=null),e}function ar(e){qi===null?qi=[e]:qi.push(e)}var Tc=M(null),Na=null,yi=null;function Pi(e,n,i){N(Tc,n._currentValue),n._currentValue=i}function _i(e){e._currentValue=Tc.current,B(Tc)}function Ac(e,n,i){for(;e!==null;){var s=e.alternate;if((e.childLanes&n)!==n?(e.childLanes|=n,s!==null&&(s.childLanes|=n)):s!==null&&(s.childLanes&n)!==n&&(s.childLanes|=n),e===i)break;e=e.return}}function Mc(e,n,i,s){var f=e.child;for(f!==null&&(f.return=e);f!==null;){var m=f.dependencies;if(m!==null){var y=f.child;m=m.firstContext;e:for(;m!==null;){var E=m;m=f;for(var z=0;z<n.length;z++)if(E.context===n[z]){m.lanes|=i,E=m.alternate,E!==null&&(E.lanes|=i),Ac(m.return,i,e),s||(y=null);break e}m=E.next}}else if(f.tag===18){if(y=f.return,y===null)throw Error(r(341));y.lanes|=i,m=y.alternate,m!==null&&(m.lanes|=i),Ac(y,i,e),y=null}else y=f.child;if(y!==null)y.return=f;else for(y=f;y!==null;){if(y===e){y=null;break}if(f=y.sibling,f!==null){f.return=y.return,y=f;break}y=y.return}f=y}}function ll(e,n,i,s){e=null;for(var f=n,m=!1;f!==null;){if(!m){if((f.flags&524288)!==0)m=!0;else if((f.flags&262144)!==0)break}if(f.tag===10){var y=f.alternate;if(y===null)throw Error(r(387));if(y=y.memoizedProps,y!==null){var E=f.type;Tn(f.pendingProps.value,y.value)||(e!==null?e.push(E):e=[E])}}else if(f===Be.current){if(y=f.alternate,y===null)throw Error(r(387));y.memoizedState.memoizedState!==f.memoizedState.memoizedState&&(e!==null?e.push(Or):e=[Or])}f=f.return}e!==null&&Mc(n,e,i,s),n.flags|=262144}function As(e){for(e=e.firstContext;e!==null;){if(!Tn(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function wa(e){Na=e,yi=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function Qt(e){return bm(Na,e)}function Ms(e,n){return Na===null&&wa(e),bm(e,n)}function bm(e,n){var i=n._currentValue;if(n={context:n,memoizedValue:i,next:null},yi===null){if(e===null)throw Error(r(308));yi=n,e.dependencies={lanes:0,firstContext:n},e.flags|=524288}else yi=yi.next=n;return i}var Sy=typeof AbortController<"u"?AbortController:function(){var e=[],n=this.signal={aborted:!1,addEventListener:function(i,s){e.push(s)}};this.abort=function(){n.aborted=!0,e.forEach(function(i){return i()})}},Ny=t.unstable_scheduleCallback,wy=t.unstable_NormalPriority,Ht={$$typeof:R,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Cc(){return{controller:new Sy,data:new Map,refCount:0}}function lr(e){e.refCount--,e.refCount===0&&Ny(wy,function(){e.controller.abort()})}var rr=null,Oc=0,rl=0,sl=null;function ky(e,n){if(rr===null){var i=rr=[];Oc=0,rl=Du(),sl={status:"pending",value:void 0,then:function(s){i.push(s)}}}return Oc++,n.then(xm,xm),n}function xm(){if(--Oc===0&&rr!==null){sl!==null&&(sl.status="fulfilled");var e=rr;rr=null,rl=0,sl=null;for(var n=0;n<e.length;n++)(0,e[n])()}}function Ty(e,n){var i=[],s={status:"pending",value:null,reason:null,then:function(f){i.push(f)}};return e.then(function(){s.status="fulfilled",s.value=n;for(var f=0;f<i.length;f++)(0,i[f])(n)},function(f){for(s.status="rejected",s.reason=f,f=0;f<i.length;f++)(0,i[f])(void 0)}),s}var ym=C.S;C.S=function(e,n){np=Tt(),typeof n=="object"&&n!==null&&typeof n.then=="function"&&ky(e,n),ym!==null&&ym(e,n)};var ka=M(null);function zc(){var e=ka.current;return e!==null?e:bt.pooledCache}function Cs(e,n){n===null?N(ka,ka.current):N(ka,n.pool)}function _m(){var e=zc();return e===null?null:{parent:Ht._currentValue,pool:e}}var ol=Error(r(460)),Rc=Error(r(474)),Os=Error(r(542)),zs={then:function(){}};function vm(e){return e=e.status,e==="fulfilled"||e==="rejected"}function Em(e,n,i){switch(i=e[i],i===void 0?e.push(n):i!==n&&(n.then(ge,ge),n=i),n.status){case"fulfilled":return n.value;case"rejected":throw e=n.reason,Nm(e),e;default:if(typeof n.status=="string")n.then(ge,ge);else{if(e=bt,e!==null&&100<e.shellSuspendCounter)throw Error(r(482));e=n,e.status="pending",e.then(function(s){if(n.status==="pending"){var f=n;f.status="fulfilled",f.value=s}},function(s){if(n.status==="pending"){var f=n;f.status="rejected",f.reason=s}})}switch(n.status){case"fulfilled":return n.value;case"rejected":throw e=n.reason,Nm(e),e}throw Aa=n,ol}}function Ta(e){try{var n=e._init;return n(e._payload)}catch(i){throw i!==null&&typeof i=="object"&&typeof i.then=="function"?(Aa=i,ol):i}}var Aa=null;function Sm(){if(Aa===null)throw Error(r(459));var e=Aa;return Aa=null,e}function Nm(e){if(e===ol||e===Os)throw Error(r(483))}var cl=null,sr=0;function Rs(e){var n=sr;return sr+=1,cl===null&&(cl=[]),Em(cl,e,n)}function or(e,n){n=n.props.ref,e.ref=n!==void 0?n:null}function Ds(e,n){throw n.$$typeof===_?Error(r(525)):(e=Object.prototype.toString.call(n),Error(r(31,e==="[object Object]"?"object with keys {"+Object.keys(n).join(", ")+"}":e)))}function wm(e){function n(I,j){if(e){var $=I.deletions;$===null?(I.deletions=[j],I.flags|=16):$.push(j)}}function i(I,j){if(!e)return null;for(;j!==null;)n(I,j),j=j.sibling;return null}function s(I){for(var j=new Map;I!==null;)I.key!==null?j.set(I.key,I):j.set(I.index,I),I=I.sibling;return j}function f(I,j){return I=bi(I,j),I.index=0,I.sibling=null,I}function m(I,j,$){return I.index=$,e?($=I.alternate,$!==null?($=$.index,$<j?(I.flags|=67108866,j):$):(I.flags|=67108866,j)):(I.flags|=1048576,j)}function y(I){return e&&I.alternate===null&&(I.flags|=67108866),I}function E(I,j,$,ee){return j===null||j.tag!==6?(j=vc($,I.mode,ee),j.return=I,j):(j=f(j,$),j.return=I,j)}function z(I,j,$,ee){var Te=$.type;return Te===T?Q(I,j,$.props.children,ee,$.key):j!==null&&(j.elementType===Te||typeof Te=="object"&&Te!==null&&Te.$$typeof===oe&&Ta(Te)===j.type)?(j=f(j,$.props),or(j,$),j.return=I,j):(j=ks($.type,$.key,$.props,null,I.mode,ee),or(j,$),j.return=I,j)}function G(I,j,$,ee){return j===null||j.tag!==4||j.stateNode.containerInfo!==$.containerInfo||j.stateNode.implementation!==$.implementation?(j=Ec($,I.mode,ee),j.return=I,j):(j=f(j,$.children||[]),j.return=I,j)}function Q(I,j,$,ee,Te){return j===null||j.tag!==7?(j=Ea($,I.mode,ee,Te),j.return=I,j):(j=f(j,$),j.return=I,j)}function te(I,j,$){if(typeof j=="string"&&j!==""||typeof j=="number"||typeof j=="bigint")return j=vc(""+j,I.mode,$),j.return=I,j;if(typeof j=="object"&&j!==null){switch(j.$$typeof){case v:return $=ks(j.type,j.key,j.props,null,I.mode,$),or($,j),$.return=I,$;case S:return j=Ec(j,I.mode,$),j.return=I,j;case oe:return j=Ta(j),te(I,j,$)}if(H(j)||ae(j))return j=Ea(j,I.mode,$,null),j.return=I,j;if(typeof j.then=="function")return te(I,Rs(j),$);if(j.$$typeof===R)return te(I,Ms(I,j),$);Ds(I,j)}return null}function P(I,j,$,ee){var Te=j!==null?j.key:null;if(typeof $=="string"&&$!==""||typeof $=="number"||typeof $=="bigint")return Te!==null?null:E(I,j,""+$,ee);if(typeof $=="object"&&$!==null){switch($.$$typeof){case v:return $.key===Te?z(I,j,$,ee):null;case S:return $.key===Te?G(I,j,$,ee):null;case oe:return $=Ta($),P(I,j,$,ee)}if(H($)||ae($))return Te!==null?null:Q(I,j,$,ee,null);if(typeof $.then=="function")return P(I,j,Rs($),ee);if($.$$typeof===R)return P(I,j,Ms(I,$),ee);Ds(I,$)}return null}function V(I,j,$,ee,Te){if(typeof ee=="string"&&ee!==""||typeof ee=="number"||typeof ee=="bigint")return I=I.get($)||null,E(j,I,""+ee,Te);if(typeof ee=="object"&&ee!==null){switch(ee.$$typeof){case v:return I=I.get(ee.key===null?$:ee.key)||null,z(j,I,ee,Te);case S:return I=I.get(ee.key===null?$:ee.key)||null,G(j,I,ee,Te);case oe:return ee=Ta(ee),V(I,j,$,ee,Te)}if(H(ee)||ae(ee))return I=I.get($)||null,Q(j,I,ee,Te,null);if(typeof ee.then=="function")return V(I,j,$,Rs(ee),Te);if(ee.$$typeof===R)return V(I,j,$,Ms(j,ee),Te);Ds(j,ee)}return null}function _e(I,j,$,ee){for(var Te=null,nt=null,Ne=j,Fe=j=0,Qe=null;Ne!==null&&Fe<$.length;Fe++){Ne.index>Fe?(Qe=Ne,Ne=null):Qe=Ne.sibling;var it=P(I,Ne,$[Fe],ee);if(it===null){Ne===null&&(Ne=Qe);break}e&&Ne&&it.alternate===null&&n(I,Ne),j=m(it,j,Fe),nt===null?Te=it:nt.sibling=it,nt=it,Ne=Qe}if(Fe===$.length)return i(I,Ne),Je&&xi(I,Fe),Te;if(Ne===null){for(;Fe<$.length;Fe++)Ne=te(I,$[Fe],ee),Ne!==null&&(j=m(Ne,j,Fe),nt===null?Te=Ne:nt.sibling=Ne,nt=Ne);return Je&&xi(I,Fe),Te}for(Ne=s(Ne);Fe<$.length;Fe++)Qe=V(Ne,I,Fe,$[Fe],ee),Qe!==null&&(e&&Qe.alternate!==null&&Ne.delete(Qe.key===null?Fe:Qe.key),j=m(Qe,j,Fe),nt===null?Te=Qe:nt.sibling=Qe,nt=Qe);return e&&Ne.forEach(function(ca){return n(I,ca)}),Je&&xi(I,Fe),Te}function Oe(I,j,$,ee){if($==null)throw Error(r(151));for(var Te=null,nt=null,Ne=j,Fe=j=0,Qe=null,it=$.next();Ne!==null&&!it.done;Fe++,it=$.next()){Ne.index>Fe?(Qe=Ne,Ne=null):Qe=Ne.sibling;var ca=P(I,Ne,it.value,ee);if(ca===null){Ne===null&&(Ne=Qe);break}e&&Ne&&ca.alternate===null&&n(I,Ne),j=m(ca,j,Fe),nt===null?Te=ca:nt.sibling=ca,nt=ca,Ne=Qe}if(it.done)return i(I,Ne),Je&&xi(I,Fe),Te;if(Ne===null){for(;!it.done;Fe++,it=$.next())it=te(I,it.value,ee),it!==null&&(j=m(it,j,Fe),nt===null?Te=it:nt.sibling=it,nt=it);return Je&&xi(I,Fe),Te}for(Ne=s(Ne);!it.done;Fe++,it=$.next())it=V(Ne,I,Fe,it.value,ee),it!==null&&(e&&it.alternate!==null&&Ne.delete(it.key===null?Fe:it.key),j=m(it,j,Fe),nt===null?Te=it:nt.sibling=it,nt=it);return e&&Ne.forEach(function(I1){return n(I,I1)}),Je&&xi(I,Fe),Te}function ht(I,j,$,ee){if(typeof $=="object"&&$!==null&&$.type===T&&$.key===null&&($=$.props.children),typeof $=="object"&&$!==null){switch($.$$typeof){case v:e:{for(var Te=$.key;j!==null;){if(j.key===Te){if(Te=$.type,Te===T){if(j.tag===7){i(I,j.sibling),ee=f(j,$.props.children),ee.return=I,I=ee;break e}}else if(j.elementType===Te||typeof Te=="object"&&Te!==null&&Te.$$typeof===oe&&Ta(Te)===j.type){i(I,j.sibling),ee=f(j,$.props),or(ee,$),ee.return=I,I=ee;break e}i(I,j);break}else n(I,j);j=j.sibling}$.type===T?(ee=Ea($.props.children,I.mode,ee,$.key),ee.return=I,I=ee):(ee=ks($.type,$.key,$.props,null,I.mode,ee),or(ee,$),ee.return=I,I=ee)}return y(I);case S:e:{for(Te=$.key;j!==null;){if(j.key===Te)if(j.tag===4&&j.stateNode.containerInfo===$.containerInfo&&j.stateNode.implementation===$.implementation){i(I,j.sibling),ee=f(j,$.children||[]),ee.return=I,I=ee;break e}else{i(I,j);break}else n(I,j);j=j.sibling}ee=Ec($,I.mode,ee),ee.return=I,I=ee}return y(I);case oe:return $=Ta($),ht(I,j,$,ee)}if(H($))return _e(I,j,$,ee);if(ae($)){if(Te=ae($),typeof Te!="function")throw Error(r(150));return $=Te.call($),Oe(I,j,$,ee)}if(typeof $.then=="function")return ht(I,j,Rs($),ee);if($.$$typeof===R)return ht(I,j,Ms(I,$),ee);Ds(I,$)}return typeof $=="string"&&$!==""||typeof $=="number"||typeof $=="bigint"?($=""+$,j!==null&&j.tag===6?(i(I,j.sibling),ee=f(j,$),ee.return=I,I=ee):(i(I,j),ee=vc($,I.mode,ee),ee.return=I,I=ee),y(I)):i(I,j)}return function(I,j,$,ee){try{sr=0;var Te=ht(I,j,$,ee);return cl=null,Te}catch(Ne){if(Ne===ol||Ne===Os)throw Ne;var nt=An(29,Ne,null,I.mode);return nt.lanes=ee,nt.return=I,nt}finally{}}}var Ma=wm(!0),km=wm(!1),Yi=!1;function Dc(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Lc(e,n){e=e.updateQueue,n.updateQueue===e&&(n.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function Vi(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function Ki(e,n,i){var s=e.updateQueue;if(s===null)return null;if(s=s.shared,(at&2)!==0){var f=s.pending;return f===null?n.next=n:(n.next=f.next,f.next=n),s.pending=n,n=ws(e),cm(e,null,i),n}return Ns(e,s,n,i),ws(e)}function cr(e,n,i){if(n=n.updateQueue,n!==null&&(n=n.shared,(i&4194048)!==0)){var s=n.lanes;s&=e.pendingLanes,i|=s,n.lanes=i,De(e,i)}}function jc(e,n){var i=e.updateQueue,s=e.alternate;if(s!==null&&(s=s.updateQueue,i===s)){var f=null,m=null;if(i=i.firstBaseUpdate,i!==null){do{var y={lane:i.lane,tag:i.tag,payload:i.payload,callback:null,next:null};m===null?f=m=y:m=m.next=y,i=i.next}while(i!==null);m===null?f=m=n:m=m.next=n}else f=m=n;i={baseState:s.baseState,firstBaseUpdate:f,lastBaseUpdate:m,shared:s.shared,callbacks:s.callbacks},e.updateQueue=i;return}e=i.lastBaseUpdate,e===null?i.firstBaseUpdate=n:e.next=n,i.lastBaseUpdate=n}var Bc=!1;function ur(){if(Bc){var e=sl;if(e!==null)throw e}}function fr(e,n,i,s){Bc=!1;var f=e.updateQueue;Yi=!1;var m=f.firstBaseUpdate,y=f.lastBaseUpdate,E=f.shared.pending;if(E!==null){f.shared.pending=null;var z=E,G=z.next;z.next=null,y===null?m=G:y.next=G,y=z;var Q=e.alternate;Q!==null&&(Q=Q.updateQueue,E=Q.lastBaseUpdate,E!==y&&(E===null?Q.firstBaseUpdate=G:E.next=G,Q.lastBaseUpdate=z))}if(m!==null){var te=f.baseState;y=0,Q=G=z=null,E=m;do{var P=E.lane&-536870913,V=P!==E.lane;if(V?(Ze&P)===P:(s&P)===P){P!==0&&P===rl&&(Bc=!0),Q!==null&&(Q=Q.next={lane:0,tag:E.tag,payload:E.payload,callback:null,next:null});e:{var _e=e,Oe=E;P=n;var ht=i;switch(Oe.tag){case 1:if(_e=Oe.payload,typeof _e=="function"){te=_e.call(ht,te,P);break e}te=_e;break e;case 3:_e.flags=_e.flags&-65537|128;case 0:if(_e=Oe.payload,P=typeof _e=="function"?_e.call(ht,te,P):_e,P==null)break e;te=x({},te,P);break e;case 2:Yi=!0}}P=E.callback,P!==null&&(e.flags|=64,V&&(e.flags|=8192),V=f.callbacks,V===null?f.callbacks=[P]:V.push(P))}else V={lane:P,tag:E.tag,payload:E.payload,callback:E.callback,next:null},Q===null?(G=Q=V,z=te):Q=Q.next=V,y|=P;if(E=E.next,E===null){if(E=f.shared.pending,E===null)break;V=E,E=V.next,V.next=null,f.lastBaseUpdate=V,f.shared.pending=null}}while(!0);Q===null&&(z=te),f.baseState=z,f.firstBaseUpdate=G,f.lastBaseUpdate=Q,m===null&&(f.shared.lanes=0),Wi|=y,e.lanes=y,e.memoizedState=te}}function Tm(e,n){if(typeof e!="function")throw Error(r(191,e));e.call(n)}function Am(e,n){var i=e.callbacks;if(i!==null)for(e.callbacks=null,e=0;e<i.length;e++)Tm(i[e],n)}var ul=M(null),Ls=M(0);function Mm(e,n){e=Mi,N(Ls,e),N(ul,n),Mi=e|n.baseLanes}function Ic(){N(Ls,Mi),N(ul,ul.current)}function Uc(){Mi=Ls.current,B(ul),B(Ls)}var Mn=M(null),qn=null;function Xi(e){var n=e.alternate;N(jt,jt.current&1),N(Mn,e),qn===null&&(n===null||ul.current!==null||n.memoizedState!==null)&&(qn=e)}function Hc(e){N(jt,jt.current),N(Mn,e),qn===null&&(qn=e)}function Cm(e){e.tag===22?(N(jt,jt.current),N(Mn,e),qn===null&&(qn=e)):Zi()}function Zi(){N(jt,jt.current),N(Mn,Mn.current)}function Cn(e){B(Mn),qn===e&&(qn=null),B(jt)}var jt=M(0);function js(e){for(var n=e;n!==null;){if(n.tag===13){var i=n.memoizedState;if(i!==null&&(i=i.dehydrated,i===null||Yu(i)||Vu(i)))return n}else if(n.tag===19&&(n.memoizedProps.revealOrder==="forwards"||n.memoizedProps.revealOrder==="backwards"||n.memoizedProps.revealOrder==="unstable_legacy-backwards"||n.memoizedProps.revealOrder==="together")){if((n.flags&128)!==0)return n}else if(n.child!==null){n.child.return=n,n=n.child;continue}if(n===e)break;for(;n.sibling===null;){if(n.return===null||n.return===e)return null;n=n.return}n.sibling.return=n.return,n=n.sibling}return null}var vi=0,He=null,dt=null,Ft=null,Bs=!1,fl=!1,Ca=!1,Is=0,dr=0,dl=null,Ay=0;function Ct(){throw Error(r(321))}function Fc(e,n){if(n===null)return!1;for(var i=0;i<n.length&&i<e.length;i++)if(!Tn(e[i],n[i]))return!1;return!0}function $c(e,n,i,s,f,m){return vi=m,He=n,n.memoizedState=null,n.updateQueue=null,n.lanes=0,C.H=e===null||e.memoizedState===null?mh:iu,Ca=!1,m=i(s,f),Ca=!1,fl&&(m=zm(n,i,s,f)),Om(e),m}function Om(e){C.H=pr;var n=dt!==null&&dt.next!==null;if(vi=0,Ft=dt=He=null,Bs=!1,dr=0,dl=null,n)throw Error(r(300));e===null||$t||(e=e.dependencies,e!==null&&As(e)&&($t=!0))}function zm(e,n,i,s){He=e;var f=0;do{if(fl&&(dl=null),dr=0,fl=!1,25<=f)throw Error(r(301));if(f+=1,Ft=dt=null,e.updateQueue!=null){var m=e.updateQueue;m.lastEffect=null,m.events=null,m.stores=null,m.memoCache!=null&&(m.memoCache.index=0)}C.H=hh,m=n(i,s)}while(fl);return m}function My(){var e=C.H,n=e.useState()[0];return n=typeof n.then=="function"?mr(n):n,e=e.useState()[0],(dt!==null?dt.memoizedState:null)!==e&&(He.flags|=1024),n}function qc(){var e=Is!==0;return Is=0,e}function Gc(e,n,i){n.updateQueue=e.updateQueue,n.flags&=-2053,e.lanes&=~i}function Pc(e){if(Bs){for(e=e.memoizedState;e!==null;){var n=e.queue;n!==null&&(n.pending=null),e=e.next}Bs=!1}vi=0,Ft=dt=He=null,fl=!1,dr=Is=0,dl=null}function un(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Ft===null?He.memoizedState=Ft=e:Ft=Ft.next=e,Ft}function Bt(){if(dt===null){var e=He.alternate;e=e!==null?e.memoizedState:null}else e=dt.next;var n=Ft===null?He.memoizedState:Ft.next;if(n!==null)Ft=n,dt=e;else{if(e===null)throw He.alternate===null?Error(r(467)):Error(r(310));dt=e,e={memoizedState:dt.memoizedState,baseState:dt.baseState,baseQueue:dt.baseQueue,queue:dt.queue,next:null},Ft===null?He.memoizedState=Ft=e:Ft=Ft.next=e}return Ft}function Us(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function mr(e){var n=dr;return dr+=1,dl===null&&(dl=[]),e=Em(dl,e,n),n=He,(Ft===null?n.memoizedState:Ft.next)===null&&(n=n.alternate,C.H=n===null||n.memoizedState===null?mh:iu),e}function Hs(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return mr(e);if(e.$$typeof===R)return Qt(e)}throw Error(r(438,String(e)))}function Yc(e){var n=null,i=He.updateQueue;if(i!==null&&(n=i.memoCache),n==null){var s=He.alternate;s!==null&&(s=s.updateQueue,s!==null&&(s=s.memoCache,s!=null&&(n={data:s.data.map(function(f){return f.slice()}),index:0})))}if(n==null&&(n={data:[],index:0}),i===null&&(i=Us(),He.updateQueue=i),i.memoCache=n,i=n.data[n.index],i===void 0)for(i=n.data[n.index]=Array(e),s=0;s<e;s++)i[s]=U;return n.index++,i}function Ei(e,n){return typeof n=="function"?n(e):n}function Fs(e){var n=Bt();return Vc(n,dt,e)}function Vc(e,n,i){var s=e.queue;if(s===null)throw Error(r(311));s.lastRenderedReducer=i;var f=e.baseQueue,m=s.pending;if(m!==null){if(f!==null){var y=f.next;f.next=m.next,m.next=y}n.baseQueue=f=m,s.pending=null}if(m=e.baseState,f===null)e.memoizedState=m;else{n=f.next;var E=y=null,z=null,G=n,Q=!1;do{var te=G.lane&-536870913;if(te!==G.lane?(Ze&te)===te:(vi&te)===te){var P=G.revertLane;if(P===0)z!==null&&(z=z.next={lane:0,revertLane:0,gesture:null,action:G.action,hasEagerState:G.hasEagerState,eagerState:G.eagerState,next:null}),te===rl&&(Q=!0);else if((vi&P)===P){G=G.next,P===rl&&(Q=!0);continue}else te={lane:0,revertLane:G.revertLane,gesture:null,action:G.action,hasEagerState:G.hasEagerState,eagerState:G.eagerState,next:null},z===null?(E=z=te,y=m):z=z.next=te,He.lanes|=P,Wi|=P;te=G.action,Ca&&i(m,te),m=G.hasEagerState?G.eagerState:i(m,te)}else P={lane:te,revertLane:G.revertLane,gesture:G.gesture,action:G.action,hasEagerState:G.hasEagerState,eagerState:G.eagerState,next:null},z===null?(E=z=P,y=m):z=z.next=P,He.lanes|=te,Wi|=te;G=G.next}while(G!==null&&G!==n);if(z===null?y=m:z.next=E,!Tn(m,e.memoizedState)&&($t=!0,Q&&(i=sl,i!==null)))throw i;e.memoizedState=m,e.baseState=y,e.baseQueue=z,s.lastRenderedState=m}return f===null&&(s.lanes=0),[e.memoizedState,s.dispatch]}function Kc(e){var n=Bt(),i=n.queue;if(i===null)throw Error(r(311));i.lastRenderedReducer=e;var s=i.dispatch,f=i.pending,m=n.memoizedState;if(f!==null){i.pending=null;var y=f=f.next;do m=e(m,y.action),y=y.next;while(y!==f);Tn(m,n.memoizedState)||($t=!0),n.memoizedState=m,n.baseQueue===null&&(n.baseState=m),i.lastRenderedState=m}return[m,s]}function Rm(e,n,i){var s=He,f=Bt(),m=Je;if(m){if(i===void 0)throw Error(r(407));i=i()}else i=n();var y=!Tn((dt||f).memoizedState,i);if(y&&(f.memoizedState=i,$t=!0),f=f.queue,Qc(jm.bind(null,s,f,e),[e]),f.getSnapshot!==n||y||Ft!==null&&Ft.memoizedState.tag&1){if(s.flags|=2048,ml(9,{destroy:void 0},Lm.bind(null,s,f,i,n),null),bt===null)throw Error(r(349));m||(vi&127)!==0||Dm(s,n,i)}return i}function Dm(e,n,i){e.flags|=16384,e={getSnapshot:n,value:i},n=He.updateQueue,n===null?(n=Us(),He.updateQueue=n,n.stores=[e]):(i=n.stores,i===null?n.stores=[e]:i.push(e))}function Lm(e,n,i,s){n.value=i,n.getSnapshot=s,Bm(n)&&Im(e)}function jm(e,n,i){return i(function(){Bm(n)&&Im(e)})}function Bm(e){var n=e.getSnapshot;e=e.value;try{var i=n();return!Tn(e,i)}catch{return!0}}function Im(e){var n=va(e,2);n!==null&&En(n,e,2)}function Xc(e){var n=un();if(typeof e=="function"){var i=e;if(e=i(),Ca){en(!0);try{i()}finally{en(!1)}}}return n.memoizedState=n.baseState=e,n.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ei,lastRenderedState:e},n}function Um(e,n,i,s){return e.baseState=i,Vc(e,dt,typeof s=="function"?s:Ei)}function Cy(e,n,i,s,f){if(Gs(e))throw Error(r(485));if(e=n.action,e!==null){var m={payload:f,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(y){m.listeners.push(y)}};C.T!==null?i(!0):m.isTransition=!1,s(m),i=n.pending,i===null?(m.next=n.pending=m,Hm(n,m)):(m.next=i.next,n.pending=i.next=m)}}function Hm(e,n){var i=n.action,s=n.payload,f=e.state;if(n.isTransition){var m=C.T,y={};C.T=y;try{var E=i(f,s),z=C.S;z!==null&&z(y,E),Fm(e,n,E)}catch(G){Zc(e,n,G)}finally{m!==null&&y.types!==null&&(m.types=y.types),C.T=m}}else try{m=i(f,s),Fm(e,n,m)}catch(G){Zc(e,n,G)}}function Fm(e,n,i){i!==null&&typeof i=="object"&&typeof i.then=="function"?i.then(function(s){$m(e,n,s)},function(s){return Zc(e,n,s)}):$m(e,n,i)}function $m(e,n,i){n.status="fulfilled",n.value=i,qm(n),e.state=i,n=e.pending,n!==null&&(i=n.next,i===n?e.pending=null:(i=i.next,n.next=i,Hm(e,i)))}function Zc(e,n,i){var s=e.pending;if(e.pending=null,s!==null){s=s.next;do n.status="rejected",n.reason=i,qm(n),n=n.next;while(n!==s)}e.action=null}function qm(e){e=e.listeners;for(var n=0;n<e.length;n++)(0,e[n])()}function Gm(e,n){return n}function Pm(e,n){if(Je){var i=bt.formState;if(i!==null){e:{var s=He;if(Je){if(Et){t:{for(var f=Et,m=$n;f.nodeType!==8;){if(!m){f=null;break t}if(f=Gn(f.nextSibling),f===null){f=null;break t}}m=f.data,f=m==="F!"||m==="F"?f:null}if(f){Et=Gn(f.nextSibling),s=f.data==="F!";break e}}Gi(s)}s=!1}s&&(n=i[0])}}return i=un(),i.memoizedState=i.baseState=n,s={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Gm,lastRenderedState:n},i.queue=s,i=uh.bind(null,He,s),s.dispatch=i,s=Xc(!1),m=nu.bind(null,He,!1,s.queue),s=un(),f={state:n,dispatch:null,action:e,pending:null},s.queue=f,i=Cy.bind(null,He,f,m,i),f.dispatch=i,s.memoizedState=e,[n,i,!1]}function Ym(e){var n=Bt();return Vm(n,dt,e)}function Vm(e,n,i){if(n=Vc(e,n,Gm)[0],e=Fs(Ei)[0],typeof n=="object"&&n!==null&&typeof n.then=="function")try{var s=mr(n)}catch(y){throw y===ol?Os:y}else s=n;n=Bt();var f=n.queue,m=f.dispatch;return i!==n.memoizedState&&(He.flags|=2048,ml(9,{destroy:void 0},Oy.bind(null,f,i),null)),[s,m,e]}function Oy(e,n){e.action=n}function Km(e){var n=Bt(),i=dt;if(i!==null)return Vm(n,i,e);Bt(),n=n.memoizedState,i=Bt();var s=i.queue.dispatch;return i.memoizedState=e,[n,s,!1]}function ml(e,n,i,s){return e={tag:e,create:i,deps:s,inst:n,next:null},n=He.updateQueue,n===null&&(n=Us(),He.updateQueue=n),i=n.lastEffect,i===null?n.lastEffect=e.next=e:(s=i.next,i.next=e,e.next=s,n.lastEffect=e),e}function Xm(){return Bt().memoizedState}function $s(e,n,i,s){var f=un();He.flags|=e,f.memoizedState=ml(1|n,{destroy:void 0},i,s===void 0?null:s)}function qs(e,n,i,s){var f=Bt();s=s===void 0?null:s;var m=f.memoizedState.inst;dt!==null&&s!==null&&Fc(s,dt.memoizedState.deps)?f.memoizedState=ml(n,m,i,s):(He.flags|=e,f.memoizedState=ml(1|n,m,i,s))}function Zm(e,n){$s(8390656,8,e,n)}function Qc(e,n){qs(2048,8,e,n)}function zy(e){He.flags|=4;var n=He.updateQueue;if(n===null)n=Us(),He.updateQueue=n,n.events=[e];else{var i=n.events;i===null?n.events=[e]:i.push(e)}}function Qm(e){var n=Bt().memoizedState;return zy({ref:n,nextImpl:e}),function(){if((at&2)!==0)throw Error(r(440));return n.impl.apply(void 0,arguments)}}function Jm(e,n){return qs(4,2,e,n)}function Wm(e,n){return qs(4,4,e,n)}function eh(e,n){if(typeof n=="function"){e=e();var i=n(e);return function(){typeof i=="function"?i():n(null)}}if(n!=null)return e=e(),n.current=e,function(){n.current=null}}function th(e,n,i){i=i!=null?i.concat([e]):null,qs(4,4,eh.bind(null,n,e),i)}function Jc(){}function nh(e,n){var i=Bt();n=n===void 0?null:n;var s=i.memoizedState;return n!==null&&Fc(n,s[1])?s[0]:(i.memoizedState=[e,n],e)}function ih(e,n){var i=Bt();n=n===void 0?null:n;var s=i.memoizedState;if(n!==null&&Fc(n,s[1]))return s[0];if(s=e(),Ca){en(!0);try{e()}finally{en(!1)}}return i.memoizedState=[s,n],s}function Wc(e,n,i){return i===void 0||(vi&1073741824)!==0&&(Ze&261930)===0?e.memoizedState=n:(e.memoizedState=i,e=ap(),He.lanes|=e,Wi|=e,i)}function ah(e,n,i,s){return Tn(i,n)?i:ul.current!==null?(e=Wc(e,i,s),Tn(e,n)||($t=!0),e):(vi&42)===0||(vi&1073741824)!==0&&(Ze&261930)===0?($t=!0,e.memoizedState=i):(e=ap(),He.lanes|=e,Wi|=e,n)}function lh(e,n,i,s,f){var m=K.p;K.p=m!==0&&8>m?m:8;var y=C.T,E={};C.T=E,nu(e,!1,n,i);try{var z=f(),G=C.S;if(G!==null&&G(E,z),z!==null&&typeof z=="object"&&typeof z.then=="function"){var Q=Ty(z,s);hr(e,n,Q,Rn(e))}else hr(e,n,s,Rn(e))}catch(te){hr(e,n,{then:function(){},status:"rejected",reason:te},Rn())}finally{K.p=m,y!==null&&E.types!==null&&(y.types=E.types),C.T=y}}function Ry(){}function eu(e,n,i,s){if(e.tag!==5)throw Error(r(476));var f=rh(e).queue;lh(e,f,n,ne,i===null?Ry:function(){return sh(e),i(s)})}function rh(e){var n=e.memoizedState;if(n!==null)return n;n={memoizedState:ne,baseState:ne,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ei,lastRenderedState:ne},next:null};var i={};return n.next={memoizedState:i,baseState:i,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ei,lastRenderedState:i},next:null},e.memoizedState=n,e=e.alternate,e!==null&&(e.memoizedState=n),n}function sh(e){var n=rh(e);n.next===null&&(n=e.alternate.memoizedState),hr(e,n.next.queue,{},Rn())}function tu(){return Qt(Or)}function oh(){return Bt().memoizedState}function ch(){return Bt().memoizedState}function Dy(e){for(var n=e.return;n!==null;){switch(n.tag){case 24:case 3:var i=Rn();e=Vi(i);var s=Ki(n,e,i);s!==null&&(En(s,n,i),cr(s,n,i)),n={cache:Cc()},e.payload=n;return}n=n.return}}function Ly(e,n,i){var s=Rn();i={lane:s,revertLane:0,gesture:null,action:i,hasEagerState:!1,eagerState:null,next:null},Gs(e)?fh(n,i):(i=yc(e,n,i,s),i!==null&&(En(i,e,s),dh(i,n,s)))}function uh(e,n,i){var s=Rn();hr(e,n,i,s)}function hr(e,n,i,s){var f={lane:s,revertLane:0,gesture:null,action:i,hasEagerState:!1,eagerState:null,next:null};if(Gs(e))fh(n,f);else{var m=e.alternate;if(e.lanes===0&&(m===null||m.lanes===0)&&(m=n.lastRenderedReducer,m!==null))try{var y=n.lastRenderedState,E=m(y,i);if(f.hasEagerState=!0,f.eagerState=E,Tn(E,y))return Ns(e,n,f,0),bt===null&&Ss(),!1}catch{}finally{}if(i=yc(e,n,f,s),i!==null)return En(i,e,s),dh(i,n,s),!0}return!1}function nu(e,n,i,s){if(s={lane:2,revertLane:Du(),gesture:null,action:s,hasEagerState:!1,eagerState:null,next:null},Gs(e)){if(n)throw Error(r(479))}else n=yc(e,i,s,2),n!==null&&En(n,e,2)}function Gs(e){var n=e.alternate;return e===He||n!==null&&n===He}function fh(e,n){fl=Bs=!0;var i=e.pending;i===null?n.next=n:(n.next=i.next,i.next=n),e.pending=n}function dh(e,n,i){if((i&4194048)!==0){var s=n.lanes;s&=e.pendingLanes,i|=s,n.lanes=i,De(e,i)}}var pr={readContext:Qt,use:Hs,useCallback:Ct,useContext:Ct,useEffect:Ct,useImperativeHandle:Ct,useLayoutEffect:Ct,useInsertionEffect:Ct,useMemo:Ct,useReducer:Ct,useRef:Ct,useState:Ct,useDebugValue:Ct,useDeferredValue:Ct,useTransition:Ct,useSyncExternalStore:Ct,useId:Ct,useHostTransitionStatus:Ct,useFormState:Ct,useActionState:Ct,useOptimistic:Ct,useMemoCache:Ct,useCacheRefresh:Ct};pr.useEffectEvent=Ct;var mh={readContext:Qt,use:Hs,useCallback:function(e,n){return un().memoizedState=[e,n===void 0?null:n],e},useContext:Qt,useEffect:Zm,useImperativeHandle:function(e,n,i){i=i!=null?i.concat([e]):null,$s(4194308,4,eh.bind(null,n,e),i)},useLayoutEffect:function(e,n){return $s(4194308,4,e,n)},useInsertionEffect:function(e,n){$s(4,2,e,n)},useMemo:function(e,n){var i=un();n=n===void 0?null:n;var s=e();if(Ca){en(!0);try{e()}finally{en(!1)}}return i.memoizedState=[s,n],s},useReducer:function(e,n,i){var s=un();if(i!==void 0){var f=i(n);if(Ca){en(!0);try{i(n)}finally{en(!1)}}}else f=n;return s.memoizedState=s.baseState=f,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:f},s.queue=e,e=e.dispatch=Ly.bind(null,He,e),[s.memoizedState,e]},useRef:function(e){var n=un();return e={current:e},n.memoizedState=e},useState:function(e){e=Xc(e);var n=e.queue,i=uh.bind(null,He,n);return n.dispatch=i,[e.memoizedState,i]},useDebugValue:Jc,useDeferredValue:function(e,n){var i=un();return Wc(i,e,n)},useTransition:function(){var e=Xc(!1);return e=lh.bind(null,He,e.queue,!0,!1),un().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,n,i){var s=He,f=un();if(Je){if(i===void 0)throw Error(r(407));i=i()}else{if(i=n(),bt===null)throw Error(r(349));(Ze&127)!==0||Dm(s,n,i)}f.memoizedState=i;var m={value:i,getSnapshot:n};return f.queue=m,Zm(jm.bind(null,s,m,e),[e]),s.flags|=2048,ml(9,{destroy:void 0},Lm.bind(null,s,m,i,n),null),i},useId:function(){var e=un(),n=bt.identifierPrefix;if(Je){var i=ii,s=ni;i=(s&~(1<<32-st(s)-1)).toString(32)+i,n="_"+n+"R_"+i,i=Is++,0<i&&(n+="H"+i.toString(32)),n+="_"}else i=Ay++,n="_"+n+"r_"+i.toString(32)+"_";return e.memoizedState=n},useHostTransitionStatus:tu,useFormState:Pm,useActionState:Pm,useOptimistic:function(e){var n=un();n.memoizedState=n.baseState=e;var i={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return n.queue=i,n=nu.bind(null,He,!0,i),i.dispatch=n,[e,n]},useMemoCache:Yc,useCacheRefresh:function(){return un().memoizedState=Dy.bind(null,He)},useEffectEvent:function(e){var n=un(),i={impl:e};return n.memoizedState=i,function(){if((at&2)!==0)throw Error(r(440));return i.impl.apply(void 0,arguments)}}},iu={readContext:Qt,use:Hs,useCallback:nh,useContext:Qt,useEffect:Qc,useImperativeHandle:th,useInsertionEffect:Jm,useLayoutEffect:Wm,useMemo:ih,useReducer:Fs,useRef:Xm,useState:function(){return Fs(Ei)},useDebugValue:Jc,useDeferredValue:function(e,n){var i=Bt();return ah(i,dt.memoizedState,e,n)},useTransition:function(){var e=Fs(Ei)[0],n=Bt().memoizedState;return[typeof e=="boolean"?e:mr(e),n]},useSyncExternalStore:Rm,useId:oh,useHostTransitionStatus:tu,useFormState:Ym,useActionState:Ym,useOptimistic:function(e,n){var i=Bt();return Um(i,dt,e,n)},useMemoCache:Yc,useCacheRefresh:ch};iu.useEffectEvent=Qm;var hh={readContext:Qt,use:Hs,useCallback:nh,useContext:Qt,useEffect:Qc,useImperativeHandle:th,useInsertionEffect:Jm,useLayoutEffect:Wm,useMemo:ih,useReducer:Kc,useRef:Xm,useState:function(){return Kc(Ei)},useDebugValue:Jc,useDeferredValue:function(e,n){var i=Bt();return dt===null?Wc(i,e,n):ah(i,dt.memoizedState,e,n)},useTransition:function(){var e=Kc(Ei)[0],n=Bt().memoizedState;return[typeof e=="boolean"?e:mr(e),n]},useSyncExternalStore:Rm,useId:oh,useHostTransitionStatus:tu,useFormState:Km,useActionState:Km,useOptimistic:function(e,n){var i=Bt();return dt!==null?Um(i,dt,e,n):(i.baseState=e,[e,i.queue.dispatch])},useMemoCache:Yc,useCacheRefresh:ch};hh.useEffectEvent=Qm;function au(e,n,i,s){n=e.memoizedState,i=i(s,n),i=i==null?n:x({},n,i),e.memoizedState=i,e.lanes===0&&(e.updateQueue.baseState=i)}var lu={enqueueSetState:function(e,n,i){e=e._reactInternals;var s=Rn(),f=Vi(s);f.payload=n,i!=null&&(f.callback=i),n=Ki(e,f,s),n!==null&&(En(n,e,s),cr(n,e,s))},enqueueReplaceState:function(e,n,i){e=e._reactInternals;var s=Rn(),f=Vi(s);f.tag=1,f.payload=n,i!=null&&(f.callback=i),n=Ki(e,f,s),n!==null&&(En(n,e,s),cr(n,e,s))},enqueueForceUpdate:function(e,n){e=e._reactInternals;var i=Rn(),s=Vi(i);s.tag=2,n!=null&&(s.callback=n),n=Ki(e,s,i),n!==null&&(En(n,e,i),cr(n,e,i))}};function ph(e,n,i,s,f,m,y){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(s,m,y):n.prototype&&n.prototype.isPureReactComponent?!tr(i,s)||!tr(f,m):!0}function gh(e,n,i,s){e=n.state,typeof n.componentWillReceiveProps=="function"&&n.componentWillReceiveProps(i,s),typeof n.UNSAFE_componentWillReceiveProps=="function"&&n.UNSAFE_componentWillReceiveProps(i,s),n.state!==e&&lu.enqueueReplaceState(n,n.state,null)}function Oa(e,n){var i=n;if("ref"in n){i={};for(var s in n)s!=="ref"&&(i[s]=n[s])}if(e=e.defaultProps){i===n&&(i=x({},i));for(var f in e)i[f]===void 0&&(i[f]=e[f])}return i}function bh(e){Es(e)}function xh(e){console.error(e)}function yh(e){Es(e)}function Ps(e,n){try{var i=e.onUncaughtError;i(n.value,{componentStack:n.stack})}catch(s){setTimeout(function(){throw s})}}function _h(e,n,i){try{var s=e.onCaughtError;s(i.value,{componentStack:i.stack,errorBoundary:n.tag===1?n.stateNode:null})}catch(f){setTimeout(function(){throw f})}}function ru(e,n,i){return i=Vi(i),i.tag=3,i.payload={element:null},i.callback=function(){Ps(e,n)},i}function vh(e){return e=Vi(e),e.tag=3,e}function Eh(e,n,i,s){var f=i.type.getDerivedStateFromError;if(typeof f=="function"){var m=s.value;e.payload=function(){return f(m)},e.callback=function(){_h(n,i,s)}}var y=i.stateNode;y!==null&&typeof y.componentDidCatch=="function"&&(e.callback=function(){_h(n,i,s),typeof f!="function"&&(ea===null?ea=new Set([this]):ea.add(this));var E=s.stack;this.componentDidCatch(s.value,{componentStack:E!==null?E:""})})}function jy(e,n,i,s,f){if(i.flags|=32768,s!==null&&typeof s=="object"&&typeof s.then=="function"){if(n=i.alternate,n!==null&&ll(n,i,f,!0),i=Mn.current,i!==null){switch(i.tag){case 31:case 13:return qn===null?io():i.alternate===null&&Ot===0&&(Ot=3),i.flags&=-257,i.flags|=65536,i.lanes=f,s===zs?i.flags|=16384:(n=i.updateQueue,n===null?i.updateQueue=new Set([s]):n.add(s),Ou(e,s,f)),!1;case 22:return i.flags|=65536,s===zs?i.flags|=16384:(n=i.updateQueue,n===null?(n={transitions:null,markerInstances:null,retryQueue:new Set([s])},i.updateQueue=n):(i=n.retryQueue,i===null?n.retryQueue=new Set([s]):i.add(s)),Ou(e,s,f)),!1}throw Error(r(435,i.tag))}return Ou(e,s,f),io(),!1}if(Je)return n=Mn.current,n!==null?((n.flags&65536)===0&&(n.flags|=256),n.flags|=65536,n.lanes=f,s!==wc&&(e=Error(r(422),{cause:s}),ar(Un(e,i)))):(s!==wc&&(n=Error(r(423),{cause:s}),ar(Un(n,i))),e=e.current.alternate,e.flags|=65536,f&=-f,e.lanes|=f,s=Un(s,i),f=ru(e.stateNode,s,f),jc(e,f),Ot!==4&&(Ot=2)),!1;var m=Error(r(520),{cause:s});if(m=Un(m,i),Sr===null?Sr=[m]:Sr.push(m),Ot!==4&&(Ot=2),n===null)return!0;s=Un(s,i),i=n;do{switch(i.tag){case 3:return i.flags|=65536,e=f&-f,i.lanes|=e,e=ru(i.stateNode,s,e),jc(i,e),!1;case 1:if(n=i.type,m=i.stateNode,(i.flags&128)===0&&(typeof n.getDerivedStateFromError=="function"||m!==null&&typeof m.componentDidCatch=="function"&&(ea===null||!ea.has(m))))return i.flags|=65536,f&=-f,i.lanes|=f,f=vh(f),Eh(f,e,i,s),jc(i,f),!1}i=i.return}while(i!==null);return!1}var su=Error(r(461)),$t=!1;function Jt(e,n,i,s){n.child=e===null?km(n,null,i,s):Ma(n,e.child,i,s)}function Sh(e,n,i,s,f){i=i.render;var m=n.ref;if("ref"in s){var y={};for(var E in s)E!=="ref"&&(y[E]=s[E])}else y=s;return wa(n),s=$c(e,n,i,y,m,f),E=qc(),e!==null&&!$t?(Gc(e,n,f),Si(e,n,f)):(Je&&E&&Sc(n),n.flags|=1,Jt(e,n,s,f),n.child)}function Nh(e,n,i,s,f){if(e===null){var m=i.type;return typeof m=="function"&&!_c(m)&&m.defaultProps===void 0&&i.compare===null?(n.tag=15,n.type=m,wh(e,n,m,s,f)):(e=ks(i.type,null,s,n,n.mode,f),e.ref=n.ref,e.return=n,n.child=e)}if(m=e.child,!pu(e,f)){var y=m.memoizedProps;if(i=i.compare,i=i!==null?i:tr,i(y,s)&&e.ref===n.ref)return Si(e,n,f)}return n.flags|=1,e=bi(m,s),e.ref=n.ref,e.return=n,n.child=e}function wh(e,n,i,s,f){if(e!==null){var m=e.memoizedProps;if(tr(m,s)&&e.ref===n.ref)if($t=!1,n.pendingProps=s=m,pu(e,f))(e.flags&131072)!==0&&($t=!0);else return n.lanes=e.lanes,Si(e,n,f)}return ou(e,n,i,s,f)}function kh(e,n,i,s){var f=s.children,m=e!==null?e.memoizedState:null;if(e===null&&n.stateNode===null&&(n.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),s.mode==="hidden"){if((n.flags&128)!==0){if(m=m!==null?m.baseLanes|i:i,e!==null){for(s=n.child=e.child,f=0;s!==null;)f=f|s.lanes|s.childLanes,s=s.sibling;s=f&~m}else s=0,n.child=null;return Th(e,n,m,i,s)}if((i&536870912)!==0)n.memoizedState={baseLanes:0,cachePool:null},e!==null&&Cs(n,m!==null?m.cachePool:null),m!==null?Mm(n,m):Ic(),Cm(n);else return s=n.lanes=536870912,Th(e,n,m!==null?m.baseLanes|i:i,i,s)}else m!==null?(Cs(n,m.cachePool),Mm(n,m),Zi(),n.memoizedState=null):(e!==null&&Cs(n,null),Ic(),Zi());return Jt(e,n,f,i),n.child}function gr(e,n){return e!==null&&e.tag===22||n.stateNode!==null||(n.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),n.sibling}function Th(e,n,i,s,f){var m=zc();return m=m===null?null:{parent:Ht._currentValue,pool:m},n.memoizedState={baseLanes:i,cachePool:m},e!==null&&Cs(n,null),Ic(),Cm(n),e!==null&&ll(e,n,s,!0),n.childLanes=f,null}function Ys(e,n){return n=Ks({mode:n.mode,children:n.children},e.mode),n.ref=e.ref,e.child=n,n.return=e,n}function Ah(e,n,i){return Ma(n,e.child,null,i),e=Ys(n,n.pendingProps),e.flags|=2,Cn(n),n.memoizedState=null,e}function By(e,n,i){var s=n.pendingProps,f=(n.flags&128)!==0;if(n.flags&=-129,e===null){if(Je){if(s.mode==="hidden")return e=Ys(n,s),n.lanes=536870912,gr(null,e);if(Hc(n),(e=Et)?(e=Hp(e,$n),e=e!==null&&e.data==="&"?e:null,e!==null&&(n.memoizedState={dehydrated:e,treeContext:$i!==null?{id:ni,overflow:ii}:null,retryLane:536870912,hydrationErrors:null},i=fm(e),i.return=n,n.child=i,Zt=n,Et=null)):e=null,e===null)throw Gi(n);return n.lanes=536870912,null}return Ys(n,s)}var m=e.memoizedState;if(m!==null){var y=m.dehydrated;if(Hc(n),f)if(n.flags&256)n.flags&=-257,n=Ah(e,n,i);else if(n.memoizedState!==null)n.child=e.child,n.flags|=128,n=null;else throw Error(r(558));else if($t||ll(e,n,i,!1),f=(i&e.childLanes)!==0,$t||f){if(s=bt,s!==null&&(y=Rt(s,i),y!==0&&y!==m.retryLane))throw m.retryLane=y,va(e,y),En(s,e,y),su;io(),n=Ah(e,n,i)}else e=m.treeContext,Et=Gn(y.nextSibling),Zt=n,Je=!0,qi=null,$n=!1,e!==null&&hm(n,e),n=Ys(n,s),n.flags|=4096;return n}return e=bi(e.child,{mode:s.mode,children:s.children}),e.ref=n.ref,n.child=e,e.return=n,e}function Vs(e,n){var i=n.ref;if(i===null)e!==null&&e.ref!==null&&(n.flags|=4194816);else{if(typeof i!="function"&&typeof i!="object")throw Error(r(284));(e===null||e.ref!==i)&&(n.flags|=4194816)}}function ou(e,n,i,s,f){return wa(n),i=$c(e,n,i,s,void 0,f),s=qc(),e!==null&&!$t?(Gc(e,n,f),Si(e,n,f)):(Je&&s&&Sc(n),n.flags|=1,Jt(e,n,i,f),n.child)}function Mh(e,n,i,s,f,m){return wa(n),n.updateQueue=null,i=zm(n,s,i,f),Om(e),s=qc(),e!==null&&!$t?(Gc(e,n,m),Si(e,n,m)):(Je&&s&&Sc(n),n.flags|=1,Jt(e,n,i,m),n.child)}function Ch(e,n,i,s,f){if(wa(n),n.stateNode===null){var m=tl,y=i.contextType;typeof y=="object"&&y!==null&&(m=Qt(y)),m=new i(s,m),n.memoizedState=m.state!==null&&m.state!==void 0?m.state:null,m.updater=lu,n.stateNode=m,m._reactInternals=n,m=n.stateNode,m.props=s,m.state=n.memoizedState,m.refs={},Dc(n),y=i.contextType,m.context=typeof y=="object"&&y!==null?Qt(y):tl,m.state=n.memoizedState,y=i.getDerivedStateFromProps,typeof y=="function"&&(au(n,i,y,s),m.state=n.memoizedState),typeof i.getDerivedStateFromProps=="function"||typeof m.getSnapshotBeforeUpdate=="function"||typeof m.UNSAFE_componentWillMount!="function"&&typeof m.componentWillMount!="function"||(y=m.state,typeof m.componentWillMount=="function"&&m.componentWillMount(),typeof m.UNSAFE_componentWillMount=="function"&&m.UNSAFE_componentWillMount(),y!==m.state&&lu.enqueueReplaceState(m,m.state,null),fr(n,s,m,f),ur(),m.state=n.memoizedState),typeof m.componentDidMount=="function"&&(n.flags|=4194308),s=!0}else if(e===null){m=n.stateNode;var E=n.memoizedProps,z=Oa(i,E);m.props=z;var G=m.context,Q=i.contextType;y=tl,typeof Q=="object"&&Q!==null&&(y=Qt(Q));var te=i.getDerivedStateFromProps;Q=typeof te=="function"||typeof m.getSnapshotBeforeUpdate=="function",E=n.pendingProps!==E,Q||typeof m.UNSAFE_componentWillReceiveProps!="function"&&typeof m.componentWillReceiveProps!="function"||(E||G!==y)&&gh(n,m,s,y),Yi=!1;var P=n.memoizedState;m.state=P,fr(n,s,m,f),ur(),G=n.memoizedState,E||P!==G||Yi?(typeof te=="function"&&(au(n,i,te,s),G=n.memoizedState),(z=Yi||ph(n,i,z,s,P,G,y))?(Q||typeof m.UNSAFE_componentWillMount!="function"&&typeof m.componentWillMount!="function"||(typeof m.componentWillMount=="function"&&m.componentWillMount(),typeof m.UNSAFE_componentWillMount=="function"&&m.UNSAFE_componentWillMount()),typeof m.componentDidMount=="function"&&(n.flags|=4194308)):(typeof m.componentDidMount=="function"&&(n.flags|=4194308),n.memoizedProps=s,n.memoizedState=G),m.props=s,m.state=G,m.context=y,s=z):(typeof m.componentDidMount=="function"&&(n.flags|=4194308),s=!1)}else{m=n.stateNode,Lc(e,n),y=n.memoizedProps,Q=Oa(i,y),m.props=Q,te=n.pendingProps,P=m.context,G=i.contextType,z=tl,typeof G=="object"&&G!==null&&(z=Qt(G)),E=i.getDerivedStateFromProps,(G=typeof E=="function"||typeof m.getSnapshotBeforeUpdate=="function")||typeof m.UNSAFE_componentWillReceiveProps!="function"&&typeof m.componentWillReceiveProps!="function"||(y!==te||P!==z)&&gh(n,m,s,z),Yi=!1,P=n.memoizedState,m.state=P,fr(n,s,m,f),ur();var V=n.memoizedState;y!==te||P!==V||Yi||e!==null&&e.dependencies!==null&&As(e.dependencies)?(typeof E=="function"&&(au(n,i,E,s),V=n.memoizedState),(Q=Yi||ph(n,i,Q,s,P,V,z)||e!==null&&e.dependencies!==null&&As(e.dependencies))?(G||typeof m.UNSAFE_componentWillUpdate!="function"&&typeof m.componentWillUpdate!="function"||(typeof m.componentWillUpdate=="function"&&m.componentWillUpdate(s,V,z),typeof m.UNSAFE_componentWillUpdate=="function"&&m.UNSAFE_componentWillUpdate(s,V,z)),typeof m.componentDidUpdate=="function"&&(n.flags|=4),typeof m.getSnapshotBeforeUpdate=="function"&&(n.flags|=1024)):(typeof m.componentDidUpdate!="function"||y===e.memoizedProps&&P===e.memoizedState||(n.flags|=4),typeof m.getSnapshotBeforeUpdate!="function"||y===e.memoizedProps&&P===e.memoizedState||(n.flags|=1024),n.memoizedProps=s,n.memoizedState=V),m.props=s,m.state=V,m.context=z,s=Q):(typeof m.componentDidUpdate!="function"||y===e.memoizedProps&&P===e.memoizedState||(n.flags|=4),typeof m.getSnapshotBeforeUpdate!="function"||y===e.memoizedProps&&P===e.memoizedState||(n.flags|=1024),s=!1)}return m=s,Vs(e,n),s=(n.flags&128)!==0,m||s?(m=n.stateNode,i=s&&typeof i.getDerivedStateFromError!="function"?null:m.render(),n.flags|=1,e!==null&&s?(n.child=Ma(n,e.child,null,f),n.child=Ma(n,null,i,f)):Jt(e,n,i,f),n.memoizedState=m.state,e=n.child):e=Si(e,n,f),e}function Oh(e,n,i,s){return Sa(),n.flags|=256,Jt(e,n,i,s),n.child}var cu={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function uu(e){return{baseLanes:e,cachePool:_m()}}function fu(e,n,i){return e=e!==null?e.childLanes&~i:0,n&&(e|=zn),e}function zh(e,n,i){var s=n.pendingProps,f=!1,m=(n.flags&128)!==0,y;if((y=m)||(y=e!==null&&e.memoizedState===null?!1:(jt.current&2)!==0),y&&(f=!0,n.flags&=-129),y=(n.flags&32)!==0,n.flags&=-33,e===null){if(Je){if(f?Xi(n):Zi(),(e=Et)?(e=Hp(e,$n),e=e!==null&&e.data!=="&"?e:null,e!==null&&(n.memoizedState={dehydrated:e,treeContext:$i!==null?{id:ni,overflow:ii}:null,retryLane:536870912,hydrationErrors:null},i=fm(e),i.return=n,n.child=i,Zt=n,Et=null)):e=null,e===null)throw Gi(n);return Vu(e)?n.lanes=32:n.lanes=536870912,null}var E=s.children;return s=s.fallback,f?(Zi(),f=n.mode,E=Ks({mode:"hidden",children:E},f),s=Ea(s,f,i,null),E.return=n,s.return=n,E.sibling=s,n.child=E,s=n.child,s.memoizedState=uu(i),s.childLanes=fu(e,y,i),n.memoizedState=cu,gr(null,s)):(Xi(n),du(n,E))}var z=e.memoizedState;if(z!==null&&(E=z.dehydrated,E!==null)){if(m)n.flags&256?(Xi(n),n.flags&=-257,n=mu(e,n,i)):n.memoizedState!==null?(Zi(),n.child=e.child,n.flags|=128,n=null):(Zi(),E=s.fallback,f=n.mode,s=Ks({mode:"visible",children:s.children},f),E=Ea(E,f,i,null),E.flags|=2,s.return=n,E.return=n,s.sibling=E,n.child=s,Ma(n,e.child,null,i),s=n.child,s.memoizedState=uu(i),s.childLanes=fu(e,y,i),n.memoizedState=cu,n=gr(null,s));else if(Xi(n),Vu(E)){if(y=E.nextSibling&&E.nextSibling.dataset,y)var G=y.dgst;y=G,s=Error(r(419)),s.stack="",s.digest=y,ar({value:s,source:null,stack:null}),n=mu(e,n,i)}else if($t||ll(e,n,i,!1),y=(i&e.childLanes)!==0,$t||y){if(y=bt,y!==null&&(s=Rt(y,i),s!==0&&s!==z.retryLane))throw z.retryLane=s,va(e,s),En(y,e,s),su;Yu(E)||io(),n=mu(e,n,i)}else Yu(E)?(n.flags|=192,n.child=e.child,n=null):(e=z.treeContext,Et=Gn(E.nextSibling),Zt=n,Je=!0,qi=null,$n=!1,e!==null&&hm(n,e),n=du(n,s.children),n.flags|=4096);return n}return f?(Zi(),E=s.fallback,f=n.mode,z=e.child,G=z.sibling,s=bi(z,{mode:"hidden",children:s.children}),s.subtreeFlags=z.subtreeFlags&65011712,G!==null?E=bi(G,E):(E=Ea(E,f,i,null),E.flags|=2),E.return=n,s.return=n,s.sibling=E,n.child=s,gr(null,s),s=n.child,E=e.child.memoizedState,E===null?E=uu(i):(f=E.cachePool,f!==null?(z=Ht._currentValue,f=f.parent!==z?{parent:z,pool:z}:f):f=_m(),E={baseLanes:E.baseLanes|i,cachePool:f}),s.memoizedState=E,s.childLanes=fu(e,y,i),n.memoizedState=cu,gr(e.child,s)):(Xi(n),i=e.child,e=i.sibling,i=bi(i,{mode:"visible",children:s.children}),i.return=n,i.sibling=null,e!==null&&(y=n.deletions,y===null?(n.deletions=[e],n.flags|=16):y.push(e)),n.child=i,n.memoizedState=null,i)}function du(e,n){return n=Ks({mode:"visible",children:n},e.mode),n.return=e,e.child=n}function Ks(e,n){return e=An(22,e,null,n),e.lanes=0,e}function mu(e,n,i){return Ma(n,e.child,null,i),e=du(n,n.pendingProps.children),e.flags|=2,n.memoizedState=null,e}function Rh(e,n,i){e.lanes|=n;var s=e.alternate;s!==null&&(s.lanes|=n),Ac(e.return,n,i)}function hu(e,n,i,s,f,m){var y=e.memoizedState;y===null?e.memoizedState={isBackwards:n,rendering:null,renderingStartTime:0,last:s,tail:i,tailMode:f,treeForkCount:m}:(y.isBackwards=n,y.rendering=null,y.renderingStartTime=0,y.last=s,y.tail=i,y.tailMode=f,y.treeForkCount=m)}function Dh(e,n,i){var s=n.pendingProps,f=s.revealOrder,m=s.tail;s=s.children;var y=jt.current,E=(y&2)!==0;if(E?(y=y&1|2,n.flags|=128):y&=1,N(jt,y),Jt(e,n,s,i),s=Je?ir:0,!E&&e!==null&&(e.flags&128)!==0)e:for(e=n.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&Rh(e,i,n);else if(e.tag===19)Rh(e,i,n);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===n)break e;for(;e.sibling===null;){if(e.return===null||e.return===n)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}switch(f){case"forwards":for(i=n.child,f=null;i!==null;)e=i.alternate,e!==null&&js(e)===null&&(f=i),i=i.sibling;i=f,i===null?(f=n.child,n.child=null):(f=i.sibling,i.sibling=null),hu(n,!1,f,i,m,s);break;case"backwards":case"unstable_legacy-backwards":for(i=null,f=n.child,n.child=null;f!==null;){if(e=f.alternate,e!==null&&js(e)===null){n.child=f;break}e=f.sibling,f.sibling=i,i=f,f=e}hu(n,!0,i,null,m,s);break;case"together":hu(n,!1,null,null,void 0,s);break;default:n.memoizedState=null}return n.child}function Si(e,n,i){if(e!==null&&(n.dependencies=e.dependencies),Wi|=n.lanes,(i&n.childLanes)===0)if(e!==null){if(ll(e,n,i,!1),(i&n.childLanes)===0)return null}else return null;if(e!==null&&n.child!==e.child)throw Error(r(153));if(n.child!==null){for(e=n.child,i=bi(e,e.pendingProps),n.child=i,i.return=n;e.sibling!==null;)e=e.sibling,i=i.sibling=bi(e,e.pendingProps),i.return=n;i.sibling=null}return n.child}function pu(e,n){return(e.lanes&n)!==0?!0:(e=e.dependencies,!!(e!==null&&As(e)))}function Iy(e,n,i){switch(n.tag){case 3:ve(n,n.stateNode.containerInfo),Pi(n,Ht,e.memoizedState.cache),Sa();break;case 27:case 5:lt(n);break;case 4:ve(n,n.stateNode.containerInfo);break;case 10:Pi(n,n.type,n.memoizedProps.value);break;case 31:if(n.memoizedState!==null)return n.flags|=128,Hc(n),null;break;case 13:var s=n.memoizedState;if(s!==null)return s.dehydrated!==null?(Xi(n),n.flags|=128,null):(i&n.child.childLanes)!==0?zh(e,n,i):(Xi(n),e=Si(e,n,i),e!==null?e.sibling:null);Xi(n);break;case 19:var f=(e.flags&128)!==0;if(s=(i&n.childLanes)!==0,s||(ll(e,n,i,!1),s=(i&n.childLanes)!==0),f){if(s)return Dh(e,n,i);n.flags|=128}if(f=n.memoizedState,f!==null&&(f.rendering=null,f.tail=null,f.lastEffect=null),N(jt,jt.current),s)break;return null;case 22:return n.lanes=0,kh(e,n,i,n.pendingProps);case 24:Pi(n,Ht,e.memoizedState.cache)}return Si(e,n,i)}function Lh(e,n,i){if(e!==null)if(e.memoizedProps!==n.pendingProps)$t=!0;else{if(!pu(e,i)&&(n.flags&128)===0)return $t=!1,Iy(e,n,i);$t=(e.flags&131072)!==0}else $t=!1,Je&&(n.flags&1048576)!==0&&mm(n,ir,n.index);switch(n.lanes=0,n.tag){case 16:e:{var s=n.pendingProps;if(e=Ta(n.elementType),n.type=e,typeof e=="function")_c(e)?(s=Oa(e,s),n.tag=1,n=Ch(null,n,e,s,i)):(n.tag=0,n=ou(null,n,e,s,i));else{if(e!=null){var f=e.$$typeof;if(f===q){n.tag=11,n=Sh(null,n,e,s,i);break e}else if(f===X){n.tag=14,n=Nh(null,n,e,s,i);break e}}throw n=W(e)||e,Error(r(306,n,""))}}return n;case 0:return ou(e,n,n.type,n.pendingProps,i);case 1:return s=n.type,f=Oa(s,n.pendingProps),Ch(e,n,s,f,i);case 3:e:{if(ve(n,n.stateNode.containerInfo),e===null)throw Error(r(387));s=n.pendingProps;var m=n.memoizedState;f=m.element,Lc(e,n),fr(n,s,null,i);var y=n.memoizedState;if(s=y.cache,Pi(n,Ht,s),s!==m.cache&&Mc(n,[Ht],i,!0),ur(),s=y.element,m.isDehydrated)if(m={element:s,isDehydrated:!1,cache:y.cache},n.updateQueue.baseState=m,n.memoizedState=m,n.flags&256){n=Oh(e,n,s,i);break e}else if(s!==f){f=Un(Error(r(424)),n),ar(f),n=Oh(e,n,s,i);break e}else{switch(e=n.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(Et=Gn(e.firstChild),Zt=n,Je=!0,qi=null,$n=!0,i=km(n,null,s,i),n.child=i;i;)i.flags=i.flags&-3|4096,i=i.sibling}else{if(Sa(),s===f){n=Si(e,n,i);break e}Jt(e,n,s,i)}n=n.child}return n;case 26:return Vs(e,n),e===null?(i=Yp(n.type,null,n.pendingProps,null))?n.memoizedState=i:Je||(i=n.type,e=n.pendingProps,s=uo(xe.current).createElement(i),s[Dt]=n,s[tn]=e,Wt(s,i,e),It(s),n.stateNode=s):n.memoizedState=Yp(n.type,e.memoizedProps,n.pendingProps,e.memoizedState),null;case 27:return lt(n),e===null&&Je&&(s=n.stateNode=qp(n.type,n.pendingProps,xe.current),Zt=n,$n=!0,f=Et,aa(n.type)?(Ku=f,Et=Gn(s.firstChild)):Et=f),Jt(e,n,n.pendingProps.children,i),Vs(e,n),e===null&&(n.flags|=4194304),n.child;case 5:return e===null&&Je&&((f=s=Et)&&(s=h1(s,n.type,n.pendingProps,$n),s!==null?(n.stateNode=s,Zt=n,Et=Gn(s.firstChild),$n=!1,f=!0):f=!1),f||Gi(n)),lt(n),f=n.type,m=n.pendingProps,y=e!==null?e.memoizedProps:null,s=m.children,qu(f,m)?s=null:y!==null&&qu(f,y)&&(n.flags|=32),n.memoizedState!==null&&(f=$c(e,n,My,null,null,i),Or._currentValue=f),Vs(e,n),Jt(e,n,s,i),n.child;case 6:return e===null&&Je&&((e=i=Et)&&(i=p1(i,n.pendingProps,$n),i!==null?(n.stateNode=i,Zt=n,Et=null,e=!0):e=!1),e||Gi(n)),null;case 13:return zh(e,n,i);case 4:return ve(n,n.stateNode.containerInfo),s=n.pendingProps,e===null?n.child=Ma(n,null,s,i):Jt(e,n,s,i),n.child;case 11:return Sh(e,n,n.type,n.pendingProps,i);case 7:return Jt(e,n,n.pendingProps,i),n.child;case 8:return Jt(e,n,n.pendingProps.children,i),n.child;case 12:return Jt(e,n,n.pendingProps.children,i),n.child;case 10:return s=n.pendingProps,Pi(n,n.type,s.value),Jt(e,n,s.children,i),n.child;case 9:return f=n.type._context,s=n.pendingProps.children,wa(n),f=Qt(f),s=s(f),n.flags|=1,Jt(e,n,s,i),n.child;case 14:return Nh(e,n,n.type,n.pendingProps,i);case 15:return wh(e,n,n.type,n.pendingProps,i);case 19:return Dh(e,n,i);case 31:return By(e,n,i);case 22:return kh(e,n,i,n.pendingProps);case 24:return wa(n),s=Qt(Ht),e===null?(f=zc(),f===null&&(f=bt,m=Cc(),f.pooledCache=m,m.refCount++,m!==null&&(f.pooledCacheLanes|=i),f=m),n.memoizedState={parent:s,cache:f},Dc(n),Pi(n,Ht,f)):((e.lanes&i)!==0&&(Lc(e,n),fr(n,null,null,i),ur()),f=e.memoizedState,m=n.memoizedState,f.parent!==s?(f={parent:s,cache:s},n.memoizedState=f,n.lanes===0&&(n.memoizedState=n.updateQueue.baseState=f),Pi(n,Ht,s)):(s=m.cache,Pi(n,Ht,s),s!==f.cache&&Mc(n,[Ht],i,!0))),Jt(e,n,n.pendingProps.children,i),n.child;case 29:throw n.pendingProps}throw Error(r(156,n.tag))}function Ni(e){e.flags|=4}function gu(e,n,i,s,f){if((n=(e.mode&32)!==0)&&(n=!1),n){if(e.flags|=16777216,(f&335544128)===f)if(e.stateNode.complete)e.flags|=8192;else if(op())e.flags|=8192;else throw Aa=zs,Rc}else e.flags&=-16777217}function jh(e,n){if(n.type!=="stylesheet"||(n.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!Qp(n))if(op())e.flags|=8192;else throw Aa=zs,Rc}function Xs(e,n){n!==null&&(e.flags|=4),e.flags&16384&&(n=e.tag!==22?je():536870912,e.lanes|=n,bl|=n)}function br(e,n){if(!Je)switch(e.tailMode){case"hidden":n=e.tail;for(var i=null;n!==null;)n.alternate!==null&&(i=n),n=n.sibling;i===null?e.tail=null:i.sibling=null;break;case"collapsed":i=e.tail;for(var s=null;i!==null;)i.alternate!==null&&(s=i),i=i.sibling;s===null?n||e.tail===null?e.tail=null:e.tail.sibling=null:s.sibling=null}}function St(e){var n=e.alternate!==null&&e.alternate.child===e.child,i=0,s=0;if(n)for(var f=e.child;f!==null;)i|=f.lanes|f.childLanes,s|=f.subtreeFlags&65011712,s|=f.flags&65011712,f.return=e,f=f.sibling;else for(f=e.child;f!==null;)i|=f.lanes|f.childLanes,s|=f.subtreeFlags,s|=f.flags,f.return=e,f=f.sibling;return e.subtreeFlags|=s,e.childLanes=i,n}function Uy(e,n,i){var s=n.pendingProps;switch(Nc(n),n.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return St(n),null;case 1:return St(n),null;case 3:return i=n.stateNode,s=null,e!==null&&(s=e.memoizedState.cache),n.memoizedState.cache!==s&&(n.flags|=2048),_i(Ht),qe(),i.pendingContext&&(i.context=i.pendingContext,i.pendingContext=null),(e===null||e.child===null)&&(al(n)?Ni(n):e===null||e.memoizedState.isDehydrated&&(n.flags&256)===0||(n.flags|=1024,kc())),St(n),null;case 26:var f=n.type,m=n.memoizedState;return e===null?(Ni(n),m!==null?(St(n),jh(n,m)):(St(n),gu(n,f,null,s,i))):m?m!==e.memoizedState?(Ni(n),St(n),jh(n,m)):(St(n),n.flags&=-16777217):(e=e.memoizedProps,e!==s&&Ni(n),St(n),gu(n,f,e,s,i)),null;case 27:if(Yt(n),i=xe.current,f=n.type,e!==null&&n.stateNode!=null)e.memoizedProps!==s&&Ni(n);else{if(!s){if(n.stateNode===null)throw Error(r(166));return St(n),null}e=ce.current,al(n)?pm(n):(e=qp(f,s,i),n.stateNode=e,Ni(n))}return St(n),null;case 5:if(Yt(n),f=n.type,e!==null&&n.stateNode!=null)e.memoizedProps!==s&&Ni(n);else{if(!s){if(n.stateNode===null)throw Error(r(166));return St(n),null}if(m=ce.current,al(n))pm(n);else{var y=uo(xe.current);switch(m){case 1:m=y.createElementNS("http://www.w3.org/2000/svg",f);break;case 2:m=y.createElementNS("http://www.w3.org/1998/Math/MathML",f);break;default:switch(f){case"svg":m=y.createElementNS("http://www.w3.org/2000/svg",f);break;case"math":m=y.createElementNS("http://www.w3.org/1998/Math/MathML",f);break;case"script":m=y.createElement("div"),m.innerHTML="<script><\/script>",m=m.removeChild(m.firstChild);break;case"select":m=typeof s.is=="string"?y.createElement("select",{is:s.is}):y.createElement("select"),s.multiple?m.multiple=!0:s.size&&(m.size=s.size);break;default:m=typeof s.is=="string"?y.createElement(f,{is:s.is}):y.createElement(f)}}m[Dt]=n,m[tn]=s;e:for(y=n.child;y!==null;){if(y.tag===5||y.tag===6)m.appendChild(y.stateNode);else if(y.tag!==4&&y.tag!==27&&y.child!==null){y.child.return=y,y=y.child;continue}if(y===n)break e;for(;y.sibling===null;){if(y.return===null||y.return===n)break e;y=y.return}y.sibling.return=y.return,y=y.sibling}n.stateNode=m;e:switch(Wt(m,f,s),f){case"button":case"input":case"select":case"textarea":s=!!s.autoFocus;break e;case"img":s=!0;break e;default:s=!1}s&&Ni(n)}}return St(n),gu(n,n.type,e===null?null:e.memoizedProps,n.pendingProps,i),null;case 6:if(e&&n.stateNode!=null)e.memoizedProps!==s&&Ni(n);else{if(typeof s!="string"&&n.stateNode===null)throw Error(r(166));if(e=xe.current,al(n)){if(e=n.stateNode,i=n.memoizedProps,s=null,f=Zt,f!==null)switch(f.tag){case 27:case 5:s=f.memoizedProps}e[Dt]=n,e=!!(e.nodeValue===i||s!==null&&s.suppressHydrationWarning===!0||zp(e.nodeValue,i)),e||Gi(n,!0)}else e=uo(e).createTextNode(s),e[Dt]=n,n.stateNode=e}return St(n),null;case 31:if(i=n.memoizedState,e===null||e.memoizedState!==null){if(s=al(n),i!==null){if(e===null){if(!s)throw Error(r(318));if(e=n.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(557));e[Dt]=n}else Sa(),(n.flags&128)===0&&(n.memoizedState=null),n.flags|=4;St(n),e=!1}else i=kc(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=i),e=!0;if(!e)return n.flags&256?(Cn(n),n):(Cn(n),null);if((n.flags&128)!==0)throw Error(r(558))}return St(n),null;case 13:if(s=n.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(f=al(n),s!==null&&s.dehydrated!==null){if(e===null){if(!f)throw Error(r(318));if(f=n.memoizedState,f=f!==null?f.dehydrated:null,!f)throw Error(r(317));f[Dt]=n}else Sa(),(n.flags&128)===0&&(n.memoizedState=null),n.flags|=4;St(n),f=!1}else f=kc(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=f),f=!0;if(!f)return n.flags&256?(Cn(n),n):(Cn(n),null)}return Cn(n),(n.flags&128)!==0?(n.lanes=i,n):(i=s!==null,e=e!==null&&e.memoizedState!==null,i&&(s=n.child,f=null,s.alternate!==null&&s.alternate.memoizedState!==null&&s.alternate.memoizedState.cachePool!==null&&(f=s.alternate.memoizedState.cachePool.pool),m=null,s.memoizedState!==null&&s.memoizedState.cachePool!==null&&(m=s.memoizedState.cachePool.pool),m!==f&&(s.flags|=2048)),i!==e&&i&&(n.child.flags|=8192),Xs(n,n.updateQueue),St(n),null);case 4:return qe(),e===null&&Iu(n.stateNode.containerInfo),St(n),null;case 10:return _i(n.type),St(n),null;case 19:if(B(jt),s=n.memoizedState,s===null)return St(n),null;if(f=(n.flags&128)!==0,m=s.rendering,m===null)if(f)br(s,!1);else{if(Ot!==0||e!==null&&(e.flags&128)!==0)for(e=n.child;e!==null;){if(m=js(e),m!==null){for(n.flags|=128,br(s,!1),e=m.updateQueue,n.updateQueue=e,Xs(n,e),n.subtreeFlags=0,e=i,i=n.child;i!==null;)um(i,e),i=i.sibling;return N(jt,jt.current&1|2),Je&&xi(n,s.treeForkCount),n.child}e=e.sibling}s.tail!==null&&Tt()>eo&&(n.flags|=128,f=!0,br(s,!1),n.lanes=4194304)}else{if(!f)if(e=js(m),e!==null){if(n.flags|=128,f=!0,e=e.updateQueue,n.updateQueue=e,Xs(n,e),br(s,!0),s.tail===null&&s.tailMode==="hidden"&&!m.alternate&&!Je)return St(n),null}else 2*Tt()-s.renderingStartTime>eo&&i!==536870912&&(n.flags|=128,f=!0,br(s,!1),n.lanes=4194304);s.isBackwards?(m.sibling=n.child,n.child=m):(e=s.last,e!==null?e.sibling=m:n.child=m,s.last=m)}return s.tail!==null?(e=s.tail,s.rendering=e,s.tail=e.sibling,s.renderingStartTime=Tt(),e.sibling=null,i=jt.current,N(jt,f?i&1|2:i&1),Je&&xi(n,s.treeForkCount),e):(St(n),null);case 22:case 23:return Cn(n),Uc(),s=n.memoizedState!==null,e!==null?e.memoizedState!==null!==s&&(n.flags|=8192):s&&(n.flags|=8192),s?(i&536870912)!==0&&(n.flags&128)===0&&(St(n),n.subtreeFlags&6&&(n.flags|=8192)):St(n),i=n.updateQueue,i!==null&&Xs(n,i.retryQueue),i=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(i=e.memoizedState.cachePool.pool),s=null,n.memoizedState!==null&&n.memoizedState.cachePool!==null&&(s=n.memoizedState.cachePool.pool),s!==i&&(n.flags|=2048),e!==null&&B(ka),null;case 24:return i=null,e!==null&&(i=e.memoizedState.cache),n.memoizedState.cache!==i&&(n.flags|=2048),_i(Ht),St(n),null;case 25:return null;case 30:return null}throw Error(r(156,n.tag))}function Hy(e,n){switch(Nc(n),n.tag){case 1:return e=n.flags,e&65536?(n.flags=e&-65537|128,n):null;case 3:return _i(Ht),qe(),e=n.flags,(e&65536)!==0&&(e&128)===0?(n.flags=e&-65537|128,n):null;case 26:case 27:case 5:return Yt(n),null;case 31:if(n.memoizedState!==null){if(Cn(n),n.alternate===null)throw Error(r(340));Sa()}return e=n.flags,e&65536?(n.flags=e&-65537|128,n):null;case 13:if(Cn(n),e=n.memoizedState,e!==null&&e.dehydrated!==null){if(n.alternate===null)throw Error(r(340));Sa()}return e=n.flags,e&65536?(n.flags=e&-65537|128,n):null;case 19:return B(jt),null;case 4:return qe(),null;case 10:return _i(n.type),null;case 22:case 23:return Cn(n),Uc(),e!==null&&B(ka),e=n.flags,e&65536?(n.flags=e&-65537|128,n):null;case 24:return _i(Ht),null;case 25:return null;default:return null}}function Bh(e,n){switch(Nc(n),n.tag){case 3:_i(Ht),qe();break;case 26:case 27:case 5:Yt(n);break;case 4:qe();break;case 31:n.memoizedState!==null&&Cn(n);break;case 13:Cn(n);break;case 19:B(jt);break;case 10:_i(n.type);break;case 22:case 23:Cn(n),Uc(),e!==null&&B(ka);break;case 24:_i(Ht)}}function xr(e,n){try{var i=n.updateQueue,s=i!==null?i.lastEffect:null;if(s!==null){var f=s.next;i=f;do{if((i.tag&e)===e){s=void 0;var m=i.create,y=i.inst;s=m(),y.destroy=s}i=i.next}while(i!==f)}}catch(E){ft(n,n.return,E)}}function Qi(e,n,i){try{var s=n.updateQueue,f=s!==null?s.lastEffect:null;if(f!==null){var m=f.next;s=m;do{if((s.tag&e)===e){var y=s.inst,E=y.destroy;if(E!==void 0){y.destroy=void 0,f=n;var z=i,G=E;try{G()}catch(Q){ft(f,z,Q)}}}s=s.next}while(s!==m)}}catch(Q){ft(n,n.return,Q)}}function Ih(e){var n=e.updateQueue;if(n!==null){var i=e.stateNode;try{Am(n,i)}catch(s){ft(e,e.return,s)}}}function Uh(e,n,i){i.props=Oa(e.type,e.memoizedProps),i.state=e.memoizedState;try{i.componentWillUnmount()}catch(s){ft(e,n,s)}}function yr(e,n){try{var i=e.ref;if(i!==null){switch(e.tag){case 26:case 27:case 5:var s=e.stateNode;break;case 30:s=e.stateNode;break;default:s=e.stateNode}typeof i=="function"?e.refCleanup=i(s):i.current=s}}catch(f){ft(e,n,f)}}function ai(e,n){var i=e.ref,s=e.refCleanup;if(i!==null)if(typeof s=="function")try{s()}catch(f){ft(e,n,f)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof i=="function")try{i(null)}catch(f){ft(e,n,f)}else i.current=null}function Hh(e){var n=e.type,i=e.memoizedProps,s=e.stateNode;try{e:switch(n){case"button":case"input":case"select":case"textarea":i.autoFocus&&s.focus();break e;case"img":i.src?s.src=i.src:i.srcSet&&(s.srcset=i.srcSet)}}catch(f){ft(e,e.return,f)}}function bu(e,n,i){try{var s=e.stateNode;o1(s,e.type,i,n),s[tn]=n}catch(f){ft(e,e.return,f)}}function Fh(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&aa(e.type)||e.tag===4}function xu(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||Fh(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&aa(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function yu(e,n,i){var s=e.tag;if(s===5||s===6)e=e.stateNode,n?(i.nodeType===9?i.body:i.nodeName==="HTML"?i.ownerDocument.body:i).insertBefore(e,n):(n=i.nodeType===9?i.body:i.nodeName==="HTML"?i.ownerDocument.body:i,n.appendChild(e),i=i._reactRootContainer,i!=null||n.onclick!==null||(n.onclick=ge));else if(s!==4&&(s===27&&aa(e.type)&&(i=e.stateNode,n=null),e=e.child,e!==null))for(yu(e,n,i),e=e.sibling;e!==null;)yu(e,n,i),e=e.sibling}function Zs(e,n,i){var s=e.tag;if(s===5||s===6)e=e.stateNode,n?i.insertBefore(e,n):i.appendChild(e);else if(s!==4&&(s===27&&aa(e.type)&&(i=e.stateNode),e=e.child,e!==null))for(Zs(e,n,i),e=e.sibling;e!==null;)Zs(e,n,i),e=e.sibling}function $h(e){var n=e.stateNode,i=e.memoizedProps;try{for(var s=e.type,f=n.attributes;f.length;)n.removeAttributeNode(f[0]);Wt(n,s,i),n[Dt]=e,n[tn]=i}catch(m){ft(e,e.return,m)}}var wi=!1,qt=!1,_u=!1,qh=typeof WeakSet=="function"?WeakSet:Set,Vt=null;function Fy(e,n){if(e=e.containerInfo,Fu=xo,e=tm(e),mc(e)){if("selectionStart"in e)var i={start:e.selectionStart,end:e.selectionEnd};else e:{i=(i=e.ownerDocument)&&i.defaultView||window;var s=i.getSelection&&i.getSelection();if(s&&s.rangeCount!==0){i=s.anchorNode;var f=s.anchorOffset,m=s.focusNode;s=s.focusOffset;try{i.nodeType,m.nodeType}catch{i=null;break e}var y=0,E=-1,z=-1,G=0,Q=0,te=e,P=null;t:for(;;){for(var V;te!==i||f!==0&&te.nodeType!==3||(E=y+f),te!==m||s!==0&&te.nodeType!==3||(z=y+s),te.nodeType===3&&(y+=te.nodeValue.length),(V=te.firstChild)!==null;)P=te,te=V;for(;;){if(te===e)break t;if(P===i&&++G===f&&(E=y),P===m&&++Q===s&&(z=y),(V=te.nextSibling)!==null)break;te=P,P=te.parentNode}te=V}i=E===-1||z===-1?null:{start:E,end:z}}else i=null}i=i||{start:0,end:0}}else i=null;for($u={focusedElem:e,selectionRange:i},xo=!1,Vt=n;Vt!==null;)if(n=Vt,e=n.child,(n.subtreeFlags&1028)!==0&&e!==null)e.return=n,Vt=e;else for(;Vt!==null;){switch(n=Vt,m=n.alternate,e=n.flags,n.tag){case 0:if((e&4)!==0&&(e=n.updateQueue,e=e!==null?e.events:null,e!==null))for(i=0;i<e.length;i++)f=e[i],f.ref.impl=f.nextImpl;break;case 11:case 15:break;case 1:if((e&1024)!==0&&m!==null){e=void 0,i=n,f=m.memoizedProps,m=m.memoizedState,s=i.stateNode;try{var _e=Oa(i.type,f);e=s.getSnapshotBeforeUpdate(_e,m),s.__reactInternalSnapshotBeforeUpdate=e}catch(Oe){ft(i,i.return,Oe)}}break;case 3:if((e&1024)!==0){if(e=n.stateNode.containerInfo,i=e.nodeType,i===9)Pu(e);else if(i===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":Pu(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(r(163))}if(e=n.sibling,e!==null){e.return=n.return,Vt=e;break}Vt=n.return}}function Gh(e,n,i){var s=i.flags;switch(i.tag){case 0:case 11:case 15:Ti(e,i),s&4&&xr(5,i);break;case 1:if(Ti(e,i),s&4)if(e=i.stateNode,n===null)try{e.componentDidMount()}catch(y){ft(i,i.return,y)}else{var f=Oa(i.type,n.memoizedProps);n=n.memoizedState;try{e.componentDidUpdate(f,n,e.__reactInternalSnapshotBeforeUpdate)}catch(y){ft(i,i.return,y)}}s&64&&Ih(i),s&512&&yr(i,i.return);break;case 3:if(Ti(e,i),s&64&&(e=i.updateQueue,e!==null)){if(n=null,i.child!==null)switch(i.child.tag){case 27:case 5:n=i.child.stateNode;break;case 1:n=i.child.stateNode}try{Am(e,n)}catch(y){ft(i,i.return,y)}}break;case 27:n===null&&s&4&&$h(i);case 26:case 5:Ti(e,i),n===null&&s&4&&Hh(i),s&512&&yr(i,i.return);break;case 12:Ti(e,i);break;case 31:Ti(e,i),s&4&&Vh(e,i);break;case 13:Ti(e,i),s&4&&Kh(e,i),s&64&&(e=i.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(i=Zy.bind(null,i),g1(e,i))));break;case 22:if(s=i.memoizedState!==null||wi,!s){n=n!==null&&n.memoizedState!==null||qt,f=wi;var m=qt;wi=s,(qt=n)&&!m?Ai(e,i,(i.subtreeFlags&8772)!==0):Ti(e,i),wi=f,qt=m}break;case 30:break;default:Ti(e,i)}}function Ph(e){var n=e.alternate;n!==null&&(e.alternate=null,Ph(n)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(n=e.stateNode,n!==null&&ql(n)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var wt=null,xn=!1;function ki(e,n,i){for(i=i.child;i!==null;)Yh(e,n,i),i=i.sibling}function Yh(e,n,i){if(Mt&&typeof Mt.onCommitFiberUnmount=="function")try{Mt.onCommitFiberUnmount(Kt,i)}catch{}switch(i.tag){case 26:qt||ai(i,n),ki(e,n,i),i.memoizedState?i.memoizedState.count--:i.stateNode&&(i=i.stateNode,i.parentNode.removeChild(i));break;case 27:qt||ai(i,n);var s=wt,f=xn;aa(i.type)&&(wt=i.stateNode,xn=!1),ki(e,n,i),Ar(i.stateNode),wt=s,xn=f;break;case 5:qt||ai(i,n);case 6:if(s=wt,f=xn,wt=null,ki(e,n,i),wt=s,xn=f,wt!==null)if(xn)try{(wt.nodeType===9?wt.body:wt.nodeName==="HTML"?wt.ownerDocument.body:wt).removeChild(i.stateNode)}catch(m){ft(i,n,m)}else try{wt.removeChild(i.stateNode)}catch(m){ft(i,n,m)}break;case 18:wt!==null&&(xn?(e=wt,Ip(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,i.stateNode),wl(e)):Ip(wt,i.stateNode));break;case 4:s=wt,f=xn,wt=i.stateNode.containerInfo,xn=!0,ki(e,n,i),wt=s,xn=f;break;case 0:case 11:case 14:case 15:Qi(2,i,n),qt||Qi(4,i,n),ki(e,n,i);break;case 1:qt||(ai(i,n),s=i.stateNode,typeof s.componentWillUnmount=="function"&&Uh(i,n,s)),ki(e,n,i);break;case 21:ki(e,n,i);break;case 22:qt=(s=qt)||i.memoizedState!==null,ki(e,n,i),qt=s;break;default:ki(e,n,i)}}function Vh(e,n){if(n.memoizedState===null&&(e=n.alternate,e!==null&&(e=e.memoizedState,e!==null))){e=e.dehydrated;try{wl(e)}catch(i){ft(n,n.return,i)}}}function Kh(e,n){if(n.memoizedState===null&&(e=n.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{wl(e)}catch(i){ft(n,n.return,i)}}function $y(e){switch(e.tag){case 31:case 13:case 19:var n=e.stateNode;return n===null&&(n=e.stateNode=new qh),n;case 22:return e=e.stateNode,n=e._retryCache,n===null&&(n=e._retryCache=new qh),n;default:throw Error(r(435,e.tag))}}function Qs(e,n){var i=$y(e);n.forEach(function(s){if(!i.has(s)){i.add(s);var f=Qy.bind(null,e,s);s.then(f,f)}})}function yn(e,n){var i=n.deletions;if(i!==null)for(var s=0;s<i.length;s++){var f=i[s],m=e,y=n,E=y;e:for(;E!==null;){switch(E.tag){case 27:if(aa(E.type)){wt=E.stateNode,xn=!1;break e}break;case 5:wt=E.stateNode,xn=!1;break e;case 3:case 4:wt=E.stateNode.containerInfo,xn=!0;break e}E=E.return}if(wt===null)throw Error(r(160));Yh(m,y,f),wt=null,xn=!1,m=f.alternate,m!==null&&(m.return=null),f.return=null}if(n.subtreeFlags&13886)for(n=n.child;n!==null;)Xh(n,e),n=n.sibling}var Xn=null;function Xh(e,n){var i=e.alternate,s=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:yn(n,e),_n(e),s&4&&(Qi(3,e,e.return),xr(3,e),Qi(5,e,e.return));break;case 1:yn(n,e),_n(e),s&512&&(qt||i===null||ai(i,i.return)),s&64&&wi&&(e=e.updateQueue,e!==null&&(s=e.callbacks,s!==null&&(i=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=i===null?s:i.concat(s))));break;case 26:var f=Xn;if(yn(n,e),_n(e),s&512&&(qt||i===null||ai(i,i.return)),s&4){var m=i!==null?i.memoizedState:null;if(s=e.memoizedState,i===null)if(s===null)if(e.stateNode===null){e:{s=e.type,i=e.memoizedProps,f=f.ownerDocument||f;t:switch(s){case"title":m=f.getElementsByTagName("title")[0],(!m||m[pa]||m[Dt]||m.namespaceURI==="http://www.w3.org/2000/svg"||m.hasAttribute("itemprop"))&&(m=f.createElement(s),f.head.insertBefore(m,f.querySelector("head > title"))),Wt(m,s,i),m[Dt]=e,It(m),s=m;break e;case"link":var y=Xp("link","href",f).get(s+(i.href||""));if(y){for(var E=0;E<y.length;E++)if(m=y[E],m.getAttribute("href")===(i.href==null||i.href===""?null:i.href)&&m.getAttribute("rel")===(i.rel==null?null:i.rel)&&m.getAttribute("title")===(i.title==null?null:i.title)&&m.getAttribute("crossorigin")===(i.crossOrigin==null?null:i.crossOrigin)){y.splice(E,1);break t}}m=f.createElement(s),Wt(m,s,i),f.head.appendChild(m);break;case"meta":if(y=Xp("meta","content",f).get(s+(i.content||""))){for(E=0;E<y.length;E++)if(m=y[E],m.getAttribute("content")===(i.content==null?null:""+i.content)&&m.getAttribute("name")===(i.name==null?null:i.name)&&m.getAttribute("property")===(i.property==null?null:i.property)&&m.getAttribute("http-equiv")===(i.httpEquiv==null?null:i.httpEquiv)&&m.getAttribute("charset")===(i.charSet==null?null:i.charSet)){y.splice(E,1);break t}}m=f.createElement(s),Wt(m,s,i),f.head.appendChild(m);break;default:throw Error(r(468,s))}m[Dt]=e,It(m),s=m}e.stateNode=s}else Zp(f,e.type,e.stateNode);else e.stateNode=Kp(f,s,e.memoizedProps);else m!==s?(m===null?i.stateNode!==null&&(i=i.stateNode,i.parentNode.removeChild(i)):m.count--,s===null?Zp(f,e.type,e.stateNode):Kp(f,s,e.memoizedProps)):s===null&&e.stateNode!==null&&bu(e,e.memoizedProps,i.memoizedProps)}break;case 27:yn(n,e),_n(e),s&512&&(qt||i===null||ai(i,i.return)),i!==null&&s&4&&bu(e,e.memoizedProps,i.memoizedProps);break;case 5:if(yn(n,e),_n(e),s&512&&(qt||i===null||ai(i,i.return)),e.flags&32){f=e.stateNode;try{ze(f,"")}catch(_e){ft(e,e.return,_e)}}s&4&&e.stateNode!=null&&(f=e.memoizedProps,bu(e,f,i!==null?i.memoizedProps:f)),s&1024&&(_u=!0);break;case 6:if(yn(n,e),_n(e),s&4){if(e.stateNode===null)throw Error(r(162));s=e.memoizedProps,i=e.stateNode;try{i.nodeValue=s}catch(_e){ft(e,e.return,_e)}}break;case 3:if(ho=null,f=Xn,Xn=fo(n.containerInfo),yn(n,e),Xn=f,_n(e),s&4&&i!==null&&i.memoizedState.isDehydrated)try{wl(n.containerInfo)}catch(_e){ft(e,e.return,_e)}_u&&(_u=!1,Zh(e));break;case 4:s=Xn,Xn=fo(e.stateNode.containerInfo),yn(n,e),_n(e),Xn=s;break;case 12:yn(n,e),_n(e);break;case 31:yn(n,e),_n(e),s&4&&(s=e.updateQueue,s!==null&&(e.updateQueue=null,Qs(e,s)));break;case 13:yn(n,e),_n(e),e.child.flags&8192&&e.memoizedState!==null!=(i!==null&&i.memoizedState!==null)&&(Ws=Tt()),s&4&&(s=e.updateQueue,s!==null&&(e.updateQueue=null,Qs(e,s)));break;case 22:f=e.memoizedState!==null;var z=i!==null&&i.memoizedState!==null,G=wi,Q=qt;if(wi=G||f,qt=Q||z,yn(n,e),qt=Q,wi=G,_n(e),s&8192)e:for(n=e.stateNode,n._visibility=f?n._visibility&-2:n._visibility|1,f&&(i===null||z||wi||qt||za(e)),i=null,n=e;;){if(n.tag===5||n.tag===26){if(i===null){z=i=n;try{if(m=z.stateNode,f)y=m.style,typeof y.setProperty=="function"?y.setProperty("display","none","important"):y.display="none";else{E=z.stateNode;var te=z.memoizedProps.style,P=te!=null&&te.hasOwnProperty("display")?te.display:null;E.style.display=P==null||typeof P=="boolean"?"":(""+P).trim()}}catch(_e){ft(z,z.return,_e)}}}else if(n.tag===6){if(i===null){z=n;try{z.stateNode.nodeValue=f?"":z.memoizedProps}catch(_e){ft(z,z.return,_e)}}}else if(n.tag===18){if(i===null){z=n;try{var V=z.stateNode;f?Up(V,!0):Up(z.stateNode,!1)}catch(_e){ft(z,z.return,_e)}}}else if((n.tag!==22&&n.tag!==23||n.memoizedState===null||n===e)&&n.child!==null){n.child.return=n,n=n.child;continue}if(n===e)break e;for(;n.sibling===null;){if(n.return===null||n.return===e)break e;i===n&&(i=null),n=n.return}i===n&&(i=null),n.sibling.return=n.return,n=n.sibling}s&4&&(s=e.updateQueue,s!==null&&(i=s.retryQueue,i!==null&&(s.retryQueue=null,Qs(e,i))));break;case 19:yn(n,e),_n(e),s&4&&(s=e.updateQueue,s!==null&&(e.updateQueue=null,Qs(e,s)));break;case 30:break;case 21:break;default:yn(n,e),_n(e)}}function _n(e){var n=e.flags;if(n&2){try{for(var i,s=e.return;s!==null;){if(Fh(s)){i=s;break}s=s.return}if(i==null)throw Error(r(160));switch(i.tag){case 27:var f=i.stateNode,m=xu(e);Zs(e,m,f);break;case 5:var y=i.stateNode;i.flags&32&&(ze(y,""),i.flags&=-33);var E=xu(e);Zs(e,E,y);break;case 3:case 4:var z=i.stateNode.containerInfo,G=xu(e);yu(e,G,z);break;default:throw Error(r(161))}}catch(Q){ft(e,e.return,Q)}e.flags&=-3}n&4096&&(e.flags&=-4097)}function Zh(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var n=e;Zh(n),n.tag===5&&n.flags&1024&&n.stateNode.reset(),e=e.sibling}}function Ti(e,n){if(n.subtreeFlags&8772)for(n=n.child;n!==null;)Gh(e,n.alternate,n),n=n.sibling}function za(e){for(e=e.child;e!==null;){var n=e;switch(n.tag){case 0:case 11:case 14:case 15:Qi(4,n,n.return),za(n);break;case 1:ai(n,n.return);var i=n.stateNode;typeof i.componentWillUnmount=="function"&&Uh(n,n.return,i),za(n);break;case 27:Ar(n.stateNode);case 26:case 5:ai(n,n.return),za(n);break;case 22:n.memoizedState===null&&za(n);break;case 30:za(n);break;default:za(n)}e=e.sibling}}function Ai(e,n,i){for(i=i&&(n.subtreeFlags&8772)!==0,n=n.child;n!==null;){var s=n.alternate,f=e,m=n,y=m.flags;switch(m.tag){case 0:case 11:case 15:Ai(f,m,i),xr(4,m);break;case 1:if(Ai(f,m,i),s=m,f=s.stateNode,typeof f.componentDidMount=="function")try{f.componentDidMount()}catch(G){ft(s,s.return,G)}if(s=m,f=s.updateQueue,f!==null){var E=s.stateNode;try{var z=f.shared.hiddenCallbacks;if(z!==null)for(f.shared.hiddenCallbacks=null,f=0;f<z.length;f++)Tm(z[f],E)}catch(G){ft(s,s.return,G)}}i&&y&64&&Ih(m),yr(m,m.return);break;case 27:$h(m);case 26:case 5:Ai(f,m,i),i&&s===null&&y&4&&Hh(m),yr(m,m.return);break;case 12:Ai(f,m,i);break;case 31:Ai(f,m,i),i&&y&4&&Vh(f,m);break;case 13:Ai(f,m,i),i&&y&4&&Kh(f,m);break;case 22:m.memoizedState===null&&Ai(f,m,i),yr(m,m.return);break;case 30:break;default:Ai(f,m,i)}n=n.sibling}}function vu(e,n){var i=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(i=e.memoizedState.cachePool.pool),e=null,n.memoizedState!==null&&n.memoizedState.cachePool!==null&&(e=n.memoizedState.cachePool.pool),e!==i&&(e!=null&&e.refCount++,i!=null&&lr(i))}function Eu(e,n){e=null,n.alternate!==null&&(e=n.alternate.memoizedState.cache),n=n.memoizedState.cache,n!==e&&(n.refCount++,e!=null&&lr(e))}function Zn(e,n,i,s){if(n.subtreeFlags&10256)for(n=n.child;n!==null;)Qh(e,n,i,s),n=n.sibling}function Qh(e,n,i,s){var f=n.flags;switch(n.tag){case 0:case 11:case 15:Zn(e,n,i,s),f&2048&&xr(9,n);break;case 1:Zn(e,n,i,s);break;case 3:Zn(e,n,i,s),f&2048&&(e=null,n.alternate!==null&&(e=n.alternate.memoizedState.cache),n=n.memoizedState.cache,n!==e&&(n.refCount++,e!=null&&lr(e)));break;case 12:if(f&2048){Zn(e,n,i,s),e=n.stateNode;try{var m=n.memoizedProps,y=m.id,E=m.onPostCommit;typeof E=="function"&&E(y,n.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(z){ft(n,n.return,z)}}else Zn(e,n,i,s);break;case 31:Zn(e,n,i,s);break;case 13:Zn(e,n,i,s);break;case 23:break;case 22:m=n.stateNode,y=n.alternate,n.memoizedState!==null?m._visibility&2?Zn(e,n,i,s):_r(e,n):m._visibility&2?Zn(e,n,i,s):(m._visibility|=2,hl(e,n,i,s,(n.subtreeFlags&10256)!==0||!1)),f&2048&&vu(y,n);break;case 24:Zn(e,n,i,s),f&2048&&Eu(n.alternate,n);break;default:Zn(e,n,i,s)}}function hl(e,n,i,s,f){for(f=f&&((n.subtreeFlags&10256)!==0||!1),n=n.child;n!==null;){var m=e,y=n,E=i,z=s,G=y.flags;switch(y.tag){case 0:case 11:case 15:hl(m,y,E,z,f),xr(8,y);break;case 23:break;case 22:var Q=y.stateNode;y.memoizedState!==null?Q._visibility&2?hl(m,y,E,z,f):_r(m,y):(Q._visibility|=2,hl(m,y,E,z,f)),f&&G&2048&&vu(y.alternate,y);break;case 24:hl(m,y,E,z,f),f&&G&2048&&Eu(y.alternate,y);break;default:hl(m,y,E,z,f)}n=n.sibling}}function _r(e,n){if(n.subtreeFlags&10256)for(n=n.child;n!==null;){var i=e,s=n,f=s.flags;switch(s.tag){case 22:_r(i,s),f&2048&&vu(s.alternate,s);break;case 24:_r(i,s),f&2048&&Eu(s.alternate,s);break;default:_r(i,s)}n=n.sibling}}var vr=8192;function pl(e,n,i){if(e.subtreeFlags&vr)for(e=e.child;e!==null;)Jh(e,n,i),e=e.sibling}function Jh(e,n,i){switch(e.tag){case 26:pl(e,n,i),e.flags&vr&&e.memoizedState!==null&&A1(i,Xn,e.memoizedState,e.memoizedProps);break;case 5:pl(e,n,i);break;case 3:case 4:var s=Xn;Xn=fo(e.stateNode.containerInfo),pl(e,n,i),Xn=s;break;case 22:e.memoizedState===null&&(s=e.alternate,s!==null&&s.memoizedState!==null?(s=vr,vr=16777216,pl(e,n,i),vr=s):pl(e,n,i));break;default:pl(e,n,i)}}function Wh(e){var n=e.alternate;if(n!==null&&(e=n.child,e!==null)){n.child=null;do n=e.sibling,e.sibling=null,e=n;while(e!==null)}}function Er(e){var n=e.deletions;if((e.flags&16)!==0){if(n!==null)for(var i=0;i<n.length;i++){var s=n[i];Vt=s,tp(s,e)}Wh(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)ep(e),e=e.sibling}function ep(e){switch(e.tag){case 0:case 11:case 15:Er(e),e.flags&2048&&Qi(9,e,e.return);break;case 3:Er(e);break;case 12:Er(e);break;case 22:var n=e.stateNode;e.memoizedState!==null&&n._visibility&2&&(e.return===null||e.return.tag!==13)?(n._visibility&=-3,Js(e)):Er(e);break;default:Er(e)}}function Js(e){var n=e.deletions;if((e.flags&16)!==0){if(n!==null)for(var i=0;i<n.length;i++){var s=n[i];Vt=s,tp(s,e)}Wh(e)}for(e=e.child;e!==null;){switch(n=e,n.tag){case 0:case 11:case 15:Qi(8,n,n.return),Js(n);break;case 22:i=n.stateNode,i._visibility&2&&(i._visibility&=-3,Js(n));break;default:Js(n)}e=e.sibling}}function tp(e,n){for(;Vt!==null;){var i=Vt;switch(i.tag){case 0:case 11:case 15:Qi(8,i,n);break;case 23:case 22:if(i.memoizedState!==null&&i.memoizedState.cachePool!==null){var s=i.memoizedState.cachePool.pool;s!=null&&s.refCount++}break;case 24:lr(i.memoizedState.cache)}if(s=i.child,s!==null)s.return=i,Vt=s;else e:for(i=e;Vt!==null;){s=Vt;var f=s.sibling,m=s.return;if(Ph(s),s===i){Vt=null;break e}if(f!==null){f.return=m,Vt=f;break e}Vt=m}}}var qy={getCacheForType:function(e){var n=Qt(Ht),i=n.data.get(e);return i===void 0&&(i=e(),n.data.set(e,i)),i},cacheSignal:function(){return Qt(Ht).controller.signal}},Gy=typeof WeakMap=="function"?WeakMap:Map,at=0,bt=null,Ye=null,Ze=0,ut=0,On=null,Ji=!1,gl=!1,Su=!1,Mi=0,Ot=0,Wi=0,Ra=0,Nu=0,zn=0,bl=0,Sr=null,vn=null,wu=!1,Ws=0,np=0,eo=1/0,to=null,ea=null,Pt=0,ta=null,xl=null,Ci=0,ku=0,Tu=null,ip=null,Nr=0,Au=null;function Rn(){return(at&2)!==0&&Ze!==0?Ze&-Ze:C.T!==null?Du():Ga()}function ap(){if(zn===0)if((Ze&536870912)===0||Je){var e=qa;qa<<=1,(qa&3932160)===0&&(qa=262144),zn=e}else zn=536870912;return e=Mn.current,e!==null&&(e.flags|=32),zn}function En(e,n,i){(e===bt&&(ut===2||ut===9)||e.cancelPendingCommit!==null)&&(yl(e,0),na(e,Ze,zn,!1)),gt(e,i),((at&2)===0||e!==bt)&&(e===bt&&((at&2)===0&&(Ra|=i),Ot===4&&na(e,Ze,zn,!1)),li(e))}function lp(e,n,i){if((at&6)!==0)throw Error(r(327));var s=!i&&(n&127)===0&&(n&e.expiredLanes)===0||J(e,n),f=s?Vy(e,n):Cu(e,n,!0),m=s;do{if(f===0){gl&&!s&&na(e,n,0,!1);break}else{if(i=e.current.alternate,m&&!Py(i)){f=Cu(e,n,!1),m=!1;continue}if(f===2){if(m=n,e.errorRecoveryDisabledLanes&m)var y=0;else y=e.pendingLanes&-536870913,y=y!==0?y:y&536870912?536870912:0;if(y!==0){n=y;e:{var E=e;f=Sr;var z=E.current.memoizedState.isDehydrated;if(z&&(yl(E,y).flags|=256),y=Cu(E,y,!1),y!==2){if(Su&&!z){E.errorRecoveryDisabledLanes|=m,Ra|=m,f=4;break e}m=vn,vn=f,m!==null&&(vn===null?vn=m:vn.push.apply(vn,m))}f=y}if(m=!1,f!==2)continue}}if(f===1){yl(e,0),na(e,n,0,!0);break}e:{switch(s=e,m=f,m){case 0:case 1:throw Error(r(345));case 4:if((n&4194048)!==n)break;case 6:na(s,n,zn,!Ji);break e;case 2:vn=null;break;case 3:case 5:break;default:throw Error(r(329))}if((n&62914560)===n&&(f=Ws+300-Tt(),10<f)){if(na(s,n,zn,!Ji),D(s,0,!0)!==0)break e;Ci=n,s.timeoutHandle=jp(rp.bind(null,s,i,vn,to,wu,n,zn,Ra,bl,Ji,m,"Throttled",-0,0),f);break e}rp(s,i,vn,to,wu,n,zn,Ra,bl,Ji,m,null,-0,0)}}break}while(!0);li(e)}function rp(e,n,i,s,f,m,y,E,z,G,Q,te,P,V){if(e.timeoutHandle=-1,te=n.subtreeFlags,te&8192||(te&16785408)===16785408){te={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:ge},Jh(n,m,te);var _e=(m&62914560)===m?Ws-Tt():(m&4194048)===m?np-Tt():0;if(_e=M1(te,_e),_e!==null){Ci=m,e.cancelPendingCommit=_e(hp.bind(null,e,n,m,i,s,f,y,E,z,Q,te,null,P,V)),na(e,m,y,!G);return}}hp(e,n,m,i,s,f,y,E,z)}function Py(e){for(var n=e;;){var i=n.tag;if((i===0||i===11||i===15)&&n.flags&16384&&(i=n.updateQueue,i!==null&&(i=i.stores,i!==null)))for(var s=0;s<i.length;s++){var f=i[s],m=f.getSnapshot;f=f.value;try{if(!Tn(m(),f))return!1}catch{return!1}}if(i=n.child,n.subtreeFlags&16384&&i!==null)i.return=n,n=i;else{if(n===e)break;for(;n.sibling===null;){if(n.return===null||n.return===e)return!0;n=n.return}n.sibling.return=n.return,n=n.sibling}}return!0}function na(e,n,i,s){n&=~Nu,n&=~Ra,e.suspendedLanes|=n,e.pingedLanes&=~n,s&&(e.warmLanes|=n),s=e.expirationTimes;for(var f=n;0<f;){var m=31-st(f),y=1<<m;s[m]=-1,f&=~y}i!==0&&ye(e,i,n)}function no(){return(at&6)===0?(wr(0),!1):!0}function Mu(){if(Ye!==null){if(ut===0)var e=Ye.return;else e=Ye,yi=Na=null,Pc(e),cl=null,sr=0,e=Ye;for(;e!==null;)Bh(e.alternate,e),e=e.return;Ye=null}}function yl(e,n){var i=e.timeoutHandle;i!==-1&&(e.timeoutHandle=-1,f1(i)),i=e.cancelPendingCommit,i!==null&&(e.cancelPendingCommit=null,i()),Ci=0,Mu(),bt=e,Ye=i=bi(e.current,null),Ze=n,ut=0,On=null,Ji=!1,gl=J(e,n),Su=!1,bl=zn=Nu=Ra=Wi=Ot=0,vn=Sr=null,wu=!1,(n&8)!==0&&(n|=n&32);var s=e.entangledLanes;if(s!==0)for(e=e.entanglements,s&=n;0<s;){var f=31-st(s),m=1<<f;n|=e[f],s&=~m}return Mi=n,Ss(),i}function sp(e,n){He=null,C.H=pr,n===ol||n===Os?(n=Sm(),ut=3):n===Rc?(n=Sm(),ut=4):ut=n===su?8:n!==null&&typeof n=="object"&&typeof n.then=="function"?6:1,On=n,Ye===null&&(Ot=1,Ps(e,Un(n,e.current)))}function op(){var e=Mn.current;return e===null?!0:(Ze&4194048)===Ze?qn===null:(Ze&62914560)===Ze||(Ze&536870912)!==0?e===qn:!1}function cp(){var e=C.H;return C.H=pr,e===null?pr:e}function up(){var e=C.A;return C.A=qy,e}function io(){Ot=4,Ji||(Ze&4194048)!==Ze&&Mn.current!==null||(gl=!0),(Wi&134217727)===0&&(Ra&134217727)===0||bt===null||na(bt,Ze,zn,!1)}function Cu(e,n,i){var s=at;at|=2;var f=cp(),m=up();(bt!==e||Ze!==n)&&(to=null,yl(e,n)),n=!1;var y=Ot;e:do try{if(ut!==0&&Ye!==null){var E=Ye,z=On;switch(ut){case 8:Mu(),y=6;break e;case 3:case 2:case 9:case 6:Mn.current===null&&(n=!0);var G=ut;if(ut=0,On=null,_l(e,E,z,G),i&&gl){y=0;break e}break;default:G=ut,ut=0,On=null,_l(e,E,z,G)}}Yy(),y=Ot;break}catch(Q){sp(e,Q)}while(!0);return n&&e.shellSuspendCounter++,yi=Na=null,at=s,C.H=f,C.A=m,Ye===null&&(bt=null,Ze=0,Ss()),y}function Yy(){for(;Ye!==null;)fp(Ye)}function Vy(e,n){var i=at;at|=2;var s=cp(),f=up();bt!==e||Ze!==n?(to=null,eo=Tt()+500,yl(e,n)):gl=J(e,n);e:do try{if(ut!==0&&Ye!==null){n=Ye;var m=On;t:switch(ut){case 1:ut=0,On=null,_l(e,n,m,1);break;case 2:case 9:if(vm(m)){ut=0,On=null,dp(n);break}n=function(){ut!==2&&ut!==9||bt!==e||(ut=7),li(e)},m.then(n,n);break e;case 3:ut=7;break e;case 4:ut=5;break e;case 7:vm(m)?(ut=0,On=null,dp(n)):(ut=0,On=null,_l(e,n,m,7));break;case 5:var y=null;switch(Ye.tag){case 26:y=Ye.memoizedState;case 5:case 27:var E=Ye;if(y?Qp(y):E.stateNode.complete){ut=0,On=null;var z=E.sibling;if(z!==null)Ye=z;else{var G=E.return;G!==null?(Ye=G,ao(G)):Ye=null}break t}}ut=0,On=null,_l(e,n,m,5);break;case 6:ut=0,On=null,_l(e,n,m,6);break;case 8:Mu(),Ot=6;break e;default:throw Error(r(462))}}Ky();break}catch(Q){sp(e,Q)}while(!0);return yi=Na=null,C.H=s,C.A=f,at=i,Ye!==null?0:(bt=null,Ze=0,Ss(),Ot)}function Ky(){for(;Ye!==null&&!Wn();)fp(Ye)}function fp(e){var n=Lh(e.alternate,e,Mi);e.memoizedProps=e.pendingProps,n===null?ao(e):Ye=n}function dp(e){var n=e,i=n.alternate;switch(n.tag){case 15:case 0:n=Mh(i,n,n.pendingProps,n.type,void 0,Ze);break;case 11:n=Mh(i,n,n.pendingProps,n.type.render,n.ref,Ze);break;case 5:Pc(n);default:Bh(i,n),n=Ye=um(n,Mi),n=Lh(i,n,Mi)}e.memoizedProps=e.pendingProps,n===null?ao(e):Ye=n}function _l(e,n,i,s){yi=Na=null,Pc(n),cl=null,sr=0;var f=n.return;try{if(jy(e,f,n,i,Ze)){Ot=1,Ps(e,Un(i,e.current)),Ye=null;return}}catch(m){if(f!==null)throw Ye=f,m;Ot=1,Ps(e,Un(i,e.current)),Ye=null;return}n.flags&32768?(Je||s===1?e=!0:gl||(Ze&536870912)!==0?e=!1:(Ji=e=!0,(s===2||s===9||s===3||s===6)&&(s=Mn.current,s!==null&&s.tag===13&&(s.flags|=16384))),mp(n,e)):ao(n)}function ao(e){var n=e;do{if((n.flags&32768)!==0){mp(n,Ji);return}e=n.return;var i=Uy(n.alternate,n,Mi);if(i!==null){Ye=i;return}if(n=n.sibling,n!==null){Ye=n;return}Ye=n=e}while(n!==null);Ot===0&&(Ot=5)}function mp(e,n){do{var i=Hy(e.alternate,e);if(i!==null){i.flags&=32767,Ye=i;return}if(i=e.return,i!==null&&(i.flags|=32768,i.subtreeFlags=0,i.deletions=null),!n&&(e=e.sibling,e!==null)){Ye=e;return}Ye=e=i}while(e!==null);Ot=6,Ye=null}function hp(e,n,i,s,f,m,y,E,z){e.cancelPendingCommit=null;do lo();while(Pt!==0);if((at&6)!==0)throw Error(r(327));if(n!==null){if(n===e.current)throw Error(r(177));if(m=n.lanes|n.childLanes,m|=xc,Ee(e,i,m,y,E,z),e===bt&&(Ye=bt=null,Ze=0),xl=n,ta=e,Ci=i,ku=m,Tu=f,ip=s,(n.subtreeFlags&10256)!==0||(n.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,Jy(Ce,function(){return yp(),null})):(e.callbackNode=null,e.callbackPriority=0),s=(n.flags&13878)!==0,(n.subtreeFlags&13878)!==0||s){s=C.T,C.T=null,f=K.p,K.p=2,y=at,at|=4;try{Fy(e,n,i)}finally{at=y,K.p=f,C.T=s}}Pt=1,pp(),gp(),bp()}}function pp(){if(Pt===1){Pt=0;var e=ta,n=xl,i=(n.flags&13878)!==0;if((n.subtreeFlags&13878)!==0||i){i=C.T,C.T=null;var s=K.p;K.p=2;var f=at;at|=4;try{Xh(n,e);var m=$u,y=tm(e.containerInfo),E=m.focusedElem,z=m.selectionRange;if(y!==E&&E&&E.ownerDocument&&em(E.ownerDocument.documentElement,E)){if(z!==null&&mc(E)){var G=z.start,Q=z.end;if(Q===void 0&&(Q=G),"selectionStart"in E)E.selectionStart=G,E.selectionEnd=Math.min(Q,E.value.length);else{var te=E.ownerDocument||document,P=te&&te.defaultView||window;if(P.getSelection){var V=P.getSelection(),_e=E.textContent.length,Oe=Math.min(z.start,_e),ht=z.end===void 0?Oe:Math.min(z.end,_e);!V.extend&&Oe>ht&&(y=ht,ht=Oe,Oe=y);var I=Wd(E,Oe),j=Wd(E,ht);if(I&&j&&(V.rangeCount!==1||V.anchorNode!==I.node||V.anchorOffset!==I.offset||V.focusNode!==j.node||V.focusOffset!==j.offset)){var $=te.createRange();$.setStart(I.node,I.offset),V.removeAllRanges(),Oe>ht?(V.addRange($),V.extend(j.node,j.offset)):($.setEnd(j.node,j.offset),V.addRange($))}}}}for(te=[],V=E;V=V.parentNode;)V.nodeType===1&&te.push({element:V,left:V.scrollLeft,top:V.scrollTop});for(typeof E.focus=="function"&&E.focus(),E=0;E<te.length;E++){var ee=te[E];ee.element.scrollLeft=ee.left,ee.element.scrollTop=ee.top}}xo=!!Fu,$u=Fu=null}finally{at=f,K.p=s,C.T=i}}e.current=n,Pt=2}}function gp(){if(Pt===2){Pt=0;var e=ta,n=xl,i=(n.flags&8772)!==0;if((n.subtreeFlags&8772)!==0||i){i=C.T,C.T=null;var s=K.p;K.p=2;var f=at;at|=4;try{Gh(e,n.alternate,n)}finally{at=f,K.p=s,C.T=i}}Pt=3}}function bp(){if(Pt===4||Pt===3){Pt=0,Fa();var e=ta,n=xl,i=Ci,s=ip;(n.subtreeFlags&10256)!==0||(n.flags&10256)!==0?Pt=5:(Pt=0,xl=ta=null,xp(e,e.pendingLanes));var f=e.pendingLanes;if(f===0&&(ea=null),di(i),n=n.stateNode,Mt&&typeof Mt.onCommitFiberRoot=="function")try{Mt.onCommitFiberRoot(Kt,n,void 0,(n.current.flags&128)===128)}catch{}if(s!==null){n=C.T,f=K.p,K.p=2,C.T=null;try{for(var m=e.onRecoverableError,y=0;y<s.length;y++){var E=s[y];m(E.value,{componentStack:E.stack})}}finally{C.T=n,K.p=f}}(Ci&3)!==0&&lo(),li(e),f=e.pendingLanes,(i&261930)!==0&&(f&42)!==0?e===Au?Nr++:(Nr=0,Au=e):Nr=0,wr(0)}}function xp(e,n){(e.pooledCacheLanes&=n)===0&&(n=e.pooledCache,n!=null&&(e.pooledCache=null,lr(n)))}function lo(){return pp(),gp(),bp(),yp()}function yp(){if(Pt!==5)return!1;var e=ta,n=ku;ku=0;var i=di(Ci),s=C.T,f=K.p;try{K.p=32>i?32:i,C.T=null,i=Tu,Tu=null;var m=ta,y=Ci;if(Pt=0,xl=ta=null,Ci=0,(at&6)!==0)throw Error(r(331));var E=at;if(at|=4,ep(m.current),Qh(m,m.current,y,i),at=E,wr(0,!1),Mt&&typeof Mt.onPostCommitFiberRoot=="function")try{Mt.onPostCommitFiberRoot(Kt,m)}catch{}return!0}finally{K.p=f,C.T=s,xp(e,n)}}function _p(e,n,i){n=Un(i,n),n=ru(e.stateNode,n,2),e=Ki(e,n,2),e!==null&&(gt(e,2),li(e))}function ft(e,n,i){if(e.tag===3)_p(e,e,i);else for(;n!==null;){if(n.tag===3){_p(n,e,i);break}else if(n.tag===1){var s=n.stateNode;if(typeof n.type.getDerivedStateFromError=="function"||typeof s.componentDidCatch=="function"&&(ea===null||!ea.has(s))){e=Un(i,e),i=vh(2),s=Ki(n,i,2),s!==null&&(Eh(i,s,n,e),gt(s,2),li(s));break}}n=n.return}}function Ou(e,n,i){var s=e.pingCache;if(s===null){s=e.pingCache=new Gy;var f=new Set;s.set(n,f)}else f=s.get(n),f===void 0&&(f=new Set,s.set(n,f));f.has(i)||(Su=!0,f.add(i),e=Xy.bind(null,e,n,i),n.then(e,e))}function Xy(e,n,i){var s=e.pingCache;s!==null&&s.delete(n),e.pingedLanes|=e.suspendedLanes&i,e.warmLanes&=~i,bt===e&&(Ze&i)===i&&(Ot===4||Ot===3&&(Ze&62914560)===Ze&&300>Tt()-Ws?(at&2)===0&&yl(e,0):Nu|=i,bl===Ze&&(bl=0)),li(e)}function vp(e,n){n===0&&(n=je()),e=va(e,n),e!==null&&(gt(e,n),li(e))}function Zy(e){var n=e.memoizedState,i=0;n!==null&&(i=n.retryLane),vp(e,i)}function Qy(e,n){var i=0;switch(e.tag){case 31:case 13:var s=e.stateNode,f=e.memoizedState;f!==null&&(i=f.retryLane);break;case 19:s=e.stateNode;break;case 22:s=e.stateNode._retryCache;break;default:throw Error(r(314))}s!==null&&s.delete(n),vp(e,i)}function Jy(e,n){return rt(e,n)}var ro=null,vl=null,zu=!1,so=!1,Ru=!1,ia=0;function li(e){e!==vl&&e.next===null&&(vl===null?ro=vl=e:vl=vl.next=e),so=!0,zu||(zu=!0,e1())}function wr(e,n){if(!Ru&&so){Ru=!0;do for(var i=!1,s=ro;s!==null;){if(e!==0){var f=s.pendingLanes;if(f===0)var m=0;else{var y=s.suspendedLanes,E=s.pingedLanes;m=(1<<31-st(42|e)+1)-1,m&=f&~(y&~E),m=m&201326741?m&201326741|1:m?m|2:0}m!==0&&(i=!0,wp(s,m))}else m=Ze,m=D(s,s===bt?m:0,s.cancelPendingCommit!==null||s.timeoutHandle!==-1),(m&3)===0||J(s,m)||(i=!0,wp(s,m));s=s.next}while(i);Ru=!1}}function Wy(){Ep()}function Ep(){so=zu=!1;var e=0;ia!==0&&u1()&&(e=ia);for(var n=Tt(),i=null,s=ro;s!==null;){var f=s.next,m=Sp(s,n);m===0?(s.next=null,i===null?ro=f:i.next=f,f===null&&(vl=i)):(i=s,(e!==0||(m&3)!==0)&&(so=!0)),s=f}Pt!==0&&Pt!==5||wr(e),ia!==0&&(ia=0)}function Sp(e,n){for(var i=e.suspendedLanes,s=e.pingedLanes,f=e.expirationTimes,m=e.pendingLanes&-62914561;0<m;){var y=31-st(m),E=1<<y,z=f[y];z===-1?((E&i)===0||(E&s)!==0)&&(f[y]=be(E,n)):z<=n&&(e.expiredLanes|=E),m&=~E}if(n=bt,i=Ze,i=D(e,e===n?i:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),s=e.callbackNode,i===0||e===n&&(ut===2||ut===9)||e.cancelPendingCommit!==null)return s!==null&&s!==null&&kt(s),e.callbackNode=null,e.callbackPriority=0;if((i&3)===0||J(e,i)){if(n=i&-i,n===e.callbackPriority)return n;switch(s!==null&&kt(s),di(i)){case 2:case 8:i=me;break;case 32:i=Ce;break;case 268435456:i=tt;break;default:i=Ce}return s=Np.bind(null,e),i=rt(i,s),e.callbackPriority=n,e.callbackNode=i,n}return s!==null&&s!==null&&kt(s),e.callbackPriority=2,e.callbackNode=null,2}function Np(e,n){if(Pt!==0&&Pt!==5)return e.callbackNode=null,e.callbackPriority=0,null;var i=e.callbackNode;if(lo()&&e.callbackNode!==i)return null;var s=Ze;return s=D(e,e===bt?s:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),s===0?null:(lp(e,s,n),Sp(e,Tt()),e.callbackNode!=null&&e.callbackNode===i?Np.bind(null,e):null)}function wp(e,n){if(lo())return null;lp(e,n,!0)}function e1(){d1(function(){(at&6)!==0?rt(Z,Wy):Ep()})}function Du(){if(ia===0){var e=rl;e===0&&(e=ma,ma<<=1,(ma&261888)===0&&(ma=256)),ia=e}return ia}function kp(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:Hi(""+e)}function Tp(e,n){var i=n.ownerDocument.createElement("input");return i.name=n.name,i.value=n.value,e.id&&i.setAttribute("form",e.id),n.parentNode.insertBefore(i,n),e=new FormData(e),i.parentNode.removeChild(i),e}function t1(e,n,i,s,f){if(n==="submit"&&i&&i.stateNode===f){var m=kp((f[tn]||null).action),y=s.submitter;y&&(n=(n=y[tn]||null)?kp(n.formAction):y.getAttribute("formAction"),n!==null&&(m=n,y=null));var E=new ys("action","action",null,s,f);e.push({event:E,listeners:[{instance:null,listener:function(){if(s.defaultPrevented){if(ia!==0){var z=y?Tp(f,y):new FormData(f);eu(i,{pending:!0,data:z,method:f.method,action:m},null,z)}}else typeof m=="function"&&(E.preventDefault(),z=y?Tp(f,y):new FormData(f),eu(i,{pending:!0,data:z,method:f.method,action:m},m,z))},currentTarget:f}]})}}for(var Lu=0;Lu<bc.length;Lu++){var ju=bc[Lu],n1=ju.toLowerCase(),i1=ju[0].toUpperCase()+ju.slice(1);Kn(n1,"on"+i1)}Kn(am,"onAnimationEnd"),Kn(lm,"onAnimationIteration"),Kn(rm,"onAnimationStart"),Kn("dblclick","onDoubleClick"),Kn("focusin","onFocus"),Kn("focusout","onBlur"),Kn(yy,"onTransitionRun"),Kn(_y,"onTransitionStart"),Kn(vy,"onTransitionCancel"),Kn(sm,"onTransitionEnd"),ue("onMouseEnter",["mouseout","mouseover"]),ue("onMouseLeave",["mouseout","mouseover"]),ue("onPointerEnter",["pointerout","pointerover"]),ue("onPointerLeave",["pointerout","pointerover"]),hi("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),hi("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),hi("onBeforeInput",["compositionend","keypress","textInput","paste"]),hi("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),hi("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),hi("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var kr="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),a1=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(kr));function Ap(e,n){n=(n&4)!==0;for(var i=0;i<e.length;i++){var s=e[i],f=s.event;s=s.listeners;e:{var m=void 0;if(n)for(var y=s.length-1;0<=y;y--){var E=s[y],z=E.instance,G=E.currentTarget;if(E=E.listener,z!==m&&f.isPropagationStopped())break e;m=E,f.currentTarget=G;try{m(f)}catch(Q){Es(Q)}f.currentTarget=null,m=z}else for(y=0;y<s.length;y++){if(E=s[y],z=E.instance,G=E.currentTarget,E=E.listener,z!==m&&f.isPropagationStopped())break e;m=E,f.currentTarget=G;try{m(f)}catch(Q){Es(Q)}f.currentTarget=null,m=z}}}}function Ve(e,n){var i=n[$l];i===void 0&&(i=n[$l]=new Set);var s=e+"__bubble";i.has(s)||(Mp(n,e,2,!1),i.add(s))}function Bu(e,n,i){var s=0;n&&(s|=4),Mp(i,e,s,n)}var oo="_reactListening"+Math.random().toString(36).slice(2);function Iu(e){if(!e[oo]){e[oo]=!0,fs.forEach(function(i){i!=="selectionchange"&&(a1.has(i)||Bu(i,!1,e),Bu(i,!0,e))});var n=e.nodeType===9?e:e.ownerDocument;n===null||n[oo]||(n[oo]=!0,Bu("selectionchange",!1,n))}}function Mp(e,n,i,s){switch(ag(n)){case 2:var f=z1;break;case 8:f=R1;break;default:f=Wu}i=f.bind(null,n,i,e),f=void 0,!ac||n!=="touchstart"&&n!=="touchmove"&&n!=="wheel"||(f=!0),s?f!==void 0?e.addEventListener(n,i,{capture:!0,passive:f}):e.addEventListener(n,i,!0):f!==void 0?e.addEventListener(n,i,{passive:f}):e.addEventListener(n,i,!1)}function Uu(e,n,i,s,f){var m=s;if((n&1)===0&&(n&2)===0&&s!==null)e:for(;;){if(s===null)return;var y=s.tag;if(y===3||y===4){var E=s.stateNode.containerInfo;if(E===f)break;if(y===4)for(y=s.return;y!==null;){var z=y.tag;if((z===3||z===4)&&y.stateNode.containerInfo===f)return;y=y.return}for(;E!==null;){if(y=cn(E),y===null)return;if(z=y.tag,z===5||z===6||z===26||z===27){s=m=y;continue e}E=E.parentNode}}s=s.return}ps(function(){var G=m,Q=Ue(i),te=[];e:{var P=om.get(e);if(P!==void 0){var V=ys,_e=e;switch(e){case"keypress":if(bs(i)===0)break e;case"keydown":case"keyup":V=Qx;break;case"focusin":_e="focus",V=oc;break;case"focusout":_e="blur",V=oc;break;case"beforeblur":case"afterblur":V=oc;break;case"click":if(i.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":V=Bd;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":V=Ux;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":V=ey;break;case am:case lm:case rm:V=$x;break;case sm:V=ny;break;case"scroll":case"scrollend":V=Bx;break;case"wheel":V=ay;break;case"copy":case"cut":case"paste":V=Gx;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":V=Ud;break;case"toggle":case"beforetoggle":V=ry}var Oe=(n&4)!==0,ht=!Oe&&(e==="scroll"||e==="scrollend"),I=Oe?P!==null?P+"Capture":null:P;Oe=[];for(var j=G,$;j!==null;){var ee=j;if($=ee.stateNode,ee=ee.tag,ee!==5&&ee!==26&&ee!==27||$===null||I===null||(ee=Kl(j,I),ee!=null&&Oe.push(Tr(j,ee,$))),ht)break;j=j.return}0<Oe.length&&(P=new V(P,_e,null,i,Q),te.push({event:P,listeners:Oe}))}}if((n&7)===0){e:{if(P=e==="mouseover"||e==="pointerover",V=e==="mouseout"||e==="pointerout",P&&i!==Se&&(_e=i.relatedTarget||i.fromElement)&&(cn(_e)||_e[ji]))break e;if((V||P)&&(P=Q.window===Q?Q:(P=Q.ownerDocument)?P.defaultView||P.parentWindow:window,V?(_e=i.relatedTarget||i.toElement,V=G,_e=_e?cn(_e):null,_e!==null&&(ht=u(_e),Oe=_e.tag,_e!==ht||Oe!==5&&Oe!==27&&Oe!==6)&&(_e=null)):(V=null,_e=G),V!==_e)){if(Oe=Bd,ee="onMouseLeave",I="onMouseEnter",j="mouse",(e==="pointerout"||e==="pointerover")&&(Oe=Ud,ee="onPointerLeave",I="onPointerEnter",j="pointer"),ht=V==null?P:Bi(V),$=_e==null?P:Bi(_e),P=new Oe(ee,j+"leave",V,i,Q),P.target=ht,P.relatedTarget=$,ee=null,cn(Q)===G&&(Oe=new Oe(I,j+"enter",_e,i,Q),Oe.target=$,Oe.relatedTarget=ht,ee=Oe),ht=ee,V&&_e)t:{for(Oe=l1,I=V,j=_e,$=0,ee=I;ee;ee=Oe(ee))$++;ee=0;for(var Te=j;Te;Te=Oe(Te))ee++;for(;0<$-ee;)I=Oe(I),$--;for(;0<ee-$;)j=Oe(j),ee--;for(;$--;){if(I===j||j!==null&&I===j.alternate){Oe=I;break t}I=Oe(I),j=Oe(j)}Oe=null}else Oe=null;V!==null&&Cp(te,P,V,Oe,!1),_e!==null&&ht!==null&&Cp(te,ht,_e,Oe,!0)}}e:{if(P=G?Bi(G):window,V=P.nodeName&&P.nodeName.toLowerCase(),V==="select"||V==="input"&&P.type==="file")var nt=Vd;else if(Pd(P))if(Kd)nt=gy;else{nt=hy;var Ne=my}else V=P.nodeName,!V||V.toLowerCase()!=="input"||P.type!=="checkbox"&&P.type!=="radio"?G&&Ui(G.elementType)&&(nt=Vd):nt=py;if(nt&&(nt=nt(e,G))){Yd(te,nt,i,Q);break e}Ne&&Ne(e,P,G),e==="focusout"&&G&&P.type==="number"&&G.memoizedProps.value!=null&&Xa(P,"number",P.value)}switch(Ne=G?Bi(G):window,e){case"focusin":(Pd(Ne)||Ne.contentEditable==="true")&&(Ja=Ne,hc=G,nr=null);break;case"focusout":nr=hc=Ja=null;break;case"mousedown":pc=!0;break;case"contextmenu":case"mouseup":case"dragend":pc=!1,nm(te,i,Q);break;case"selectionchange":if(xy)break;case"keydown":case"keyup":nm(te,i,Q)}var Fe;if(uc)e:{switch(e){case"compositionstart":var Qe="onCompositionStart";break e;case"compositionend":Qe="onCompositionEnd";break e;case"compositionupdate":Qe="onCompositionUpdate";break e}Qe=void 0}else Qa?qd(e,i)&&(Qe="onCompositionEnd"):e==="keydown"&&i.keyCode===229&&(Qe="onCompositionStart");Qe&&(Hd&&i.locale!=="ko"&&(Qa||Qe!=="onCompositionStart"?Qe==="onCompositionEnd"&&Qa&&(Fe=Ld()):(Fi=Q,lc="value"in Fi?Fi.value:Fi.textContent,Qa=!0)),Ne=co(G,Qe),0<Ne.length&&(Qe=new Id(Qe,e,null,i,Q),te.push({event:Qe,listeners:Ne}),Fe?Qe.data=Fe:(Fe=Gd(i),Fe!==null&&(Qe.data=Fe)))),(Fe=oy?cy(e,i):uy(e,i))&&(Qe=co(G,"onBeforeInput"),0<Qe.length&&(Ne=new Id("onBeforeInput","beforeinput",null,i,Q),te.push({event:Ne,listeners:Qe}),Ne.data=Fe)),t1(te,e,G,i,Q)}Ap(te,n)})}function Tr(e,n,i){return{instance:e,listener:n,currentTarget:i}}function co(e,n){for(var i=n+"Capture",s=[];e!==null;){var f=e,m=f.stateNode;if(f=f.tag,f!==5&&f!==26&&f!==27||m===null||(f=Kl(e,i),f!=null&&s.unshift(Tr(e,f,m)),f=Kl(e,n),f!=null&&s.push(Tr(e,f,m))),e.tag===3)return s;e=e.return}return[]}function l1(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function Cp(e,n,i,s,f){for(var m=n._reactName,y=[];i!==null&&i!==s;){var E=i,z=E.alternate,G=E.stateNode;if(E=E.tag,z!==null&&z===s)break;E!==5&&E!==26&&E!==27||G===null||(z=G,f?(G=Kl(i,m),G!=null&&y.unshift(Tr(i,G,z))):f||(G=Kl(i,m),G!=null&&y.push(Tr(i,G,z)))),i=i.return}y.length!==0&&e.push({event:n,listeners:y})}var r1=/\r\n?/g,s1=/\u0000|\uFFFD/g;function Op(e){return(typeof e=="string"?e:""+e).replace(r1,`
`).replace(s1,"")}function zp(e,n){return n=Op(n),Op(e)===n}function mt(e,n,i,s,f,m){switch(i){case"children":typeof s=="string"?n==="body"||n==="textarea"&&s===""||ze(e,s):(typeof s=="number"||typeof s=="bigint")&&n!=="body"&&ze(e,""+s);break;case"className":wn(e,"class",s);break;case"tabIndex":wn(e,"tabindex",s);break;case"dir":case"role":case"viewBox":case"width":case"height":wn(e,i,s);break;case"style":ct(e,s,m);break;case"data":if(n!=="object"){wn(e,"data",s);break}case"src":case"href":if(s===""&&(n!=="a"||i!=="href")){e.removeAttribute(i);break}if(s==null||typeof s=="function"||typeof s=="symbol"||typeof s=="boolean"){e.removeAttribute(i);break}s=Hi(""+s),e.setAttribute(i,s);break;case"action":case"formAction":if(typeof s=="function"){e.setAttribute(i,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof m=="function"&&(i==="formAction"?(n!=="input"&&mt(e,n,"name",f.name,f,null),mt(e,n,"formEncType",f.formEncType,f,null),mt(e,n,"formMethod",f.formMethod,f,null),mt(e,n,"formTarget",f.formTarget,f,null)):(mt(e,n,"encType",f.encType,f,null),mt(e,n,"method",f.method,f,null),mt(e,n,"target",f.target,f,null)));if(s==null||typeof s=="symbol"||typeof s=="boolean"){e.removeAttribute(i);break}s=Hi(""+s),e.setAttribute(i,s);break;case"onClick":s!=null&&(e.onclick=ge);break;case"onScroll":s!=null&&Ve("scroll",e);break;case"onScrollEnd":s!=null&&Ve("scrollend",e);break;case"dangerouslySetInnerHTML":if(s!=null){if(typeof s!="object"||!("__html"in s))throw Error(r(61));if(i=s.__html,i!=null){if(f.children!=null)throw Error(r(60));e.innerHTML=i}}break;case"multiple":e.multiple=s&&typeof s!="function"&&typeof s!="symbol";break;case"muted":e.muted=s&&typeof s!="function"&&typeof s!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(s==null||typeof s=="function"||typeof s=="boolean"||typeof s=="symbol"){e.removeAttribute("xlink:href");break}i=Hi(""+s),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",i);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":s!=null&&typeof s!="function"&&typeof s!="symbol"?e.setAttribute(i,""+s):e.removeAttribute(i);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":s&&typeof s!="function"&&typeof s!="symbol"?e.setAttribute(i,""):e.removeAttribute(i);break;case"capture":case"download":s===!0?e.setAttribute(i,""):s!==!1&&s!=null&&typeof s!="function"&&typeof s!="symbol"?e.setAttribute(i,s):e.removeAttribute(i);break;case"cols":case"rows":case"size":case"span":s!=null&&typeof s!="function"&&typeof s!="symbol"&&!isNaN(s)&&1<=s?e.setAttribute(i,s):e.removeAttribute(i);break;case"rowSpan":case"start":s==null||typeof s=="function"||typeof s=="symbol"||isNaN(s)?e.removeAttribute(i):e.setAttribute(i,s);break;case"popover":Ve("beforetoggle",e),Ve("toggle",e),nn(e,"popover",s);break;case"xlinkActuate":pn(e,"http://www.w3.org/1999/xlink","xlink:actuate",s);break;case"xlinkArcrole":pn(e,"http://www.w3.org/1999/xlink","xlink:arcrole",s);break;case"xlinkRole":pn(e,"http://www.w3.org/1999/xlink","xlink:role",s);break;case"xlinkShow":pn(e,"http://www.w3.org/1999/xlink","xlink:show",s);break;case"xlinkTitle":pn(e,"http://www.w3.org/1999/xlink","xlink:title",s);break;case"xlinkType":pn(e,"http://www.w3.org/1999/xlink","xlink:type",s);break;case"xmlBase":pn(e,"http://www.w3.org/XML/1998/namespace","xml:base",s);break;case"xmlLang":pn(e,"http://www.w3.org/XML/1998/namespace","xml:lang",s);break;case"xmlSpace":pn(e,"http://www.w3.org/XML/1998/namespace","xml:space",s);break;case"is":nn(e,"is",s);break;case"innerText":case"textContent":break;default:(!(2<i.length)||i[0]!=="o"&&i[0]!=="O"||i[1]!=="n"&&i[1]!=="N")&&(i=pi.get(i)||i,nn(e,i,s))}}function Hu(e,n,i,s,f,m){switch(i){case"style":ct(e,s,m);break;case"dangerouslySetInnerHTML":if(s!=null){if(typeof s!="object"||!("__html"in s))throw Error(r(61));if(i=s.__html,i!=null){if(f.children!=null)throw Error(r(60));e.innerHTML=i}}break;case"children":typeof s=="string"?ze(e,s):(typeof s=="number"||typeof s=="bigint")&&ze(e,""+s);break;case"onScroll":s!=null&&Ve("scroll",e);break;case"onScrollEnd":s!=null&&Ve("scrollend",e);break;case"onClick":s!=null&&(e.onclick=ge);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!ga.hasOwnProperty(i))e:{if(i[0]==="o"&&i[1]==="n"&&(f=i.endsWith("Capture"),n=i.slice(2,f?i.length-7:void 0),m=e[tn]||null,m=m!=null?m[i]:null,typeof m=="function"&&e.removeEventListener(n,m,f),typeof s=="function")){typeof m!="function"&&m!==null&&(i in e?e[i]=null:e.hasAttribute(i)&&e.removeAttribute(i)),e.addEventListener(n,s,f);break e}i in e?e[i]=s:s===!0?e.setAttribute(i,""):nn(e,i,s)}}}function Wt(e,n,i){switch(n){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Ve("error",e),Ve("load",e);var s=!1,f=!1,m;for(m in i)if(i.hasOwnProperty(m)){var y=i[m];if(y!=null)switch(m){case"src":s=!0;break;case"srcSet":f=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,n));default:mt(e,n,m,y,i,null)}}f&&mt(e,n,"srcSet",i.srcSet,i,null),s&&mt(e,n,"src",i.src,i,null);return;case"input":Ve("invalid",e);var E=m=y=f=null,z=null,G=null;for(s in i)if(i.hasOwnProperty(s)){var Q=i[s];if(Q!=null)switch(s){case"name":f=Q;break;case"type":y=Q;break;case"checked":z=Q;break;case"defaultChecked":G=Q;break;case"value":m=Q;break;case"defaultValue":E=Q;break;case"children":case"dangerouslySetInnerHTML":if(Q!=null)throw Error(r(137,n));break;default:mt(e,n,s,Q,i,null)}}ba(e,m,E,z,G,y,f,!1);return;case"select":Ve("invalid",e),s=y=m=null;for(f in i)if(i.hasOwnProperty(f)&&(E=i[f],E!=null))switch(f){case"value":m=E;break;case"defaultValue":y=E;break;case"multiple":s=E;default:mt(e,n,f,E,i,null)}n=m,i=y,e.multiple=!!s,n!=null?Xt(e,!!s,n,!1):i!=null&&Xt(e,!!s,i,!0);return;case"textarea":Ve("invalid",e),m=f=s=null;for(y in i)if(i.hasOwnProperty(y)&&(E=i[y],E!=null))switch(y){case"value":s=E;break;case"defaultValue":f=E;break;case"children":m=E;break;case"dangerouslySetInnerHTML":if(E!=null)throw Error(r(91));break;default:mt(e,n,y,E,i,null)}Za(e,s,f,m);return;case"option":for(z in i)if(i.hasOwnProperty(z)&&(s=i[z],s!=null))switch(z){case"selected":e.selected=s&&typeof s!="function"&&typeof s!="symbol";break;default:mt(e,n,z,s,i,null)}return;case"dialog":Ve("beforetoggle",e),Ve("toggle",e),Ve("cancel",e),Ve("close",e);break;case"iframe":case"object":Ve("load",e);break;case"video":case"audio":for(s=0;s<kr.length;s++)Ve(kr[s],e);break;case"image":Ve("error",e),Ve("load",e);break;case"details":Ve("toggle",e);break;case"embed":case"source":case"link":Ve("error",e),Ve("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(G in i)if(i.hasOwnProperty(G)&&(s=i[G],s!=null))switch(G){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,n));default:mt(e,n,G,s,i,null)}return;default:if(Ui(n)){for(Q in i)i.hasOwnProperty(Q)&&(s=i[Q],s!==void 0&&Hu(e,n,Q,s,i,void 0));return}}for(E in i)i.hasOwnProperty(E)&&(s=i[E],s!=null&&mt(e,n,E,s,i,null))}function o1(e,n,i,s){switch(n){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var f=null,m=null,y=null,E=null,z=null,G=null,Q=null;for(V in i){var te=i[V];if(i.hasOwnProperty(V)&&te!=null)switch(V){case"checked":break;case"value":break;case"defaultValue":z=te;default:s.hasOwnProperty(V)||mt(e,n,V,null,s,te)}}for(var P in s){var V=s[P];if(te=i[P],s.hasOwnProperty(P)&&(V!=null||te!=null))switch(P){case"type":m=V;break;case"name":f=V;break;case"checked":G=V;break;case"defaultChecked":Q=V;break;case"value":y=V;break;case"defaultValue":E=V;break;case"children":case"dangerouslySetInnerHTML":if(V!=null)throw Error(r(137,n));break;default:V!==te&&mt(e,n,P,V,s,te)}}Pl(e,y,E,z,G,Q,m,f);return;case"select":V=y=E=P=null;for(m in i)if(z=i[m],i.hasOwnProperty(m)&&z!=null)switch(m){case"value":break;case"multiple":V=z;default:s.hasOwnProperty(m)||mt(e,n,m,null,s,z)}for(f in s)if(m=s[f],z=i[f],s.hasOwnProperty(f)&&(m!=null||z!=null))switch(f){case"value":P=m;break;case"defaultValue":E=m;break;case"multiple":y=m;default:m!==z&&mt(e,n,f,m,s,z)}n=E,i=y,s=V,P!=null?Xt(e,!!i,P,!1):!!s!=!!i&&(n!=null?Xt(e,!!i,n,!0):Xt(e,!!i,i?[]:"",!1));return;case"textarea":V=P=null;for(E in i)if(f=i[E],i.hasOwnProperty(E)&&f!=null&&!s.hasOwnProperty(E))switch(E){case"value":break;case"children":break;default:mt(e,n,E,null,s,f)}for(y in s)if(f=s[y],m=i[y],s.hasOwnProperty(y)&&(f!=null||m!=null))switch(y){case"value":P=f;break;case"defaultValue":V=f;break;case"children":break;case"dangerouslySetInnerHTML":if(f!=null)throw Error(r(91));break;default:f!==m&&mt(e,n,y,f,s,m)}ms(e,P,V);return;case"option":for(var _e in i)if(P=i[_e],i.hasOwnProperty(_e)&&P!=null&&!s.hasOwnProperty(_e))switch(_e){case"selected":e.selected=!1;break;default:mt(e,n,_e,null,s,P)}for(z in s)if(P=s[z],V=i[z],s.hasOwnProperty(z)&&P!==V&&(P!=null||V!=null))switch(z){case"selected":e.selected=P&&typeof P!="function"&&typeof P!="symbol";break;default:mt(e,n,z,P,s,V)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var Oe in i)P=i[Oe],i.hasOwnProperty(Oe)&&P!=null&&!s.hasOwnProperty(Oe)&&mt(e,n,Oe,null,s,P);for(G in s)if(P=s[G],V=i[G],s.hasOwnProperty(G)&&P!==V&&(P!=null||V!=null))switch(G){case"children":case"dangerouslySetInnerHTML":if(P!=null)throw Error(r(137,n));break;default:mt(e,n,G,P,s,V)}return;default:if(Ui(n)){for(var ht in i)P=i[ht],i.hasOwnProperty(ht)&&P!==void 0&&!s.hasOwnProperty(ht)&&Hu(e,n,ht,void 0,s,P);for(Q in s)P=s[Q],V=i[Q],!s.hasOwnProperty(Q)||P===V||P===void 0&&V===void 0||Hu(e,n,Q,P,s,V);return}}for(var I in i)P=i[I],i.hasOwnProperty(I)&&P!=null&&!s.hasOwnProperty(I)&&mt(e,n,I,null,s,P);for(te in s)P=s[te],V=i[te],!s.hasOwnProperty(te)||P===V||P==null&&V==null||mt(e,n,te,P,s,V)}function Rp(e){switch(e){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function c1(){if(typeof performance.getEntriesByType=="function"){for(var e=0,n=0,i=performance.getEntriesByType("resource"),s=0;s<i.length;s++){var f=i[s],m=f.transferSize,y=f.initiatorType,E=f.duration;if(m&&E&&Rp(y)){for(y=0,E=f.responseEnd,s+=1;s<i.length;s++){var z=i[s],G=z.startTime;if(G>E)break;var Q=z.transferSize,te=z.initiatorType;Q&&Rp(te)&&(z=z.responseEnd,y+=Q*(z<E?1:(E-G)/(z-G)))}if(--s,n+=8*(m+y)/(f.duration/1e3),e++,10<e)break}}if(0<e)return n/e/1e6}return navigator.connection&&(e=navigator.connection.downlink,typeof e=="number")?e:5}var Fu=null,$u=null;function uo(e){return e.nodeType===9?e:e.ownerDocument}function Dp(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Lp(e,n){if(e===0)switch(n){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&n==="foreignObject"?0:e}function qu(e,n){return e==="textarea"||e==="noscript"||typeof n.children=="string"||typeof n.children=="number"||typeof n.children=="bigint"||typeof n.dangerouslySetInnerHTML=="object"&&n.dangerouslySetInnerHTML!==null&&n.dangerouslySetInnerHTML.__html!=null}var Gu=null;function u1(){var e=window.event;return e&&e.type==="popstate"?e===Gu?!1:(Gu=e,!0):(Gu=null,!1)}var jp=typeof setTimeout=="function"?setTimeout:void 0,f1=typeof clearTimeout=="function"?clearTimeout:void 0,Bp=typeof Promise=="function"?Promise:void 0,d1=typeof queueMicrotask=="function"?queueMicrotask:typeof Bp<"u"?function(e){return Bp.resolve(null).then(e).catch(m1)}:jp;function m1(e){setTimeout(function(){throw e})}function aa(e){return e==="head"}function Ip(e,n){var i=n,s=0;do{var f=i.nextSibling;if(e.removeChild(i),f&&f.nodeType===8)if(i=f.data,i==="/$"||i==="/&"){if(s===0){e.removeChild(f),wl(n);return}s--}else if(i==="$"||i==="$?"||i==="$~"||i==="$!"||i==="&")s++;else if(i==="html")Ar(e.ownerDocument.documentElement);else if(i==="head"){i=e.ownerDocument.head,Ar(i);for(var m=i.firstChild;m;){var y=m.nextSibling,E=m.nodeName;m[pa]||E==="SCRIPT"||E==="STYLE"||E==="LINK"&&m.rel.toLowerCase()==="stylesheet"||i.removeChild(m),m=y}}else i==="body"&&Ar(e.ownerDocument.body);i=f}while(i);wl(n)}function Up(e,n){var i=e;e=0;do{var s=i.nextSibling;if(i.nodeType===1?n?(i._stashedDisplay=i.style.display,i.style.display="none"):(i.style.display=i._stashedDisplay||"",i.getAttribute("style")===""&&i.removeAttribute("style")):i.nodeType===3&&(n?(i._stashedText=i.nodeValue,i.nodeValue=""):i.nodeValue=i._stashedText||""),s&&s.nodeType===8)if(i=s.data,i==="/$"){if(e===0)break;e--}else i!=="$"&&i!=="$?"&&i!=="$~"&&i!=="$!"||e++;i=s}while(i)}function Pu(e){var n=e.firstChild;for(n&&n.nodeType===10&&(n=n.nextSibling);n;){var i=n;switch(n=n.nextSibling,i.nodeName){case"HTML":case"HEAD":case"BODY":Pu(i),ql(i);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(i.rel.toLowerCase()==="stylesheet")continue}e.removeChild(i)}}function h1(e,n,i,s){for(;e.nodeType===1;){var f=i;if(e.nodeName.toLowerCase()!==n.toLowerCase()){if(!s&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(s){if(!e[pa])switch(n){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(m=e.getAttribute("rel"),m==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(m!==f.rel||e.getAttribute("href")!==(f.href==null||f.href===""?null:f.href)||e.getAttribute("crossorigin")!==(f.crossOrigin==null?null:f.crossOrigin)||e.getAttribute("title")!==(f.title==null?null:f.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(m=e.getAttribute("src"),(m!==(f.src==null?null:f.src)||e.getAttribute("type")!==(f.type==null?null:f.type)||e.getAttribute("crossorigin")!==(f.crossOrigin==null?null:f.crossOrigin))&&m&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(n==="input"&&e.type==="hidden"){var m=f.name==null?null:""+f.name;if(f.type==="hidden"&&e.getAttribute("name")===m)return e}else return e;if(e=Gn(e.nextSibling),e===null)break}return null}function p1(e,n,i){if(n==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!i||(e=Gn(e.nextSibling),e===null))return null;return e}function Hp(e,n){for(;e.nodeType!==8;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!n||(e=Gn(e.nextSibling),e===null))return null;return e}function Yu(e){return e.data==="$?"||e.data==="$~"}function Vu(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState!=="loading"}function g1(e,n){var i=e.ownerDocument;if(e.data==="$~")e._reactRetry=n;else if(e.data!=="$?"||i.readyState!=="loading")n();else{var s=function(){n(),i.removeEventListener("DOMContentLoaded",s)};i.addEventListener("DOMContentLoaded",s),e._reactRetry=s}}function Gn(e){for(;e!=null;e=e.nextSibling){var n=e.nodeType;if(n===1||n===3)break;if(n===8){if(n=e.data,n==="$"||n==="$!"||n==="$?"||n==="$~"||n==="&"||n==="F!"||n==="F")break;if(n==="/$"||n==="/&")return null}}return e}var Ku=null;function Fp(e){e=e.nextSibling;for(var n=0;e;){if(e.nodeType===8){var i=e.data;if(i==="/$"||i==="/&"){if(n===0)return Gn(e.nextSibling);n--}else i!=="$"&&i!=="$!"&&i!=="$?"&&i!=="$~"&&i!=="&"||n++}e=e.nextSibling}return null}function $p(e){e=e.previousSibling;for(var n=0;e;){if(e.nodeType===8){var i=e.data;if(i==="$"||i==="$!"||i==="$?"||i==="$~"||i==="&"){if(n===0)return e;n--}else i!=="/$"&&i!=="/&"||n++}e=e.previousSibling}return null}function qp(e,n,i){switch(n=uo(i),e){case"html":if(e=n.documentElement,!e)throw Error(r(452));return e;case"head":if(e=n.head,!e)throw Error(r(453));return e;case"body":if(e=n.body,!e)throw Error(r(454));return e;default:throw Error(r(451))}}function Ar(e){for(var n=e.attributes;n.length;)e.removeAttributeNode(n[0]);ql(e)}var Pn=new Map,Gp=new Set;function fo(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var Oi=K.d;K.d={f:b1,r:x1,D:y1,C:_1,L:v1,m:E1,X:N1,S:S1,M:w1};function b1(){var e=Oi.f(),n=no();return e||n}function x1(e){var n=mi(e);n!==null&&n.tag===5&&n.type==="form"?sh(n):Oi.r(e)}var El=typeof document>"u"?null:document;function Pp(e,n,i){var s=El;if(s&&typeof n=="string"&&n){var f=gn(n);f='link[rel="'+e+'"][href="'+f+'"]',typeof i=="string"&&(f+='[crossorigin="'+i+'"]'),Gp.has(f)||(Gp.add(f),e={rel:e,crossOrigin:i,href:n},s.querySelector(f)===null&&(n=s.createElement("link"),Wt(n,"link",e),It(n),s.head.appendChild(n)))}}function y1(e){Oi.D(e),Pp("dns-prefetch",e,null)}function _1(e,n){Oi.C(e,n),Pp("preconnect",e,n)}function v1(e,n,i){Oi.L(e,n,i);var s=El;if(s&&e&&n){var f='link[rel="preload"][as="'+gn(n)+'"]';n==="image"&&i&&i.imageSrcSet?(f+='[imagesrcset="'+gn(i.imageSrcSet)+'"]',typeof i.imageSizes=="string"&&(f+='[imagesizes="'+gn(i.imageSizes)+'"]')):f+='[href="'+gn(e)+'"]';var m=f;switch(n){case"style":m=Sl(e);break;case"script":m=Nl(e)}Pn.has(m)||(e=x({rel:"preload",href:n==="image"&&i&&i.imageSrcSet?void 0:e,as:n},i),Pn.set(m,e),s.querySelector(f)!==null||n==="style"&&s.querySelector(Mr(m))||n==="script"&&s.querySelector(Cr(m))||(n=s.createElement("link"),Wt(n,"link",e),It(n),s.head.appendChild(n)))}}function E1(e,n){Oi.m(e,n);var i=El;if(i&&e){var s=n&&typeof n.as=="string"?n.as:"script",f='link[rel="modulepreload"][as="'+gn(s)+'"][href="'+gn(e)+'"]',m=f;switch(s){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":m=Nl(e)}if(!Pn.has(m)&&(e=x({rel:"modulepreload",href:e},n),Pn.set(m,e),i.querySelector(f)===null)){switch(s){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(i.querySelector(Cr(m)))return}s=i.createElement("link"),Wt(s,"link",e),It(s),i.head.appendChild(s)}}}function S1(e,n,i){Oi.S(e,n,i);var s=El;if(s&&e){var f=Ii(s).hoistableStyles,m=Sl(e);n=n||"default";var y=f.get(m);if(!y){var E={loading:0,preload:null};if(y=s.querySelector(Mr(m)))E.loading=5;else{e=x({rel:"stylesheet",href:e,"data-precedence":n},i),(i=Pn.get(m))&&Xu(e,i);var z=y=s.createElement("link");It(z),Wt(z,"link",e),z._p=new Promise(function(G,Q){z.onload=G,z.onerror=Q}),z.addEventListener("load",function(){E.loading|=1}),z.addEventListener("error",function(){E.loading|=2}),E.loading|=4,mo(y,n,s)}y={type:"stylesheet",instance:y,count:1,state:E},f.set(m,y)}}}function N1(e,n){Oi.X(e,n);var i=El;if(i&&e){var s=Ii(i).hoistableScripts,f=Nl(e),m=s.get(f);m||(m=i.querySelector(Cr(f)),m||(e=x({src:e,async:!0},n),(n=Pn.get(f))&&Zu(e,n),m=i.createElement("script"),It(m),Wt(m,"link",e),i.head.appendChild(m)),m={type:"script",instance:m,count:1,state:null},s.set(f,m))}}function w1(e,n){Oi.M(e,n);var i=El;if(i&&e){var s=Ii(i).hoistableScripts,f=Nl(e),m=s.get(f);m||(m=i.querySelector(Cr(f)),m||(e=x({src:e,async:!0,type:"module"},n),(n=Pn.get(f))&&Zu(e,n),m=i.createElement("script"),It(m),Wt(m,"link",e),i.head.appendChild(m)),m={type:"script",instance:m,count:1,state:null},s.set(f,m))}}function Yp(e,n,i,s){var f=(f=xe.current)?fo(f):null;if(!f)throw Error(r(446));switch(e){case"meta":case"title":return null;case"style":return typeof i.precedence=="string"&&typeof i.href=="string"?(n=Sl(i.href),i=Ii(f).hoistableStyles,s=i.get(n),s||(s={type:"style",instance:null,count:0,state:null},i.set(n,s)),s):{type:"void",instance:null,count:0,state:null};case"link":if(i.rel==="stylesheet"&&typeof i.href=="string"&&typeof i.precedence=="string"){e=Sl(i.href);var m=Ii(f).hoistableStyles,y=m.get(e);if(y||(f=f.ownerDocument||f,y={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},m.set(e,y),(m=f.querySelector(Mr(e)))&&!m._p&&(y.instance=m,y.state.loading=5),Pn.has(e)||(i={rel:"preload",as:"style",href:i.href,crossOrigin:i.crossOrigin,integrity:i.integrity,media:i.media,hrefLang:i.hrefLang,referrerPolicy:i.referrerPolicy},Pn.set(e,i),m||k1(f,e,i,y.state))),n&&s===null)throw Error(r(528,""));return y}if(n&&s!==null)throw Error(r(529,""));return null;case"script":return n=i.async,i=i.src,typeof i=="string"&&n&&typeof n!="function"&&typeof n!="symbol"?(n=Nl(i),i=Ii(f).hoistableScripts,s=i.get(n),s||(s={type:"script",instance:null,count:0,state:null},i.set(n,s)),s):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,e))}}function Sl(e){return'href="'+gn(e)+'"'}function Mr(e){return'link[rel="stylesheet"]['+e+"]"}function Vp(e){return x({},e,{"data-precedence":e.precedence,precedence:null})}function k1(e,n,i,s){e.querySelector('link[rel="preload"][as="style"]['+n+"]")?s.loading=1:(n=e.createElement("link"),s.preload=n,n.addEventListener("load",function(){return s.loading|=1}),n.addEventListener("error",function(){return s.loading|=2}),Wt(n,"link",i),It(n),e.head.appendChild(n))}function Nl(e){return'[src="'+gn(e)+'"]'}function Cr(e){return"script[async]"+e}function Kp(e,n,i){if(n.count++,n.instance===null)switch(n.type){case"style":var s=e.querySelector('style[data-href~="'+gn(i.href)+'"]');if(s)return n.instance=s,It(s),s;var f=x({},i,{"data-href":i.href,"data-precedence":i.precedence,href:null,precedence:null});return s=(e.ownerDocument||e).createElement("style"),It(s),Wt(s,"style",f),mo(s,i.precedence,e),n.instance=s;case"stylesheet":f=Sl(i.href);var m=e.querySelector(Mr(f));if(m)return n.state.loading|=4,n.instance=m,It(m),m;s=Vp(i),(f=Pn.get(f))&&Xu(s,f),m=(e.ownerDocument||e).createElement("link"),It(m);var y=m;return y._p=new Promise(function(E,z){y.onload=E,y.onerror=z}),Wt(m,"link",s),n.state.loading|=4,mo(m,i.precedence,e),n.instance=m;case"script":return m=Nl(i.src),(f=e.querySelector(Cr(m)))?(n.instance=f,It(f),f):(s=i,(f=Pn.get(m))&&(s=x({},i),Zu(s,f)),e=e.ownerDocument||e,f=e.createElement("script"),It(f),Wt(f,"link",s),e.head.appendChild(f),n.instance=f);case"void":return null;default:throw Error(r(443,n.type))}else n.type==="stylesheet"&&(n.state.loading&4)===0&&(s=n.instance,n.state.loading|=4,mo(s,i.precedence,e));return n.instance}function mo(e,n,i){for(var s=i.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),f=s.length?s[s.length-1]:null,m=f,y=0;y<s.length;y++){var E=s[y];if(E.dataset.precedence===n)m=E;else if(m!==f)break}m?m.parentNode.insertBefore(e,m.nextSibling):(n=i.nodeType===9?i.head:i,n.insertBefore(e,n.firstChild))}function Xu(e,n){e.crossOrigin==null&&(e.crossOrigin=n.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=n.referrerPolicy),e.title==null&&(e.title=n.title)}function Zu(e,n){e.crossOrigin==null&&(e.crossOrigin=n.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=n.referrerPolicy),e.integrity==null&&(e.integrity=n.integrity)}var ho=null;function Xp(e,n,i){if(ho===null){var s=new Map,f=ho=new Map;f.set(i,s)}else f=ho,s=f.get(i),s||(s=new Map,f.set(i,s));if(s.has(e))return s;for(s.set(e,null),i=i.getElementsByTagName(e),f=0;f<i.length;f++){var m=i[f];if(!(m[pa]||m[Dt]||e==="link"&&m.getAttribute("rel")==="stylesheet")&&m.namespaceURI!=="http://www.w3.org/2000/svg"){var y=m.getAttribute(n)||"";y=e+y;var E=s.get(y);E?E.push(m):s.set(y,[m])}}return s}function Zp(e,n,i){e=e.ownerDocument||e,e.head.insertBefore(i,n==="title"?e.querySelector("head > title"):null)}function T1(e,n,i){if(i===1||n.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof n.precedence!="string"||typeof n.href!="string"||n.href==="")break;return!0;case"link":if(typeof n.rel!="string"||typeof n.href!="string"||n.href===""||n.onLoad||n.onError)break;switch(n.rel){case"stylesheet":return e=n.disabled,typeof n.precedence=="string"&&e==null;default:return!0}case"script":if(n.async&&typeof n.async!="function"&&typeof n.async!="symbol"&&!n.onLoad&&!n.onError&&n.src&&typeof n.src=="string")return!0}return!1}function Qp(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}function A1(e,n,i,s){if(i.type==="stylesheet"&&(typeof s.media!="string"||matchMedia(s.media).matches!==!1)&&(i.state.loading&4)===0){if(i.instance===null){var f=Sl(s.href),m=n.querySelector(Mr(f));if(m){n=m._p,n!==null&&typeof n=="object"&&typeof n.then=="function"&&(e.count++,e=po.bind(e),n.then(e,e)),i.state.loading|=4,i.instance=m,It(m);return}m=n.ownerDocument||n,s=Vp(s),(f=Pn.get(f))&&Xu(s,f),m=m.createElement("link"),It(m);var y=m;y._p=new Promise(function(E,z){y.onload=E,y.onerror=z}),Wt(m,"link",s),i.instance=m}e.stylesheets===null&&(e.stylesheets=new Map),e.stylesheets.set(i,n),(n=i.state.preload)&&(i.state.loading&3)===0&&(e.count++,i=po.bind(e),n.addEventListener("load",i),n.addEventListener("error",i))}}var Qu=0;function M1(e,n){return e.stylesheets&&e.count===0&&bo(e,e.stylesheets),0<e.count||0<e.imgCount?function(i){var s=setTimeout(function(){if(e.stylesheets&&bo(e,e.stylesheets),e.unsuspend){var m=e.unsuspend;e.unsuspend=null,m()}},6e4+n);0<e.imgBytes&&Qu===0&&(Qu=62500*c1());var f=setTimeout(function(){if(e.waitingForImages=!1,e.count===0&&(e.stylesheets&&bo(e,e.stylesheets),e.unsuspend)){var m=e.unsuspend;e.unsuspend=null,m()}},(e.imgBytes>Qu?50:800)+n);return e.unsuspend=i,function(){e.unsuspend=null,clearTimeout(s),clearTimeout(f)}}:null}function po(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)bo(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var go=null;function bo(e,n){e.stylesheets=null,e.unsuspend!==null&&(e.count++,go=new Map,n.forEach(C1,e),go=null,po.call(e))}function C1(e,n){if(!(n.state.loading&4)){var i=go.get(e);if(i)var s=i.get(null);else{i=new Map,go.set(e,i);for(var f=e.querySelectorAll("link[data-precedence],style[data-precedence]"),m=0;m<f.length;m++){var y=f[m];(y.nodeName==="LINK"||y.getAttribute("media")!=="not all")&&(i.set(y.dataset.precedence,y),s=y)}s&&i.set(null,s)}f=n.instance,y=f.getAttribute("data-precedence"),m=i.get(y)||s,m===s&&i.set(null,f),i.set(y,f),this.count++,s=po.bind(this),f.addEventListener("load",s),f.addEventListener("error",s),m?m.parentNode.insertBefore(f,m.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(f,e.firstChild)),n.state.loading|=4}}var Or={$$typeof:R,Provider:null,Consumer:null,_currentValue:ne,_currentValue2:ne,_threadCount:0};function O1(e,n,i,s,f,m,y,E,z){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=vt(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=vt(0),this.hiddenUpdates=vt(null),this.identifierPrefix=s,this.onUncaughtError=f,this.onCaughtError=m,this.onRecoverableError=y,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=z,this.incompleteTransitions=new Map}function Jp(e,n,i,s,f,m,y,E,z,G,Q,te){return e=new O1(e,n,i,y,z,G,Q,te,E),n=1,m===!0&&(n|=24),m=An(3,null,null,n),e.current=m,m.stateNode=e,n=Cc(),n.refCount++,e.pooledCache=n,n.refCount++,m.memoizedState={element:s,isDehydrated:i,cache:n},Dc(m),e}function Wp(e){return e?(e=tl,e):tl}function eg(e,n,i,s,f,m){f=Wp(f),s.context===null?s.context=f:s.pendingContext=f,s=Vi(n),s.payload={element:i},m=m===void 0?null:m,m!==null&&(s.callback=m),i=Ki(e,s,n),i!==null&&(En(i,e,n),cr(i,e,n))}function tg(e,n){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var i=e.retryLane;e.retryLane=i!==0&&i<n?i:n}}function Ju(e,n){tg(e,n),(e=e.alternate)&&tg(e,n)}function ng(e){if(e.tag===13||e.tag===31){var n=va(e,67108864);n!==null&&En(n,e,67108864),Ju(e,67108864)}}function ig(e){if(e.tag===13||e.tag===31){var n=Rn();n=Nt(n);var i=va(e,n);i!==null&&En(i,e,n),Ju(e,n)}}var xo=!0;function z1(e,n,i,s){var f=C.T;C.T=null;var m=K.p;try{K.p=2,Wu(e,n,i,s)}finally{K.p=m,C.T=f}}function R1(e,n,i,s){var f=C.T;C.T=null;var m=K.p;try{K.p=8,Wu(e,n,i,s)}finally{K.p=m,C.T=f}}function Wu(e,n,i,s){if(xo){var f=ef(s);if(f===null)Uu(e,n,s,yo,i),lg(e,s);else if(L1(f,e,n,i,s))s.stopPropagation();else if(lg(e,s),n&4&&-1<D1.indexOf(e)){for(;f!==null;){var m=mi(f);if(m!==null)switch(m.tag){case 3:if(m=m.stateNode,m.current.memoizedState.isDehydrated){var y=hn(m.pendingLanes);if(y!==0){var E=m;for(E.pendingLanes|=2,E.entangledLanes|=2;y;){var z=1<<31-st(y);E.entanglements[1]|=z,y&=~z}li(m),(at&6)===0&&(eo=Tt()+500,wr(0))}}break;case 31:case 13:E=va(m,2),E!==null&&En(E,m,2),no(),Ju(m,2)}if(m=ef(s),m===null&&Uu(e,n,s,yo,i),m===f)break;f=m}f!==null&&s.stopPropagation()}else Uu(e,n,s,null,i)}}function ef(e){return e=Ue(e),tf(e)}var yo=null;function tf(e){if(yo=null,e=cn(e),e!==null){var n=u(e);if(n===null)e=null;else{var i=n.tag;if(i===13){if(e=c(n),e!==null)return e;e=null}else if(i===31){if(e=h(n),e!==null)return e;e=null}else if(i===3){if(n.stateNode.current.memoizedState.isDehydrated)return n.tag===3?n.stateNode.containerInfo:null;e=null}else n!==e&&(e=null)}}return yo=e,null}function ag(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch($a()){case Z:return 2;case me:return 8;case Ce:case Ge:return 32;case tt:return 268435456;default:return 32}default:return 32}}var nf=!1,la=null,ra=null,sa=null,zr=new Map,Rr=new Map,oa=[],D1="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function lg(e,n){switch(e){case"focusin":case"focusout":la=null;break;case"dragenter":case"dragleave":ra=null;break;case"mouseover":case"mouseout":sa=null;break;case"pointerover":case"pointerout":zr.delete(n.pointerId);break;case"gotpointercapture":case"lostpointercapture":Rr.delete(n.pointerId)}}function Dr(e,n,i,s,f,m){return e===null||e.nativeEvent!==m?(e={blockedOn:n,domEventName:i,eventSystemFlags:s,nativeEvent:m,targetContainers:[f]},n!==null&&(n=mi(n),n!==null&&ng(n)),e):(e.eventSystemFlags|=s,n=e.targetContainers,f!==null&&n.indexOf(f)===-1&&n.push(f),e)}function L1(e,n,i,s,f){switch(n){case"focusin":return la=Dr(la,e,n,i,s,f),!0;case"dragenter":return ra=Dr(ra,e,n,i,s,f),!0;case"mouseover":return sa=Dr(sa,e,n,i,s,f),!0;case"pointerover":var m=f.pointerId;return zr.set(m,Dr(zr.get(m)||null,e,n,i,s,f)),!0;case"gotpointercapture":return m=f.pointerId,Rr.set(m,Dr(Rr.get(m)||null,e,n,i,s,f)),!0}return!1}function rg(e){var n=cn(e.target);if(n!==null){var i=u(n);if(i!==null){if(n=i.tag,n===13){if(n=c(i),n!==null){e.blockedOn=n,Pa(e.priority,function(){ig(i)});return}}else if(n===31){if(n=h(i),n!==null){e.blockedOn=n,Pa(e.priority,function(){ig(i)});return}}else if(n===3&&i.stateNode.current.memoizedState.isDehydrated){e.blockedOn=i.tag===3?i.stateNode.containerInfo:null;return}}}e.blockedOn=null}function _o(e){if(e.blockedOn!==null)return!1;for(var n=e.targetContainers;0<n.length;){var i=ef(e.nativeEvent);if(i===null){i=e.nativeEvent;var s=new i.constructor(i.type,i);Se=s,i.target.dispatchEvent(s),Se=null}else return n=mi(i),n!==null&&ng(n),e.blockedOn=i,!1;n.shift()}return!0}function sg(e,n,i){_o(e)&&i.delete(n)}function j1(){nf=!1,la!==null&&_o(la)&&(la=null),ra!==null&&_o(ra)&&(ra=null),sa!==null&&_o(sa)&&(sa=null),zr.forEach(sg),Rr.forEach(sg)}function vo(e,n){e.blockedOn===n&&(e.blockedOn=null,nf||(nf=!0,t.unstable_scheduleCallback(t.unstable_NormalPriority,j1)))}var Eo=null;function og(e){Eo!==e&&(Eo=e,t.unstable_scheduleCallback(t.unstable_NormalPriority,function(){Eo===e&&(Eo=null);for(var n=0;n<e.length;n+=3){var i=e[n],s=e[n+1],f=e[n+2];if(typeof s!="function"){if(tf(s||i)===null)continue;break}var m=mi(i);m!==null&&(e.splice(n,3),n-=3,eu(m,{pending:!0,data:f,method:i.method,action:s},s,f))}}))}function wl(e){function n(z){return vo(z,e)}la!==null&&vo(la,e),ra!==null&&vo(ra,e),sa!==null&&vo(sa,e),zr.forEach(n),Rr.forEach(n);for(var i=0;i<oa.length;i++){var s=oa[i];s.blockedOn===e&&(s.blockedOn=null)}for(;0<oa.length&&(i=oa[0],i.blockedOn===null);)rg(i),i.blockedOn===null&&oa.shift();if(i=(e.ownerDocument||e).$$reactFormReplay,i!=null)for(s=0;s<i.length;s+=3){var f=i[s],m=i[s+1],y=f[tn]||null;if(typeof m=="function")y||og(i);else if(y){var E=null;if(m&&m.hasAttribute("formAction")){if(f=m,y=m[tn]||null)E=y.formAction;else if(tf(f)!==null)continue}else E=y.action;typeof E=="function"?i[s+1]=E:(i.splice(s,3),s-=3),og(i)}}}function cg(){function e(m){m.canIntercept&&m.info==="react-transition"&&m.intercept({handler:function(){return new Promise(function(y){return f=y})},focusReset:"manual",scroll:"manual"})}function n(){f!==null&&(f(),f=null),s||setTimeout(i,20)}function i(){if(!s&&!navigation.transition){var m=navigation.currentEntry;m&&m.url!=null&&navigation.navigate(m.url,{state:m.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var s=!1,f=null;return navigation.addEventListener("navigate",e),navigation.addEventListener("navigatesuccess",n),navigation.addEventListener("navigateerror",n),setTimeout(i,100),function(){s=!0,navigation.removeEventListener("navigate",e),navigation.removeEventListener("navigatesuccess",n),navigation.removeEventListener("navigateerror",n),f!==null&&(f(),f=null)}}}function af(e){this._internalRoot=e}So.prototype.render=af.prototype.render=function(e){var n=this._internalRoot;if(n===null)throw Error(r(409));var i=n.current,s=Rn();eg(i,s,e,n,null,null)},So.prototype.unmount=af.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var n=e.containerInfo;eg(e.current,2,null,e,null,null),no(),n[ji]=null}};function So(e){this._internalRoot=e}So.prototype.unstable_scheduleHydration=function(e){if(e){var n=Ga();e={blockedOn:null,target:e,priority:n};for(var i=0;i<oa.length&&n!==0&&n<oa[i].priority;i++);oa.splice(i,0,e),i===0&&rg(e)}};var ug=a.version;if(ug!=="19.2.4")throw Error(r(527,ug,"19.2.4"));K.findDOMNode=function(e){var n=e._reactInternals;if(n===void 0)throw typeof e.render=="function"?Error(r(188)):(e=Object.keys(e).join(","),Error(r(268,e)));return e=p(n),e=e!==null?b(e):null,e=e===null?null:e.stateNode,e};var B1={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:C,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var No=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!No.isDisabled&&No.supportsFiber)try{Kt=No.inject(B1),Mt=No}catch{}}return jr.createRoot=function(e,n){if(!o(e))throw Error(r(299));var i=!1,s="",f=bh,m=xh,y=yh;return n!=null&&(n.unstable_strictMode===!0&&(i=!0),n.identifierPrefix!==void 0&&(s=n.identifierPrefix),n.onUncaughtError!==void 0&&(f=n.onUncaughtError),n.onCaughtError!==void 0&&(m=n.onCaughtError),n.onRecoverableError!==void 0&&(y=n.onRecoverableError)),n=Jp(e,1,!1,null,null,i,s,null,f,m,y,cg),e[ji]=n.current,Iu(e),new af(n)},jr.hydrateRoot=function(e,n,i){if(!o(e))throw Error(r(299));var s=!1,f="",m=bh,y=xh,E=yh,z=null;return i!=null&&(i.unstable_strictMode===!0&&(s=!0),i.identifierPrefix!==void 0&&(f=i.identifierPrefix),i.onUncaughtError!==void 0&&(m=i.onUncaughtError),i.onCaughtError!==void 0&&(y=i.onCaughtError),i.onRecoverableError!==void 0&&(E=i.onRecoverableError),i.formState!==void 0&&(z=i.formState)),n=Jp(e,1,!0,n,i??null,s,f,z,m,y,E,cg),n.context=Wp(null),i=n.current,s=Rn(),s=Nt(s),f=Vi(s),f.callback=null,Ki(i,f,s),i=s,n.current.lanes=i,gt(n,i),li(n),e[ji]=n.current,Iu(e),new So(n)},jr.version="19.2.4",jr}var _g;function Y1(){if(_g)return sf.exports;_g=1;function t(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(t)}catch(a){console.error(a)}}return t(),sf.exports=P1(),sf.exports}var V1=Y1();/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const G0=(...t)=>t.filter((a,l,r)=>!!a&&a.trim()!==""&&r.indexOf(a)===l).join(" ").trim();/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const K1=t=>t.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase();/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const X1=t=>t.replace(/^([A-Z])|[\s-_]+(\w)/g,(a,l,r)=>r?r.toUpperCase():l.toLowerCase());/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const vg=t=>{const a=X1(t);return a.charAt(0).toUpperCase()+a.slice(1)};/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var Z1={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Q1=t=>{for(const a in t)if(a.startsWith("aria-")||a==="role"||a==="title")return!0;return!1};/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const J1=F.forwardRef(({color:t="currentColor",size:a=24,strokeWidth:l=2,absoluteStrokeWidth:r,className:o="",children:u,iconNode:c,...h},g)=>F.createElement("svg",{ref:g,...Z1,width:a,height:a,stroke:t,strokeWidth:r?Number(l)*24/Number(a):l,className:G0("lucide",o),...!u&&!Q1(h)&&{"aria-hidden":"true"},...h},[...c.map(([p,b])=>F.createElement(p,b)),...Array.isArray(u)?u:[u]]));/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Le=(t,a)=>{const l=F.forwardRef(({className:r,...o},u)=>F.createElement(J1,{ref:u,iconNode:a,className:G0(`lucide-${K1(vg(t))}`,`lucide-${t}`,r),...o}));return l.displayName=vg(t),l};/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const W1=[["path",{d:"m7 7 10 10",key:"1fmybs"}],["path",{d:"M17 7v10H7",key:"6fjiku"}]],e_=Le("arrow-down-right",W1);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const t_=[["path",{d:"m12 19-7-7 7-7",key:"1l729n"}],["path",{d:"M19 12H5",key:"x3x0zl"}]],n_=Le("arrow-left",t_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const i_=[["path",{d:"M7 7h10v10",key:"1tivn9"}],["path",{d:"M7 17 17 7",key:"1vkiza"}]],a_=Le("arrow-up-right",i_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const l_=[["path",{d:"M12 8V4H8",key:"hb8ula"}],["rect",{width:"16",height:"12",x:"4",y:"8",rx:"2",key:"enze0r"}],["path",{d:"M2 14h2",key:"vft8re"}],["path",{d:"M20 14h2",key:"4cs60a"}],["path",{d:"M15 13v2",key:"1xurst"}],["path",{d:"M9 13v2",key:"rq6x2g"}]],La=Le("bot",l_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const r_=[["path",{d:"M12 20v-9",key:"1qisl0"}],["path",{d:"M14 7a4 4 0 0 1 4 4v3a6 6 0 0 1-12 0v-3a4 4 0 0 1 4-4z",key:"uouzyp"}],["path",{d:"M14.12 3.88 16 2",key:"qol33r"}],["path",{d:"M21 21a4 4 0 0 0-3.81-4",key:"1b0z45"}],["path",{d:"M21 5a4 4 0 0 1-3.55 3.97",key:"5cxbf6"}],["path",{d:"M22 13h-4",key:"1jl80f"}],["path",{d:"M3 21a4 4 0 0 1 3.81-4",key:"1fjd4g"}],["path",{d:"M3 5a4 4 0 0 0 3.55 3.97",key:"1d7oge"}],["path",{d:"M6 13H2",key:"82j7cp"}],["path",{d:"m8 2 1.88 1.88",key:"fmnt4t"}],["path",{d:"M9 7.13V6a3 3 0 1 1 6 0v1.13",key:"1vgav8"}]],s_=Le("bug",r_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const o_=[["path",{d:"M8 2v4",key:"1cmpym"}],["path",{d:"M16 2v4",key:"4m81vk"}],["rect",{width:"18",height:"18",x:"3",y:"4",rx:"2",key:"1hopcy"}],["path",{d:"M3 10h18",key:"8toen8"}]],c_=Le("calendar",o_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const u_=[["path",{d:"M3 3v16a2 2 0 0 0 2 2h16",key:"c24i48"}],["path",{d:"M18 17V9",key:"2bz60n"}],["path",{d:"M13 17V5",key:"1frdt8"}],["path",{d:"M8 17v-3",key:"17ska0"}]],Io=Le("chart-column",u_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const f_=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],cd=Le("check",f_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d_=[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]],ui=Le("chevron-down",d_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const m_=[["path",{d:"m9 18 6-6-6-6",key:"mthhwq"}]],Di=Le("chevron-right",m_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const h_=[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]],P0=Le("chevron-up",h_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const p_=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"M12 6v6l4 2",key:"mmk7yg"}]],Uo=Le("clock",p_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const g_=[["rect",{width:"14",height:"14",x:"8",y:"8",rx:"2",ry:"2",key:"17jyea"}],["path",{d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2",key:"zix9uf"}]],b_=Le("copy",g_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const x_=[["path",{d:"M12 20v2",key:"1lh1kg"}],["path",{d:"M12 2v2",key:"tus03m"}],["path",{d:"M17 20v2",key:"1rnc9c"}],["path",{d:"M17 2v2",key:"11trls"}],["path",{d:"M2 12h2",key:"1t8f8n"}],["path",{d:"M2 17h2",key:"7oei6x"}],["path",{d:"M2 7h2",key:"asdhe0"}],["path",{d:"M20 12h2",key:"1q8mjw"}],["path",{d:"M20 17h2",key:"1fpfkl"}],["path",{d:"M20 7h2",key:"1o8tra"}],["path",{d:"M7 20v2",key:"4gnj0m"}],["path",{d:"M7 2v2",key:"1i4yhu"}],["rect",{x:"4",y:"4",width:"16",height:"16",rx:"2",key:"1vbyd7"}],["rect",{x:"8",y:"8",width:"8",height:"8",rx:"1",key:"z9xiuo"}]],Y0=Le("cpu",x_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const y_=[["ellipse",{cx:"12",cy:"5",rx:"9",ry:"3",key:"msslwz"}],["path",{d:"M3 5V19A9 3 0 0 0 21 19V5",key:"1wlel7"}],["path",{d:"M3 12A9 3 0 0 0 21 12",key:"mv7ke4"}]],__=Le("database",y_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const v_=[["line",{x1:"12",x2:"12",y1:"2",y2:"22",key:"7eqyqh"}],["path",{d:"M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6",key:"1b0p4s"}]],V0=Le("dollar-sign",v_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const E_=[["path",{d:"M12 15V3",key:"m9g1x1"}],["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["path",{d:"m7 10 5 5 5-5",key:"brsn70"}]],Ho=Le("download",E_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const S_=[["path",{d:"M13.659 22H18a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v11.5",key:"4pqfef"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M8 12v-1",key:"1ej8lb"}],["path",{d:"M8 18v-2",key:"qcmpov"}],["path",{d:"M8 7V6",key:"1nbb54"}],["circle",{cx:"8",cy:"20",r:"2",key:"ckkr5m"}]],Eg=Le("file-archive",S_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const N_=[["path",{d:"M6 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.704.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2z",key:"1oefj6"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M10 12.5 8 15l2 2.5",key:"1tg20x"}],["path",{d:"m14 12.5 2 2.5-2 2.5",key:"yinavb"}]],K0=Le("file-code",N_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const w_=[["path",{d:"M11.35 22H6a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v5.35",key:"17jvcc"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M14 19h6",key:"bvotb8"}],["path",{d:"M17 16v6",key:"18yu1i"}]],X0=Le("file-plus-corner",w_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const k_=[["path",{d:"M6 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.704.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2z",key:"1oefj6"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M12 12v6",key:"3ahymv"}],["path",{d:"m15 15-3-3-3 3",key:"15xj92"}]],T_=Le("file-up",k_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const A_=[["path",{d:"m6 14 1.5-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.54 6a2 2 0 0 1-1.95 1.5H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H18a2 2 0 0 1 2 2v2",key:"usdka0"}]],Ll=Le("folder-open",A_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const M_=[["path",{d:"M15 6a9 9 0 0 0-9 9V3",key:"1cii5b"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["circle",{cx:"6",cy:"18",r:"3",key:"fqmcym"}]],Z0=Le("git-branch",M_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const C_=[["path",{d:"M10 16h.01",key:"1bzywj"}],["path",{d:"M2.212 11.577a2 2 0 0 0-.212.896V18a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5.527a2 2 0 0 0-.212-.896L18.55 5.11A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z",key:"18tbho"}],["path",{d:"M21.946 12.013H2.054",key:"zqlbp7"}],["path",{d:"M6 16h.01",key:"1pmjb7"}]],O_=Le("hard-drive",C_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const z_=[["line",{x1:"4",x2:"20",y1:"9",y2:"9",key:"4lhtct"}],["line",{x1:"4",x2:"20",y1:"15",y2:"15",key:"vyu0kd"}],["line",{x1:"10",x2:"8",y1:"3",y2:"21",key:"1ggp8o"}],["line",{x1:"16",x2:"14",y1:"3",y2:"21",key:"weycgp"}]],ud=Le("hash",z_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const R_=[["path",{d:"M2 9.5a5.5 5.5 0 0 1 9.591-3.676.56.56 0 0 0 .818 0A5.49 5.49 0 0 1 22 9.5c0 2.29-1.5 4-3 5.5l-5.492 5.313a2 2 0 0 1-3 .019L5 15c-1.5-1.5-3-3.2-3-5.5",key:"mvr1a0"}]],D_=Le("heart",R_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const L_=[["path",{d:"M12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83z",key:"zw3jo"}],["path",{d:"M2 12a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 12",key:"1wduqc"}],["path",{d:"M2 17a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 17",key:"kqbvx6"}]],Q0=Le("layers",L_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const j_=[["path",{d:"M15 14c.2-1 .7-1.7 1.5-2.5 1-.9 1.5-2.2 1.5-3.5A6 6 0 0 0 6 8c0 1 .2 2.2 1.5 3.5.7.7 1.3 1.5 1.5 2.5",key:"1gvzjb"}],["path",{d:"M9 18h6",key:"x1upvd"}],["path",{d:"M10 22h4",key:"ceow96"}]],J0=Le("lightbulb",j_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const B_=[["path",{d:"M3 5h.01",key:"18ugdj"}],["path",{d:"M3 12h.01",key:"nlz23k"}],["path",{d:"M3 19h.01",key:"noohij"}],["path",{d:"M8 5h13",key:"1pao27"}],["path",{d:"M8 12h13",key:"1za7za"}],["path",{d:"M8 19h13",key:"m83p4d"}]],I_=Le("list",B_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const U_=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]],Pr=Le("loader-circle",U_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const H_=[["path",{d:"M4 5h16",key:"1tepv9"}],["path",{d:"M4 12h16",key:"1lakjw"}],["path",{d:"M4 19h16",key:"1djgab"}]],F_=Le("menu",H_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $_=[["path",{d:"M22 17a2 2 0 0 1-2 2H6.828a2 2 0 0 0-1.414.586l-2.202 2.202A.71.71 0 0 1 2 21.286V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2z",key:"18887p"}]],Xr=Le("message-square",$_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const q_=[["rect",{width:"20",height:"14",x:"2",y:"3",rx:"2",key:"48i651"}],["line",{x1:"8",x2:"16",y1:"21",y2:"21",key:"1svkeh"}],["line",{x1:"12",x2:"12",y1:"17",y2:"21",key:"vw1qmm"}]],G_=Le("monitor",q_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const P_=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M9 3v18",key:"fh3hqa"}],["path",{d:"m16 15-3-3 3-3",key:"14y99z"}]],Y_=Le("panel-left-close",P_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const V_=[["path",{d:"M21.174 6.812a1 1 0 0 0-3.986-3.987L3.842 16.174a2 2 0 0 0-.5.83l-1.321 4.352a.5.5 0 0 0 .623.622l4.353-1.32a2 2 0 0 0 .83-.497z",key:"1a8usu"}],["path",{d:"m15 5 4 4",key:"1mk7zo"}]],W0=Le("pencil",V_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const K_=[["path",{d:"m21 21-4.34-4.34",key:"14j7rj"}],["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}]],fd=Le("search",K_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const X_=[["path",{d:"M9.671 4.136a2.34 2.34 0 0 1 4.659 0 2.34 2.34 0 0 0 3.319 1.915 2.34 2.34 0 0 1 2.33 4.033 2.34 2.34 0 0 0 0 3.831 2.34 2.34 0 0 1-2.33 4.033 2.34 2.34 0 0 0-3.319 1.915 2.34 2.34 0 0 1-4.659 0 2.34 2.34 0 0 0-3.32-1.915 2.34 2.34 0 0 1-2.33-4.033 2.34 2.34 0 0 0 0-3.831A2.34 2.34 0 0 1 6.35 6.051a2.34 2.34 0 0 0 3.319-1.915",key:"1i5ecw"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]],Z_=Le("settings",X_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Q_=[["circle",{cx:"18",cy:"5",r:"3",key:"gq8acd"}],["circle",{cx:"6",cy:"12",r:"3",key:"w7nqdw"}],["circle",{cx:"18",cy:"19",r:"3",key:"1xt0gg"}],["line",{x1:"8.59",x2:"15.42",y1:"13.51",y2:"17.49",key:"47mynk"}],["line",{x1:"15.41",x2:"8.59",y1:"6.51",y2:"10.49",key:"1n3mei"}]],eb=Le("share-2",Q_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const J_=[["path",{d:"M10 5H3",key:"1qgfaw"}],["path",{d:"M12 19H3",key:"yhmn1j"}],["path",{d:"M14 3v4",key:"1sua03"}],["path",{d:"M16 17v4",key:"1q0r14"}],["path",{d:"M21 12h-9",key:"1o4lsq"}],["path",{d:"M21 19h-5",key:"1rlt1p"}],["path",{d:"M21 5h-7",key:"1oszz2"}],["path",{d:"M8 10v4",key:"tgpxqk"}],["path",{d:"M8 12H3",key:"a7s4jb"}]],W_=Le("sliders-horizontal",J_);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ev=[["path",{d:"M11.017 2.814a1 1 0 0 1 1.966 0l1.051 5.558a2 2 0 0 0 1.594 1.594l5.558 1.051a1 1 0 0 1 0 1.966l-5.558 1.051a2 2 0 0 0-1.594 1.594l-1.051 5.558a1 1 0 0 1-1.966 0l-1.051-5.558a2 2 0 0 0-1.594-1.594l-5.558-1.051a1 1 0 0 1 0-1.966l5.558-1.051a2 2 0 0 0 1.594-1.594z",key:"1s2grr"}],["path",{d:"M20 2v4",key:"1rf3ol"}],["path",{d:"M22 4h-4",key:"gwowj6"}],["circle",{cx:"4",cy:"20",r:"2",key:"6kqj1y"}]],tv=Le("sparkles",ev);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nv=[["path",{d:"M21 10.656V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h12.344",key:"2acyp4"}],["path",{d:"m9 11 3 3L22 4",key:"1pflzl"}]],Uf=Le("square-check-big",nv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const iv=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M8 12h8",key:"1wcyev"}]],Sg=Le("square-minus",iv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const av=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}]],Hf=Le("square",av);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const lv=[["path",{d:"M12 19h8",key:"baeox8"}],["path",{d:"m4 17 6-6-6-6",key:"1yngyt"}]],tb=Le("terminal",lv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const rv=[["path",{d:"M10 11v6",key:"nco0om"}],["path",{d:"M14 11v6",key:"outv1u"}],["path",{d:"M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6",key:"miytrc"}],["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2",key:"e791ji"}]],sv=Le("trash-2",rv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ov=[["path",{d:"M12 3v12",key:"1x0j5s"}],["path",{d:"m17 8-5-5-5 5",key:"7q97r8"}],["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}]],cv=Le("upload",ov);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const uv=[["path",{d:"M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.106-3.105c.32-.322.863-.22.983.218a6 6 0 0 1-8.259 7.057l-7.91 7.91a1 1 0 0 1-2.999-3l7.91-7.91a6 6 0 0 1 7.057-8.259c.438.12.54.662.219.984z",key:"1ngwbx"}]],Qo=Le("wrench",uv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const fv=[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]],Ul=Le("x",fv);/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const dv=[["path",{d:"M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",key:"1xq2db"}]],nb=Le("zap",dv);function Ng({title:t,message:a,confirmLabel:l="Confirm",cancelLabel:r="Cancel",onConfirm:o,onCancel:u,loading:c=!1}){return d.jsxs("div",{className:"fixed inset-0 z-50 flex items-center justify-center",children:[d.jsx("div",{className:"absolute inset-0 bg-black/60 backdrop-blur-sm",onClick:u}),d.jsxs("div",{className:"relative bg-zinc-900 border border-zinc-700 rounded-lg shadow-2xl w-full max-w-md mx-4",children:[d.jsxs("div",{className:"flex items-center justify-between px-5 py-4 border-b border-zinc-800",children:[d.jsx("h2",{className:"text-sm font-semibold text-zinc-100",children:t}),d.jsx("button",{onClick:u,className:"text-zinc-500 hover:text-zinc-300 transition",children:d.jsx(Ul,{className:"w-4 h-4"})})]}),d.jsx("div",{className:"px-5 py-4",children:d.jsx("p",{className:"text-sm text-zinc-300 whitespace-pre-line",children:a})}),d.jsxs("div",{className:"flex justify-end gap-2 px-5 py-3 border-t border-zinc-800",children:[d.jsx("button",{onClick:u,disabled:c,className:"px-3 py-1.5 text-xs text-zinc-400 hover:text-zinc-200 border border-zinc-700 hover:border-zinc-600 rounded transition disabled:opacity-50",children:r}),d.jsx("button",{onClick:o,disabled:c,className:"px-3 py-1.5 text-xs text-white bg-cyan-600 hover:bg-cyan-500 rounded transition disabled:opacity-50 disabled:cursor-not-allowed",children:c?"Sending...":l})]})]})]})}const mv=["My donated sessions may contain code snippets, file paths, and conversation content from my coding agent interactions.","Donated data will be used for academic research on coding agent behavior by CHATS-Lab at Northeastern University.","I have reviewed the selected sessions and confirm they do not contain sensitive credentials, API keys, or private information I wish to keep confidential.","Donated data may be shared in anonymized or aggregated form in research publications and datasets."];function hv({sessionCount:t,onConfirm:a,onCancel:l}){const[r,o]=F.useState(!1);return d.jsxs("div",{className:"fixed inset-0 z-50 flex items-center justify-center",children:[d.jsx("div",{className:"absolute inset-0 bg-black/60 backdrop-blur-sm",onClick:l}),d.jsxs("div",{className:"relative bg-zinc-900 border border-zinc-700 rounded-lg shadow-2xl w-full max-w-lg mx-4",children:[d.jsxs("div",{className:"flex items-center justify-between px-5 py-4 border-b border-zinc-800",children:[d.jsxs("h2",{className:"text-sm font-semibold text-zinc-100",children:["Donate ",t," Session",t!==1?"s":""]}),d.jsx("button",{onClick:l,className:"text-zinc-500 hover:text-zinc-300 transition",children:d.jsx(Ul,{className:"w-4 h-4"})})]}),d.jsxs("div",{className:"px-5 py-4 space-y-4",children:[d.jsxs("p",{className:"text-sm text-zinc-300",children:["Your sessions will be donated to"," ",d.jsx("a",{href:"https://github.com/CHATS-lab",target:"_blank",rel:"noopener noreferrer",className:"text-cyan-400 hover:text-cyan-300 underline",children:"CHATS-Lab"})," ","at Northeastern University for research on coding agent behavior."]}),d.jsxs("div",{className:"space-y-2 text-xs text-zinc-400",children:[d.jsx("p",{className:"font-medium text-zinc-300",children:"By donating, you acknowledge that:"}),d.jsx("ul",{className:"space-y-1.5 list-disc list-inside",children:mv.map((u,c)=>d.jsx("li",{children:u},c))})]}),d.jsxs("label",{className:"flex items-start gap-2.5 cursor-pointer group",children:[d.jsx("input",{type:"checkbox",checked:r,onChange:u=>o(u.target.checked),className:"mt-0.5 w-4 h-4 rounded border-zinc-600 bg-zinc-800 text-cyan-500 focus:ring-cyan-500 focus:ring-offset-0 cursor-pointer"}),d.jsx("span",{className:"text-xs text-zinc-300 group-hover:text-zinc-100 transition select-none",children:"I have read and agree to the above terms"})]})]}),d.jsxs("div",{className:"flex justify-end gap-2 px-5 py-3 border-t border-zinc-800",children:[d.jsx("button",{onClick:l,className:"px-3 py-1.5 text-xs text-zinc-400 hover:text-zinc-200 border border-zinc-700 hover:border-zinc-600 rounded transition",children:"Cancel"}),d.jsx("button",{onClick:a,disabled:!r,className:"px-3 py-1.5 text-xs text-white bg-rose-600 hover:bg-rose-500 rounded transition disabled:opacity-40 disabled:cursor-not-allowed",children:"Donate"})]})]})]})}function Ff({side:t,onResize:a}){const l=F.useRef(!1),r=F.useRef(0),o=F.useCallback(h=>{if(!l.current)return;const g=h.clientX-r.current;r.current=h.clientX,a(t==="left"?g:-g)},[a,t]),u=F.useCallback(()=>{l.current=!1,document.body.style.cursor="",document.body.style.userSelect=""},[]);F.useEffect(()=>(document.addEventListener("mousemove",o),document.addEventListener("mouseup",u),()=>{document.removeEventListener("mousemove",o),document.removeEventListener("mouseup",u)}),[o,u]);const c=h=>{h.preventDefault(),l.current=!0,r.current=h.clientX,document.body.style.cursor="col-resize",document.body.style.userSelect="none"};return d.jsx("div",{onMouseDown:c,className:`absolute top-0 bottom-0 w-1 cursor-col-resize z-20 hover:bg-cyan-500/40 active:bg-cyan-500/60 transition-colors ${t==="left"?"right-0":"left-0"}`})}const Zr=60,jl=3600,wg=86400;function kg(t){if(!t)return"";const a=Math.floor((Date.now()-new Date(t).getTime())/1e3);return a<Zr?"now":a<jl?`${Math.floor(a/Zr)}m`:a<wg?`${Math.floor(a/jl)}h`:`${Math.floor(a/wg)}d`}const pv=/<(?:system-reminder|command-name|command-message|user-prompt-submit-hook|local-command-caveat|local-command-stdout|task-notification)[^>]*>[\s\S]*?<\/(?:system-reminder|command-name|command-message|user-prompt-submit-hook|local-command-caveat|local-command-stdout|task-notification)>/g;function Qr(t){return t.replace(pv,"").trim()}function Fo(t,a){return t.length<=a?t:t.slice(0,a)+"..."}function fa(t){return t>=1e6?`${(t/1e6).toFixed(1)}M`:t>=1e3?`${(t/1e3).toFixed(1)}K`:String(t)}function Ln(t){return t>=1e3?`$${(t/1e3).toFixed(1)}K`:t>=1?`$${t.toFixed(2)}`:t>=.01?`$${t.toFixed(2)}`:t>0?"<$0.01":"$0.00"}function Ri(t){if(!t||t<=0)return"0m";const a=Math.floor(t/jl),l=Math.floor(t%jl/Zr),r=[];return a>0&&r.push(`${a}h`),(l>0||r.length===0)&&r.push(`${l}m`),r.join(" ")}function Bl(t){return Qr(typeof t=="string"?t:t.filter(a=>a.type==="text"&&a.text).map(a=>a.text).join(`

`))}function $f(t){return Bl(t.message)}function es(t){if(!t)return"Unknown";const l=t.replace(/[\\/]+$/,"").split(/[\\/]/).filter(Boolean);return l.length===0?t:l.slice(-2).join("/")}function ff(t){const a=Math.floor(t/jl),l=Math.floor(t%jl/Zr),r=Math.floor(t%Zr);return a>0?`${a}:${String(l).padStart(2,"0")}:${String(r).padStart(2,"0")}`:`${l}:${String(r).padStart(2,"0")}`}function gv(t,a){const l=new Date(t);return isNaN(l.getTime())?"":a&&(()=>{const o=new Date(a);return o.getFullYear()===l.getFullYear()&&o.getMonth()===l.getMonth()&&o.getDate()===l.getDate()})()?l.toLocaleTimeString(void 0,{hour:"numeric",minute:"2-digit"}):l.toLocaleString(void 0,{month:"short",day:"numeric",hour:"numeric",minute:"2-digit"})}function bv(t){const a=new Date(t);return isNaN(a.getTime())?"":a.toLocaleString(void 0,{weekday:"short",year:"numeric",month:"short",day:"numeric",hour:"numeric",minute:"2-digit",second:"2-digit"})}const xv=[{key:"user_prompts",label:"User prompts",description:"All messages typed by the user"},{key:"agent_content",label:"Agent responses & tool calls",description:"Agent messages, tool names, and arguments"},{key:"session_id",label:"Session ID",description:"Match against session identifiers"}];function yv({sources:t,onApply:a,onClose:l}){const r=new Set(t),o=u=>{r.has(u)?r.delete(u):r.add(u),a(new Set(r))};return d.jsxs("div",{className:"fixed inset-0 z-50 flex items-center justify-center",children:[d.jsx("div",{className:"absolute inset-0 bg-black/60 backdrop-blur-sm",onClick:l}),d.jsxs("div",{className:"relative bg-zinc-900 border border-zinc-700 rounded-lg shadow-2xl w-full max-w-sm mx-4",children:[d.jsxs("div",{className:"flex items-center justify-between px-5 py-4 border-b border-zinc-800",children:[d.jsx("h2",{className:"text-sm font-semibold text-zinc-100",children:"Search Options"}),d.jsx("button",{onClick:l,className:"text-zinc-500 hover:text-zinc-300 transition",children:d.jsx(Ul,{className:"w-4 h-4"})})]}),d.jsx("div",{className:"px-5 py-4 space-y-3",children:xv.map(u=>d.jsxs("label",{className:"flex items-start gap-3 cursor-pointer group",children:[d.jsx("input",{type:"checkbox",checked:t.has(u.key),onChange:()=>o(u.key),className:"mt-0.5 accent-cyan-500 w-4 h-4 rounded border-zinc-600 bg-zinc-800"}),d.jsxs("div",{children:[d.jsx("span",{className:"text-sm text-zinc-200 group-hover:text-zinc-100 transition",children:u.label}),d.jsx("p",{className:"text-xs text-zinc-500",children:u.description})]})]},u.key))}),d.jsx("div",{className:"flex justify-end gap-2 px-5 py-3 border-t border-zinc-800",children:d.jsx("button",{onClick:l,className:"px-3 py-1.5 text-xs text-zinc-400 hover:text-zinc-200 transition",children:"Close"})})]})]})}const ib="flex gap-0.5 bg-zinc-800 rounded p-0.5",$o="flex-1 flex items-center justify-center gap-1.5 text-xs py-1.5 rounded transition",ja="bg-zinc-700 text-zinc-100",Ba="text-zinc-500 hover:text-zinc-300",_v="text-[11px] text-zinc-400 mt-0.5 leading-tight",ab="text-zinc-400 text-xs";function vv({sessions:t,selectedId:a,onSelect:l,checkedIds:r,onCheckedChange:o,viewMode:u,onViewModeChange:c,agentFilter:h,onAgentFilterChange:g,availableAgents:p}){const{fetchWithToken:b}=ss(),[x,_]=F.useState(""),[v,S]=F.useState(new Set),[T,A]=F.useState(null),[w,O]=F.useState(!1),[R,q]=F.useState(!1),[Y,L]=F.useState(()=>new Set(["user_prompts"])),X=F.useRef(null),oe=300,he=new Set(["user_prompts"]),U=Y.size!==he.size||![...he].every(B=>Y.has(B)),re=F.useCallback((B,N)=>{if(!B.trim()){A(null),O(!1);return}O(!0);const ce=new URLSearchParams({q:B.trim(),sources:[...N].join(",")});b(`/api/sessions/search?${ce}`).then(pe=>pe.json()).then(pe=>A(new Set(pe))).catch(pe=>{console.error("Search failed:",pe),A(null)}).finally(()=>O(!1))},[b]);F.useEffect(()=>(X.current&&clearTimeout(X.current),X.current=setTimeout(()=>re(x,Y),oe),()=>{X.current&&clearTimeout(X.current)}),[x,Y,re]);const ae=t.filter(B=>{var N;return h!=="all"&&((N=B.agent)==null?void 0:N.name)!==h?!1:x&&T!==null?T.has(B.session_id):!0}),le=new Set(ae.map(B=>B.session_id)),W=[...r].filter(B=>le.has(B)),H=ae.length>0&&W.length===ae.length,C=W.length>0&&!H,K=F.useMemo(()=>{const B=new Map;for(const N of ae){const ce=N.project_path||"Unknown",pe=B.get(ce)||[];pe.push(N),B.set(ce,pe)}return B},[ae]),ne=B=>{B==="project"&&u!=="project"&&S(new Set),c(B)},ie=B=>{const N=new Set(v);N.has(B)?N.delete(B):N.add(B),S(N)},k=()=>{if(H){const B=new Set(r);for(const N of ae)B.delete(N.session_id);o(B)}else{const B=new Set(r);for(const N of ae)B.add(N.session_id);o(B)}},M=B=>{const N=new Set(r);N.has(B)?N.delete(B):N.add(B),o(N)};return d.jsxs("div",{className:"flex flex-col flex-1 min-h-0",children:[d.jsxs("div",{className:"p-3 space-y-2 border-b border-zinc-800",children:[d.jsxs("div",{className:ib,children:[d.jsxs("button",{onClick:()=>ne("project"),className:`${$o} ${u==="project"?ja:Ba}`,children:[d.jsx(Ll,{className:"w-3.5 h-3.5"}),"By Project"]}),d.jsxs("button",{onClick:()=>ne("time"),className:`${$o} ${u==="time"?ja:Ba}`,children:[d.jsx(Uo,{className:"w-3.5 h-3.5"}),"By Time"]})]}),d.jsxs("div",{className:"relative",children:[w?d.jsx(Pr,{className:"absolute left-2 top-1/2 -translate-y-1/2 w-3.5 h-3.5 text-cyan-400 animate-spin"}):d.jsx(fd,{className:"absolute left-2 top-1/2 -translate-y-1/2 w-3.5 h-3.5 text-zinc-500"}),d.jsx("input",{type:"text",placeholder:"Search sessions...",value:x,onChange:B=>_(B.target.value),className:"w-full bg-zinc-800 text-zinc-200 text-sm rounded pl-7 pr-8 py-1.5 border border-zinc-700 focus:outline-none focus:border-cyan-600 placeholder:text-zinc-500"}),d.jsx("button",{onClick:()=>q(!0),className:"absolute right-1.5 top-1/2 -translate-y-1/2 p-0.5 text-zinc-500 hover:text-zinc-300 transition",title:"Search options",children:d.jsxs("div",{className:"relative",children:[d.jsx(W_,{className:"w-3.5 h-3.5"}),U&&d.jsx("span",{className:"absolute -top-0.5 -right-0.5 w-1.5 h-1.5 bg-cyan-400 rounded-full"})]})})]}),R&&d.jsx(yv,{sources:Y,onApply:L,onClose:()=>q(!1)}),p.length>0&&d.jsxs("div",{className:"relative",children:[d.jsx(La,{className:"absolute left-2 top-1/2 -translate-y-1/2 w-3.5 h-3.5 text-zinc-500"}),d.jsxs("select",{value:h,onChange:B=>g(B.target.value),className:"w-full bg-zinc-800 text-zinc-200 text-sm rounded pl-7 pr-2 py-1.5 border border-zinc-700 focus:outline-none focus:border-cyan-600 appearance-none cursor-pointer",children:[d.jsx("option",{value:"all",children:"All agents"}),p.map(B=>d.jsx("option",{value:B,children:B},B))]})]}),d.jsxs("button",{onClick:k,className:"flex items-center gap-1.5 text-xs text-zinc-300 hover:text-zinc-100 transition",children:[H?d.jsx(Uf,{className:"w-3.5 h-3.5 text-cyan-400"}):C?d.jsx(Sg,{className:"w-3.5 h-3.5 text-cyan-400"}):d.jsx(Hf,{className:"w-3.5 h-3.5"}),"Select all (",ae.length,")"]})]}),d.jsx("div",{className:"flex-1 overflow-y-auto",children:u==="time"?ae.map(B=>d.jsx(Tg,{session:B,selectedId:a,checkedIds:r,onSelect:l,onToggle:M,showProject:!0},B.session_id)):Array.from(K.entries()).map(([B,N])=>{const ce=N.map(ve=>ve.session_id),pe=ce.every(ve=>r.has(ve)),xe=!pe&&ce.some(ve=>r.has(ve)),Be=ve=>{ve.stopPropagation();const qe=new Set(r);if(pe)for(const lt of ce)qe.delete(lt);else for(const lt of ce)qe.add(lt);o(qe)};return d.jsxs("div",{children:[d.jsxs("div",{className:"sticky top-0 z-10 w-full flex items-center gap-1 bg-zinc-900 border-b border-zinc-800 text-sm text-zinc-200",children:[d.jsx("button",{onClick:Be,className:"shrink-0 pl-3 pr-1 py-2 text-zinc-500 hover:text-cyan-400 transition",title:pe?"Deselect project":"Select project",children:pe?d.jsx(Uf,{className:"w-3.5 h-3.5 text-cyan-400"}):xe?d.jsx(Sg,{className:"w-3.5 h-3.5 text-cyan-400"}):d.jsx(Hf,{className:"w-3.5 h-3.5"})}),d.jsxs("button",{onClick:()=>ie(B),className:"flex-1 flex items-center gap-2 pr-3 py-2 hover:text-zinc-100 transition min-w-0",children:[v.has(B)?d.jsx(ui,{className:"w-3.5 h-3.5 shrink-0"}):d.jsx(Di,{className:"w-3.5 h-3.5 shrink-0"}),d.jsx(Ll,{className:"w-3.5 h-3.5 shrink-0 text-zinc-500"}),d.jsx("span",{className:"truncate font-medium",title:B,children:es(B)}),d.jsx("span",{className:"ml-auto text-zinc-500 shrink-0",children:N.length})]})]}),v.has(B)&&N.map(ve=>d.jsx(Tg,{session:ve,selectedId:a,checkedIds:r,onSelect:l,onToggle:M,showProject:!1},ve.session_id))]},B)})})]})}function Tg({session:t,selectedId:a,checkedIds:l,onSelect:r,onToggle:o,showProject:u}){return d.jsxs("div",{className:`flex items-center border-b border-zinc-800/50 transition-all duration-200 ${a===t.session_id?"bg-cyan-600/15 border-l-2 border-l-cyan-400":"hover:bg-zinc-800/50 border-l-2 border-l-transparent"}`,children:[d.jsx("button",{onClick:c=>{c.stopPropagation(),o(t.session_id)},className:`shrink-0 pr-1 text-zinc-500 hover:text-cyan-400 transition ${u?"pl-3":"pl-8"}`,children:l.has(t.session_id)?d.jsx(Uf,{className:"w-3.5 h-3.5 text-cyan-400"}):d.jsx(Hf,{className:"w-3.5 h-3.5"})}),d.jsxs("button",{onClick:()=>r(t.session_id),className:"flex-1 text-left pr-3 py-2.5 min-w-0",children:[u&&d.jsxs("div",{className:"flex items-center justify-between mb-0.5",children:[d.jsx("span",{className:"text-xs text-zinc-400 uppercase tracking-wide",title:t.project_path||"",children:es(t.project_path||"")}),d.jsx("span",{className:"text-xs text-zinc-400",children:kg(t.timestamp??null)})]}),d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx("p",{className:"text-sm text-zinc-200 line-clamp-2 leading-relaxed flex-1 min-w-0",children:Fo(t.first_message||"",120)||"Empty session"}),!u&&d.jsx("span",{className:"text-xs text-zinc-400 shrink-0",children:kg(t.timestamp??null)})]})]})]})}class Ev{diff(a,l,r={}){let o;typeof r=="function"?(o=r,r={}):"callback"in r&&(o=r.callback);const u=this.castInput(a,r),c=this.castInput(l,r),h=this.removeEmpty(this.tokenize(u,r)),g=this.removeEmpty(this.tokenize(c,r));return this.diffWithOptionsObj(h,g,r,o)}diffWithOptionsObj(a,l,r,o){var u;const c=O=>{if(O=this.postProcess(O,r),o){setTimeout(function(){o(O)},0);return}else return O},h=l.length,g=a.length;let p=1,b=h+g;r.maxEditLength!=null&&(b=Math.min(b,r.maxEditLength));const x=(u=r.timeout)!==null&&u!==void 0?u:1/0,_=Date.now()+x,v=[{oldPos:-1,lastComponent:void 0}];let S=this.extractCommon(v[0],l,a,0,r);if(v[0].oldPos+1>=g&&S+1>=h)return c(this.buildValues(v[0].lastComponent,l,a));let T=-1/0,A=1/0;const w=()=>{for(let O=Math.max(T,-p);O<=Math.min(A,p);O+=2){let R;const q=v[O-1],Y=v[O+1];q&&(v[O-1]=void 0);let L=!1;if(Y){const oe=Y.oldPos-O;L=Y&&0<=oe&&oe<h}const X=q&&q.oldPos+1<g;if(!L&&!X){v[O]=void 0;continue}if(!X||L&&q.oldPos<Y.oldPos?R=this.addToPath(Y,!0,!1,0,r):R=this.addToPath(q,!1,!0,1,r),S=this.extractCommon(R,l,a,O,r),R.oldPos+1>=g&&S+1>=h)return c(this.buildValues(R.lastComponent,l,a))||!0;v[O]=R,R.oldPos+1>=g&&(A=Math.min(A,O-1)),S+1>=h&&(T=Math.max(T,O+1))}p++};if(o)(function O(){setTimeout(function(){if(p>b||Date.now()>_)return o(void 0);w()||O()},0)})();else for(;p<=b&&Date.now()<=_;){const O=w();if(O)return O}}addToPath(a,l,r,o,u){const c=a.lastComponent;return c&&!u.oneChangePerToken&&c.added===l&&c.removed===r?{oldPos:a.oldPos+o,lastComponent:{count:c.count+1,added:l,removed:r,previousComponent:c.previousComponent}}:{oldPos:a.oldPos+o,lastComponent:{count:1,added:l,removed:r,previousComponent:c}}}extractCommon(a,l,r,o,u){const c=l.length,h=r.length;let g=a.oldPos,p=g-o,b=0;for(;p+1<c&&g+1<h&&this.equals(r[g+1],l[p+1],u);)p++,g++,b++,u.oneChangePerToken&&(a.lastComponent={count:1,previousComponent:a.lastComponent,added:!1,removed:!1});return b&&!u.oneChangePerToken&&(a.lastComponent={count:b,previousComponent:a.lastComponent,added:!1,removed:!1}),a.oldPos=g,p}equals(a,l,r){return r.comparator?r.comparator(a,l):a===l||!!r.ignoreCase&&a.toLowerCase()===l.toLowerCase()}removeEmpty(a){const l=[];for(let r=0;r<a.length;r++)a[r]&&l.push(a[r]);return l}castInput(a,l){return a}tokenize(a,l){return Array.from(a)}join(a){return a.join("")}postProcess(a,l){return a}get useLongestToken(){return!1}buildValues(a,l,r){const o=[];let u;for(;a;)o.push(a),u=a.previousComponent,delete a.previousComponent,a=u;o.reverse();const c=o.length;let h=0,g=0,p=0;for(;h<c;h++){const b=o[h];if(b.removed)b.value=this.join(r.slice(p,p+b.count)),p+=b.count;else{if(!b.added&&this.useLongestToken){let x=l.slice(g,g+b.count);x=x.map(function(_,v){const S=r[p+v];return S.length>_.length?S:_}),b.value=this.join(x)}else b.value=this.join(l.slice(g,g+b.count));g+=b.count,b.added||(p+=b.count)}}return o}}class Sv extends Ev{constructor(){super(...arguments),this.tokenize=wv}equals(a,l,r){return r.ignoreWhitespace?((!r.newlineIsToken||!a.includes(`
`))&&(a=a.trim()),(!r.newlineIsToken||!l.includes(`
`))&&(l=l.trim())):r.ignoreNewlineAtEof&&!r.newlineIsToken&&(a.endsWith(`
`)&&(a=a.slice(0,-1)),l.endsWith(`
`)&&(l=l.slice(0,-1))),super.equals(a,l,r)}}const Nv=new Sv;function Ag(t,a,l){return Nv.diff(t,a,l)}function wv(t,a){a.stripTrailingCr&&(t=t.replace(/\r\n/g,`
`));const l=[],r=t.split(/(\n|\r\n)/);r[r.length-1]||r.pop();for(let o=0;o<r.length;o++){const u=r[o];o%2&&!a.newlineIsToken?l[l.length-1]+=u:l.push(u)}return l}const kv={includeIndex:!0,includeUnderline:!0,includeFileHeaders:!0};function Mg(t,a,l,r,o,u,c){let h;c?typeof c=="function"?h={callback:c}:h=c:h={},typeof h.context>"u"&&(h.context=4);const g=h.context;if(h.newlineIsToken)throw new Error("newlineIsToken may not be used with patch-generation functions, only with diffing functions");if(h.callback){const{callback:b}=h;Ag(l,r,Object.assign(Object.assign({},h),{callback:x=>{const _=p(x);b(_)}}))}else return p(Ag(l,r,h));function p(b){if(!b)return;b.push({value:"",lines:[]});function x(O){return O.map(function(R){return" "+R})}const _=[];let v=0,S=0,T=[],A=1,w=1;for(let O=0;O<b.length;O++){const R=b[O],q=R.lines||Av(R.value);if(R.lines=q,R.added||R.removed){if(!v){const Y=b[O-1];v=A,S=w,Y&&(T=g>0?x(Y.lines.slice(-g)):[],v-=T.length,S-=T.length)}for(const Y of q)T.push((R.added?"+":"-")+Y);R.added?w+=q.length:A+=q.length}else{if(v)if(q.length<=g*2&&O<b.length-2)for(const Y of x(q))T.push(Y);else{const Y=Math.min(q.length,g);for(const X of x(q.slice(0,Y)))T.push(X);const L={oldStart:v,oldLines:A-v+Y,newStart:S,newLines:w-S+Y,lines:T};_.push(L),v=0,S=0,T=[]}A+=q.length,w+=q.length}}for(const O of _)for(let R=0;R<O.lines.length;R++)O.lines[R].endsWith(`
`)?O.lines[R]=O.lines[R].slice(0,-1):(O.lines.splice(R+1,0,"\\ No newline at end of file"),R++);return{oldFileName:t,newFileName:a,oldHeader:o,newHeader:u,hunks:_}}}function qf(t,a){if(a||(a=kv),Array.isArray(t)){if(t.length>1&&!a.includeFileHeaders)throw new Error("Cannot omit file headers on a multi-file patch. (The result would be unparseable; how would a tool trying to apply the patch know which changes are to which file?)");return t.map(r=>qf(r,a)).join(`
`)}const l=[];a.includeIndex&&t.oldFileName==t.newFileName&&l.push("Index: "+t.oldFileName),a.includeUnderline&&l.push("==================================================================="),a.includeFileHeaders&&(l.push("--- "+t.oldFileName+(typeof t.oldHeader>"u"?"":"	"+t.oldHeader)),l.push("+++ "+t.newFileName+(typeof t.newHeader>"u"?"":"	"+t.newHeader)));for(let r=0;r<t.hunks.length;r++){const o=t.hunks[r];o.oldLines===0&&(o.oldStart-=1),o.newLines===0&&(o.newStart-=1),l.push("@@ -"+o.oldStart+","+o.oldLines+" +"+o.newStart+","+o.newLines+" @@");for(const u of o.lines)l.push(u)}return l.join(`
`)+`
`}function Tv(t,a,l,r,o,u,c){if(typeof c=="function"&&(c={callback:c}),c!=null&&c.callback){const{callback:h}=c;Mg(t,a,l,r,o,u,Object.assign(Object.assign({},c),{callback:g=>{h(g?qf(g,c.headerOptions):void 0)}}))}else{const h=Mg(t,a,l,r,o,u,c);return h?qf(h,c==null?void 0:c.headerOptions):void 0}}function Av(t){const a=t.endsWith(`
`),l=t.split(`
`).map(r=>r+`
`);return a?l.pop():l.push(l.pop().slice(0,-1)),l}function Mv(t,a){const l={};return(t[t.length-1]===""?[...t,""]:t).join((l.padRight?" ":"")+","+(l.padLeft===!1?"":" ")).trim()}const Cv=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,Ov=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,zv={};function Cg(t,a){return(zv.jsx?Ov:Cv).test(t)}const Rv=/[ \t\n\f\r]/g;function Dv(t){return typeof t=="object"?t.type==="text"?Og(t.value):!1:Og(t)}function Og(t){return t.replace(Rv,"")===""}class ts{constructor(a,l,r){this.normal=l,this.property=a,r&&(this.space=r)}}ts.prototype.normal={};ts.prototype.property={};ts.prototype.space=void 0;function lb(t,a){const l={},r={};for(const o of t)Object.assign(l,o.property),Object.assign(r,o.normal);return new ts(l,r,a)}function Gf(t){return t.toLowerCase()}class Nn{constructor(a,l){this.attribute=l,this.property=a}}Nn.prototype.attribute="";Nn.prototype.booleanish=!1;Nn.prototype.boolean=!1;Nn.prototype.commaOrSpaceSeparated=!1;Nn.prototype.commaSeparated=!1;Nn.prototype.defined=!1;Nn.prototype.mustUseProperty=!1;Nn.prototype.number=!1;Nn.prototype.overloadedBoolean=!1;Nn.prototype.property="";Nn.prototype.spaceSeparated=!1;Nn.prototype.space=void 0;let Lv=0;const $e=Ua(),Gt=Ua(),Pf=Ua(),fe=Ua(),_t=Ua(),Dl=Ua(),Dn=Ua();function Ua(){return 2**++Lv}const Yf=Object.freeze(Object.defineProperty({__proto__:null,boolean:$e,booleanish:Gt,commaOrSpaceSeparated:Dn,commaSeparated:Dl,number:fe,overloadedBoolean:Pf,spaceSeparated:_t},Symbol.toStringTag,{value:"Module"})),df=Object.keys(Yf);class dd extends Nn{constructor(a,l,r,o){let u=-1;if(super(a,l),zg(this,"space",o),typeof r=="number")for(;++u<df.length;){const c=df[u];zg(this,df[u],(r&Yf[c])===Yf[c])}}}dd.prototype.defined=!0;function zg(t,a,l){l&&(t[a]=l)}function Hl(t){const a={},l={};for(const[r,o]of Object.entries(t.properties)){const u=new dd(r,t.transform(t.attributes||{},r),o,t.space);t.mustUseProperty&&t.mustUseProperty.includes(r)&&(u.mustUseProperty=!0),a[r]=u,l[Gf(r)]=r,l[Gf(u.attribute)]=r}return new ts(a,l,t.space)}const rb=Hl({properties:{ariaActiveDescendant:null,ariaAtomic:Gt,ariaAutoComplete:null,ariaBusy:Gt,ariaChecked:Gt,ariaColCount:fe,ariaColIndex:fe,ariaColSpan:fe,ariaControls:_t,ariaCurrent:null,ariaDescribedBy:_t,ariaDetails:null,ariaDisabled:Gt,ariaDropEffect:_t,ariaErrorMessage:null,ariaExpanded:Gt,ariaFlowTo:_t,ariaGrabbed:Gt,ariaHasPopup:null,ariaHidden:Gt,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:_t,ariaLevel:fe,ariaLive:null,ariaModal:Gt,ariaMultiLine:Gt,ariaMultiSelectable:Gt,ariaOrientation:null,ariaOwns:_t,ariaPlaceholder:null,ariaPosInSet:fe,ariaPressed:Gt,ariaReadOnly:Gt,ariaRelevant:null,ariaRequired:Gt,ariaRoleDescription:_t,ariaRowCount:fe,ariaRowIndex:fe,ariaRowSpan:fe,ariaSelected:Gt,ariaSetSize:fe,ariaSort:null,ariaValueMax:fe,ariaValueMin:fe,ariaValueNow:fe,ariaValueText:null,role:null},transform(t,a){return a==="role"?a:"aria-"+a.slice(4).toLowerCase()}});function sb(t,a){return a in t?t[a]:a}function ob(t,a){return sb(t,a.toLowerCase())}const jv=Hl({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:Dl,acceptCharset:_t,accessKey:_t,action:null,allow:null,allowFullScreen:$e,allowPaymentRequest:$e,allowUserMedia:$e,alt:null,as:null,async:$e,autoCapitalize:null,autoComplete:_t,autoFocus:$e,autoPlay:$e,blocking:_t,capture:null,charSet:null,checked:$e,cite:null,className:_t,cols:fe,colSpan:null,content:null,contentEditable:Gt,controls:$e,controlsList:_t,coords:fe|Dl,crossOrigin:null,data:null,dateTime:null,decoding:null,default:$e,defer:$e,dir:null,dirName:null,disabled:$e,download:Pf,draggable:Gt,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:$e,formTarget:null,headers:_t,height:fe,hidden:Pf,high:fe,href:null,hrefLang:null,htmlFor:_t,httpEquiv:_t,id:null,imageSizes:null,imageSrcSet:null,inert:$e,inputMode:null,integrity:null,is:null,isMap:$e,itemId:null,itemProp:_t,itemRef:_t,itemScope:$e,itemType:_t,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:$e,low:fe,manifest:null,max:null,maxLength:fe,media:null,method:null,min:null,minLength:fe,multiple:$e,muted:$e,name:null,nonce:null,noModule:$e,noValidate:$e,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:$e,optimum:fe,pattern:null,ping:_t,placeholder:null,playsInline:$e,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:$e,referrerPolicy:null,rel:_t,required:$e,reversed:$e,rows:fe,rowSpan:fe,sandbox:_t,scope:null,scoped:$e,seamless:$e,selected:$e,shadowRootClonable:$e,shadowRootDelegatesFocus:$e,shadowRootMode:null,shape:null,size:fe,sizes:null,slot:null,span:fe,spellCheck:Gt,src:null,srcDoc:null,srcLang:null,srcSet:null,start:fe,step:null,style:null,tabIndex:fe,target:null,title:null,translate:null,type:null,typeMustMatch:$e,useMap:null,value:Gt,width:fe,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:_t,axis:null,background:null,bgColor:null,border:fe,borderColor:null,bottomMargin:fe,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:$e,declare:$e,event:null,face:null,frame:null,frameBorder:null,hSpace:fe,leftMargin:fe,link:null,longDesc:null,lowSrc:null,marginHeight:fe,marginWidth:fe,noResize:$e,noHref:$e,noShade:$e,noWrap:$e,object:null,profile:null,prompt:null,rev:null,rightMargin:fe,rules:null,scheme:null,scrolling:Gt,standby:null,summary:null,text:null,topMargin:fe,valueType:null,version:null,vAlign:null,vLink:null,vSpace:fe,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:$e,disableRemotePlayback:$e,prefix:null,property:null,results:fe,security:null,unselectable:null},space:"html",transform:ob}),Bv=Hl({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:Dn,accentHeight:fe,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:fe,amplitude:fe,arabicForm:null,ascent:fe,attributeName:null,attributeType:null,azimuth:fe,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:fe,by:null,calcMode:null,capHeight:fe,className:_t,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:fe,diffuseConstant:fe,direction:null,display:null,dur:null,divisor:fe,dominantBaseline:null,download:$e,dx:null,dy:null,edgeMode:null,editable:null,elevation:fe,enableBackground:null,end:null,event:null,exponent:fe,externalResourcesRequired:null,fill:null,fillOpacity:fe,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:Dl,g2:Dl,glyphName:Dl,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:fe,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:fe,horizOriginX:fe,horizOriginY:fe,id:null,ideographic:fe,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:fe,k:fe,k1:fe,k2:fe,k3:fe,k4:fe,kernelMatrix:Dn,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:fe,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:fe,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:fe,overlineThickness:fe,paintOrder:null,panose1:null,path:null,pathLength:fe,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:_t,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:fe,pointsAtY:fe,pointsAtZ:fe,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Dn,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Dn,rev:Dn,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Dn,requiredFeatures:Dn,requiredFonts:Dn,requiredFormats:Dn,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:fe,specularExponent:fe,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:fe,strikethroughThickness:fe,string:null,stroke:null,strokeDashArray:Dn,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:fe,strokeOpacity:fe,strokeWidth:null,style:null,surfaceScale:fe,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Dn,tabIndex:fe,tableValues:null,target:null,targetX:fe,targetY:fe,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Dn,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:fe,underlineThickness:fe,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:fe,values:null,vAlphabetic:fe,vMathematical:fe,vectorEffect:null,vHanging:fe,vIdeographic:fe,version:null,vertAdvY:fe,vertOriginX:fe,vertOriginY:fe,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:fe,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:sb}),cb=Hl({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(t,a){return"xlink:"+a.slice(5).toLowerCase()}}),ub=Hl({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:ob}),fb=Hl({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(t,a){return"xml:"+a.slice(3).toLowerCase()}}),Iv={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},Uv=/[A-Z]/g,Rg=/-[a-z]/g,Hv=/^data[-\w.:]+$/i;function Fv(t,a){const l=Gf(a);let r=a,o=Nn;if(l in t.normal)return t.property[t.normal[l]];if(l.length>4&&l.slice(0,4)==="data"&&Hv.test(a)){if(a.charAt(4)==="-"){const u=a.slice(5).replace(Rg,qv);r="data"+u.charAt(0).toUpperCase()+u.slice(1)}else{const u=a.slice(4);if(!Rg.test(u)){let c=u.replace(Uv,$v);c.charAt(0)!=="-"&&(c="-"+c),a="data"+c}}o=dd}return new o(r,a)}function $v(t){return"-"+t.toLowerCase()}function qv(t){return t.charAt(1).toUpperCase()}const Gv=lb([rb,jv,cb,ub,fb],"html"),md=lb([rb,Bv,cb,ub,fb],"svg");function Pv(t){return t.join(" ").trim()}var kl={},mf,Dg;function Yv(){if(Dg)return mf;Dg=1;var t=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,a=/\n/g,l=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,o=/^:\s*/,u=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,c=/^[;\s]*/,h=/^\s+|\s+$/g,g=`
`,p="/",b="*",x="",_="comment",v="declaration";function S(A,w){if(typeof A!="string")throw new TypeError("First argument must be a string");if(!A)return[];w=w||{};var O=1,R=1;function q(W){var H=W.match(a);H&&(O+=H.length);var C=W.lastIndexOf(g);R=~C?W.length-C:R+W.length}function Y(){var W={line:O,column:R};return function(H){return H.position=new L(W),he(),H}}function L(W){this.start=W,this.end={line:O,column:R},this.source=w.source}L.prototype.content=A;function X(W){var H=new Error(w.source+":"+O+":"+R+": "+W);if(H.reason=W,H.filename=w.source,H.line=O,H.column=R,H.source=A,!w.silent)throw H}function oe(W){var H=W.exec(A);if(H){var C=H[0];return q(C),A=A.slice(C.length),H}}function he(){oe(l)}function U(W){var H;for(W=W||[];H=re();)H!==!1&&W.push(H);return W}function re(){var W=Y();if(!(p!=A.charAt(0)||b!=A.charAt(1))){for(var H=2;x!=A.charAt(H)&&(b!=A.charAt(H)||p!=A.charAt(H+1));)++H;if(H+=2,x===A.charAt(H-1))return X("End of comment missing");var C=A.slice(2,H-2);return R+=2,q(C),A=A.slice(H),R+=2,W({type:_,comment:C})}}function ae(){var W=Y(),H=oe(r);if(H){if(re(),!oe(o))return X("property missing ':'");var C=oe(u),K=W({type:v,property:T(H[0].replace(t,x)),value:C?T(C[0].replace(t,x)):x});return oe(c),K}}function le(){var W=[];U(W);for(var H;H=ae();)H!==!1&&(W.push(H),U(W));return W}return he(),le()}function T(A){return A?A.replace(h,x):x}return mf=S,mf}var Lg;function Vv(){if(Lg)return kl;Lg=1;var t=kl&&kl.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(kl,"__esModule",{value:!0}),kl.default=l;const a=t(Yv());function l(r,o){let u=null;if(!r||typeof r!="string")return u;const c=(0,a.default)(r),h=typeof o=="function";return c.forEach(g=>{if(g.type!=="declaration")return;const{property:p,value:b}=g;h?o(p,b,g):b&&(u=u||{},u[p]=b)}),u}return kl}var Br={},jg;function Kv(){if(jg)return Br;jg=1,Object.defineProperty(Br,"__esModule",{value:!0}),Br.camelCase=void 0;var t=/^--[a-zA-Z0-9_-]+$/,a=/-([a-z])/g,l=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,o=/^-(ms)-/,u=function(p){return!p||l.test(p)||t.test(p)},c=function(p,b){return b.toUpperCase()},h=function(p,b){return"".concat(b,"-")},g=function(p,b){return b===void 0&&(b={}),u(p)?p:(p=p.toLowerCase(),b.reactCompat?p=p.replace(o,h):p=p.replace(r,h),p.replace(a,c))};return Br.camelCase=g,Br}var Ir,Bg;function Xv(){if(Bg)return Ir;Bg=1;var t=Ir&&Ir.__importDefault||function(o){return o&&o.__esModule?o:{default:o}},a=t(Vv()),l=Kv();function r(o,u){var c={};return!o||typeof o!="string"||(0,a.default)(o,function(h,g){h&&g&&(c[(0,l.camelCase)(h,u)]=g)}),c}return r.default=r,Ir=r,Ir}var Zv=Xv();const Qv=sd(Zv),db=mb("end"),hd=mb("start");function mb(t){return a;function a(l){const r=l&&l.position&&l.position[t]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function Jv(t){const a=hd(t),l=db(t);if(a&&l)return{start:a,end:l}}function Yr(t){return!t||typeof t!="object"?"":"position"in t||"type"in t?Ig(t.position):"start"in t||"end"in t?Ig(t):"line"in t||"column"in t?Vf(t):""}function Vf(t){return Ug(t&&t.line)+":"+Ug(t&&t.column)}function Ig(t){return Vf(t&&t.start)+"-"+Vf(t&&t.end)}function Ug(t){return t&&typeof t=="number"?t:1}class rn extends Error{constructor(a,l,r){super(),typeof l=="string"&&(r=l,l=void 0);let o="",u={},c=!1;if(l&&("line"in l&&"column"in l?u={place:l}:"start"in l&&"end"in l?u={place:l}:"type"in l?u={ancestors:[l],place:l.position}:u={...l}),typeof a=="string"?o=a:!u.cause&&a&&(c=!0,o=a.message,u.cause=a),!u.ruleId&&!u.source&&typeof r=="string"){const g=r.indexOf(":");g===-1?u.ruleId=r:(u.source=r.slice(0,g),u.ruleId=r.slice(g+1))}if(!u.place&&u.ancestors&&u.ancestors){const g=u.ancestors[u.ancestors.length-1];g&&(u.place=g.position)}const h=u.place&&"start"in u.place?u.place.start:u.place;this.ancestors=u.ancestors||void 0,this.cause=u.cause||void 0,this.column=h?h.column:void 0,this.fatal=void 0,this.file="",this.message=o,this.line=h?h.line:void 0,this.name=Yr(u.place)||"1:1",this.place=u.place||void 0,this.reason=this.message,this.ruleId=u.ruleId||void 0,this.source=u.source||void 0,this.stack=c&&u.cause&&typeof u.cause.stack=="string"?u.cause.stack:"",this.actual=void 0,this.expected=void 0,this.note=void 0,this.url=void 0}}rn.prototype.file="";rn.prototype.name="";rn.prototype.reason="";rn.prototype.message="";rn.prototype.stack="";rn.prototype.column=void 0;rn.prototype.line=void 0;rn.prototype.ancestors=void 0;rn.prototype.cause=void 0;rn.prototype.fatal=void 0;rn.prototype.place=void 0;rn.prototype.ruleId=void 0;rn.prototype.source=void 0;const pd={}.hasOwnProperty,Wv=new Map,eE=/[A-Z]/g,tE=new Set(["table","tbody","thead","tfoot","tr"]),nE=new Set(["td","th"]),hb="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function iE(t,a){if(!a||a.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const l=a.filePath||void 0;let r;if(a.development){if(typeof a.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=fE(l,a.jsxDEV)}else{if(typeof a.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof a.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=uE(l,a.jsx,a.jsxs)}const o={Fragment:a.Fragment,ancestors:[],components:a.components||{},create:r,elementAttributeNameCase:a.elementAttributeNameCase||"react",evaluater:a.createEvaluater?a.createEvaluater():void 0,filePath:l,ignoreInvalidStyle:a.ignoreInvalidStyle||!1,passKeys:a.passKeys!==!1,passNode:a.passNode||!1,schema:a.space==="svg"?md:Gv,stylePropertyNameCase:a.stylePropertyNameCase||"dom",tableCellAlignToStyle:a.tableCellAlignToStyle!==!1},u=pb(o,t,void 0);return u&&typeof u!="string"?u:o.create(t,o.Fragment,{children:u||void 0},void 0)}function pb(t,a,l){if(a.type==="element")return aE(t,a,l);if(a.type==="mdxFlowExpression"||a.type==="mdxTextExpression")return lE(t,a);if(a.type==="mdxJsxFlowElement"||a.type==="mdxJsxTextElement")return sE(t,a,l);if(a.type==="mdxjsEsm")return rE(t,a);if(a.type==="root")return oE(t,a,l);if(a.type==="text")return cE(t,a)}function aE(t,a,l){const r=t.schema;let o=r;a.tagName.toLowerCase()==="svg"&&r.space==="html"&&(o=md,t.schema=o),t.ancestors.push(a);const u=bb(t,a.tagName,!1),c=dE(t,a);let h=bd(t,a);return tE.has(a.tagName)&&(h=h.filter(function(g){return typeof g=="string"?!Dv(g):!0})),gb(t,c,u,a),gd(c,h),t.ancestors.pop(),t.schema=r,t.create(a,u,c,l)}function lE(t,a){if(a.data&&a.data.estree&&t.evaluater){const r=a.data.estree.body[0];return r.type,t.evaluater.evaluateExpression(r.expression)}Jr(t,a.position)}function rE(t,a){if(a.data&&a.data.estree&&t.evaluater)return t.evaluater.evaluateProgram(a.data.estree);Jr(t,a.position)}function sE(t,a,l){const r=t.schema;let o=r;a.name==="svg"&&r.space==="html"&&(o=md,t.schema=o),t.ancestors.push(a);const u=a.name===null?t.Fragment:bb(t,a.name,!0),c=mE(t,a),h=bd(t,a);return gb(t,c,u,a),gd(c,h),t.ancestors.pop(),t.schema=r,t.create(a,u,c,l)}function oE(t,a,l){const r={};return gd(r,bd(t,a)),t.create(a,t.Fragment,r,l)}function cE(t,a){return a.value}function gb(t,a,l,r){typeof l!="string"&&l!==t.Fragment&&t.passNode&&(a.node=r)}function gd(t,a){if(a.length>0){const l=a.length>1?a:a[0];l&&(t.children=l)}}function uE(t,a,l){return r;function r(o,u,c,h){const p=Array.isArray(c.children)?l:a;return h?p(u,c,h):p(u,c)}}function fE(t,a){return l;function l(r,o,u,c){const h=Array.isArray(u.children),g=hd(r);return a(o,u,c,h,{columnNumber:g?g.column-1:void 0,fileName:t,lineNumber:g?g.line:void 0},void 0)}}function dE(t,a){const l={};let r,o;for(o in a.properties)if(o!=="children"&&pd.call(a.properties,o)){const u=hE(t,o,a.properties[o]);if(u){const[c,h]=u;t.tableCellAlignToStyle&&c==="align"&&typeof h=="string"&&nE.has(a.tagName)?r=h:l[c]=h}}if(r){const u=l.style||(l.style={});u[t.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return l}function mE(t,a){const l={};for(const r of a.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&t.evaluater){const u=r.data.estree.body[0];u.type;const c=u.expression;c.type;const h=c.properties[0];h.type,Object.assign(l,t.evaluater.evaluateExpression(h.argument))}else Jr(t,a.position);else{const o=r.name;let u;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&t.evaluater){const h=r.value.data.estree.body[0];h.type,u=t.evaluater.evaluateExpression(h.expression)}else Jr(t,a.position);else u=r.value===null?!0:r.value;l[o]=u}return l}function bd(t,a){const l=[];let r=-1;const o=t.passKeys?new Map:Wv;for(;++r<a.children.length;){const u=a.children[r];let c;if(t.passKeys){const g=u.type==="element"?u.tagName:u.type==="mdxJsxFlowElement"||u.type==="mdxJsxTextElement"?u.name:void 0;if(g){const p=o.get(g)||0;c=g+"-"+p,o.set(g,p+1)}}const h=pb(t,u,c);h!==void 0&&l.push(h)}return l}function hE(t,a,l){const r=Fv(t.schema,a);if(!(l==null||typeof l=="number"&&Number.isNaN(l))){if(Array.isArray(l)&&(l=r.commaSeparated?Mv(l):Pv(l)),r.property==="style"){let o=typeof l=="object"?l:pE(t,String(l));return t.stylePropertyNameCase==="css"&&(o=gE(o)),["style",o]}return[t.elementAttributeNameCase==="react"&&r.space?Iv[r.property]||r.property:r.attribute,l]}}function pE(t,a){try{return Qv(a,{reactCompat:!0})}catch(l){if(t.ignoreInvalidStyle)return{};const r=l,o=new rn("Cannot parse `style` attribute",{ancestors:t.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw o.file=t.filePath||void 0,o.url=hb+"#cannot-parse-style-attribute",o}}function bb(t,a,l){let r;if(!l)r={type:"Literal",value:a};else if(a.includes(".")){const o=a.split(".");let u=-1,c;for(;++u<o.length;){const h=Cg(o[u])?{type:"Identifier",name:o[u]}:{type:"Literal",value:o[u]};c=c?{type:"MemberExpression",object:c,property:h,computed:!!(u&&h.type==="Literal"),optional:!1}:h}r=c}else r=Cg(a)&&!/^[a-z]/.test(a)?{type:"Identifier",name:a}:{type:"Literal",value:a};if(r.type==="Literal"){const o=r.value;return pd.call(t.components,o)?t.components[o]:o}if(t.evaluater)return t.evaluater.evaluateExpression(r);Jr(t)}function Jr(t,a){const l=new rn("Cannot handle MDX estrees without `createEvaluater`",{ancestors:t.ancestors,place:a,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw l.file=t.filePath||void 0,l.url=hb+"#cannot-handle-mdx-estrees-without-createevaluater",l}function gE(t){const a={};let l;for(l in t)pd.call(t,l)&&(a[bE(l)]=t[l]);return a}function bE(t){let a=t.replace(eE,xE);return a.slice(0,3)==="ms-"&&(a="-"+a),a}function xE(t){return"-"+t.toLowerCase()}const hf={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},yE={};function xd(t,a){const l=yE,r=typeof l.includeImageAlt=="boolean"?l.includeImageAlt:!0,o=typeof l.includeHtml=="boolean"?l.includeHtml:!0;return xb(t,r,o)}function xb(t,a,l){if(_E(t)){if("value"in t)return t.type==="html"&&!l?"":t.value;if(a&&"alt"in t&&t.alt)return t.alt;if("children"in t)return Hg(t.children,a,l)}return Array.isArray(t)?Hg(t,a,l):""}function Hg(t,a,l){const r=[];let o=-1;for(;++o<t.length;)r[o]=xb(t[o],a,l);return r.join("")}function _E(t){return!!(t&&typeof t=="object")}const Fg=document.createElement("i");function yd(t){const a="&"+t+";";Fg.innerHTML=a;const l=Fg.textContent;return l.charCodeAt(l.length-1)===59&&t!=="semi"||l===a?!1:l}function jn(t,a,l,r){const o=t.length;let u=0,c;if(a<0?a=-a>o?0:o+a:a=a>o?o:a,l=l>0?l:0,r.length<1e4)c=Array.from(r),c.unshift(a,l),t.splice(...c);else for(l&&t.splice(a,l);u<r.length;)c=r.slice(u,u+1e4),c.unshift(a,0),t.splice(...c),u+=1e4,a+=1e4}function Yn(t,a){return t.length>0?(jn(t,t.length,0,a),t):a}const $g={}.hasOwnProperty;function yb(t){const a={};let l=-1;for(;++l<t.length;)vE(a,t[l]);return a}function vE(t,a){let l;for(l in a){const o=($g.call(t,l)?t[l]:void 0)||(t[l]={}),u=a[l];let c;if(u)for(c in u){$g.call(o,c)||(o[c]=[]);const h=u[c];EE(o[c],Array.isArray(h)?h:h?[h]:[])}}}function EE(t,a){let l=-1;const r=[];for(;++l<a.length;)(a[l].add==="after"?t:r).push(a[l]);jn(t,0,0,r)}function _b(t,a){const l=Number.parseInt(t,a);return l<9||l===11||l>13&&l<32||l>126&&l<160||l>55295&&l<57344||l>64975&&l<65008||(l&65535)===65535||(l&65535)===65534||l>1114111?"�":String.fromCodePoint(l)}function Jn(t){return t.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const dn=da(/[A-Za-z]/),ln=da(/[\dA-Za-z]/),SE=da(/[#-'*+\--9=?A-Z^-~]/);function qo(t){return t!==null&&(t<32||t===127)}const Kf=da(/\d/),NE=da(/[\dA-Fa-f]/),wE=da(/[!-/:-@[-`{-~]/);function Ae(t){return t!==null&&t<-2}function xt(t){return t!==null&&(t<0||t===32)}function Ke(t){return t===-2||t===-1||t===32}const Jo=da(new RegExp("\\p{P}|\\p{S}","u")),Ia=da(/\s/);function da(t){return a;function a(l){return l!==null&&l>-1&&t.test(String.fromCharCode(l))}}function Fl(t){const a=[];let l=-1,r=0,o=0;for(;++l<t.length;){const u=t.charCodeAt(l);let c="";if(u===37&&ln(t.charCodeAt(l+1))&&ln(t.charCodeAt(l+2)))o=2;else if(u<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(u))||(c=String.fromCharCode(u));else if(u>55295&&u<57344){const h=t.charCodeAt(l+1);u<56320&&h>56319&&h<57344?(c=String.fromCharCode(u,h),o=1):c="�"}else c=String.fromCharCode(u);c&&(a.push(t.slice(r,l),encodeURIComponent(c)),r=l+o+1,c=""),o&&(l+=o,o=0)}return a.join("")+t.slice(r)}function We(t,a,l,r){const o=r?r-1:Number.POSITIVE_INFINITY;let u=0;return c;function c(g){return Ke(g)?(t.enter(l),h(g)):a(g)}function h(g){return Ke(g)&&u++<o?(t.consume(g),h):(t.exit(l),a(g))}}const kE={tokenize:TE};function TE(t){const a=t.attempt(this.parser.constructs.contentInitial,r,o);let l;return a;function r(h){if(h===null){t.consume(h);return}return t.enter("lineEnding"),t.consume(h),t.exit("lineEnding"),We(t,a,"linePrefix")}function o(h){return t.enter("paragraph"),u(h)}function u(h){const g=t.enter("chunkText",{contentType:"text",previous:l});return l&&(l.next=g),l=g,c(h)}function c(h){if(h===null){t.exit("chunkText"),t.exit("paragraph"),t.consume(h);return}return Ae(h)?(t.consume(h),t.exit("chunkText"),u):(t.consume(h),c)}}const AE={tokenize:ME},qg={tokenize:CE};function ME(t){const a=this,l=[];let r=0,o,u,c;return h;function h(R){if(r<l.length){const q=l[r];return a.containerState=q[1],t.attempt(q[0].continuation,g,p)(R)}return p(R)}function g(R){if(r++,a.containerState._closeFlow){a.containerState._closeFlow=void 0,o&&O();const q=a.events.length;let Y=q,L;for(;Y--;)if(a.events[Y][0]==="exit"&&a.events[Y][1].type==="chunkFlow"){L=a.events[Y][1].end;break}w(r);let X=q;for(;X<a.events.length;)a.events[X][1].end={...L},X++;return jn(a.events,Y+1,0,a.events.slice(q)),a.events.length=X,p(R)}return h(R)}function p(R){if(r===l.length){if(!o)return _(R);if(o.currentConstruct&&o.currentConstruct.concrete)return S(R);a.interrupt=!!(o.currentConstruct&&!o._gfmTableDynamicInterruptHack)}return a.containerState={},t.check(qg,b,x)(R)}function b(R){return o&&O(),w(r),_(R)}function x(R){return a.parser.lazy[a.now().line]=r!==l.length,c=a.now().offset,S(R)}function _(R){return a.containerState={},t.attempt(qg,v,S)(R)}function v(R){return r++,l.push([a.currentConstruct,a.containerState]),_(R)}function S(R){if(R===null){o&&O(),w(0),t.consume(R);return}return o=o||a.parser.flow(a.now()),t.enter("chunkFlow",{_tokenizer:o,contentType:"flow",previous:u}),T(R)}function T(R){if(R===null){A(t.exit("chunkFlow"),!0),w(0),t.consume(R);return}return Ae(R)?(t.consume(R),A(t.exit("chunkFlow")),r=0,a.interrupt=void 0,h):(t.consume(R),T)}function A(R,q){const Y=a.sliceStream(R);if(q&&Y.push(null),R.previous=u,u&&(u.next=R),u=R,o.defineSkip(R.start),o.write(Y),a.parser.lazy[R.start.line]){let L=o.events.length;for(;L--;)if(o.events[L][1].start.offset<c&&(!o.events[L][1].end||o.events[L][1].end.offset>c))return;const X=a.events.length;let oe=X,he,U;for(;oe--;)if(a.events[oe][0]==="exit"&&a.events[oe][1].type==="chunkFlow"){if(he){U=a.events[oe][1].end;break}he=!0}for(w(r),L=X;L<a.events.length;)a.events[L][1].end={...U},L++;jn(a.events,oe+1,0,a.events.slice(X)),a.events.length=L}}function w(R){let q=l.length;for(;q-- >R;){const Y=l[q];a.containerState=Y[1],Y[0].exit.call(a,t)}l.length=R}function O(){o.write([null]),u=void 0,o=void 0,a.containerState._closeFlow=void 0}}function CE(t,a,l){return We(t,t.attempt(this.parser.constructs.document,a,l),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function Il(t){if(t===null||xt(t)||Ia(t))return 1;if(Jo(t))return 2}function Wo(t,a,l){const r=[];let o=-1;for(;++o<t.length;){const u=t[o].resolveAll;u&&!r.includes(u)&&(a=u(a,l),r.push(u))}return a}const Xf={name:"attention",resolveAll:OE,tokenize:zE};function OE(t,a){let l=-1,r,o,u,c,h,g,p,b;for(;++l<t.length;)if(t[l][0]==="enter"&&t[l][1].type==="attentionSequence"&&t[l][1]._close){for(r=l;r--;)if(t[r][0]==="exit"&&t[r][1].type==="attentionSequence"&&t[r][1]._open&&a.sliceSerialize(t[r][1]).charCodeAt(0)===a.sliceSerialize(t[l][1]).charCodeAt(0)){if((t[r][1]._close||t[l][1]._open)&&(t[l][1].end.offset-t[l][1].start.offset)%3&&!((t[r][1].end.offset-t[r][1].start.offset+t[l][1].end.offset-t[l][1].start.offset)%3))continue;g=t[r][1].end.offset-t[r][1].start.offset>1&&t[l][1].end.offset-t[l][1].start.offset>1?2:1;const x={...t[r][1].end},_={...t[l][1].start};Gg(x,-g),Gg(_,g),c={type:g>1?"strongSequence":"emphasisSequence",start:x,end:{...t[r][1].end}},h={type:g>1?"strongSequence":"emphasisSequence",start:{...t[l][1].start},end:_},u={type:g>1?"strongText":"emphasisText",start:{...t[r][1].end},end:{...t[l][1].start}},o={type:g>1?"strong":"emphasis",start:{...c.start},end:{...h.end}},t[r][1].end={...c.start},t[l][1].start={...h.end},p=[],t[r][1].end.offset-t[r][1].start.offset&&(p=Yn(p,[["enter",t[r][1],a],["exit",t[r][1],a]])),p=Yn(p,[["enter",o,a],["enter",c,a],["exit",c,a],["enter",u,a]]),p=Yn(p,Wo(a.parser.constructs.insideSpan.null,t.slice(r+1,l),a)),p=Yn(p,[["exit",u,a],["enter",h,a],["exit",h,a],["exit",o,a]]),t[l][1].end.offset-t[l][1].start.offset?(b=2,p=Yn(p,[["enter",t[l][1],a],["exit",t[l][1],a]])):b=0,jn(t,r-1,l-r+3,p),l=r+p.length-b-2;break}}for(l=-1;++l<t.length;)t[l][1].type==="attentionSequence"&&(t[l][1].type="data");return t}function zE(t,a){const l=this.parser.constructs.attentionMarkers.null,r=this.previous,o=Il(r);let u;return c;function c(g){return u=g,t.enter("attentionSequence"),h(g)}function h(g){if(g===u)return t.consume(g),h;const p=t.exit("attentionSequence"),b=Il(g),x=!b||b===2&&o||l.includes(g),_=!o||o===2&&b||l.includes(r);return p._open=!!(u===42?x:x&&(o||!_)),p._close=!!(u===42?_:_&&(b||!x)),a(g)}}function Gg(t,a){t.column+=a,t.offset+=a,t._bufferIndex+=a}const RE={name:"autolink",tokenize:DE};function DE(t,a,l){let r=0;return o;function o(v){return t.enter("autolink"),t.enter("autolinkMarker"),t.consume(v),t.exit("autolinkMarker"),t.enter("autolinkProtocol"),u}function u(v){return dn(v)?(t.consume(v),c):v===64?l(v):p(v)}function c(v){return v===43||v===45||v===46||ln(v)?(r=1,h(v)):p(v)}function h(v){return v===58?(t.consume(v),r=0,g):(v===43||v===45||v===46||ln(v))&&r++<32?(t.consume(v),h):(r=0,p(v))}function g(v){return v===62?(t.exit("autolinkProtocol"),t.enter("autolinkMarker"),t.consume(v),t.exit("autolinkMarker"),t.exit("autolink"),a):v===null||v===32||v===60||qo(v)?l(v):(t.consume(v),g)}function p(v){return v===64?(t.consume(v),b):SE(v)?(t.consume(v),p):l(v)}function b(v){return ln(v)?x(v):l(v)}function x(v){return v===46?(t.consume(v),r=0,b):v===62?(t.exit("autolinkProtocol").type="autolinkEmail",t.enter("autolinkMarker"),t.consume(v),t.exit("autolinkMarker"),t.exit("autolink"),a):_(v)}function _(v){if((v===45||ln(v))&&r++<63){const S=v===45?_:x;return t.consume(v),S}return l(v)}}const ns={partial:!0,tokenize:LE};function LE(t,a,l){return r;function r(u){return Ke(u)?We(t,o,"linePrefix")(u):o(u)}function o(u){return u===null||Ae(u)?a(u):l(u)}}const vb={continuation:{tokenize:BE},exit:IE,name:"blockQuote",tokenize:jE};function jE(t,a,l){const r=this;return o;function o(c){if(c===62){const h=r.containerState;return h.open||(t.enter("blockQuote",{_container:!0}),h.open=!0),t.enter("blockQuotePrefix"),t.enter("blockQuoteMarker"),t.consume(c),t.exit("blockQuoteMarker"),u}return l(c)}function u(c){return Ke(c)?(t.enter("blockQuotePrefixWhitespace"),t.consume(c),t.exit("blockQuotePrefixWhitespace"),t.exit("blockQuotePrefix"),a):(t.exit("blockQuotePrefix"),a(c))}}function BE(t,a,l){const r=this;return o;function o(c){return Ke(c)?We(t,u,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(c):u(c)}function u(c){return t.attempt(vb,a,l)(c)}}function IE(t){t.exit("blockQuote")}const Eb={name:"characterEscape",tokenize:UE};function UE(t,a,l){return r;function r(u){return t.enter("characterEscape"),t.enter("escapeMarker"),t.consume(u),t.exit("escapeMarker"),o}function o(u){return wE(u)?(t.enter("characterEscapeValue"),t.consume(u),t.exit("characterEscapeValue"),t.exit("characterEscape"),a):l(u)}}const Sb={name:"characterReference",tokenize:HE};function HE(t,a,l){const r=this;let o=0,u,c;return h;function h(x){return t.enter("characterReference"),t.enter("characterReferenceMarker"),t.consume(x),t.exit("characterReferenceMarker"),g}function g(x){return x===35?(t.enter("characterReferenceMarkerNumeric"),t.consume(x),t.exit("characterReferenceMarkerNumeric"),p):(t.enter("characterReferenceValue"),u=31,c=ln,b(x))}function p(x){return x===88||x===120?(t.enter("characterReferenceMarkerHexadecimal"),t.consume(x),t.exit("characterReferenceMarkerHexadecimal"),t.enter("characterReferenceValue"),u=6,c=NE,b):(t.enter("characterReferenceValue"),u=7,c=Kf,b(x))}function b(x){if(x===59&&o){const _=t.exit("characterReferenceValue");return c===ln&&!yd(r.sliceSerialize(_))?l(x):(t.enter("characterReferenceMarker"),t.consume(x),t.exit("characterReferenceMarker"),t.exit("characterReference"),a)}return c(x)&&o++<u?(t.consume(x),b):l(x)}}const Pg={partial:!0,tokenize:$E},Yg={concrete:!0,name:"codeFenced",tokenize:FE};function FE(t,a,l){const r=this,o={partial:!0,tokenize:Y};let u=0,c=0,h;return g;function g(L){return p(L)}function p(L){const X=r.events[r.events.length-1];return u=X&&X[1].type==="linePrefix"?X[2].sliceSerialize(X[1],!0).length:0,h=L,t.enter("codeFenced"),t.enter("codeFencedFence"),t.enter("codeFencedFenceSequence"),b(L)}function b(L){return L===h?(c++,t.consume(L),b):c<3?l(L):(t.exit("codeFencedFenceSequence"),Ke(L)?We(t,x,"whitespace")(L):x(L))}function x(L){return L===null||Ae(L)?(t.exit("codeFencedFence"),r.interrupt?a(L):t.check(Pg,T,q)(L)):(t.enter("codeFencedFenceInfo"),t.enter("chunkString",{contentType:"string"}),_(L))}function _(L){return L===null||Ae(L)?(t.exit("chunkString"),t.exit("codeFencedFenceInfo"),x(L)):Ke(L)?(t.exit("chunkString"),t.exit("codeFencedFenceInfo"),We(t,v,"whitespace")(L)):L===96&&L===h?l(L):(t.consume(L),_)}function v(L){return L===null||Ae(L)?x(L):(t.enter("codeFencedFenceMeta"),t.enter("chunkString",{contentType:"string"}),S(L))}function S(L){return L===null||Ae(L)?(t.exit("chunkString"),t.exit("codeFencedFenceMeta"),x(L)):L===96&&L===h?l(L):(t.consume(L),S)}function T(L){return t.attempt(o,q,A)(L)}function A(L){return t.enter("lineEnding"),t.consume(L),t.exit("lineEnding"),w}function w(L){return u>0&&Ke(L)?We(t,O,"linePrefix",u+1)(L):O(L)}function O(L){return L===null||Ae(L)?t.check(Pg,T,q)(L):(t.enter("codeFlowValue"),R(L))}function R(L){return L===null||Ae(L)?(t.exit("codeFlowValue"),O(L)):(t.consume(L),R)}function q(L){return t.exit("codeFenced"),a(L)}function Y(L,X,oe){let he=0;return U;function U(H){return L.enter("lineEnding"),L.consume(H),L.exit("lineEnding"),re}function re(H){return L.enter("codeFencedFence"),Ke(H)?We(L,ae,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(H):ae(H)}function ae(H){return H===h?(L.enter("codeFencedFenceSequence"),le(H)):oe(H)}function le(H){return H===h?(he++,L.consume(H),le):he>=c?(L.exit("codeFencedFenceSequence"),Ke(H)?We(L,W,"whitespace")(H):W(H)):oe(H)}function W(H){return H===null||Ae(H)?(L.exit("codeFencedFence"),X(H)):oe(H)}}}function $E(t,a,l){const r=this;return o;function o(c){return c===null?l(c):(t.enter("lineEnding"),t.consume(c),t.exit("lineEnding"),u)}function u(c){return r.parser.lazy[r.now().line]?l(c):a(c)}}const pf={name:"codeIndented",tokenize:GE},qE={partial:!0,tokenize:PE};function GE(t,a,l){const r=this;return o;function o(p){return t.enter("codeIndented"),We(t,u,"linePrefix",5)(p)}function u(p){const b=r.events[r.events.length-1];return b&&b[1].type==="linePrefix"&&b[2].sliceSerialize(b[1],!0).length>=4?c(p):l(p)}function c(p){return p===null?g(p):Ae(p)?t.attempt(qE,c,g)(p):(t.enter("codeFlowValue"),h(p))}function h(p){return p===null||Ae(p)?(t.exit("codeFlowValue"),c(p)):(t.consume(p),h)}function g(p){return t.exit("codeIndented"),a(p)}}function PE(t,a,l){const r=this;return o;function o(c){return r.parser.lazy[r.now().line]?l(c):Ae(c)?(t.enter("lineEnding"),t.consume(c),t.exit("lineEnding"),o):We(t,u,"linePrefix",5)(c)}function u(c){const h=r.events[r.events.length-1];return h&&h[1].type==="linePrefix"&&h[2].sliceSerialize(h[1],!0).length>=4?a(c):Ae(c)?o(c):l(c)}}const YE={name:"codeText",previous:KE,resolve:VE,tokenize:XE};function VE(t){let a=t.length-4,l=3,r,o;if((t[l][1].type==="lineEnding"||t[l][1].type==="space")&&(t[a][1].type==="lineEnding"||t[a][1].type==="space")){for(r=l;++r<a;)if(t[r][1].type==="codeTextData"){t[l][1].type="codeTextPadding",t[a][1].type="codeTextPadding",l+=2,a-=2;break}}for(r=l-1,a++;++r<=a;)o===void 0?r!==a&&t[r][1].type!=="lineEnding"&&(o=r):(r===a||t[r][1].type==="lineEnding")&&(t[o][1].type="codeTextData",r!==o+2&&(t[o][1].end=t[r-1][1].end,t.splice(o+2,r-o-2),a-=r-o-2,r=o+2),o=void 0);return t}function KE(t){return t!==96||this.events[this.events.length-1][1].type==="characterEscape"}function XE(t,a,l){let r=0,o,u;return c;function c(x){return t.enter("codeText"),t.enter("codeTextSequence"),h(x)}function h(x){return x===96?(t.consume(x),r++,h):(t.exit("codeTextSequence"),g(x))}function g(x){return x===null?l(x):x===32?(t.enter("space"),t.consume(x),t.exit("space"),g):x===96?(u=t.enter("codeTextSequence"),o=0,b(x)):Ae(x)?(t.enter("lineEnding"),t.consume(x),t.exit("lineEnding"),g):(t.enter("codeTextData"),p(x))}function p(x){return x===null||x===32||x===96||Ae(x)?(t.exit("codeTextData"),g(x)):(t.consume(x),p)}function b(x){return x===96?(t.consume(x),o++,b):o===r?(t.exit("codeTextSequence"),t.exit("codeText"),a(x)):(u.type="codeTextData",p(x))}}class ZE{constructor(a){this.left=a?[...a]:[],this.right=[]}get(a){if(a<0||a>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+a+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return a<this.left.length?this.left[a]:this.right[this.right.length-a+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(a,l){const r=l??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(a,r):a>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-a+this.left.length).reverse():this.left.slice(a).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(a,l,r){const o=l||0;this.setCursor(Math.trunc(a));const u=this.right.splice(this.right.length-o,Number.POSITIVE_INFINITY);return r&&Ur(this.left,r),u.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(a){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(a)}pushMany(a){this.setCursor(Number.POSITIVE_INFINITY),Ur(this.left,a)}unshift(a){this.setCursor(0),this.right.push(a)}unshiftMany(a){this.setCursor(0),Ur(this.right,a.reverse())}setCursor(a){if(!(a===this.left.length||a>this.left.length&&this.right.length===0||a<0&&this.left.length===0))if(a<this.left.length){const l=this.left.splice(a,Number.POSITIVE_INFINITY);Ur(this.right,l.reverse())}else{const l=this.right.splice(this.left.length+this.right.length-a,Number.POSITIVE_INFINITY);Ur(this.left,l.reverse())}}}function Ur(t,a){let l=0;if(a.length<1e4)t.push(...a);else for(;l<a.length;)t.push(...a.slice(l,l+1e4)),l+=1e4}function Nb(t){const a={};let l=-1,r,o,u,c,h,g,p;const b=new ZE(t);for(;++l<b.length;){for(;l in a;)l=a[l];if(r=b.get(l),l&&r[1].type==="chunkFlow"&&b.get(l-1)[1].type==="listItemPrefix"&&(g=r[1]._tokenizer.events,u=0,u<g.length&&g[u][1].type==="lineEndingBlank"&&(u+=2),u<g.length&&g[u][1].type==="content"))for(;++u<g.length&&g[u][1].type!=="content";)g[u][1].type==="chunkText"&&(g[u][1]._isInFirstContentOfListItem=!0,u++);if(r[0]==="enter")r[1].contentType&&(Object.assign(a,QE(b,l)),l=a[l],p=!0);else if(r[1]._container){for(u=l,o=void 0;u--;)if(c=b.get(u),c[1].type==="lineEnding"||c[1].type==="lineEndingBlank")c[0]==="enter"&&(o&&(b.get(o)[1].type="lineEndingBlank"),c[1].type="lineEnding",o=u);else if(!(c[1].type==="linePrefix"||c[1].type==="listItemIndent"))break;o&&(r[1].end={...b.get(o)[1].start},h=b.slice(o,l),h.unshift(r),b.splice(o,l-o+1,h))}}return jn(t,0,Number.POSITIVE_INFINITY,b.slice(0)),!p}function QE(t,a){const l=t.get(a)[1],r=t.get(a)[2];let o=a-1;const u=[];let c=l._tokenizer;c||(c=r.parser[l.contentType](l.start),l._contentTypeTextTrailing&&(c._contentTypeTextTrailing=!0));const h=c.events,g=[],p={};let b,x,_=-1,v=l,S=0,T=0;const A=[T];for(;v;){for(;t.get(++o)[1]!==v;);u.push(o),v._tokenizer||(b=r.sliceStream(v),v.next||b.push(null),x&&c.defineSkip(v.start),v._isInFirstContentOfListItem&&(c._gfmTasklistFirstContentOfListItem=!0),c.write(b),v._isInFirstContentOfListItem&&(c._gfmTasklistFirstContentOfListItem=void 0)),x=v,v=v.next}for(v=l;++_<h.length;)h[_][0]==="exit"&&h[_-1][0]==="enter"&&h[_][1].type===h[_-1][1].type&&h[_][1].start.line!==h[_][1].end.line&&(T=_+1,A.push(T),v._tokenizer=void 0,v.previous=void 0,v=v.next);for(c.events=[],v?(v._tokenizer=void 0,v.previous=void 0):A.pop(),_=A.length;_--;){const w=h.slice(A[_],A[_+1]),O=u.pop();g.push([O,O+w.length-1]),t.splice(O,2,w)}for(g.reverse(),_=-1;++_<g.length;)p[S+g[_][0]]=S+g[_][1],S+=g[_][1]-g[_][0]-1;return p}const JE={resolve:eS,tokenize:tS},WE={partial:!0,tokenize:nS};function eS(t){return Nb(t),t}function tS(t,a){let l;return r;function r(h){return t.enter("content"),l=t.enter("chunkContent",{contentType:"content"}),o(h)}function o(h){return h===null?u(h):Ae(h)?t.check(WE,c,u)(h):(t.consume(h),o)}function u(h){return t.exit("chunkContent"),t.exit("content"),a(h)}function c(h){return t.consume(h),t.exit("chunkContent"),l.next=t.enter("chunkContent",{contentType:"content",previous:l}),l=l.next,o}}function nS(t,a,l){const r=this;return o;function o(c){return t.exit("chunkContent"),t.enter("lineEnding"),t.consume(c),t.exit("lineEnding"),We(t,u,"linePrefix")}function u(c){if(c===null||Ae(c))return l(c);const h=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&h&&h[1].type==="linePrefix"&&h[2].sliceSerialize(h[1],!0).length>=4?a(c):t.interrupt(r.parser.constructs.flow,l,a)(c)}}function wb(t,a,l,r,o,u,c,h,g){const p=g||Number.POSITIVE_INFINITY;let b=0;return x;function x(w){return w===60?(t.enter(r),t.enter(o),t.enter(u),t.consume(w),t.exit(u),_):w===null||w===32||w===41||qo(w)?l(w):(t.enter(r),t.enter(c),t.enter(h),t.enter("chunkString",{contentType:"string"}),T(w))}function _(w){return w===62?(t.enter(u),t.consume(w),t.exit(u),t.exit(o),t.exit(r),a):(t.enter(h),t.enter("chunkString",{contentType:"string"}),v(w))}function v(w){return w===62?(t.exit("chunkString"),t.exit(h),_(w)):w===null||w===60||Ae(w)?l(w):(t.consume(w),w===92?S:v)}function S(w){return w===60||w===62||w===92?(t.consume(w),v):v(w)}function T(w){return!b&&(w===null||w===41||xt(w))?(t.exit("chunkString"),t.exit(h),t.exit(c),t.exit(r),a(w)):b<p&&w===40?(t.consume(w),b++,T):w===41?(t.consume(w),b--,T):w===null||w===32||w===40||qo(w)?l(w):(t.consume(w),w===92?A:T)}function A(w){return w===40||w===41||w===92?(t.consume(w),T):T(w)}}function kb(t,a,l,r,o,u){const c=this;let h=0,g;return p;function p(v){return t.enter(r),t.enter(o),t.consume(v),t.exit(o),t.enter(u),b}function b(v){return h>999||v===null||v===91||v===93&&!g||v===94&&!h&&"_hiddenFootnoteSupport"in c.parser.constructs?l(v):v===93?(t.exit(u),t.enter(o),t.consume(v),t.exit(o),t.exit(r),a):Ae(v)?(t.enter("lineEnding"),t.consume(v),t.exit("lineEnding"),b):(t.enter("chunkString",{contentType:"string"}),x(v))}function x(v){return v===null||v===91||v===93||Ae(v)||h++>999?(t.exit("chunkString"),b(v)):(t.consume(v),g||(g=!Ke(v)),v===92?_:x)}function _(v){return v===91||v===92||v===93?(t.consume(v),h++,x):x(v)}}function Tb(t,a,l,r,o,u){let c;return h;function h(_){return _===34||_===39||_===40?(t.enter(r),t.enter(o),t.consume(_),t.exit(o),c=_===40?41:_,g):l(_)}function g(_){return _===c?(t.enter(o),t.consume(_),t.exit(o),t.exit(r),a):(t.enter(u),p(_))}function p(_){return _===c?(t.exit(u),g(c)):_===null?l(_):Ae(_)?(t.enter("lineEnding"),t.consume(_),t.exit("lineEnding"),We(t,p,"linePrefix")):(t.enter("chunkString",{contentType:"string"}),b(_))}function b(_){return _===c||_===null||Ae(_)?(t.exit("chunkString"),p(_)):(t.consume(_),_===92?x:b)}function x(_){return _===c||_===92?(t.consume(_),b):b(_)}}function Vr(t,a){let l;return r;function r(o){return Ae(o)?(t.enter("lineEnding"),t.consume(o),t.exit("lineEnding"),l=!0,r):Ke(o)?We(t,r,l?"linePrefix":"lineSuffix")(o):a(o)}}const iS={name:"definition",tokenize:lS},aS={partial:!0,tokenize:rS};function lS(t,a,l){const r=this;let o;return u;function u(v){return t.enter("definition"),c(v)}function c(v){return kb.call(r,t,h,l,"definitionLabel","definitionLabelMarker","definitionLabelString")(v)}function h(v){return o=Jn(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),v===58?(t.enter("definitionMarker"),t.consume(v),t.exit("definitionMarker"),g):l(v)}function g(v){return xt(v)?Vr(t,p)(v):p(v)}function p(v){return wb(t,b,l,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(v)}function b(v){return t.attempt(aS,x,x)(v)}function x(v){return Ke(v)?We(t,_,"whitespace")(v):_(v)}function _(v){return v===null||Ae(v)?(t.exit("definition"),r.parser.defined.push(o),a(v)):l(v)}}function rS(t,a,l){return r;function r(h){return xt(h)?Vr(t,o)(h):l(h)}function o(h){return Tb(t,u,l,"definitionTitle","definitionTitleMarker","definitionTitleString")(h)}function u(h){return Ke(h)?We(t,c,"whitespace")(h):c(h)}function c(h){return h===null||Ae(h)?a(h):l(h)}}const sS={name:"hardBreakEscape",tokenize:oS};function oS(t,a,l){return r;function r(u){return t.enter("hardBreakEscape"),t.consume(u),o}function o(u){return Ae(u)?(t.exit("hardBreakEscape"),a(u)):l(u)}}const cS={name:"headingAtx",resolve:uS,tokenize:fS};function uS(t,a){let l=t.length-2,r=3,o,u;return t[r][1].type==="whitespace"&&(r+=2),l-2>r&&t[l][1].type==="whitespace"&&(l-=2),t[l][1].type==="atxHeadingSequence"&&(r===l-1||l-4>r&&t[l-2][1].type==="whitespace")&&(l-=r+1===l?2:4),l>r&&(o={type:"atxHeadingText",start:t[r][1].start,end:t[l][1].end},u={type:"chunkText",start:t[r][1].start,end:t[l][1].end,contentType:"text"},jn(t,r,l-r+1,[["enter",o,a],["enter",u,a],["exit",u,a],["exit",o,a]])),t}function fS(t,a,l){let r=0;return o;function o(b){return t.enter("atxHeading"),u(b)}function u(b){return t.enter("atxHeadingSequence"),c(b)}function c(b){return b===35&&r++<6?(t.consume(b),c):b===null||xt(b)?(t.exit("atxHeadingSequence"),h(b)):l(b)}function h(b){return b===35?(t.enter("atxHeadingSequence"),g(b)):b===null||Ae(b)?(t.exit("atxHeading"),a(b)):Ke(b)?We(t,h,"whitespace")(b):(t.enter("atxHeadingText"),p(b))}function g(b){return b===35?(t.consume(b),g):(t.exit("atxHeadingSequence"),h(b))}function p(b){return b===null||b===35||xt(b)?(t.exit("atxHeadingText"),h(b)):(t.consume(b),p)}}const dS=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],Vg=["pre","script","style","textarea"],mS={concrete:!0,name:"htmlFlow",resolveTo:gS,tokenize:bS},hS={partial:!0,tokenize:yS},pS={partial:!0,tokenize:xS};function gS(t){let a=t.length;for(;a--&&!(t[a][0]==="enter"&&t[a][1].type==="htmlFlow"););return a>1&&t[a-2][1].type==="linePrefix"&&(t[a][1].start=t[a-2][1].start,t[a+1][1].start=t[a-2][1].start,t.splice(a-2,2)),t}function bS(t,a,l){const r=this;let o,u,c,h,g;return p;function p(N){return b(N)}function b(N){return t.enter("htmlFlow"),t.enter("htmlFlowData"),t.consume(N),x}function x(N){return N===33?(t.consume(N),_):N===47?(t.consume(N),u=!0,T):N===63?(t.consume(N),o=3,r.interrupt?a:k):dn(N)?(t.consume(N),c=String.fromCharCode(N),A):l(N)}function _(N){return N===45?(t.consume(N),o=2,v):N===91?(t.consume(N),o=5,h=0,S):dn(N)?(t.consume(N),o=4,r.interrupt?a:k):l(N)}function v(N){return N===45?(t.consume(N),r.interrupt?a:k):l(N)}function S(N){const ce="CDATA[";return N===ce.charCodeAt(h++)?(t.consume(N),h===ce.length?r.interrupt?a:ae:S):l(N)}function T(N){return dn(N)?(t.consume(N),c=String.fromCharCode(N),A):l(N)}function A(N){if(N===null||N===47||N===62||xt(N)){const ce=N===47,pe=c.toLowerCase();return!ce&&!u&&Vg.includes(pe)?(o=1,r.interrupt?a(N):ae(N)):dS.includes(c.toLowerCase())?(o=6,ce?(t.consume(N),w):r.interrupt?a(N):ae(N)):(o=7,r.interrupt&&!r.parser.lazy[r.now().line]?l(N):u?O(N):R(N))}return N===45||ln(N)?(t.consume(N),c+=String.fromCharCode(N),A):l(N)}function w(N){return N===62?(t.consume(N),r.interrupt?a:ae):l(N)}function O(N){return Ke(N)?(t.consume(N),O):U(N)}function R(N){return N===47?(t.consume(N),U):N===58||N===95||dn(N)?(t.consume(N),q):Ke(N)?(t.consume(N),R):U(N)}function q(N){return N===45||N===46||N===58||N===95||ln(N)?(t.consume(N),q):Y(N)}function Y(N){return N===61?(t.consume(N),L):Ke(N)?(t.consume(N),Y):R(N)}function L(N){return N===null||N===60||N===61||N===62||N===96?l(N):N===34||N===39?(t.consume(N),g=N,X):Ke(N)?(t.consume(N),L):oe(N)}function X(N){return N===g?(t.consume(N),g=null,he):N===null||Ae(N)?l(N):(t.consume(N),X)}function oe(N){return N===null||N===34||N===39||N===47||N===60||N===61||N===62||N===96||xt(N)?Y(N):(t.consume(N),oe)}function he(N){return N===47||N===62||Ke(N)?R(N):l(N)}function U(N){return N===62?(t.consume(N),re):l(N)}function re(N){return N===null||Ae(N)?ae(N):Ke(N)?(t.consume(N),re):l(N)}function ae(N){return N===45&&o===2?(t.consume(N),C):N===60&&o===1?(t.consume(N),K):N===62&&o===4?(t.consume(N),M):N===63&&o===3?(t.consume(N),k):N===93&&o===5?(t.consume(N),ie):Ae(N)&&(o===6||o===7)?(t.exit("htmlFlowData"),t.check(hS,B,le)(N)):N===null||Ae(N)?(t.exit("htmlFlowData"),le(N)):(t.consume(N),ae)}function le(N){return t.check(pS,W,B)(N)}function W(N){return t.enter("lineEnding"),t.consume(N),t.exit("lineEnding"),H}function H(N){return N===null||Ae(N)?le(N):(t.enter("htmlFlowData"),ae(N))}function C(N){return N===45?(t.consume(N),k):ae(N)}function K(N){return N===47?(t.consume(N),c="",ne):ae(N)}function ne(N){if(N===62){const ce=c.toLowerCase();return Vg.includes(ce)?(t.consume(N),M):ae(N)}return dn(N)&&c.length<8?(t.consume(N),c+=String.fromCharCode(N),ne):ae(N)}function ie(N){return N===93?(t.consume(N),k):ae(N)}function k(N){return N===62?(t.consume(N),M):N===45&&o===2?(t.consume(N),k):ae(N)}function M(N){return N===null||Ae(N)?(t.exit("htmlFlowData"),B(N)):(t.consume(N),M)}function B(N){return t.exit("htmlFlow"),a(N)}}function xS(t,a,l){const r=this;return o;function o(c){return Ae(c)?(t.enter("lineEnding"),t.consume(c),t.exit("lineEnding"),u):l(c)}function u(c){return r.parser.lazy[r.now().line]?l(c):a(c)}}function yS(t,a,l){return r;function r(o){return t.enter("lineEnding"),t.consume(o),t.exit("lineEnding"),t.attempt(ns,a,l)}}const _S={name:"htmlText",tokenize:vS};function vS(t,a,l){const r=this;let o,u,c;return h;function h(k){return t.enter("htmlText"),t.enter("htmlTextData"),t.consume(k),g}function g(k){return k===33?(t.consume(k),p):k===47?(t.consume(k),Y):k===63?(t.consume(k),R):dn(k)?(t.consume(k),oe):l(k)}function p(k){return k===45?(t.consume(k),b):k===91?(t.consume(k),u=0,S):dn(k)?(t.consume(k),O):l(k)}function b(k){return k===45?(t.consume(k),v):l(k)}function x(k){return k===null?l(k):k===45?(t.consume(k),_):Ae(k)?(c=x,K(k)):(t.consume(k),x)}function _(k){return k===45?(t.consume(k),v):x(k)}function v(k){return k===62?C(k):k===45?_(k):x(k)}function S(k){const M="CDATA[";return k===M.charCodeAt(u++)?(t.consume(k),u===M.length?T:S):l(k)}function T(k){return k===null?l(k):k===93?(t.consume(k),A):Ae(k)?(c=T,K(k)):(t.consume(k),T)}function A(k){return k===93?(t.consume(k),w):T(k)}function w(k){return k===62?C(k):k===93?(t.consume(k),w):T(k)}function O(k){return k===null||k===62?C(k):Ae(k)?(c=O,K(k)):(t.consume(k),O)}function R(k){return k===null?l(k):k===63?(t.consume(k),q):Ae(k)?(c=R,K(k)):(t.consume(k),R)}function q(k){return k===62?C(k):R(k)}function Y(k){return dn(k)?(t.consume(k),L):l(k)}function L(k){return k===45||ln(k)?(t.consume(k),L):X(k)}function X(k){return Ae(k)?(c=X,K(k)):Ke(k)?(t.consume(k),X):C(k)}function oe(k){return k===45||ln(k)?(t.consume(k),oe):k===47||k===62||xt(k)?he(k):l(k)}function he(k){return k===47?(t.consume(k),C):k===58||k===95||dn(k)?(t.consume(k),U):Ae(k)?(c=he,K(k)):Ke(k)?(t.consume(k),he):C(k)}function U(k){return k===45||k===46||k===58||k===95||ln(k)?(t.consume(k),U):re(k)}function re(k){return k===61?(t.consume(k),ae):Ae(k)?(c=re,K(k)):Ke(k)?(t.consume(k),re):he(k)}function ae(k){return k===null||k===60||k===61||k===62||k===96?l(k):k===34||k===39?(t.consume(k),o=k,le):Ae(k)?(c=ae,K(k)):Ke(k)?(t.consume(k),ae):(t.consume(k),W)}function le(k){return k===o?(t.consume(k),o=void 0,H):k===null?l(k):Ae(k)?(c=le,K(k)):(t.consume(k),le)}function W(k){return k===null||k===34||k===39||k===60||k===61||k===96?l(k):k===47||k===62||xt(k)?he(k):(t.consume(k),W)}function H(k){return k===47||k===62||xt(k)?he(k):l(k)}function C(k){return k===62?(t.consume(k),t.exit("htmlTextData"),t.exit("htmlText"),a):l(k)}function K(k){return t.exit("htmlTextData"),t.enter("lineEnding"),t.consume(k),t.exit("lineEnding"),ne}function ne(k){return Ke(k)?We(t,ie,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(k):ie(k)}function ie(k){return t.enter("htmlTextData"),c(k)}}const _d={name:"labelEnd",resolveAll:wS,resolveTo:kS,tokenize:TS},ES={tokenize:AS},SS={tokenize:MS},NS={tokenize:CS};function wS(t){let a=-1;const l=[];for(;++a<t.length;){const r=t[a][1];if(l.push(t[a]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const o=r.type==="labelImage"?4:2;r.type="data",a+=o}}return t.length!==l.length&&jn(t,0,t.length,l),t}function kS(t,a){let l=t.length,r=0,o,u,c,h;for(;l--;)if(o=t[l][1],u){if(o.type==="link"||o.type==="labelLink"&&o._inactive)break;t[l][0]==="enter"&&o.type==="labelLink"&&(o._inactive=!0)}else if(c){if(t[l][0]==="enter"&&(o.type==="labelImage"||o.type==="labelLink")&&!o._balanced&&(u=l,o.type!=="labelLink")){r=2;break}}else o.type==="labelEnd"&&(c=l);const g={type:t[u][1].type==="labelLink"?"link":"image",start:{...t[u][1].start},end:{...t[t.length-1][1].end}},p={type:"label",start:{...t[u][1].start},end:{...t[c][1].end}},b={type:"labelText",start:{...t[u+r+2][1].end},end:{...t[c-2][1].start}};return h=[["enter",g,a],["enter",p,a]],h=Yn(h,t.slice(u+1,u+r+3)),h=Yn(h,[["enter",b,a]]),h=Yn(h,Wo(a.parser.constructs.insideSpan.null,t.slice(u+r+4,c-3),a)),h=Yn(h,[["exit",b,a],t[c-2],t[c-1],["exit",p,a]]),h=Yn(h,t.slice(c+1)),h=Yn(h,[["exit",g,a]]),jn(t,u,t.length,h),t}function TS(t,a,l){const r=this;let o=r.events.length,u,c;for(;o--;)if((r.events[o][1].type==="labelImage"||r.events[o][1].type==="labelLink")&&!r.events[o][1]._balanced){u=r.events[o][1];break}return h;function h(_){return u?u._inactive?x(_):(c=r.parser.defined.includes(Jn(r.sliceSerialize({start:u.end,end:r.now()}))),t.enter("labelEnd"),t.enter("labelMarker"),t.consume(_),t.exit("labelMarker"),t.exit("labelEnd"),g):l(_)}function g(_){return _===40?t.attempt(ES,b,c?b:x)(_):_===91?t.attempt(SS,b,c?p:x)(_):c?b(_):x(_)}function p(_){return t.attempt(NS,b,x)(_)}function b(_){return a(_)}function x(_){return u._balanced=!0,l(_)}}function AS(t,a,l){return r;function r(x){return t.enter("resource"),t.enter("resourceMarker"),t.consume(x),t.exit("resourceMarker"),o}function o(x){return xt(x)?Vr(t,u)(x):u(x)}function u(x){return x===41?b(x):wb(t,c,h,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(x)}function c(x){return xt(x)?Vr(t,g)(x):b(x)}function h(x){return l(x)}function g(x){return x===34||x===39||x===40?Tb(t,p,l,"resourceTitle","resourceTitleMarker","resourceTitleString")(x):b(x)}function p(x){return xt(x)?Vr(t,b)(x):b(x)}function b(x){return x===41?(t.enter("resourceMarker"),t.consume(x),t.exit("resourceMarker"),t.exit("resource"),a):l(x)}}function MS(t,a,l){const r=this;return o;function o(h){return kb.call(r,t,u,c,"reference","referenceMarker","referenceString")(h)}function u(h){return r.parser.defined.includes(Jn(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?a(h):l(h)}function c(h){return l(h)}}function CS(t,a,l){return r;function r(u){return t.enter("reference"),t.enter("referenceMarker"),t.consume(u),t.exit("referenceMarker"),o}function o(u){return u===93?(t.enter("referenceMarker"),t.consume(u),t.exit("referenceMarker"),t.exit("reference"),a):l(u)}}const OS={name:"labelStartImage",resolveAll:_d.resolveAll,tokenize:zS};function zS(t,a,l){const r=this;return o;function o(h){return t.enter("labelImage"),t.enter("labelImageMarker"),t.consume(h),t.exit("labelImageMarker"),u}function u(h){return h===91?(t.enter("labelMarker"),t.consume(h),t.exit("labelMarker"),t.exit("labelImage"),c):l(h)}function c(h){return h===94&&"_hiddenFootnoteSupport"in r.parser.constructs?l(h):a(h)}}const RS={name:"labelStartLink",resolveAll:_d.resolveAll,tokenize:DS};function DS(t,a,l){const r=this;return o;function o(c){return t.enter("labelLink"),t.enter("labelMarker"),t.consume(c),t.exit("labelMarker"),t.exit("labelLink"),u}function u(c){return c===94&&"_hiddenFootnoteSupport"in r.parser.constructs?l(c):a(c)}}const gf={name:"lineEnding",tokenize:LS};function LS(t,a){return l;function l(r){return t.enter("lineEnding"),t.consume(r),t.exit("lineEnding"),We(t,a,"linePrefix")}}const Bo={name:"thematicBreak",tokenize:jS};function jS(t,a,l){let r=0,o;return u;function u(p){return t.enter("thematicBreak"),c(p)}function c(p){return o=p,h(p)}function h(p){return p===o?(t.enter("thematicBreakSequence"),g(p)):r>=3&&(p===null||Ae(p))?(t.exit("thematicBreak"),a(p)):l(p)}function g(p){return p===o?(t.consume(p),r++,g):(t.exit("thematicBreakSequence"),Ke(p)?We(t,h,"whitespace")(p):h(p))}}const Sn={continuation:{tokenize:HS},exit:$S,name:"list",tokenize:US},BS={partial:!0,tokenize:qS},IS={partial:!0,tokenize:FS};function US(t,a,l){const r=this,o=r.events[r.events.length-1];let u=o&&o[1].type==="linePrefix"?o[2].sliceSerialize(o[1],!0).length:0,c=0;return h;function h(v){const S=r.containerState.type||(v===42||v===43||v===45?"listUnordered":"listOrdered");if(S==="listUnordered"?!r.containerState.marker||v===r.containerState.marker:Kf(v)){if(r.containerState.type||(r.containerState.type=S,t.enter(S,{_container:!0})),S==="listUnordered")return t.enter("listItemPrefix"),v===42||v===45?t.check(Bo,l,p)(v):p(v);if(!r.interrupt||v===49)return t.enter("listItemPrefix"),t.enter("listItemValue"),g(v)}return l(v)}function g(v){return Kf(v)&&++c<10?(t.consume(v),g):(!r.interrupt||c<2)&&(r.containerState.marker?v===r.containerState.marker:v===41||v===46)?(t.exit("listItemValue"),p(v)):l(v)}function p(v){return t.enter("listItemMarker"),t.consume(v),t.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||v,t.check(ns,r.interrupt?l:b,t.attempt(BS,_,x))}function b(v){return r.containerState.initialBlankLine=!0,u++,_(v)}function x(v){return Ke(v)?(t.enter("listItemPrefixWhitespace"),t.consume(v),t.exit("listItemPrefixWhitespace"),_):l(v)}function _(v){return r.containerState.size=u+r.sliceSerialize(t.exit("listItemPrefix"),!0).length,a(v)}}function HS(t,a,l){const r=this;return r.containerState._closeFlow=void 0,t.check(ns,o,u);function o(h){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,We(t,a,"listItemIndent",r.containerState.size+1)(h)}function u(h){return r.containerState.furtherBlankLines||!Ke(h)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,c(h)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,t.attempt(IS,a,c)(h))}function c(h){return r.containerState._closeFlow=!0,r.interrupt=void 0,We(t,t.attempt(Sn,a,l),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(h)}}function FS(t,a,l){const r=this;return We(t,o,"listItemIndent",r.containerState.size+1);function o(u){const c=r.events[r.events.length-1];return c&&c[1].type==="listItemIndent"&&c[2].sliceSerialize(c[1],!0).length===r.containerState.size?a(u):l(u)}}function $S(t){t.exit(this.containerState.type)}function qS(t,a,l){const r=this;return We(t,o,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function o(u){const c=r.events[r.events.length-1];return!Ke(u)&&c&&c[1].type==="listItemPrefixWhitespace"?a(u):l(u)}}const Kg={name:"setextUnderline",resolveTo:GS,tokenize:PS};function GS(t,a){let l=t.length,r,o,u;for(;l--;)if(t[l][0]==="enter"){if(t[l][1].type==="content"){r=l;break}t[l][1].type==="paragraph"&&(o=l)}else t[l][1].type==="content"&&t.splice(l,1),!u&&t[l][1].type==="definition"&&(u=l);const c={type:"setextHeading",start:{...t[r][1].start},end:{...t[t.length-1][1].end}};return t[o][1].type="setextHeadingText",u?(t.splice(o,0,["enter",c,a]),t.splice(u+1,0,["exit",t[r][1],a]),t[r][1].end={...t[u][1].end}):t[r][1]=c,t.push(["exit",c,a]),t}function PS(t,a,l){const r=this;let o;return u;function u(p){let b=r.events.length,x;for(;b--;)if(r.events[b][1].type!=="lineEnding"&&r.events[b][1].type!=="linePrefix"&&r.events[b][1].type!=="content"){x=r.events[b][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||x)?(t.enter("setextHeadingLine"),o=p,c(p)):l(p)}function c(p){return t.enter("setextHeadingLineSequence"),h(p)}function h(p){return p===o?(t.consume(p),h):(t.exit("setextHeadingLineSequence"),Ke(p)?We(t,g,"lineSuffix")(p):g(p))}function g(p){return p===null||Ae(p)?(t.exit("setextHeadingLine"),a(p)):l(p)}}const YS={tokenize:VS};function VS(t){const a=this,l=t.attempt(ns,r,t.attempt(this.parser.constructs.flowInitial,o,We(t,t.attempt(this.parser.constructs.flow,o,t.attempt(JE,o)),"linePrefix")));return l;function r(u){if(u===null){t.consume(u);return}return t.enter("lineEndingBlank"),t.consume(u),t.exit("lineEndingBlank"),a.currentConstruct=void 0,l}function o(u){if(u===null){t.consume(u);return}return t.enter("lineEnding"),t.consume(u),t.exit("lineEnding"),a.currentConstruct=void 0,l}}const KS={resolveAll:Mb()},XS=Ab("string"),ZS=Ab("text");function Ab(t){return{resolveAll:Mb(t==="text"?QS:void 0),tokenize:a};function a(l){const r=this,o=this.parser.constructs[t],u=l.attempt(o,c,h);return c;function c(b){return p(b)?u(b):h(b)}function h(b){if(b===null){l.consume(b);return}return l.enter("data"),l.consume(b),g}function g(b){return p(b)?(l.exit("data"),u(b)):(l.consume(b),g)}function p(b){if(b===null)return!0;const x=o[b];let _=-1;if(x)for(;++_<x.length;){const v=x[_];if(!v.previous||v.previous.call(r,r.previous))return!0}return!1}}}function Mb(t){return a;function a(l,r){let o=-1,u;for(;++o<=l.length;)u===void 0?l[o]&&l[o][1].type==="data"&&(u=o,o++):(!l[o]||l[o][1].type!=="data")&&(o!==u+2&&(l[u][1].end=l[o-1][1].end,l.splice(u+2,o-u-2),o=u+2),u=void 0);return t?t(l,r):l}}function QS(t,a){let l=0;for(;++l<=t.length;)if((l===t.length||t[l][1].type==="lineEnding")&&t[l-1][1].type==="data"){const r=t[l-1][1],o=a.sliceStream(r);let u=o.length,c=-1,h=0,g;for(;u--;){const p=o[u];if(typeof p=="string"){for(c=p.length;p.charCodeAt(c-1)===32;)h++,c--;if(c)break;c=-1}else if(p===-2)g=!0,h++;else if(p!==-1){u++;break}}if(a._contentTypeTextTrailing&&l===t.length&&(h=0),h){const p={type:l===t.length||g||h<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:u?c:r.start._bufferIndex+c,_index:r.start._index+u,line:r.end.line,column:r.end.column-h,offset:r.end.offset-h},end:{...r.end}};r.end={...p.start},r.start.offset===r.end.offset?Object.assign(r,p):(t.splice(l,0,["enter",p,a],["exit",p,a]),l+=2)}l++}return t}const JS={42:Sn,43:Sn,45:Sn,48:Sn,49:Sn,50:Sn,51:Sn,52:Sn,53:Sn,54:Sn,55:Sn,56:Sn,57:Sn,62:vb},WS={91:iS},eN={[-2]:pf,[-1]:pf,32:pf},tN={35:cS,42:Bo,45:[Kg,Bo],60:mS,61:Kg,95:Bo,96:Yg,126:Yg},nN={38:Sb,92:Eb},iN={[-5]:gf,[-4]:gf,[-3]:gf,33:OS,38:Sb,42:Xf,60:[RE,_S],91:RS,92:[sS,Eb],93:_d,95:Xf,96:YE},aN={null:[Xf,KS]},lN={null:[42,95]},rN={null:[]},sN=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:lN,contentInitial:WS,disable:rN,document:JS,flow:tN,flowInitial:eN,insideSpan:aN,string:nN,text:iN},Symbol.toStringTag,{value:"Module"}));function oN(t,a,l){let r={_bufferIndex:-1,_index:0,line:l&&l.line||1,column:l&&l.column||1,offset:l&&l.offset||0};const o={},u=[];let c=[],h=[];const g={attempt:X(Y),check:X(L),consume:O,enter:R,exit:q,interrupt:X(L,{interrupt:!0})},p={code:null,containerState:{},defineSkip:T,events:[],now:S,parser:t,previous:null,sliceSerialize:_,sliceStream:v,write:x};let b=a.tokenize.call(p,g);return a.resolveAll&&u.push(a),p;function x(re){return c=Yn(c,re),A(),c[c.length-1]!==null?[]:(oe(a,0),p.events=Wo(u,p.events,p),p.events)}function _(re,ae){return uN(v(re),ae)}function v(re){return cN(c,re)}function S(){const{_bufferIndex:re,_index:ae,line:le,column:W,offset:H}=r;return{_bufferIndex:re,_index:ae,line:le,column:W,offset:H}}function T(re){o[re.line]=re.column,U()}function A(){let re;for(;r._index<c.length;){const ae=c[r._index];if(typeof ae=="string")for(re=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===re&&r._bufferIndex<ae.length;)w(ae.charCodeAt(r._bufferIndex));else w(ae)}}function w(re){b=b(re)}function O(re){Ae(re)?(r.line++,r.column=1,r.offset+=re===-3?2:1,U()):re!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===c[r._index].length&&(r._bufferIndex=-1,r._index++)),p.previous=re}function R(re,ae){const le=ae||{};return le.type=re,le.start=S(),p.events.push(["enter",le,p]),h.push(le),le}function q(re){const ae=h.pop();return ae.end=S(),p.events.push(["exit",ae,p]),ae}function Y(re,ae){oe(re,ae.from)}function L(re,ae){ae.restore()}function X(re,ae){return le;function le(W,H,C){let K,ne,ie,k;return Array.isArray(W)?B(W):"tokenize"in W?B([W]):M(W);function M(xe){return Be;function Be(ve){const qe=ve!==null&&xe[ve],lt=ve!==null&&xe.null,Yt=[...Array.isArray(qe)?qe:qe?[qe]:[],...Array.isArray(lt)?lt:lt?[lt]:[]];return B(Yt)(ve)}}function B(xe){return K=xe,ne=0,xe.length===0?C:N(xe[ne])}function N(xe){return Be;function Be(ve){return k=he(),ie=xe,xe.partial||(p.currentConstruct=xe),xe.name&&p.parser.constructs.disable.null.includes(xe.name)?pe():xe.tokenize.call(ae?Object.assign(Object.create(p),ae):p,g,ce,pe)(ve)}}function ce(xe){return re(ie,k),H}function pe(xe){return k.restore(),++ne<K.length?N(K[ne]):C}}}function oe(re,ae){re.resolveAll&&!u.includes(re)&&u.push(re),re.resolve&&jn(p.events,ae,p.events.length-ae,re.resolve(p.events.slice(ae),p)),re.resolveTo&&(p.events=re.resolveTo(p.events,p))}function he(){const re=S(),ae=p.previous,le=p.currentConstruct,W=p.events.length,H=Array.from(h);return{from:W,restore:C};function C(){r=re,p.previous=ae,p.currentConstruct=le,p.events.length=W,h=H,U()}}function U(){r.line in o&&r.column<2&&(r.column=o[r.line],r.offset+=o[r.line]-1)}}function cN(t,a){const l=a.start._index,r=a.start._bufferIndex,o=a.end._index,u=a.end._bufferIndex;let c;if(l===o)c=[t[l].slice(r,u)];else{if(c=t.slice(l,o),r>-1){const h=c[0];typeof h=="string"?c[0]=h.slice(r):c.shift()}u>0&&c.push(t[o].slice(0,u))}return c}function uN(t,a){let l=-1;const r=[];let o;for(;++l<t.length;){const u=t[l];let c;if(typeof u=="string")c=u;else switch(u){case-5:{c="\r";break}case-4:{c=`
`;break}case-3:{c=`\r
`;break}case-2:{c=a?" ":"	";break}case-1:{if(!a&&o)continue;c=" ";break}default:c=String.fromCharCode(u)}o=u===-2,r.push(c)}return r.join("")}function fN(t){const r={constructs:yb([sN,...(t||{}).extensions||[]]),content:o(kE),defined:[],document:o(AE),flow:o(YS),lazy:{},string:o(XS),text:o(ZS)};return r;function o(u){return c;function c(h){return oN(r,u,h)}}}function dN(t){for(;!Nb(t););return t}const Xg=/[\0\t\n\r]/g;function mN(){let t=1,a="",l=!0,r;return o;function o(u,c,h){const g=[];let p,b,x,_,v;for(u=a+(typeof u=="string"?u.toString():new TextDecoder(c||void 0).decode(u)),x=0,a="",l&&(u.charCodeAt(0)===65279&&x++,l=void 0);x<u.length;){if(Xg.lastIndex=x,p=Xg.exec(u),_=p&&p.index!==void 0?p.index:u.length,v=u.charCodeAt(_),!p){a=u.slice(x);break}if(v===10&&x===_&&r)g.push(-3),r=void 0;else switch(r&&(g.push(-5),r=void 0),x<_&&(g.push(u.slice(x,_)),t+=_-x),v){case 0:{g.push(65533),t++;break}case 9:{for(b=Math.ceil(t/4)*4,g.push(-2);t++<b;)g.push(-1);break}case 10:{g.push(-4),t=1;break}default:r=!0,t=1}x=_+1}return h&&(r&&g.push(-5),a&&g.push(a),g.push(null)),g}}const hN=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function pN(t){return t.replace(hN,gN)}function gN(t,a,l){if(a)return a;if(l.charCodeAt(0)===35){const o=l.charCodeAt(1),u=o===120||o===88;return _b(l.slice(u?2:1),u?16:10)}return yd(l)||t}const Cb={}.hasOwnProperty;function bN(t,a,l){return a&&typeof a=="object"&&(l=a,a=void 0),xN(l)(dN(fN(l).document().write(mN()(t,a,!0))))}function xN(t){const a={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:u(Re),autolinkProtocol:he,autolinkEmail:he,atxHeading:u(et),blockQuote:u(lt),characterEscape:he,characterReference:he,codeFenced:u(Yt),codeFencedFenceInfo:c,codeFencedFenceMeta:c,codeIndented:u(Yt,c),codeText:u(mn,c),codeTextData:he,data:he,codeFlowValue:he,definition:u(se),definitionDestinationString:c,definitionLabelString:c,definitionTitleString:c,emphasis:u(Me),hardBreakEscape:u(we),hardBreakTrailing:u(we),htmlFlow:u(zt,c),htmlFlowData:he,htmlText:u(zt,c),htmlTextData:he,image:u(de),label:c,link:u(Re),listItem:u(kt),listItemValue:_,listOrdered:u(rt,x),listUnordered:u(rt),paragraph:u(Wn),reference:N,referenceString:c,resourceDestinationString:c,resourceTitleString:c,setextHeading:u(et),strong:u(Fa),thematicBreak:u($a)},exit:{atxHeading:g(),atxHeadingSequence:Y,autolink:g(),autolinkEmail:qe,autolinkProtocol:ve,blockQuote:g(),characterEscapeValue:U,characterReferenceMarkerHexadecimal:pe,characterReferenceMarkerNumeric:pe,characterReferenceValue:xe,characterReference:Be,codeFenced:g(A),codeFencedFence:T,codeFencedFenceInfo:v,codeFencedFenceMeta:S,codeFlowValue:U,codeIndented:g(w),codeText:g(H),codeTextData:U,data:U,definition:g(),definitionDestinationString:q,definitionLabelString:O,definitionTitleString:R,emphasis:g(),hardBreakEscape:g(ae),hardBreakTrailing:g(ae),htmlFlow:g(le),htmlFlowData:U,htmlText:g(W),htmlTextData:U,image:g(K),label:ie,labelText:ne,lineEnding:re,link:g(C),listItem:g(),listOrdered:g(),listUnordered:g(),paragraph:g(),referenceString:ce,resourceDestinationString:k,resourceTitleString:M,resource:B,setextHeading:g(oe),setextHeadingLineSequence:X,setextHeadingText:L,strong:g(),thematicBreak:g()}};Ob(a,(t||{}).mdastExtensions||[]);const l={};return r;function r(Z){let me={type:"root",children:[]};const Ce={stack:[me],tokenStack:[],config:a,enter:h,exit:p,buffer:c,resume:b,data:l},Ge=[];let tt=-1;for(;++tt<Z.length;)if(Z[tt][1].type==="listOrdered"||Z[tt][1].type==="listUnordered")if(Z[tt][0]==="enter")Ge.push(tt);else{const sn=Ge.pop();tt=o(Z,sn,tt)}for(tt=-1;++tt<Z.length;){const sn=a[Z[tt][0]];Cb.call(sn,Z[tt][1].type)&&sn[Z[tt][1].type].call(Object.assign({sliceSerialize:Z[tt][2].sliceSerialize},Ce),Z[tt][1])}if(Ce.tokenStack.length>0){const sn=Ce.tokenStack[Ce.tokenStack.length-1];(sn[1]||Zg).call(Ce,void 0,sn[0])}for(me.position={start:ua(Z.length>0?Z[0][1].start:{line:1,column:1,offset:0}),end:ua(Z.length>0?Z[Z.length-2][1].end:{line:1,column:1,offset:0})},tt=-1;++tt<a.transforms.length;)me=a.transforms[tt](me)||me;return me}function o(Z,me,Ce){let Ge=me-1,tt=-1,sn=!1,Vn,Kt,Mt,en;for(;++Ge<=Ce;){const st=Z[Ge];switch(st[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{st[0]==="enter"?tt++:tt--,en=void 0;break}case"lineEndingBlank":{st[0]==="enter"&&(Vn&&!en&&!tt&&!Mt&&(Mt=Ge),en=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:en=void 0}if(!tt&&st[0]==="enter"&&st[1].type==="listItemPrefix"||tt===-1&&st[0]==="exit"&&(st[1].type==="listUnordered"||st[1].type==="listOrdered")){if(Vn){let ei=Ge;for(Kt=void 0;ei--;){const on=Z[ei];if(on[1].type==="lineEnding"||on[1].type==="lineEndingBlank"){if(on[0]==="exit")continue;Kt&&(Z[Kt][1].type="lineEndingBlank",sn=!0),on[1].type="lineEnding",Kt=ei}else if(!(on[1].type==="linePrefix"||on[1].type==="blockQuotePrefix"||on[1].type==="blockQuotePrefixWhitespace"||on[1].type==="blockQuoteMarker"||on[1].type==="listItemIndent"))break}Mt&&(!Kt||Mt<Kt)&&(Vn._spread=!0),Vn.end=Object.assign({},Kt?Z[Kt][1].start:st[1].end),Z.splice(Kt||Ge,0,["exit",Vn,st[2]]),Ge++,Ce++}if(st[1].type==="listItemPrefix"){const ei={type:"listItem",_spread:!1,start:Object.assign({},st[1].start),end:void 0};Vn=ei,Z.splice(Ge,0,["enter",ei,st[2]]),Ge++,Ce++,Mt=void 0,en=!0}}}return Z[me][1]._spread=sn,Ce}function u(Z,me){return Ce;function Ce(Ge){h.call(this,Z(Ge),Ge),me&&me.call(this,Ge)}}function c(){this.stack.push({type:"fragment",children:[]})}function h(Z,me,Ce){this.stack[this.stack.length-1].children.push(Z),this.stack.push(Z),this.tokenStack.push([me,Ce||void 0]),Z.position={start:ua(me.start),end:void 0}}function g(Z){return me;function me(Ce){Z&&Z.call(this,Ce),p.call(this,Ce)}}function p(Z,me){const Ce=this.stack.pop(),Ge=this.tokenStack.pop();if(Ge)Ge[0].type!==Z.type&&(me?me.call(this,Z,Ge[0]):(Ge[1]||Zg).call(this,Z,Ge[0]));else throw new Error("Cannot close `"+Z.type+"` ("+Yr({start:Z.start,end:Z.end})+"): it’s not open");Ce.position.end=ua(Z.end)}function b(){return xd(this.stack.pop())}function x(){this.data.expectingFirstListItemValue=!0}function _(Z){if(this.data.expectingFirstListItemValue){const me=this.stack[this.stack.length-2];me.start=Number.parseInt(this.sliceSerialize(Z),10),this.data.expectingFirstListItemValue=void 0}}function v(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.lang=Z}function S(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.meta=Z}function T(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function A(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.value=Z.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function w(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.value=Z.replace(/(\r?\n|\r)$/g,"")}function O(Z){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.label=me,Ce.identifier=Jn(this.sliceSerialize(Z)).toLowerCase()}function R(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.title=Z}function q(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.url=Z}function Y(Z){const me=this.stack[this.stack.length-1];if(!me.depth){const Ce=this.sliceSerialize(Z).length;me.depth=Ce}}function L(){this.data.setextHeadingSlurpLineEnding=!0}function X(Z){const me=this.stack[this.stack.length-1];me.depth=this.sliceSerialize(Z).codePointAt(0)===61?1:2}function oe(){this.data.setextHeadingSlurpLineEnding=void 0}function he(Z){const Ce=this.stack[this.stack.length-1].children;let Ge=Ce[Ce.length-1];(!Ge||Ge.type!=="text")&&(Ge=Tt(),Ge.position={start:ua(Z.start),end:void 0},Ce.push(Ge)),this.stack.push(Ge)}function U(Z){const me=this.stack.pop();me.value+=this.sliceSerialize(Z),me.position.end=ua(Z.end)}function re(Z){const me=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Ce=me.children[me.children.length-1];Ce.position.end=ua(Z.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&a.canContainEols.includes(me.type)&&(he.call(this,Z),U.call(this,Z))}function ae(){this.data.atHardBreak=!0}function le(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.value=Z}function W(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.value=Z}function H(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.value=Z}function C(){const Z=this.stack[this.stack.length-1];if(this.data.inReference){const me=this.data.referenceType||"shortcut";Z.type+="Reference",Z.referenceType=me,delete Z.url,delete Z.title}else delete Z.identifier,delete Z.label;this.data.referenceType=void 0}function K(){const Z=this.stack[this.stack.length-1];if(this.data.inReference){const me=this.data.referenceType||"shortcut";Z.type+="Reference",Z.referenceType=me,delete Z.url,delete Z.title}else delete Z.identifier,delete Z.label;this.data.referenceType=void 0}function ne(Z){const me=this.sliceSerialize(Z),Ce=this.stack[this.stack.length-2];Ce.label=pN(me),Ce.identifier=Jn(me).toLowerCase()}function ie(){const Z=this.stack[this.stack.length-1],me=this.resume(),Ce=this.stack[this.stack.length-1];if(this.data.inReference=!0,Ce.type==="link"){const Ge=Z.children;Ce.children=Ge}else Ce.alt=me}function k(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.url=Z}function M(){const Z=this.resume(),me=this.stack[this.stack.length-1];me.title=Z}function B(){this.data.inReference=void 0}function N(){this.data.referenceType="collapsed"}function ce(Z){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.label=me,Ce.identifier=Jn(this.sliceSerialize(Z)).toLowerCase(),this.data.referenceType="full"}function pe(Z){this.data.characterReferenceType=Z.type}function xe(Z){const me=this.sliceSerialize(Z),Ce=this.data.characterReferenceType;let Ge;Ce?(Ge=_b(me,Ce==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):Ge=yd(me);const tt=this.stack[this.stack.length-1];tt.value+=Ge}function Be(Z){const me=this.stack.pop();me.position.end=ua(Z.end)}function ve(Z){U.call(this,Z);const me=this.stack[this.stack.length-1];me.url=this.sliceSerialize(Z)}function qe(Z){U.call(this,Z);const me=this.stack[this.stack.length-1];me.url="mailto:"+this.sliceSerialize(Z)}function lt(){return{type:"blockquote",children:[]}}function Yt(){return{type:"code",lang:null,meta:null,value:""}}function mn(){return{type:"inlineCode",value:""}}function se(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function Me(){return{type:"emphasis",children:[]}}function et(){return{type:"heading",depth:0,children:[]}}function we(){return{type:"break"}}function zt(){return{type:"html",value:""}}function de(){return{type:"image",title:null,url:"",alt:null}}function Re(){return{type:"link",title:null,url:"",children:[]}}function rt(Z){return{type:"list",ordered:Z.type==="listOrdered",start:null,spread:Z._spread,children:[]}}function kt(Z){return{type:"listItem",spread:Z._spread,checked:null,children:[]}}function Wn(){return{type:"paragraph",children:[]}}function Fa(){return{type:"strong",children:[]}}function Tt(){return{type:"text",value:""}}function $a(){return{type:"thematicBreak"}}}function ua(t){return{line:t.line,column:t.column,offset:t.offset}}function Ob(t,a){let l=-1;for(;++l<a.length;){const r=a[l];Array.isArray(r)?Ob(t,r):yN(t,r)}}function yN(t,a){let l;for(l in a)if(Cb.call(a,l))switch(l){case"canContainEols":{const r=a[l];r&&t[l].push(...r);break}case"transforms":{const r=a[l];r&&t[l].push(...r);break}case"enter":case"exit":{const r=a[l];r&&Object.assign(t[l],r);break}}}function Zg(t,a){throw t?new Error("Cannot close `"+t.type+"` ("+Yr({start:t.start,end:t.end})+"): a different token (`"+a.type+"`, "+Yr({start:a.start,end:a.end})+") is open"):new Error("Cannot close document, a token (`"+a.type+"`, "+Yr({start:a.start,end:a.end})+") is still open")}function _N(t){const a=this;a.parser=l;function l(r){return bN(r,{...a.data("settings"),...t,extensions:a.data("micromarkExtensions")||[],mdastExtensions:a.data("fromMarkdownExtensions")||[]})}}function vN(t,a){const l={type:"element",tagName:"blockquote",properties:{},children:t.wrap(t.all(a),!0)};return t.patch(a,l),t.applyData(a,l)}function EN(t,a){const l={type:"element",tagName:"br",properties:{},children:[]};return t.patch(a,l),[t.applyData(a,l),{type:"text",value:`
`}]}function SN(t,a){const l=a.value?a.value+`
`:"",r={},o=a.lang?a.lang.split(/\s+/):[];o.length>0&&(r.className=["language-"+o[0]]);let u={type:"element",tagName:"code",properties:r,children:[{type:"text",value:l}]};return a.meta&&(u.data={meta:a.meta}),t.patch(a,u),u=t.applyData(a,u),u={type:"element",tagName:"pre",properties:{},children:[u]},t.patch(a,u),u}function NN(t,a){const l={type:"element",tagName:"del",properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}function wN(t,a){const l={type:"element",tagName:"em",properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}function kN(t,a){const l=typeof t.options.clobberPrefix=="string"?t.options.clobberPrefix:"user-content-",r=String(a.identifier).toUpperCase(),o=Fl(r.toLowerCase()),u=t.footnoteOrder.indexOf(r);let c,h=t.footnoteCounts.get(r);h===void 0?(h=0,t.footnoteOrder.push(r),c=t.footnoteOrder.length):c=u+1,h+=1,t.footnoteCounts.set(r,h);const g={type:"element",tagName:"a",properties:{href:"#"+l+"fn-"+o,id:l+"fnref-"+o+(h>1?"-"+h:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(c)}]};t.patch(a,g);const p={type:"element",tagName:"sup",properties:{},children:[g]};return t.patch(a,p),t.applyData(a,p)}function TN(t,a){const l={type:"element",tagName:"h"+a.depth,properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}function AN(t,a){if(t.options.allowDangerousHtml){const l={type:"raw",value:a.value};return t.patch(a,l),t.applyData(a,l)}}function zb(t,a){const l=a.referenceType;let r="]";if(l==="collapsed"?r+="[]":l==="full"&&(r+="["+(a.label||a.identifier)+"]"),a.type==="imageReference")return[{type:"text",value:"!["+a.alt+r}];const o=t.all(a),u=o[0];u&&u.type==="text"?u.value="["+u.value:o.unshift({type:"text",value:"["});const c=o[o.length-1];return c&&c.type==="text"?c.value+=r:o.push({type:"text",value:r}),o}function MN(t,a){const l=String(a.identifier).toUpperCase(),r=t.definitionById.get(l);if(!r)return zb(t,a);const o={src:Fl(r.url||""),alt:a.alt};r.title!==null&&r.title!==void 0&&(o.title=r.title);const u={type:"element",tagName:"img",properties:o,children:[]};return t.patch(a,u),t.applyData(a,u)}function CN(t,a){const l={src:Fl(a.url)};a.alt!==null&&a.alt!==void 0&&(l.alt=a.alt),a.title!==null&&a.title!==void 0&&(l.title=a.title);const r={type:"element",tagName:"img",properties:l,children:[]};return t.patch(a,r),t.applyData(a,r)}function ON(t,a){const l={type:"text",value:a.value.replace(/\r?\n|\r/g," ")};t.patch(a,l);const r={type:"element",tagName:"code",properties:{},children:[l]};return t.patch(a,r),t.applyData(a,r)}function zN(t,a){const l=String(a.identifier).toUpperCase(),r=t.definitionById.get(l);if(!r)return zb(t,a);const o={href:Fl(r.url||"")};r.title!==null&&r.title!==void 0&&(o.title=r.title);const u={type:"element",tagName:"a",properties:o,children:t.all(a)};return t.patch(a,u),t.applyData(a,u)}function RN(t,a){const l={href:Fl(a.url)};a.title!==null&&a.title!==void 0&&(l.title=a.title);const r={type:"element",tagName:"a",properties:l,children:t.all(a)};return t.patch(a,r),t.applyData(a,r)}function DN(t,a,l){const r=t.all(a),o=l?LN(l):Rb(a),u={},c=[];if(typeof a.checked=="boolean"){const b=r[0];let x;b&&b.type==="element"&&b.tagName==="p"?x=b:(x={type:"element",tagName:"p",properties:{},children:[]},r.unshift(x)),x.children.length>0&&x.children.unshift({type:"text",value:" "}),x.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:a.checked,disabled:!0},children:[]}),u.className=["task-list-item"]}let h=-1;for(;++h<r.length;){const b=r[h];(o||h!==0||b.type!=="element"||b.tagName!=="p")&&c.push({type:"text",value:`
`}),b.type==="element"&&b.tagName==="p"&&!o?c.push(...b.children):c.push(b)}const g=r[r.length-1];g&&(o||g.type!=="element"||g.tagName!=="p")&&c.push({type:"text",value:`
`});const p={type:"element",tagName:"li",properties:u,children:c};return t.patch(a,p),t.applyData(a,p)}function LN(t){let a=!1;if(t.type==="list"){a=t.spread||!1;const l=t.children;let r=-1;for(;!a&&++r<l.length;)a=Rb(l[r])}return a}function Rb(t){const a=t.spread;return a??t.children.length>1}function jN(t,a){const l={},r=t.all(a);let o=-1;for(typeof a.start=="number"&&a.start!==1&&(l.start=a.start);++o<r.length;){const c=r[o];if(c.type==="element"&&c.tagName==="li"&&c.properties&&Array.isArray(c.properties.className)&&c.properties.className.includes("task-list-item")){l.className=["contains-task-list"];break}}const u={type:"element",tagName:a.ordered?"ol":"ul",properties:l,children:t.wrap(r,!0)};return t.patch(a,u),t.applyData(a,u)}function BN(t,a){const l={type:"element",tagName:"p",properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}function IN(t,a){const l={type:"root",children:t.wrap(t.all(a))};return t.patch(a,l),t.applyData(a,l)}function UN(t,a){const l={type:"element",tagName:"strong",properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}function HN(t,a){const l=t.all(a),r=l.shift(),o=[];if(r){const c={type:"element",tagName:"thead",properties:{},children:t.wrap([r],!0)};t.patch(a.children[0],c),o.push(c)}if(l.length>0){const c={type:"element",tagName:"tbody",properties:{},children:t.wrap(l,!0)},h=hd(a.children[1]),g=db(a.children[a.children.length-1]);h&&g&&(c.position={start:h,end:g}),o.push(c)}const u={type:"element",tagName:"table",properties:{},children:t.wrap(o,!0)};return t.patch(a,u),t.applyData(a,u)}function FN(t,a,l){const r=l?l.children:void 0,u=(r?r.indexOf(a):1)===0?"th":"td",c=l&&l.type==="table"?l.align:void 0,h=c?c.length:a.children.length;let g=-1;const p=[];for(;++g<h;){const x=a.children[g],_={},v=c?c[g]:void 0;v&&(_.align=v);let S={type:"element",tagName:u,properties:_,children:[]};x&&(S.children=t.all(x),t.patch(x,S),S=t.applyData(x,S)),p.push(S)}const b={type:"element",tagName:"tr",properties:{},children:t.wrap(p,!0)};return t.patch(a,b),t.applyData(a,b)}function $N(t,a){const l={type:"element",tagName:"td",properties:{},children:t.all(a)};return t.patch(a,l),t.applyData(a,l)}const Qg=9,Jg=32;function qN(t){const a=String(t),l=/\r?\n|\r/g;let r=l.exec(a),o=0;const u=[];for(;r;)u.push(Wg(a.slice(o,r.index),o>0,!0),r[0]),o=r.index+r[0].length,r=l.exec(a);return u.push(Wg(a.slice(o),o>0,!1)),u.join("")}function Wg(t,a,l){let r=0,o=t.length;if(a){let u=t.codePointAt(r);for(;u===Qg||u===Jg;)r++,u=t.codePointAt(r)}if(l){let u=t.codePointAt(o-1);for(;u===Qg||u===Jg;)o--,u=t.codePointAt(o-1)}return o>r?t.slice(r,o):""}function GN(t,a){const l={type:"text",value:qN(String(a.value))};return t.patch(a,l),t.applyData(a,l)}function PN(t,a){const l={type:"element",tagName:"hr",properties:{},children:[]};return t.patch(a,l),t.applyData(a,l)}const YN={blockquote:vN,break:EN,code:SN,delete:NN,emphasis:wN,footnoteReference:kN,heading:TN,html:AN,imageReference:MN,image:CN,inlineCode:ON,linkReference:zN,link:RN,listItem:DN,list:jN,paragraph:BN,root:IN,strong:UN,table:HN,tableCell:$N,tableRow:FN,text:GN,thematicBreak:PN,toml:wo,yaml:wo,definition:wo,footnoteDefinition:wo};function wo(){}const Db=-1,ec=0,Kr=1,Go=2,vd=3,Ed=4,Sd=5,Nd=6,Lb=7,jb=8,e0=typeof self=="object"?self:globalThis,VN=(t,a)=>{const l=(o,u)=>(t.set(u,o),o),r=o=>{if(t.has(o))return t.get(o);const[u,c]=a[o];switch(u){case ec:case Db:return l(c,o);case Kr:{const h=l([],o);for(const g of c)h.push(r(g));return h}case Go:{const h=l({},o);for(const[g,p]of c)h[r(g)]=r(p);return h}case vd:return l(new Date(c),o);case Ed:{const{source:h,flags:g}=c;return l(new RegExp(h,g),o)}case Sd:{const h=l(new Map,o);for(const[g,p]of c)h.set(r(g),r(p));return h}case Nd:{const h=l(new Set,o);for(const g of c)h.add(r(g));return h}case Lb:{const{name:h,message:g}=c;return l(new e0[h](g),o)}case jb:return l(BigInt(c),o);case"BigInt":return l(Object(BigInt(c)),o);case"ArrayBuffer":return l(new Uint8Array(c).buffer,c);case"DataView":{const{buffer:h}=new Uint8Array(c);return l(new DataView(h),c)}}return l(new e0[u](c),o)};return r},t0=t=>VN(new Map,t)(0),Tl="",{toString:KN}={},{keys:XN}=Object,Hr=t=>{const a=typeof t;if(a!=="object"||!t)return[ec,a];const l=KN.call(t).slice(8,-1);switch(l){case"Array":return[Kr,Tl];case"Object":return[Go,Tl];case"Date":return[vd,Tl];case"RegExp":return[Ed,Tl];case"Map":return[Sd,Tl];case"Set":return[Nd,Tl];case"DataView":return[Kr,l]}return l.includes("Array")?[Kr,l]:l.includes("Error")?[Lb,l]:[Go,l]},ko=([t,a])=>t===ec&&(a==="function"||a==="symbol"),ZN=(t,a,l,r)=>{const o=(c,h)=>{const g=r.push(c)-1;return l.set(h,g),g},u=c=>{if(l.has(c))return l.get(c);let[h,g]=Hr(c);switch(h){case ec:{let b=c;switch(g){case"bigint":h=jb,b=c.toString();break;case"function":case"symbol":if(t)throw new TypeError("unable to serialize "+g);b=null;break;case"undefined":return o([Db],c)}return o([h,b],c)}case Kr:{if(g){let _=c;return g==="DataView"?_=new Uint8Array(c.buffer):g==="ArrayBuffer"&&(_=new Uint8Array(c)),o([g,[..._]],c)}const b=[],x=o([h,b],c);for(const _ of c)b.push(u(_));return x}case Go:{if(g)switch(g){case"BigInt":return o([g,c.toString()],c);case"Boolean":case"Number":case"String":return o([g,c.valueOf()],c)}if(a&&"toJSON"in c)return u(c.toJSON());const b=[],x=o([h,b],c);for(const _ of XN(c))(t||!ko(Hr(c[_])))&&b.push([u(_),u(c[_])]);return x}case vd:return o([h,c.toISOString()],c);case Ed:{const{source:b,flags:x}=c;return o([h,{source:b,flags:x}],c)}case Sd:{const b=[],x=o([h,b],c);for(const[_,v]of c)(t||!(ko(Hr(_))||ko(Hr(v))))&&b.push([u(_),u(v)]);return x}case Nd:{const b=[],x=o([h,b],c);for(const _ of c)(t||!ko(Hr(_)))&&b.push(u(_));return x}}const{message:p}=c;return o([h,{name:g,message:p}],c)};return u},n0=(t,{json:a,lossy:l}={})=>{const r=[];return ZN(!(a||l),!!a,new Map,r)(t),r},Po=typeof structuredClone=="function"?(t,a)=>a&&("json"in a||"lossy"in a)?t0(n0(t,a)):structuredClone(t):(t,a)=>t0(n0(t,a));function QN(t,a){const l=[{type:"text",value:"↩"}];return a>1&&l.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(a)}]}),l}function JN(t,a){return"Back to reference "+(t+1)+(a>1?"-"+a:"")}function WN(t){const a=typeof t.options.clobberPrefix=="string"?t.options.clobberPrefix:"user-content-",l=t.options.footnoteBackContent||QN,r=t.options.footnoteBackLabel||JN,o=t.options.footnoteLabel||"Footnotes",u=t.options.footnoteLabelTagName||"h2",c=t.options.footnoteLabelProperties||{className:["sr-only"]},h=[];let g=-1;for(;++g<t.footnoteOrder.length;){const p=t.footnoteById.get(t.footnoteOrder[g]);if(!p)continue;const b=t.all(p),x=String(p.identifier).toUpperCase(),_=Fl(x.toLowerCase());let v=0;const S=[],T=t.footnoteCounts.get(x);for(;T!==void 0&&++v<=T;){S.length>0&&S.push({type:"text",value:" "});let O=typeof l=="string"?l:l(g,v);typeof O=="string"&&(O={type:"text",value:O}),S.push({type:"element",tagName:"a",properties:{href:"#"+a+"fnref-"+_+(v>1?"-"+v:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(g,v),className:["data-footnote-backref"]},children:Array.isArray(O)?O:[O]})}const A=b[b.length-1];if(A&&A.type==="element"&&A.tagName==="p"){const O=A.children[A.children.length-1];O&&O.type==="text"?O.value+=" ":A.children.push({type:"text",value:" "}),A.children.push(...S)}else b.push(...S);const w={type:"element",tagName:"li",properties:{id:a+"fn-"+_},children:t.wrap(b,!0)};t.patch(p,w),h.push(w)}if(h.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:u,properties:{...Po(c),id:"footnote-label"},children:[{type:"text",value:o}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:t.wrap(h,!0)},{type:"text",value:`
`}]}}const is=(function(t){if(t==null)return iw;if(typeof t=="function")return tc(t);if(typeof t=="object")return Array.isArray(t)?ew(t):tw(t);if(typeof t=="string")return nw(t);throw new Error("Expected function, string, or object as test")});function ew(t){const a=[];let l=-1;for(;++l<t.length;)a[l]=is(t[l]);return tc(r);function r(...o){let u=-1;for(;++u<a.length;)if(a[u].apply(this,o))return!0;return!1}}function tw(t){const a=t;return tc(l);function l(r){const o=r;let u;for(u in t)if(o[u]!==a[u])return!1;return!0}}function nw(t){return tc(a);function a(l){return l&&l.type===t}}function tc(t){return a;function a(l,r,o){return!!(aw(l)&&t.call(this,l,typeof r=="number"?r:void 0,o||void 0))}}function iw(){return!0}function aw(t){return t!==null&&typeof t=="object"&&"type"in t}const Bb=[],lw=!0,Zf=!1,rw="skip";function Ib(t,a,l,r){let o;typeof a=="function"&&typeof l!="function"?(r=l,l=a):o=a;const u=is(o),c=r?-1:1;h(t,void 0,[])();function h(g,p,b){const x=g&&typeof g=="object"?g:{};if(typeof x.type=="string"){const v=typeof x.tagName=="string"?x.tagName:typeof x.name=="string"?x.name:void 0;Object.defineProperty(_,"name",{value:"node ("+(g.type+(v?"<"+v+">":""))+")"})}return _;function _(){let v=Bb,S,T,A;if((!a||u(g,p,b[b.length-1]||void 0))&&(v=sw(l(g,b)),v[0]===Zf))return v;if("children"in g&&g.children){const w=g;if(w.children&&v[0]!==rw)for(T=(r?w.children.length:-1)+c,A=b.concat(w);T>-1&&T<w.children.length;){const O=w.children[T];if(S=h(O,T,A)(),S[0]===Zf)return S;T=typeof S[1]=="number"?S[1]:T+c}}return v}}}function sw(t){return Array.isArray(t)?t:typeof t=="number"?[lw,t]:t==null?Bb:[t]}function nc(t,a,l,r){let o,u,c;typeof a=="function"&&typeof l!="function"?(u=void 0,c=a,o=l):(u=a,c=l,o=r),Ib(t,u,h,o);function h(g,p){const b=p[p.length-1],x=b?b.children.indexOf(g):void 0;return c(g,x,b)}}const Qf={}.hasOwnProperty,ow={};function cw(t,a){const l=a||ow,r=new Map,o=new Map,u=new Map,c={...YN,...l.handlers},h={all:p,applyData:fw,definitionById:r,footnoteById:o,footnoteCounts:u,footnoteOrder:[],handlers:c,one:g,options:l,patch:uw,wrap:mw};return nc(t,function(b){if(b.type==="definition"||b.type==="footnoteDefinition"){const x=b.type==="definition"?r:o,_=String(b.identifier).toUpperCase();x.has(_)||x.set(_,b)}}),h;function g(b,x){const _=b.type,v=h.handlers[_];if(Qf.call(h.handlers,_)&&v)return v(h,b,x);if(h.options.passThrough&&h.options.passThrough.includes(_)){if("children"in b){const{children:T,...A}=b,w=Po(A);return w.children=h.all(b),w}return Po(b)}return(h.options.unknownHandler||dw)(h,b,x)}function p(b){const x=[];if("children"in b){const _=b.children;let v=-1;for(;++v<_.length;){const S=h.one(_[v],b);if(S){if(v&&_[v-1].type==="break"&&(!Array.isArray(S)&&S.type==="text"&&(S.value=i0(S.value)),!Array.isArray(S)&&S.type==="element")){const T=S.children[0];T&&T.type==="text"&&(T.value=i0(T.value))}Array.isArray(S)?x.push(...S):x.push(S)}}}return x}}function uw(t,a){t.position&&(a.position=Jv(t))}function fw(t,a){let l=a;if(t&&t.data){const r=t.data.hName,o=t.data.hChildren,u=t.data.hProperties;if(typeof r=="string")if(l.type==="element")l.tagName=r;else{const c="children"in l?l.children:[l];l={type:"element",tagName:r,properties:{},children:c}}l.type==="element"&&u&&Object.assign(l.properties,Po(u)),"children"in l&&l.children&&o!==null&&o!==void 0&&(l.children=o)}return l}function dw(t,a){const l=a.data||{},r="value"in a&&!(Qf.call(l,"hProperties")||Qf.call(l,"hChildren"))?{type:"text",value:a.value}:{type:"element",tagName:"div",properties:{},children:t.all(a)};return t.patch(a,r),t.applyData(a,r)}function mw(t,a){const l=[];let r=-1;for(a&&l.push({type:"text",value:`
`});++r<t.length;)r&&l.push({type:"text",value:`
`}),l.push(t[r]);return a&&t.length>0&&l.push({type:"text",value:`
`}),l}function i0(t){let a=0,l=t.charCodeAt(a);for(;l===9||l===32;)a++,l=t.charCodeAt(a);return t.slice(a)}function a0(t,a){const l=cw(t,a),r=l.one(t,void 0),o=WN(l),u=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return o&&u.children.push({type:"text",value:`
`},o),u}function hw(t,a){return t&&"run"in t?async function(l,r){const o=a0(l,{file:r,...a});await t.run(o,r)}:function(l,r){return a0(l,{file:r,...t||a})}}function l0(t){if(t)throw t}var bf,r0;function pw(){if(r0)return bf;r0=1;var t=Object.prototype.hasOwnProperty,a=Object.prototype.toString,l=Object.defineProperty,r=Object.getOwnPropertyDescriptor,o=function(p){return typeof Array.isArray=="function"?Array.isArray(p):a.call(p)==="[object Array]"},u=function(p){if(!p||a.call(p)!=="[object Object]")return!1;var b=t.call(p,"constructor"),x=p.constructor&&p.constructor.prototype&&t.call(p.constructor.prototype,"isPrototypeOf");if(p.constructor&&!b&&!x)return!1;var _;for(_ in p);return typeof _>"u"||t.call(p,_)},c=function(p,b){l&&b.name==="__proto__"?l(p,b.name,{enumerable:!0,configurable:!0,value:b.newValue,writable:!0}):p[b.name]=b.newValue},h=function(p,b){if(b==="__proto__")if(t.call(p,b)){if(r)return r(p,b).value}else return;return p[b]};return bf=function g(){var p,b,x,_,v,S,T=arguments[0],A=1,w=arguments.length,O=!1;for(typeof T=="boolean"&&(O=T,T=arguments[1]||{},A=2),(T==null||typeof T!="object"&&typeof T!="function")&&(T={});A<w;++A)if(p=arguments[A],p!=null)for(b in p)x=h(T,b),_=h(p,b),T!==_&&(O&&_&&(u(_)||(v=o(_)))?(v?(v=!1,S=x&&o(x)?x:[]):S=x&&u(x)?x:{},c(T,{name:b,newValue:g(O,S,_)})):typeof _<"u"&&c(T,{name:b,newValue:_}));return T},bf}var gw=pw();const xf=sd(gw);function Jf(t){if(typeof t!="object"||t===null)return!1;const a=Object.getPrototypeOf(t);return(a===null||a===Object.prototype||Object.getPrototypeOf(a)===null)&&!(Symbol.toStringTag in t)&&!(Symbol.iterator in t)}function bw(){const t=[],a={run:l,use:r};return a;function l(...o){let u=-1;const c=o.pop();if(typeof c!="function")throw new TypeError("Expected function as last argument, not "+c);h(null,...o);function h(g,...p){const b=t[++u];let x=-1;if(g){c(g);return}for(;++x<o.length;)(p[x]===null||p[x]===void 0)&&(p[x]=o[x]);o=p,b?xw(b,h)(...p):c(null,...p)}}function r(o){if(typeof o!="function")throw new TypeError("Expected `middelware` to be a function, not "+o);return t.push(o),a}}function xw(t,a){let l;return r;function r(...c){const h=t.length>c.length;let g;h&&c.push(o);try{g=t.apply(this,c)}catch(p){const b=p;if(h&&l)throw b;return o(b)}h||(g&&g.then&&typeof g.then=="function"?g.then(u,o):g instanceof Error?o(g):u(g))}function o(c,...h){l||(l=!0,a(c,...h))}function u(c){o(null,c)}}const ci={basename:yw,dirname:_w,extname:vw,join:Ew,sep:"/"};function yw(t,a){if(a!==void 0&&typeof a!="string")throw new TypeError('"ext" argument must be a string');as(t);let l=0,r=-1,o=t.length,u;if(a===void 0||a.length===0||a.length>t.length){for(;o--;)if(t.codePointAt(o)===47){if(u){l=o+1;break}}else r<0&&(u=!0,r=o+1);return r<0?"":t.slice(l,r)}if(a===t)return"";let c=-1,h=a.length-1;for(;o--;)if(t.codePointAt(o)===47){if(u){l=o+1;break}}else c<0&&(u=!0,c=o+1),h>-1&&(t.codePointAt(o)===a.codePointAt(h--)?h<0&&(r=o):(h=-1,r=c));return l===r?r=c:r<0&&(r=t.length),t.slice(l,r)}function _w(t){if(as(t),t.length===0)return".";let a=-1,l=t.length,r;for(;--l;)if(t.codePointAt(l)===47){if(r){a=l;break}}else r||(r=!0);return a<0?t.codePointAt(0)===47?"/":".":a===1&&t.codePointAt(0)===47?"//":t.slice(0,a)}function vw(t){as(t);let a=t.length,l=-1,r=0,o=-1,u=0,c;for(;a--;){const h=t.codePointAt(a);if(h===47){if(c){r=a+1;break}continue}l<0&&(c=!0,l=a+1),h===46?o<0?o=a:u!==1&&(u=1):o>-1&&(u=-1)}return o<0||l<0||u===0||u===1&&o===l-1&&o===r+1?"":t.slice(o,l)}function Ew(...t){let a=-1,l;for(;++a<t.length;)as(t[a]),t[a]&&(l=l===void 0?t[a]:l+"/"+t[a]);return l===void 0?".":Sw(l)}function Sw(t){as(t);const a=t.codePointAt(0)===47;let l=Nw(t,!a);return l.length===0&&!a&&(l="."),l.length>0&&t.codePointAt(t.length-1)===47&&(l+="/"),a?"/"+l:l}function Nw(t,a){let l="",r=0,o=-1,u=0,c=-1,h,g;for(;++c<=t.length;){if(c<t.length)h=t.codePointAt(c);else{if(h===47)break;h=47}if(h===47){if(!(o===c-1||u===1))if(o!==c-1&&u===2){if(l.length<2||r!==2||l.codePointAt(l.length-1)!==46||l.codePointAt(l.length-2)!==46){if(l.length>2){if(g=l.lastIndexOf("/"),g!==l.length-1){g<0?(l="",r=0):(l=l.slice(0,g),r=l.length-1-l.lastIndexOf("/")),o=c,u=0;continue}}else if(l.length>0){l="",r=0,o=c,u=0;continue}}a&&(l=l.length>0?l+"/..":"..",r=2)}else l.length>0?l+="/"+t.slice(o+1,c):l=t.slice(o+1,c),r=c-o-1;o=c,u=0}else h===46&&u>-1?u++:u=-1}return l}function as(t){if(typeof t!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(t))}const ww={cwd:kw};function kw(){return"/"}function Wf(t){return!!(t!==null&&typeof t=="object"&&"href"in t&&t.href&&"protocol"in t&&t.protocol&&t.auth===void 0)}function Tw(t){if(typeof t=="string")t=new URL(t);else if(!Wf(t)){const a=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+t+"`");throw a.code="ERR_INVALID_ARG_TYPE",a}if(t.protocol!=="file:"){const a=new TypeError("The URL must be of scheme file");throw a.code="ERR_INVALID_URL_SCHEME",a}return Aw(t)}function Aw(t){if(t.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const a=t.pathname;let l=-1;for(;++l<a.length;)if(a.codePointAt(l)===37&&a.codePointAt(l+1)===50){const r=a.codePointAt(l+2);if(r===70||r===102){const o=new TypeError("File URL path must not include encoded / characters");throw o.code="ERR_INVALID_FILE_URL_PATH",o}}return decodeURIComponent(a)}const yf=["history","path","basename","stem","extname","dirname"];class Ub{constructor(a){let l;a?Wf(a)?l={path:a}:typeof a=="string"||Mw(a)?l={value:a}:l=a:l={},this.cwd="cwd"in l?"":ww.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<yf.length;){const u=yf[r];u in l&&l[u]!==void 0&&l[u]!==null&&(this[u]=u==="history"?[...l[u]]:l[u])}let o;for(o in l)yf.includes(o)||(this[o]=l[o])}get basename(){return typeof this.path=="string"?ci.basename(this.path):void 0}set basename(a){vf(a,"basename"),_f(a,"basename"),this.path=ci.join(this.dirname||"",a)}get dirname(){return typeof this.path=="string"?ci.dirname(this.path):void 0}set dirname(a){s0(this.basename,"dirname"),this.path=ci.join(a||"",this.basename)}get extname(){return typeof this.path=="string"?ci.extname(this.path):void 0}set extname(a){if(_f(a,"extname"),s0(this.dirname,"extname"),a){if(a.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(a.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=ci.join(this.dirname,this.stem+(a||""))}get path(){return this.history[this.history.length-1]}set path(a){Wf(a)&&(a=Tw(a)),vf(a,"path"),this.path!==a&&this.history.push(a)}get stem(){return typeof this.path=="string"?ci.basename(this.path,this.extname):void 0}set stem(a){vf(a,"stem"),_f(a,"stem"),this.path=ci.join(this.dirname||"",a+(this.extname||""))}fail(a,l,r){const o=this.message(a,l,r);throw o.fatal=!0,o}info(a,l,r){const o=this.message(a,l,r);return o.fatal=void 0,o}message(a,l,r){const o=new rn(a,l,r);return this.path&&(o.name=this.path+":"+o.name,o.file=this.path),o.fatal=!1,this.messages.push(o),o}toString(a){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(a||void 0).decode(this.value)}}function _f(t,a){if(t&&t.includes(ci.sep))throw new Error("`"+a+"` cannot be a path: did not expect `"+ci.sep+"`")}function vf(t,a){if(!t)throw new Error("`"+a+"` cannot be empty")}function s0(t,a){if(!t)throw new Error("Setting `"+a+"` requires `path` to be set too")}function Mw(t){return!!(t&&typeof t=="object"&&"byteLength"in t&&"byteOffset"in t)}const Cw=(function(t){const r=this.constructor.prototype,o=r[t],u=function(){return o.apply(u,arguments)};return Object.setPrototypeOf(u,r),u}),Ow={}.hasOwnProperty;class wd extends Cw{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=bw()}copy(){const a=new wd;let l=-1;for(;++l<this.attachers.length;){const r=this.attachers[l];a.use(...r)}return a.data(xf(!0,{},this.namespace)),a}data(a,l){return typeof a=="string"?arguments.length===2?(Nf("data",this.frozen),this.namespace[a]=l,this):Ow.call(this.namespace,a)&&this.namespace[a]||void 0:a?(Nf("data",this.frozen),this.namespace=a,this):this.namespace}freeze(){if(this.frozen)return this;const a=this;for(;++this.freezeIndex<this.attachers.length;){const[l,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const o=l.call(a,...r);typeof o=="function"&&this.transformers.use(o)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(a){this.freeze();const l=To(a),r=this.parser||this.Parser;return Ef("parse",r),r(String(l),l)}process(a,l){const r=this;return this.freeze(),Ef("process",this.parser||this.Parser),Sf("process",this.compiler||this.Compiler),l?o(void 0,l):new Promise(o);function o(u,c){const h=To(a),g=r.parse(h);r.run(g,h,function(b,x,_){if(b||!x||!_)return p(b);const v=x,S=r.stringify(v,_);Dw(S)?_.value=S:_.result=S,p(b,_)});function p(b,x){b||!x?c(b):u?u(x):l(void 0,x)}}}processSync(a){let l=!1,r;return this.freeze(),Ef("processSync",this.parser||this.Parser),Sf("processSync",this.compiler||this.Compiler),this.process(a,o),c0("processSync","process",l),r;function o(u,c){l=!0,l0(u),r=c}}run(a,l,r){o0(a),this.freeze();const o=this.transformers;return!r&&typeof l=="function"&&(r=l,l=void 0),r?u(void 0,r):new Promise(u);function u(c,h){const g=To(l);o.run(a,g,p);function p(b,x,_){const v=x||a;b?h(b):c?c(v):r(void 0,v,_)}}}runSync(a,l){let r=!1,o;return this.run(a,l,u),c0("runSync","run",r),o;function u(c,h){l0(c),o=h,r=!0}}stringify(a,l){this.freeze();const r=To(l),o=this.compiler||this.Compiler;return Sf("stringify",o),o0(a),o(a,r)}use(a,...l){const r=this.attachers,o=this.namespace;if(Nf("use",this.frozen),a!=null)if(typeof a=="function")g(a,l);else if(typeof a=="object")Array.isArray(a)?h(a):c(a);else throw new TypeError("Expected usable value, not `"+a+"`");return this;function u(p){if(typeof p=="function")g(p,[]);else if(typeof p=="object")if(Array.isArray(p)){const[b,...x]=p;g(b,x)}else c(p);else throw new TypeError("Expected usable value, not `"+p+"`")}function c(p){if(!("plugins"in p)&&!("settings"in p))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");h(p.plugins),p.settings&&(o.settings=xf(!0,o.settings,p.settings))}function h(p){let b=-1;if(p!=null)if(Array.isArray(p))for(;++b<p.length;){const x=p[b];u(x)}else throw new TypeError("Expected a list of plugins, not `"+p+"`")}function g(p,b){let x=-1,_=-1;for(;++x<r.length;)if(r[x][0]===p){_=x;break}if(_===-1)r.push([p,...b]);else if(b.length>0){let[v,...S]=b;const T=r[_][1];Jf(T)&&Jf(v)&&(v=xf(!0,T,v)),r[_]=[p,v,...S]}}}}const zw=new wd().freeze();function Ef(t,a){if(typeof a!="function")throw new TypeError("Cannot `"+t+"` without `parser`")}function Sf(t,a){if(typeof a!="function")throw new TypeError("Cannot `"+t+"` without `compiler`")}function Nf(t,a){if(a)throw new Error("Cannot call `"+t+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function o0(t){if(!Jf(t)||typeof t.type!="string")throw new TypeError("Expected node, got `"+t+"`")}function c0(t,a,l){if(!l)throw new Error("`"+t+"` finished async. Use `"+a+"` instead")}function To(t){return Rw(t)?t:new Ub(t)}function Rw(t){return!!(t&&typeof t=="object"&&"message"in t&&"messages"in t)}function Dw(t){return typeof t=="string"||Lw(t)}function Lw(t){return!!(t&&typeof t=="object"&&"byteLength"in t&&"byteOffset"in t)}const jw="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",u0=[],f0={allowDangerousHtml:!0},Bw=/^(https?|ircs?|mailto|xmpp)$/i,Iw=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function Uw(t){const a=Hw(t),l=Fw(t);return $w(a.runSync(a.parse(l),l),t)}function Hw(t){const a=t.rehypePlugins||u0,l=t.remarkPlugins||u0,r=t.remarkRehypeOptions?{...t.remarkRehypeOptions,...f0}:f0;return zw().use(_N).use(l).use(hw,r).use(a)}function Fw(t){const a=t.children||"",l=new Ub;return typeof a=="string"&&(l.value=a),l}function $w(t,a){const l=a.allowedElements,r=a.allowElement,o=a.components,u=a.disallowedElements,c=a.skipHtml,h=a.unwrapDisallowed,g=a.urlTransform||qw;for(const b of Iw)Object.hasOwn(a,b.from)&&(""+b.from+(b.to?"use `"+b.to+"` instead":"remove it")+jw+b.id,void 0);return nc(t,p),iE(t,{Fragment:d.Fragment,components:o,ignoreInvalidStyle:!0,jsx:d.jsx,jsxs:d.jsxs,passKeys:!0,passNode:!0});function p(b,x,_){if(b.type==="raw"&&_&&typeof x=="number")return c?_.children.splice(x,1):_.children[x]={type:"text",value:b.value},x;if(b.type==="element"){let v;for(v in hf)if(Object.hasOwn(hf,v)&&Object.hasOwn(b.properties,v)){const S=b.properties[v],T=hf[v];(T===null||T.includes(b.tagName))&&(b.properties[v]=g(String(S||""),v,b))}}if(b.type==="element"){let v=l?!l.includes(b.tagName):u?u.includes(b.tagName):!1;if(!v&&r&&typeof x=="number"&&(v=!r(b,x,_)),v&&_&&typeof x=="number")return h&&b.children?_.children.splice(x,1,...b.children):_.children.splice(x,1),x}}}function qw(t){const a=t.indexOf(":"),l=t.indexOf("?"),r=t.indexOf("#"),o=t.indexOf("/");return a===-1||o!==-1&&a>o||l!==-1&&a>l||r!==-1&&a>r||Bw.test(t.slice(0,a))?t:""}function d0(t,a){const l=String(t);if(typeof a!="string")throw new TypeError("Expected character");let r=0,o=l.indexOf(a);for(;o!==-1;)r++,o=l.indexOf(a,o+a.length);return r}function Gw(t){if(typeof t!="string")throw new TypeError("Expected a string");return t.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function Pw(t,a,l){const o=is((l||{}).ignore||[]),u=Yw(a);let c=-1;for(;++c<u.length;)Ib(t,"text",h);function h(p,b){let x=-1,_;for(;++x<b.length;){const v=b[x],S=_?_.children:void 0;if(o(v,S?S.indexOf(v):void 0,_))return;_=v}if(_)return g(p,b)}function g(p,b){const x=b[b.length-1],_=u[c][0],v=u[c][1];let S=0;const A=x.children.indexOf(p);let w=!1,O=[];_.lastIndex=0;let R=_.exec(p.value);for(;R;){const q=R.index,Y={index:R.index,input:R.input,stack:[...b,p]};let L=v(...R,Y);if(typeof L=="string"&&(L=L.length>0?{type:"text",value:L}:void 0),L===!1?_.lastIndex=q+1:(S!==q&&O.push({type:"text",value:p.value.slice(S,q)}),Array.isArray(L)?O.push(...L):L&&O.push(L),S=q+R[0].length,w=!0),!_.global)break;R=_.exec(p.value)}return w?(S<p.value.length&&O.push({type:"text",value:p.value.slice(S)}),x.children.splice(A,1,...O)):O=[p],A+O.length}}function Yw(t){const a=[];if(!Array.isArray(t))throw new TypeError("Expected find and replace tuple or list of tuples");const l=!t[0]||Array.isArray(t[0])?t:[t];let r=-1;for(;++r<l.length;){const o=l[r];a.push([Vw(o[0]),Kw(o[1])])}return a}function Vw(t){return typeof t=="string"?new RegExp(Gw(t),"g"):t}function Kw(t){return typeof t=="function"?t:function(){return t}}const wf="phrasing",kf=["autolink","link","image","label"];function Xw(){return{transforms:[nk],enter:{literalAutolink:Qw,literalAutolinkEmail:Tf,literalAutolinkHttp:Tf,literalAutolinkWww:Tf},exit:{literalAutolink:tk,literalAutolinkEmail:ek,literalAutolinkHttp:Jw,literalAutolinkWww:Ww}}}function Zw(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:wf,notInConstruct:kf},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:wf,notInConstruct:kf},{character:":",before:"[ps]",after:"\\/",inConstruct:wf,notInConstruct:kf}]}}function Qw(t){this.enter({type:"link",title:null,url:"",children:[]},t)}function Tf(t){this.config.enter.autolinkProtocol.call(this,t)}function Jw(t){this.config.exit.autolinkProtocol.call(this,t)}function Ww(t){this.config.exit.data.call(this,t);const a=this.stack[this.stack.length-1];a.type,a.url="http://"+this.sliceSerialize(t)}function ek(t){this.config.exit.autolinkEmail.call(this,t)}function tk(t){this.exit(t)}function nk(t){Pw(t,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,ik],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),ak]],{ignore:["link","linkReference"]})}function ik(t,a,l,r,o){let u="";if(!Hb(o)||(/^w/i.test(a)&&(l=a+l,a="",u="http://"),!lk(l)))return!1;const c=rk(l+r);if(!c[0])return!1;const h={type:"link",title:null,url:u+a+c[0],children:[{type:"text",value:a+c[0]}]};return c[1]?[h,{type:"text",value:c[1]}]:h}function ak(t,a,l,r){return!Hb(r,!0)||/[-\d_]$/.test(l)?!1:{type:"link",title:null,url:"mailto:"+a+"@"+l,children:[{type:"text",value:a+"@"+l}]}}function lk(t){const a=t.split(".");return!(a.length<2||a[a.length-1]&&(/_/.test(a[a.length-1])||!/[a-zA-Z\d]/.test(a[a.length-1]))||a[a.length-2]&&(/_/.test(a[a.length-2])||!/[a-zA-Z\d]/.test(a[a.length-2])))}function rk(t){const a=/[!"&'),.:;<>?\]}]+$/.exec(t);if(!a)return[t,void 0];t=t.slice(0,a.index);let l=a[0],r=l.indexOf(")");const o=d0(t,"(");let u=d0(t,")");for(;r!==-1&&o>u;)t+=l.slice(0,r+1),l=l.slice(r+1),r=l.indexOf(")"),u++;return[t,l]}function Hb(t,a){const l=t.input.charCodeAt(t.index-1);return(t.index===0||Ia(l)||Jo(l))&&(!a||l!==47)}Fb.peek=pk;function sk(){this.buffer()}function ok(t){this.enter({type:"footnoteReference",identifier:"",label:""},t)}function ck(){this.buffer()}function uk(t){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},t)}function fk(t){const a=this.resume(),l=this.stack[this.stack.length-1];l.type,l.identifier=Jn(this.sliceSerialize(t)).toLowerCase(),l.label=a}function dk(t){this.exit(t)}function mk(t){const a=this.resume(),l=this.stack[this.stack.length-1];l.type,l.identifier=Jn(this.sliceSerialize(t)).toLowerCase(),l.label=a}function hk(t){this.exit(t)}function pk(){return"["}function Fb(t,a,l,r){const o=l.createTracker(r);let u=o.move("[^");const c=l.enter("footnoteReference"),h=l.enter("reference");return u+=o.move(l.safe(l.associationId(t),{after:"]",before:u})),h(),c(),u+=o.move("]"),u}function gk(){return{enter:{gfmFootnoteCallString:sk,gfmFootnoteCall:ok,gfmFootnoteDefinitionLabelString:ck,gfmFootnoteDefinition:uk},exit:{gfmFootnoteCallString:fk,gfmFootnoteCall:dk,gfmFootnoteDefinitionLabelString:mk,gfmFootnoteDefinition:hk}}}function bk(t){let a=!1;return t&&t.firstLineBlank&&(a=!0),{handlers:{footnoteDefinition:l,footnoteReference:Fb},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function l(r,o,u,c){const h=u.createTracker(c);let g=h.move("[^");const p=u.enter("footnoteDefinition"),b=u.enter("label");return g+=h.move(u.safe(u.associationId(r),{before:g,after:"]"})),b(),g+=h.move("]:"),r.children&&r.children.length>0&&(h.shift(4),g+=h.move((a?`
`:" ")+u.indentLines(u.containerFlow(r,h.current()),a?$b:xk))),p(),g}}function xk(t,a,l){return a===0?t:$b(t,a,l)}function $b(t,a,l){return(l?"":"    ")+t}const yk=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];qb.peek=Nk;function _k(){return{canContainEols:["delete"],enter:{strikethrough:Ek},exit:{strikethrough:Sk}}}function vk(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:yk}],handlers:{delete:qb}}}function Ek(t){this.enter({type:"delete",children:[]},t)}function Sk(t){this.exit(t)}function qb(t,a,l,r){const o=l.createTracker(r),u=l.enter("strikethrough");let c=o.move("~~");return c+=l.containerPhrasing(t,{...o.current(),before:c,after:"~"}),c+=o.move("~~"),u(),c}function Nk(){return"~"}function wk(t){return t.length}function kk(t,a){const l=a||{},r=(l.align||[]).concat(),o=l.stringLength||wk,u=[],c=[],h=[],g=[];let p=0,b=-1;for(;++b<t.length;){const T=[],A=[];let w=-1;for(t[b].length>p&&(p=t[b].length);++w<t[b].length;){const O=Tk(t[b][w]);if(l.alignDelimiters!==!1){const R=o(O);A[w]=R,(g[w]===void 0||R>g[w])&&(g[w]=R)}T.push(O)}c[b]=T,h[b]=A}let x=-1;if(typeof r=="object"&&"length"in r)for(;++x<p;)u[x]=m0(r[x]);else{const T=m0(r);for(;++x<p;)u[x]=T}x=-1;const _=[],v=[];for(;++x<p;){const T=u[x];let A="",w="";T===99?(A=":",w=":"):T===108?A=":":T===114&&(w=":");let O=l.alignDelimiters===!1?1:Math.max(1,g[x]-A.length-w.length);const R=A+"-".repeat(O)+w;l.alignDelimiters!==!1&&(O=A.length+O+w.length,O>g[x]&&(g[x]=O),v[x]=O),_[x]=R}c.splice(1,0,_),h.splice(1,0,v),b=-1;const S=[];for(;++b<c.length;){const T=c[b],A=h[b];x=-1;const w=[];for(;++x<p;){const O=T[x]||"";let R="",q="";if(l.alignDelimiters!==!1){const Y=g[x]-(A[x]||0),L=u[x];L===114?R=" ".repeat(Y):L===99?Y%2?(R=" ".repeat(Y/2+.5),q=" ".repeat(Y/2-.5)):(R=" ".repeat(Y/2),q=R):q=" ".repeat(Y)}l.delimiterStart!==!1&&!x&&w.push("|"),l.padding!==!1&&!(l.alignDelimiters===!1&&O==="")&&(l.delimiterStart!==!1||x)&&w.push(" "),l.alignDelimiters!==!1&&w.push(R),w.push(O),l.alignDelimiters!==!1&&w.push(q),l.padding!==!1&&w.push(" "),(l.delimiterEnd!==!1||x!==p-1)&&w.push("|")}S.push(l.delimiterEnd===!1?w.join("").replace(/ +$/,""):w.join(""))}return S.join(`
`)}function Tk(t){return t==null?"":String(t)}function m0(t){const a=typeof t=="string"?t.codePointAt(0):0;return a===67||a===99?99:a===76||a===108?108:a===82||a===114?114:0}function Ak(t,a,l,r){const o=l.enter("blockquote"),u=l.createTracker(r);u.move("> "),u.shift(2);const c=l.indentLines(l.containerFlow(t,u.current()),Mk);return o(),c}function Mk(t,a,l){return">"+(l?"":" ")+t}function Ck(t,a){return h0(t,a.inConstruct,!0)&&!h0(t,a.notInConstruct,!1)}function h0(t,a,l){if(typeof a=="string"&&(a=[a]),!a||a.length===0)return l;let r=-1;for(;++r<a.length;)if(t.includes(a[r]))return!0;return!1}function p0(t,a,l,r){let o=-1;for(;++o<l.unsafe.length;)if(l.unsafe[o].character===`
`&&Ck(l.stack,l.unsafe[o]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function Ok(t,a){const l=String(t);let r=l.indexOf(a),o=r,u=0,c=0;if(typeof a!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===o?++u>c&&(c=u):u=1,o=r+a.length,r=l.indexOf(a,o);return c}function zk(t,a){return!!(a.options.fences===!1&&t.value&&!t.lang&&/[^ \r\n]/.test(t.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(t.value))}function Rk(t){const a=t.options.fence||"`";if(a!=="`"&&a!=="~")throw new Error("Cannot serialize code with `"+a+"` for `options.fence`, expected `` ` `` or `~`");return a}function Dk(t,a,l,r){const o=Rk(l),u=t.value||"",c=o==="`"?"GraveAccent":"Tilde";if(zk(t,l)){const x=l.enter("codeIndented"),_=l.indentLines(u,Lk);return x(),_}const h=l.createTracker(r),g=o.repeat(Math.max(Ok(u,o)+1,3)),p=l.enter("codeFenced");let b=h.move(g);if(t.lang){const x=l.enter(`codeFencedLang${c}`);b+=h.move(l.safe(t.lang,{before:b,after:" ",encode:["`"],...h.current()})),x()}if(t.lang&&t.meta){const x=l.enter(`codeFencedMeta${c}`);b+=h.move(" "),b+=h.move(l.safe(t.meta,{before:b,after:`
`,encode:["`"],...h.current()})),x()}return b+=h.move(`
`),u&&(b+=h.move(u+`
`)),b+=h.move(g),p(),b}function Lk(t,a,l){return(l?"":"    ")+t}function kd(t){const a=t.options.quote||'"';if(a!=='"'&&a!=="'")throw new Error("Cannot serialize title with `"+a+"` for `options.quote`, expected `\"`, or `'`");return a}function jk(t,a,l,r){const o=kd(l),u=o==='"'?"Quote":"Apostrophe",c=l.enter("definition");let h=l.enter("label");const g=l.createTracker(r);let p=g.move("[");return p+=g.move(l.safe(l.associationId(t),{before:p,after:"]",...g.current()})),p+=g.move("]: "),h(),!t.url||/[\0- \u007F]/.test(t.url)?(h=l.enter("destinationLiteral"),p+=g.move("<"),p+=g.move(l.safe(t.url,{before:p,after:">",...g.current()})),p+=g.move(">")):(h=l.enter("destinationRaw"),p+=g.move(l.safe(t.url,{before:p,after:t.title?" ":`
`,...g.current()}))),h(),t.title&&(h=l.enter(`title${u}`),p+=g.move(" "+o),p+=g.move(l.safe(t.title,{before:p,after:o,...g.current()})),p+=g.move(o),h()),c(),p}function Bk(t){const a=t.options.emphasis||"*";if(a!=="*"&&a!=="_")throw new Error("Cannot serialize emphasis with `"+a+"` for `options.emphasis`, expected `*`, or `_`");return a}function Wr(t){return"&#x"+t.toString(16).toUpperCase()+";"}function Yo(t,a,l){const r=Il(t),o=Il(a);return r===void 0?o===void 0?l==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:o===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?o===void 0?{inside:!1,outside:!1}:o===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:o===void 0?{inside:!1,outside:!1}:o===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}Gb.peek=Ik;function Gb(t,a,l,r){const o=Bk(l),u=l.enter("emphasis"),c=l.createTracker(r),h=c.move(o);let g=c.move(l.containerPhrasing(t,{after:o,before:h,...c.current()}));const p=g.charCodeAt(0),b=Yo(r.before.charCodeAt(r.before.length-1),p,o);b.inside&&(g=Wr(p)+g.slice(1));const x=g.charCodeAt(g.length-1),_=Yo(r.after.charCodeAt(0),x,o);_.inside&&(g=g.slice(0,-1)+Wr(x));const v=c.move(o);return u(),l.attentionEncodeSurroundingInfo={after:_.outside,before:b.outside},h+g+v}function Ik(t,a,l){return l.options.emphasis||"*"}function Uk(t,a){let l=!1;return nc(t,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return l=!0,Zf}),!!((!t.depth||t.depth<3)&&xd(t)&&(a.options.setext||l))}function Hk(t,a,l,r){const o=Math.max(Math.min(6,t.depth||1),1),u=l.createTracker(r);if(Uk(t,l)){const b=l.enter("headingSetext"),x=l.enter("phrasing"),_=l.containerPhrasing(t,{...u.current(),before:`
`,after:`
`});return x(),b(),_+`
`+(o===1?"=":"-").repeat(_.length-(Math.max(_.lastIndexOf("\r"),_.lastIndexOf(`
`))+1))}const c="#".repeat(o),h=l.enter("headingAtx"),g=l.enter("phrasing");u.move(c+" ");let p=l.containerPhrasing(t,{before:"# ",after:`
`,...u.current()});return/^[\t ]/.test(p)&&(p=Wr(p.charCodeAt(0))+p.slice(1)),p=p?c+" "+p:c,l.options.closeAtx&&(p+=" "+c),g(),h(),p}Pb.peek=Fk;function Pb(t){return t.value||""}function Fk(){return"<"}Yb.peek=$k;function Yb(t,a,l,r){const o=kd(l),u=o==='"'?"Quote":"Apostrophe",c=l.enter("image");let h=l.enter("label");const g=l.createTracker(r);let p=g.move("![");return p+=g.move(l.safe(t.alt,{before:p,after:"]",...g.current()})),p+=g.move("]("),h(),!t.url&&t.title||/[\0- \u007F]/.test(t.url)?(h=l.enter("destinationLiteral"),p+=g.move("<"),p+=g.move(l.safe(t.url,{before:p,after:">",...g.current()})),p+=g.move(">")):(h=l.enter("destinationRaw"),p+=g.move(l.safe(t.url,{before:p,after:t.title?" ":")",...g.current()}))),h(),t.title&&(h=l.enter(`title${u}`),p+=g.move(" "+o),p+=g.move(l.safe(t.title,{before:p,after:o,...g.current()})),p+=g.move(o),h()),p+=g.move(")"),c(),p}function $k(){return"!"}Vb.peek=qk;function Vb(t,a,l,r){const o=t.referenceType,u=l.enter("imageReference");let c=l.enter("label");const h=l.createTracker(r);let g=h.move("![");const p=l.safe(t.alt,{before:g,after:"]",...h.current()});g+=h.move(p+"]["),c();const b=l.stack;l.stack=[],c=l.enter("reference");const x=l.safe(l.associationId(t),{before:g,after:"]",...h.current()});return c(),l.stack=b,u(),o==="full"||!p||p!==x?g+=h.move(x+"]"):o==="shortcut"?g=g.slice(0,-1):g+=h.move("]"),g}function qk(){return"!"}Kb.peek=Gk;function Kb(t,a,l){let r=t.value||"",o="`",u=-1;for(;new RegExp("(^|[^`])"+o+"([^`]|$)").test(r);)o+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++u<l.unsafe.length;){const c=l.unsafe[u],h=l.compilePattern(c);let g;if(c.atBreak)for(;g=h.exec(r);){let p=g.index;r.charCodeAt(p)===10&&r.charCodeAt(p-1)===13&&p--,r=r.slice(0,p)+" "+r.slice(g.index+1)}}return o+r+o}function Gk(){return"`"}function Xb(t,a){const l=xd(t);return!!(!a.options.resourceLink&&t.url&&!t.title&&t.children&&t.children.length===1&&t.children[0].type==="text"&&(l===t.url||"mailto:"+l===t.url)&&/^[a-z][a-z+.-]+:/i.test(t.url)&&!/[\0- <>\u007F]/.test(t.url))}Zb.peek=Pk;function Zb(t,a,l,r){const o=kd(l),u=o==='"'?"Quote":"Apostrophe",c=l.createTracker(r);let h,g;if(Xb(t,l)){const b=l.stack;l.stack=[],h=l.enter("autolink");let x=c.move("<");return x+=c.move(l.containerPhrasing(t,{before:x,after:">",...c.current()})),x+=c.move(">"),h(),l.stack=b,x}h=l.enter("link"),g=l.enter("label");let p=c.move("[");return p+=c.move(l.containerPhrasing(t,{before:p,after:"](",...c.current()})),p+=c.move("]("),g(),!t.url&&t.title||/[\0- \u007F]/.test(t.url)?(g=l.enter("destinationLiteral"),p+=c.move("<"),p+=c.move(l.safe(t.url,{before:p,after:">",...c.current()})),p+=c.move(">")):(g=l.enter("destinationRaw"),p+=c.move(l.safe(t.url,{before:p,after:t.title?" ":")",...c.current()}))),g(),t.title&&(g=l.enter(`title${u}`),p+=c.move(" "+o),p+=c.move(l.safe(t.title,{before:p,after:o,...c.current()})),p+=c.move(o),g()),p+=c.move(")"),h(),p}function Pk(t,a,l){return Xb(t,l)?"<":"["}Qb.peek=Yk;function Qb(t,a,l,r){const o=t.referenceType,u=l.enter("linkReference");let c=l.enter("label");const h=l.createTracker(r);let g=h.move("[");const p=l.containerPhrasing(t,{before:g,after:"]",...h.current()});g+=h.move(p+"]["),c();const b=l.stack;l.stack=[],c=l.enter("reference");const x=l.safe(l.associationId(t),{before:g,after:"]",...h.current()});return c(),l.stack=b,u(),o==="full"||!p||p!==x?g+=h.move(x+"]"):o==="shortcut"?g=g.slice(0,-1):g+=h.move("]"),g}function Yk(){return"["}function Td(t){const a=t.options.bullet||"*";if(a!=="*"&&a!=="+"&&a!=="-")throw new Error("Cannot serialize items with `"+a+"` for `options.bullet`, expected `*`, `+`, or `-`");return a}function Vk(t){const a=Td(t),l=t.options.bulletOther;if(!l)return a==="*"?"-":"*";if(l!=="*"&&l!=="+"&&l!=="-")throw new Error("Cannot serialize items with `"+l+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(l===a)throw new Error("Expected `bullet` (`"+a+"`) and `bulletOther` (`"+l+"`) to be different");return l}function Kk(t){const a=t.options.bulletOrdered||".";if(a!=="."&&a!==")")throw new Error("Cannot serialize items with `"+a+"` for `options.bulletOrdered`, expected `.` or `)`");return a}function Jb(t){const a=t.options.rule||"*";if(a!=="*"&&a!=="-"&&a!=="_")throw new Error("Cannot serialize rules with `"+a+"` for `options.rule`, expected `*`, `-`, or `_`");return a}function Xk(t,a,l,r){const o=l.enter("list"),u=l.bulletCurrent;let c=t.ordered?Kk(l):Td(l);const h=t.ordered?c==="."?")":".":Vk(l);let g=a&&l.bulletLastUsed?c===l.bulletLastUsed:!1;if(!t.ordered){const b=t.children?t.children[0]:void 0;if((c==="*"||c==="-")&&b&&(!b.children||!b.children[0])&&l.stack[l.stack.length-1]==="list"&&l.stack[l.stack.length-2]==="listItem"&&l.stack[l.stack.length-3]==="list"&&l.stack[l.stack.length-4]==="listItem"&&l.indexStack[l.indexStack.length-1]===0&&l.indexStack[l.indexStack.length-2]===0&&l.indexStack[l.indexStack.length-3]===0&&(g=!0),Jb(l)===c&&b){let x=-1;for(;++x<t.children.length;){const _=t.children[x];if(_&&_.type==="listItem"&&_.children&&_.children[0]&&_.children[0].type==="thematicBreak"){g=!0;break}}}}g&&(c=h),l.bulletCurrent=c;const p=l.containerFlow(t,r);return l.bulletLastUsed=c,l.bulletCurrent=u,o(),p}function Zk(t){const a=t.options.listItemIndent||"one";if(a!=="tab"&&a!=="one"&&a!=="mixed")throw new Error("Cannot serialize items with `"+a+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return a}function Qk(t,a,l,r){const o=Zk(l);let u=l.bulletCurrent||Td(l);a&&a.type==="list"&&a.ordered&&(u=(typeof a.start=="number"&&a.start>-1?a.start:1)+(l.options.incrementListMarker===!1?0:a.children.indexOf(t))+u);let c=u.length+1;(o==="tab"||o==="mixed"&&(a&&a.type==="list"&&a.spread||t.spread))&&(c=Math.ceil(c/4)*4);const h=l.createTracker(r);h.move(u+" ".repeat(c-u.length)),h.shift(c);const g=l.enter("listItem"),p=l.indentLines(l.containerFlow(t,h.current()),b);return g(),p;function b(x,_,v){return _?(v?"":" ".repeat(c))+x:(v?u:u+" ".repeat(c-u.length))+x}}function Jk(t,a,l,r){const o=l.enter("paragraph"),u=l.enter("phrasing"),c=l.containerPhrasing(t,r);return u(),o(),c}const Wk=is(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function eT(t,a,l,r){return(t.children.some(function(c){return Wk(c)})?l.containerPhrasing:l.containerFlow).call(l,t,r)}function tT(t){const a=t.options.strong||"*";if(a!=="*"&&a!=="_")throw new Error("Cannot serialize strong with `"+a+"` for `options.strong`, expected `*`, or `_`");return a}Wb.peek=nT;function Wb(t,a,l,r){const o=tT(l),u=l.enter("strong"),c=l.createTracker(r),h=c.move(o+o);let g=c.move(l.containerPhrasing(t,{after:o,before:h,...c.current()}));const p=g.charCodeAt(0),b=Yo(r.before.charCodeAt(r.before.length-1),p,o);b.inside&&(g=Wr(p)+g.slice(1));const x=g.charCodeAt(g.length-1),_=Yo(r.after.charCodeAt(0),x,o);_.inside&&(g=g.slice(0,-1)+Wr(x));const v=c.move(o+o);return u(),l.attentionEncodeSurroundingInfo={after:_.outside,before:b.outside},h+g+v}function nT(t,a,l){return l.options.strong||"*"}function iT(t,a,l,r){return l.safe(t.value,r)}function aT(t){const a=t.options.ruleRepetition||3;if(a<3)throw new Error("Cannot serialize rules with repetition `"+a+"` for `options.ruleRepetition`, expected `3` or more");return a}function lT(t,a,l){const r=(Jb(l)+(l.options.ruleSpaces?" ":"")).repeat(aT(l));return l.options.ruleSpaces?r.slice(0,-1):r}const ex={blockquote:Ak,break:p0,code:Dk,definition:jk,emphasis:Gb,hardBreak:p0,heading:Hk,html:Pb,image:Yb,imageReference:Vb,inlineCode:Kb,link:Zb,linkReference:Qb,list:Xk,listItem:Qk,paragraph:Jk,root:eT,strong:Wb,text:iT,thematicBreak:lT};function rT(){return{enter:{table:sT,tableData:g0,tableHeader:g0,tableRow:cT},exit:{codeText:uT,table:oT,tableData:Af,tableHeader:Af,tableRow:Af}}}function sT(t){const a=t._align;this.enter({type:"table",align:a.map(function(l){return l==="none"?null:l}),children:[]},t),this.data.inTable=!0}function oT(t){this.exit(t),this.data.inTable=void 0}function cT(t){this.enter({type:"tableRow",children:[]},t)}function Af(t){this.exit(t)}function g0(t){this.enter({type:"tableCell",children:[]},t)}function uT(t){let a=this.resume();this.data.inTable&&(a=a.replace(/\\([\\|])/g,fT));const l=this.stack[this.stack.length-1];l.type,l.value=a,this.exit(t)}function fT(t,a){return a==="|"?a:t}function dT(t){const a=t||{},l=a.tableCellPadding,r=a.tablePipeAlign,o=a.stringLength,u=l?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:_,table:c,tableCell:g,tableRow:h}};function c(v,S,T,A){return p(b(v,T,A),v.align)}function h(v,S,T,A){const w=x(v,T,A),O=p([w]);return O.slice(0,O.indexOf(`
`))}function g(v,S,T,A){const w=T.enter("tableCell"),O=T.enter("phrasing"),R=T.containerPhrasing(v,{...A,before:u,after:u});return O(),w(),R}function p(v,S){return kk(v,{align:S,alignDelimiters:r,padding:l,stringLength:o})}function b(v,S,T){const A=v.children;let w=-1;const O=[],R=S.enter("table");for(;++w<A.length;)O[w]=x(A[w],S,T);return R(),O}function x(v,S,T){const A=v.children;let w=-1;const O=[],R=S.enter("tableRow");for(;++w<A.length;)O[w]=g(A[w],v,S,T);return R(),O}function _(v,S,T){let A=ex.inlineCode(v,S,T);return T.stack.includes("tableCell")&&(A=A.replace(/\|/g,"\\$&")),A}}function mT(){return{exit:{taskListCheckValueChecked:b0,taskListCheckValueUnchecked:b0,paragraph:pT}}}function hT(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:gT}}}function b0(t){const a=this.stack[this.stack.length-2];a.type,a.checked=t.type==="taskListCheckValueChecked"}function pT(t){const a=this.stack[this.stack.length-2];if(a&&a.type==="listItem"&&typeof a.checked=="boolean"){const l=this.stack[this.stack.length-1];l.type;const r=l.children[0];if(r&&r.type==="text"){const o=a.children;let u=-1,c;for(;++u<o.length;){const h=o[u];if(h.type==="paragraph"){c=h;break}}c===l&&(r.value=r.value.slice(1),r.value.length===0?l.children.shift():l.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,l.position.start=Object.assign({},r.position.start)))}}this.exit(t)}function gT(t,a,l,r){const o=t.children[0],u=typeof t.checked=="boolean"&&o&&o.type==="paragraph",c="["+(t.checked?"x":" ")+"] ",h=l.createTracker(r);u&&h.move(c);let g=ex.listItem(t,a,l,{...r,...h.current()});return u&&(g=g.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,p)),g;function p(b){return b+c}}function bT(){return[Xw(),gk(),_k(),rT(),mT()]}function xT(t){return{extensions:[Zw(),bk(t),vk(),dT(t),hT()]}}const yT={tokenize:wT,partial:!0},tx={tokenize:kT,partial:!0},nx={tokenize:TT,partial:!0},ix={tokenize:AT,partial:!0},_T={tokenize:MT,partial:!0},ax={name:"wwwAutolink",tokenize:ST,previous:rx},lx={name:"protocolAutolink",tokenize:NT,previous:sx},Li={name:"emailAutolink",tokenize:ET,previous:ox},fi={};function vT(){return{text:fi}}let Da=48;for(;Da<123;)fi[Da]=Li,Da++,Da===58?Da=65:Da===91&&(Da=97);fi[43]=Li;fi[45]=Li;fi[46]=Li;fi[95]=Li;fi[72]=[Li,lx];fi[104]=[Li,lx];fi[87]=[Li,ax];fi[119]=[Li,ax];function ET(t,a,l){const r=this;let o,u;return c;function c(x){return!ed(x)||!ox.call(r,r.previous)||Ad(r.events)?l(x):(t.enter("literalAutolink"),t.enter("literalAutolinkEmail"),h(x))}function h(x){return ed(x)?(t.consume(x),h):x===64?(t.consume(x),g):l(x)}function g(x){return x===46?t.check(_T,b,p)(x):x===45||x===95||ln(x)?(u=!0,t.consume(x),g):b(x)}function p(x){return t.consume(x),o=!0,g}function b(x){return u&&o&&dn(r.previous)?(t.exit("literalAutolinkEmail"),t.exit("literalAutolink"),a(x)):l(x)}}function ST(t,a,l){const r=this;return o;function o(c){return c!==87&&c!==119||!rx.call(r,r.previous)||Ad(r.events)?l(c):(t.enter("literalAutolink"),t.enter("literalAutolinkWww"),t.check(yT,t.attempt(tx,t.attempt(nx,u),l),l)(c))}function u(c){return t.exit("literalAutolinkWww"),t.exit("literalAutolink"),a(c)}}function NT(t,a,l){const r=this;let o="",u=!1;return c;function c(x){return(x===72||x===104)&&sx.call(r,r.previous)&&!Ad(r.events)?(t.enter("literalAutolink"),t.enter("literalAutolinkHttp"),o+=String.fromCodePoint(x),t.consume(x),h):l(x)}function h(x){if(dn(x)&&o.length<5)return o+=String.fromCodePoint(x),t.consume(x),h;if(x===58){const _=o.toLowerCase();if(_==="http"||_==="https")return t.consume(x),g}return l(x)}function g(x){return x===47?(t.consume(x),u?p:(u=!0,g)):l(x)}function p(x){return x===null||qo(x)||xt(x)||Ia(x)||Jo(x)?l(x):t.attempt(tx,t.attempt(nx,b),l)(x)}function b(x){return t.exit("literalAutolinkHttp"),t.exit("literalAutolink"),a(x)}}function wT(t,a,l){let r=0;return o;function o(c){return(c===87||c===119)&&r<3?(r++,t.consume(c),o):c===46&&r===3?(t.consume(c),u):l(c)}function u(c){return c===null?l(c):a(c)}}function kT(t,a,l){let r,o,u;return c;function c(p){return p===46||p===95?t.check(ix,g,h)(p):p===null||xt(p)||Ia(p)||p!==45&&Jo(p)?g(p):(u=!0,t.consume(p),c)}function h(p){return p===95?r=!0:(o=r,r=void 0),t.consume(p),c}function g(p){return o||r||!u?l(p):a(p)}}function TT(t,a){let l=0,r=0;return o;function o(c){return c===40?(l++,t.consume(c),o):c===41&&r<l?u(c):c===33||c===34||c===38||c===39||c===41||c===42||c===44||c===46||c===58||c===59||c===60||c===63||c===93||c===95||c===126?t.check(ix,a,u)(c):c===null||xt(c)||Ia(c)?a(c):(t.consume(c),o)}function u(c){return c===41&&r++,t.consume(c),o}}function AT(t,a,l){return r;function r(h){return h===33||h===34||h===39||h===41||h===42||h===44||h===46||h===58||h===59||h===63||h===95||h===126?(t.consume(h),r):h===38?(t.consume(h),u):h===93?(t.consume(h),o):h===60||h===null||xt(h)||Ia(h)?a(h):l(h)}function o(h){return h===null||h===40||h===91||xt(h)||Ia(h)?a(h):r(h)}function u(h){return dn(h)?c(h):l(h)}function c(h){return h===59?(t.consume(h),r):dn(h)?(t.consume(h),c):l(h)}}function MT(t,a,l){return r;function r(u){return t.consume(u),o}function o(u){return ln(u)?l(u):a(u)}}function rx(t){return t===null||t===40||t===42||t===95||t===91||t===93||t===126||xt(t)}function sx(t){return!dn(t)}function ox(t){return!(t===47||ed(t))}function ed(t){return t===43||t===45||t===46||t===95||ln(t)}function Ad(t){let a=t.length,l=!1;for(;a--;){const r=t[a][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){l=!0;break}if(r._gfmAutolinkLiteralWalkedInto){l=!1;break}}return t.length>0&&!l&&(t[t.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),l}const CT={tokenize:IT,partial:!0};function OT(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:LT,continuation:{tokenize:jT},exit:BT}},text:{91:{name:"gfmFootnoteCall",tokenize:DT},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:zT,resolveTo:RT}}}}function zT(t,a,l){const r=this;let o=r.events.length;const u=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let c;for(;o--;){const g=r.events[o][1];if(g.type==="labelImage"){c=g;break}if(g.type==="gfmFootnoteCall"||g.type==="labelLink"||g.type==="label"||g.type==="image"||g.type==="link")break}return h;function h(g){if(!c||!c._balanced)return l(g);const p=Jn(r.sliceSerialize({start:c.end,end:r.now()}));return p.codePointAt(0)!==94||!u.includes(p.slice(1))?l(g):(t.enter("gfmFootnoteCallLabelMarker"),t.consume(g),t.exit("gfmFootnoteCallLabelMarker"),a(g))}}function RT(t,a){let l=t.length;for(;l--;)if(t[l][1].type==="labelImage"&&t[l][0]==="enter"){t[l][1];break}t[l+1][1].type="data",t[l+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},t[l+3][1].start),end:Object.assign({},t[t.length-1][1].end)},o={type:"gfmFootnoteCallMarker",start:Object.assign({},t[l+3][1].end),end:Object.assign({},t[l+3][1].end)};o.end.column++,o.end.offset++,o.end._bufferIndex++;const u={type:"gfmFootnoteCallString",start:Object.assign({},o.end),end:Object.assign({},t[t.length-1][1].start)},c={type:"chunkString",contentType:"string",start:Object.assign({},u.start),end:Object.assign({},u.end)},h=[t[l+1],t[l+2],["enter",r,a],t[l+3],t[l+4],["enter",o,a],["exit",o,a],["enter",u,a],["enter",c,a],["exit",c,a],["exit",u,a],t[t.length-2],t[t.length-1],["exit",r,a]];return t.splice(l,t.length-l+1,...h),t}function DT(t,a,l){const r=this,o=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let u=0,c;return h;function h(x){return t.enter("gfmFootnoteCall"),t.enter("gfmFootnoteCallLabelMarker"),t.consume(x),t.exit("gfmFootnoteCallLabelMarker"),g}function g(x){return x!==94?l(x):(t.enter("gfmFootnoteCallMarker"),t.consume(x),t.exit("gfmFootnoteCallMarker"),t.enter("gfmFootnoteCallString"),t.enter("chunkString").contentType="string",p)}function p(x){if(u>999||x===93&&!c||x===null||x===91||xt(x))return l(x);if(x===93){t.exit("chunkString");const _=t.exit("gfmFootnoteCallString");return o.includes(Jn(r.sliceSerialize(_)))?(t.enter("gfmFootnoteCallLabelMarker"),t.consume(x),t.exit("gfmFootnoteCallLabelMarker"),t.exit("gfmFootnoteCall"),a):l(x)}return xt(x)||(c=!0),u++,t.consume(x),x===92?b:p}function b(x){return x===91||x===92||x===93?(t.consume(x),u++,p):p(x)}}function LT(t,a,l){const r=this,o=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let u,c=0,h;return g;function g(S){return t.enter("gfmFootnoteDefinition")._container=!0,t.enter("gfmFootnoteDefinitionLabel"),t.enter("gfmFootnoteDefinitionLabelMarker"),t.consume(S),t.exit("gfmFootnoteDefinitionLabelMarker"),p}function p(S){return S===94?(t.enter("gfmFootnoteDefinitionMarker"),t.consume(S),t.exit("gfmFootnoteDefinitionMarker"),t.enter("gfmFootnoteDefinitionLabelString"),t.enter("chunkString").contentType="string",b):l(S)}function b(S){if(c>999||S===93&&!h||S===null||S===91||xt(S))return l(S);if(S===93){t.exit("chunkString");const T=t.exit("gfmFootnoteDefinitionLabelString");return u=Jn(r.sliceSerialize(T)),t.enter("gfmFootnoteDefinitionLabelMarker"),t.consume(S),t.exit("gfmFootnoteDefinitionLabelMarker"),t.exit("gfmFootnoteDefinitionLabel"),_}return xt(S)||(h=!0),c++,t.consume(S),S===92?x:b}function x(S){return S===91||S===92||S===93?(t.consume(S),c++,b):b(S)}function _(S){return S===58?(t.enter("definitionMarker"),t.consume(S),t.exit("definitionMarker"),o.includes(u)||o.push(u),We(t,v,"gfmFootnoteDefinitionWhitespace")):l(S)}function v(S){return a(S)}}function jT(t,a,l){return t.check(ns,a,t.attempt(CT,a,l))}function BT(t){t.exit("gfmFootnoteDefinition")}function IT(t,a,l){const r=this;return We(t,o,"gfmFootnoteDefinitionIndent",5);function o(u){const c=r.events[r.events.length-1];return c&&c[1].type==="gfmFootnoteDefinitionIndent"&&c[2].sliceSerialize(c[1],!0).length===4?a(u):l(u)}}function UT(t){let l=(t||{}).singleTilde;const r={name:"strikethrough",tokenize:u,resolveAll:o};return l==null&&(l=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function o(c,h){let g=-1;for(;++g<c.length;)if(c[g][0]==="enter"&&c[g][1].type==="strikethroughSequenceTemporary"&&c[g][1]._close){let p=g;for(;p--;)if(c[p][0]==="exit"&&c[p][1].type==="strikethroughSequenceTemporary"&&c[p][1]._open&&c[g][1].end.offset-c[g][1].start.offset===c[p][1].end.offset-c[p][1].start.offset){c[g][1].type="strikethroughSequence",c[p][1].type="strikethroughSequence";const b={type:"strikethrough",start:Object.assign({},c[p][1].start),end:Object.assign({},c[g][1].end)},x={type:"strikethroughText",start:Object.assign({},c[p][1].end),end:Object.assign({},c[g][1].start)},_=[["enter",b,h],["enter",c[p][1],h],["exit",c[p][1],h],["enter",x,h]],v=h.parser.constructs.insideSpan.null;v&&jn(_,_.length,0,Wo(v,c.slice(p+1,g),h)),jn(_,_.length,0,[["exit",x,h],["enter",c[g][1],h],["exit",c[g][1],h],["exit",b,h]]),jn(c,p-1,g-p+3,_),g=p+_.length-2;break}}for(g=-1;++g<c.length;)c[g][1].type==="strikethroughSequenceTemporary"&&(c[g][1].type="data");return c}function u(c,h,g){const p=this.previous,b=this.events;let x=0;return _;function _(S){return p===126&&b[b.length-1][1].type!=="characterEscape"?g(S):(c.enter("strikethroughSequenceTemporary"),v(S))}function v(S){const T=Il(p);if(S===126)return x>1?g(S):(c.consume(S),x++,v);if(x<2&&!l)return g(S);const A=c.exit("strikethroughSequenceTemporary"),w=Il(S);return A._open=!w||w===2&&!!T,A._close=!T||T===2&&!!w,h(S)}}}class HT{constructor(){this.map=[]}add(a,l,r){FT(this,a,l,r)}consume(a){if(this.map.sort(function(u,c){return u[0]-c[0]}),this.map.length===0)return;let l=this.map.length;const r=[];for(;l>0;)l-=1,r.push(a.slice(this.map[l][0]+this.map[l][1]),this.map[l][2]),a.length=this.map[l][0];r.push(a.slice()),a.length=0;let o=r.pop();for(;o;){for(const u of o)a.push(u);o=r.pop()}this.map.length=0}}function FT(t,a,l,r){let o=0;if(!(l===0&&r.length===0)){for(;o<t.map.length;){if(t.map[o][0]===a){t.map[o][1]+=l,t.map[o][2].push(...r);return}o+=1}t.map.push([a,l,r])}}function $T(t,a){let l=!1;const r=[];for(;a<t.length;){const o=t[a];if(l){if(o[0]==="enter")o[1].type==="tableContent"&&r.push(t[a+1][1].type==="tableDelimiterMarker"?"left":"none");else if(o[1].type==="tableContent"){if(t[a-1][1].type==="tableDelimiterMarker"){const u=r.length-1;r[u]=r[u]==="left"?"center":"right"}}else if(o[1].type==="tableDelimiterRow")break}else o[0]==="enter"&&o[1].type==="tableDelimiterRow"&&(l=!0);a+=1}return r}function qT(){return{flow:{null:{name:"table",tokenize:GT,resolveAll:PT}}}}function GT(t,a,l){const r=this;let o=0,u=0,c;return h;function h(U){let re=r.events.length-1;for(;re>-1;){const W=r.events[re][1].type;if(W==="lineEnding"||W==="linePrefix")re--;else break}const ae=re>-1?r.events[re][1].type:null,le=ae==="tableHead"||ae==="tableRow"?L:g;return le===L&&r.parser.lazy[r.now().line]?l(U):le(U)}function g(U){return t.enter("tableHead"),t.enter("tableRow"),p(U)}function p(U){return U===124||(c=!0,u+=1),b(U)}function b(U){return U===null?l(U):Ae(U)?u>1?(u=0,r.interrupt=!0,t.exit("tableRow"),t.enter("lineEnding"),t.consume(U),t.exit("lineEnding"),v):l(U):Ke(U)?We(t,b,"whitespace")(U):(u+=1,c&&(c=!1,o+=1),U===124?(t.enter("tableCellDivider"),t.consume(U),t.exit("tableCellDivider"),c=!0,b):(t.enter("data"),x(U)))}function x(U){return U===null||U===124||xt(U)?(t.exit("data"),b(U)):(t.consume(U),U===92?_:x)}function _(U){return U===92||U===124?(t.consume(U),x):x(U)}function v(U){return r.interrupt=!1,r.parser.lazy[r.now().line]?l(U):(t.enter("tableDelimiterRow"),c=!1,Ke(U)?We(t,S,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(U):S(U))}function S(U){return U===45||U===58?A(U):U===124?(c=!0,t.enter("tableCellDivider"),t.consume(U),t.exit("tableCellDivider"),T):Y(U)}function T(U){return Ke(U)?We(t,A,"whitespace")(U):A(U)}function A(U){return U===58?(u+=1,c=!0,t.enter("tableDelimiterMarker"),t.consume(U),t.exit("tableDelimiterMarker"),w):U===45?(u+=1,w(U)):U===null||Ae(U)?q(U):Y(U)}function w(U){return U===45?(t.enter("tableDelimiterFiller"),O(U)):Y(U)}function O(U){return U===45?(t.consume(U),O):U===58?(c=!0,t.exit("tableDelimiterFiller"),t.enter("tableDelimiterMarker"),t.consume(U),t.exit("tableDelimiterMarker"),R):(t.exit("tableDelimiterFiller"),R(U))}function R(U){return Ke(U)?We(t,q,"whitespace")(U):q(U)}function q(U){return U===124?S(U):U===null||Ae(U)?!c||o!==u?Y(U):(t.exit("tableDelimiterRow"),t.exit("tableHead"),a(U)):Y(U)}function Y(U){return l(U)}function L(U){return t.enter("tableRow"),X(U)}function X(U){return U===124?(t.enter("tableCellDivider"),t.consume(U),t.exit("tableCellDivider"),X):U===null||Ae(U)?(t.exit("tableRow"),a(U)):Ke(U)?We(t,X,"whitespace")(U):(t.enter("data"),oe(U))}function oe(U){return U===null||U===124||xt(U)?(t.exit("data"),X(U)):(t.consume(U),U===92?he:oe)}function he(U){return U===92||U===124?(t.consume(U),oe):oe(U)}}function PT(t,a){let l=-1,r=!0,o=0,u=[0,0,0,0],c=[0,0,0,0],h=!1,g=0,p,b,x;const _=new HT;for(;++l<t.length;){const v=t[l],S=v[1];v[0]==="enter"?S.type==="tableHead"?(h=!1,g!==0&&(x0(_,a,g,p,b),b=void 0,g=0),p={type:"table",start:Object.assign({},S.start),end:Object.assign({},S.end)},_.add(l,0,[["enter",p,a]])):S.type==="tableRow"||S.type==="tableDelimiterRow"?(r=!0,x=void 0,u=[0,0,0,0],c=[0,l+1,0,0],h&&(h=!1,b={type:"tableBody",start:Object.assign({},S.start),end:Object.assign({},S.end)},_.add(l,0,[["enter",b,a]])),o=S.type==="tableDelimiterRow"?2:b?3:1):o&&(S.type==="data"||S.type==="tableDelimiterMarker"||S.type==="tableDelimiterFiller")?(r=!1,c[2]===0&&(u[1]!==0&&(c[0]=c[1],x=Ao(_,a,u,o,void 0,x),u=[0,0,0,0]),c[2]=l)):S.type==="tableCellDivider"&&(r?r=!1:(u[1]!==0&&(c[0]=c[1],x=Ao(_,a,u,o,void 0,x)),u=c,c=[u[1],l,0,0])):S.type==="tableHead"?(h=!0,g=l):S.type==="tableRow"||S.type==="tableDelimiterRow"?(g=l,u[1]!==0?(c[0]=c[1],x=Ao(_,a,u,o,l,x)):c[1]!==0&&(x=Ao(_,a,c,o,l,x)),o=0):o&&(S.type==="data"||S.type==="tableDelimiterMarker"||S.type==="tableDelimiterFiller")&&(c[3]=l)}for(g!==0&&x0(_,a,g,p,b),_.consume(a.events),l=-1;++l<a.events.length;){const v=a.events[l];v[0]==="enter"&&v[1].type==="table"&&(v[1]._align=$T(a.events,l))}return t}function Ao(t,a,l,r,o,u){const c=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",h="tableContent";l[0]!==0&&(u.end=Object.assign({},Ml(a.events,l[0])),t.add(l[0],0,[["exit",u,a]]));const g=Ml(a.events,l[1]);if(u={type:c,start:Object.assign({},g),end:Object.assign({},g)},t.add(l[1],0,[["enter",u,a]]),l[2]!==0){const p=Ml(a.events,l[2]),b=Ml(a.events,l[3]),x={type:h,start:Object.assign({},p),end:Object.assign({},b)};if(t.add(l[2],0,[["enter",x,a]]),r!==2){const _=a.events[l[2]],v=a.events[l[3]];if(_[1].end=Object.assign({},v[1].end),_[1].type="chunkText",_[1].contentType="text",l[3]>l[2]+1){const S=l[2]+1,T=l[3]-l[2]-1;t.add(S,T,[])}}t.add(l[3]+1,0,[["exit",x,a]])}return o!==void 0&&(u.end=Object.assign({},Ml(a.events,o)),t.add(o,0,[["exit",u,a]]),u=void 0),u}function x0(t,a,l,r,o){const u=[],c=Ml(a.events,l);o&&(o.end=Object.assign({},c),u.push(["exit",o,a])),r.end=Object.assign({},c),u.push(["exit",r,a]),t.add(l+1,0,u)}function Ml(t,a){const l=t[a],r=l[0]==="enter"?"start":"end";return l[1][r]}const YT={name:"tasklistCheck",tokenize:KT};function VT(){return{text:{91:YT}}}function KT(t,a,l){const r=this;return o;function o(g){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?l(g):(t.enter("taskListCheck"),t.enter("taskListCheckMarker"),t.consume(g),t.exit("taskListCheckMarker"),u)}function u(g){return xt(g)?(t.enter("taskListCheckValueUnchecked"),t.consume(g),t.exit("taskListCheckValueUnchecked"),c):g===88||g===120?(t.enter("taskListCheckValueChecked"),t.consume(g),t.exit("taskListCheckValueChecked"),c):l(g)}function c(g){return g===93?(t.enter("taskListCheckMarker"),t.consume(g),t.exit("taskListCheckMarker"),t.exit("taskListCheck"),h):l(g)}function h(g){return Ae(g)?a(g):Ke(g)?t.check({tokenize:XT},a,l)(g):l(g)}}function XT(t,a,l){return We(t,r,"whitespace");function r(o){return o===null?l(o):a(o)}}function ZT(t){return yb([vT(),OT(),UT(t),qT(),VT()])}const QT={};function JT(t){const a=this,l=t||QT,r=a.data(),o=r.micromarkExtensions||(r.micromarkExtensions=[]),u=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),c=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);o.push(ZT(l)),u.push(bT()),c.push(xT(l))}const y0=(function(t,a,l){const r=is(l);if(!t||!t.type||!t.children)throw new Error("Expected parent node");if(typeof a=="number"){if(a<0||a===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(a=t.children.indexOf(a),a<0)throw new Error("Expected child node or index");for(;++a<t.children.length;)if(r(t.children[a],a,t))return t.children[a]}),Ha=(function(t){if(t==null)return t2;if(typeof t=="string")return e2(t);if(typeof t=="object")return WT(t);if(typeof t=="function")return Md(t);throw new Error("Expected function, string, or array as `test`")});function WT(t){const a=[];let l=-1;for(;++l<t.length;)a[l]=Ha(t[l]);return Md(r);function r(...o){let u=-1;for(;++u<a.length;)if(a[u].apply(this,o))return!0;return!1}}function e2(t){return Md(a);function a(l){return l.tagName===t}}function Md(t){return a;function a(l,r,o){return!!(n2(l)&&t.call(this,l,typeof r=="number"?r:void 0,o||void 0))}}function t2(t){return!!(t&&typeof t=="object"&&"type"in t&&t.type==="element"&&"tagName"in t&&typeof t.tagName=="string")}function n2(t){return t!==null&&typeof t=="object"&&"type"in t&&"tagName"in t}const _0=/\n/g,v0=/[\t ]+/g,td=Ha("br"),E0=Ha(u2),i2=Ha("p"),S0=Ha("tr"),a2=Ha(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",c2,f2]),cx=Ha(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function l2(t,a){const l=a||{},r="children"in t?t.children:[],o=cx(t),u=dx(t,{whitespace:l.whitespace||"normal"}),c=[];(t.type==="text"||t.type==="comment")&&c.push(...fx(t,{breakBefore:!0,breakAfter:!0}));let h=-1;for(;++h<r.length;)c.push(...ux(r[h],t,{whitespace:u,breakBefore:h?void 0:o,breakAfter:h<r.length-1?td(r[h+1]):o}));const g=[];let p;for(h=-1;++h<c.length;){const b=c[h];typeof b=="number"?p!==void 0&&b>p&&(p=b):b&&(p!==void 0&&p>-1&&g.push(`
`.repeat(p)||" "),p=-1,g.push(b))}return g.join("")}function ux(t,a,l){return t.type==="element"?r2(t,a,l):t.type==="text"?l.whitespace==="normal"?fx(t,l):s2(t):[]}function r2(t,a,l){const r=dx(t,l),o=t.children||[];let u=-1,c=[];if(a2(t))return c;let h,g;for(td(t)||S0(t)&&y0(a,t,S0)?g=`
`:i2(t)?(h=2,g=2):cx(t)&&(h=1,g=1);++u<o.length;)c=c.concat(ux(o[u],t,{whitespace:r,breakBefore:u?void 0:h,breakAfter:u<o.length-1?td(o[u+1]):g}));return E0(t)&&y0(a,t,E0)&&c.push("	"),h&&c.unshift(h),g&&c.push(g),c}function fx(t,a){const l=String(t.value),r=[],o=[];let u=0;for(;u<=l.length;){_0.lastIndex=u;const g=_0.exec(l),p=g&&"index"in g?g.index:l.length;r.push(o2(l.slice(u,p).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),u===0?a.breakBefore:!0,p===l.length?a.breakAfter:!0)),u=p+1}let c=-1,h;for(;++c<r.length;)r[c].charCodeAt(r[c].length-1)===8203||c<r.length-1&&r[c+1].charCodeAt(0)===8203?(o.push(r[c]),h=void 0):r[c]?(typeof h=="number"&&o.push(h),o.push(r[c]),h=0):(c===0||c===r.length-1)&&o.push(0);return o}function s2(t){return[String(t.value)]}function o2(t,a,l){const r=[];let o=0,u;for(;o<t.length;){v0.lastIndex=o;const c=v0.exec(t);u=c?c.index:t.length,!o&&!u&&c&&!a&&r.push(""),o!==u&&r.push(t.slice(o,u)),o=c?u+c[0].length:u}return o!==u&&!l&&r.push(""),r.join(" ")}function dx(t,a){if(t.type==="element"){const l=t.properties||{};switch(t.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return l.wrap?"pre-wrap":"pre";case"td":case"th":return l.noWrap?"nowrap":a.whitespace;case"textarea":return"pre-wrap"}}return a.whitespace}function c2(t){return!!(t.properties||{}).hidden}function u2(t){return t.tagName==="td"||t.tagName==="th"}function f2(t){return t.tagName==="dialog"&&!(t.properties||{}).open}function d2(t){const a=t.regex,l=t.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",o="[a-zA-Z_]\\w*::",c="(?!struct)("+r+"|"+a.optional(o)+"[a-zA-Z_]\\w*"+a.optional("<[^<>]+>")+")",h={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},p={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[t.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},t.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},b={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},x={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},t.inherit(p,{className:"string"}),{className:"string",begin:/<.*?>/},l,t.C_BLOCK_COMMENT_MODE]},_={className:"title",begin:a.optional(o)+t.IDENT_RE,relevance:0},v=a.optional(o)+t.IDENT_RE+"\\s*\\(",S=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],T=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],A=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],w=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],q={type:T,keyword:S,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:A},Y={className:"function.dispatch",relevance:0,keywords:{_hint:w},begin:a.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,t.IDENT_RE,a.lookahead(/(<[^<>]+>|)\s*\(/))},L=[Y,x,h,l,t.C_BLOCK_COMMENT_MODE,b,p],X={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:q,contains:L.concat([{begin:/\(/,end:/\)/,keywords:q,contains:L.concat(["self"]),relevance:0}]),relevance:0},oe={className:"function",begin:"("+c+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:q,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:q,relevance:0},{begin:v,returnBegin:!0,contains:[_],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[p,b]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:q,relevance:0,contains:[l,t.C_BLOCK_COMMENT_MODE,p,b,h,{begin:/\(/,end:/\)/,keywords:q,relevance:0,contains:["self",l,t.C_BLOCK_COMMENT_MODE,p,b,h]}]},h,l,t.C_BLOCK_COMMENT_MODE,x]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:q,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(X,oe,Y,L,[x,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:q,contains:["self",h]},{begin:t.IDENT_RE+"::",keywords:q},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function m2(t){const a={type:["boolean","byte","word","String"],built_in:["KeyboardController","MouseController","SoftwareSerial","EthernetServer","EthernetClient","LiquidCrystal","RobotControl","GSMVoiceCall","EthernetUDP","EsploraTFT","HttpClient","RobotMotor","WiFiClient","GSMScanner","FileSystem","Scheduler","GSMServer","YunClient","YunServer","IPAddress","GSMClient","GSMModem","Keyboard","Ethernet","Console","GSMBand","Esplora","Stepper","Process","WiFiUDP","GSM_SMS","Mailbox","USBHost","Firmata","PImage","Client","Server","GSMPIN","FileIO","Bridge","Serial","EEPROM","Stream","Mouse","Audio","Servo","File","Task","GPRS","WiFi","Wire","TFT","GSM","SPI","SD"],_hints:["setup","loop","runShellCommandAsynchronously","analogWriteResolution","retrieveCallingNumber","printFirmwareVersion","analogReadResolution","sendDigitalPortPair","noListenOnLocalhost","readJoystickButton","setFirmwareVersion","readJoystickSwitch","scrollDisplayRight","getVoiceCallStatus","scrollDisplayLeft","writeMicroseconds","delayMicroseconds","beginTransmission","getSignalStrength","runAsynchronously","getAsynchronously","listenOnLocalhost","getCurrentCarrier","readAccelerometer","messageAvailable","sendDigitalPorts","lineFollowConfig","countryNameWrite","runShellCommand","readStringUntil","rewindDirectory","readTemperature","setClockDivider","readLightSensor","endTransmission","analogReference","detachInterrupt","countryNameRead","attachInterrupt","encryptionType","readBytesUntil","robotNameWrite","readMicrophone","robotNameRead","cityNameWrite","userNameWrite","readJoystickY","readJoystickX","mouseReleased","openNextFile","scanNetworks","noInterrupts","digitalWrite","beginSpeaker","mousePressed","isActionDone","mouseDragged","displayLogos","noAutoscroll","addParameter","remoteNumber","getModifiers","keyboardRead","userNameRead","waitContinue","processInput","parseCommand","printVersion","readNetworks","writeMessage","blinkVersion","cityNameRead","readMessage","setDataMode","parsePacket","isListening","setBitOrder","beginPacket","isDirectory","motorsWrite","drawCompass","digitalRead","clearScreen","serialEvent","rightToLeft","setTextSize","leftToRight","requestFrom","keyReleased","compassRead","analogWrite","interrupts","WiFiServer","disconnect","playMelody","parseFloat","autoscroll","getPINUsed","setPINUsed","setTimeout","sendAnalog","readSlider","analogRead","beginWrite","createChar","motorsStop","keyPressed","tempoWrite","readButton","subnetMask","debugPrint","macAddress","writeGreen","randomSeed","attachGPRS","readString","sendString","remotePort","releaseAll","mouseMoved","background","getXChange","getYChange","answerCall","getResult","voiceCall","endPacket","constrain","getSocket","writeJSON","getButton","available","connected","findUntil","readBytes","exitValue","readGreen","writeBlue","startLoop","IPAddress","isPressed","sendSysex","pauseMode","gatewayIP","setCursor","getOemKey","tuneWrite","noDisplay","loadImage","switchPIN","onRequest","onReceive","changePIN","playFile","noBuffer","parseInt","overflow","checkPIN","knobRead","beginTFT","bitClear","updateIR","bitWrite","position","writeRGB","highByte","writeRed","setSpeed","readBlue","noStroke","remoteIP","transfer","shutdown","hangCall","beginSMS","endWrite","attached","maintain","noCursor","checkReg","checkPUK","shiftOut","isValid","shiftIn","pulseIn","connect","println","localIP","pinMode","getIMEI","display","noBlink","process","getBand","running","beginSD","drawBMP","lowByte","setBand","release","bitRead","prepare","pointTo","readRed","setMode","noFill","remove","listen","stroke","detach","attach","noTone","exists","buffer","height","bitSet","circle","config","cursor","random","IRread","setDNS","endSMS","getKey","micros","millis","begin","print","write","ready","flush","width","isPIN","blink","clear","press","mkdir","rmdir","close","point","yield","image","BSSID","click","delay","read","text","move","peek","beep","rect","line","open","seek","fill","size","turn","stop","home","find","step","tone","sqrt","RSSI","SSID","end","bit","tan","cos","sin","pow","map","abs","max","min","get","run","put"],literal:["DIGITAL_MESSAGE","FIRMATA_STRING","ANALOG_MESSAGE","REPORT_DIGITAL","REPORT_ANALOG","INPUT_PULLUP","SET_PIN_MODE","INTERNAL2V56","SYSTEM_RESET","LED_BUILTIN","INTERNAL1V1","SYSEX_START","INTERNAL","EXTERNAL","DEFAULT","OUTPUT","INPUT","HIGH","LOW"]},l=d2(t),r=l.keywords;return r.type=[...r.type,...a.type],r.literal=[...r.literal,...a.literal],r.built_in=[...r.built_in,...a.built_in],r._hints=a._hints,l.name="Arduino",l.aliases=["ino"],l.supersetOf="cpp",l}function h2(t){const a=t.regex,l={},r={begin:/\$\{/,end:/\}/,contains:["self",{begin:/:-/,contains:[l]}]};Object.assign(l,{className:"variable",variants:[{begin:a.concat(/\$[\w\d#@][\w\d_]*/,"(?![\\w\\d])(?![$])")},r]});const o={className:"subst",begin:/\$\(/,end:/\)/,contains:[t.BACKSLASH_ESCAPE]},u=t.inherit(t.COMMENT(),{match:[/(^|\s)/,/#.*$/],scope:{2:"comment"}}),c={begin:/<<-?\s*(?=\w+)/,starts:{contains:[t.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,className:"string"})]}},h={className:"string",begin:/"/,end:/"/,contains:[t.BACKSLASH_ESCAPE,l,o]};o.contains.push(h);const g={match:/\\"/},p={className:"string",begin:/'/,end:/'/},b={match:/\\'/},x={begin:/\$?\(\(/,end:/\)\)/,contains:[{begin:/\d+#[0-9a-f]+/,className:"number"},t.NUMBER_MODE,l]},_=["fish","bash","zsh","sh","csh","ksh","tcsh","dash","scsh"],v=t.SHEBANG({binary:`(${_.join("|")})`,relevance:10}),S={className:"function",begin:/\w[\w\d_]*\s*\(\s*\)\s*\{/,returnBegin:!0,contains:[t.inherit(t.TITLE_MODE,{begin:/\w[\w\d_]*/})],relevance:0},T=["if","then","else","elif","fi","time","for","while","until","in","do","done","case","esac","coproc","function","select"],A=["true","false"],w={match:/(\/[a-z._-]+)+/},O=["break","cd","continue","eval","exec","exit","export","getopts","hash","pwd","readonly","return","shift","test","times","trap","umask","unset"],R=["alias","bind","builtin","caller","command","declare","echo","enable","help","let","local","logout","mapfile","printf","read","readarray","source","sudo","type","typeset","ulimit","unalias"],q=["autoload","bg","bindkey","bye","cap","chdir","clone","comparguments","compcall","compctl","compdescribe","compfiles","compgroups","compquote","comptags","comptry","compvalues","dirs","disable","disown","echotc","echoti","emulate","fc","fg","float","functions","getcap","getln","history","integer","jobs","kill","limit","log","noglob","popd","print","pushd","pushln","rehash","sched","setcap","setopt","stat","suspend","ttyctl","unfunction","unhash","unlimit","unsetopt","vared","wait","whence","where","which","zcompile","zformat","zftp","zle","zmodload","zparseopts","zprof","zpty","zregexparse","zsocket","zstyle","ztcp"],Y=["chcon","chgrp","chown","chmod","cp","dd","df","dir","dircolors","ln","ls","mkdir","mkfifo","mknod","mktemp","mv","realpath","rm","rmdir","shred","sync","touch","truncate","vdir","b2sum","base32","base64","cat","cksum","comm","csplit","cut","expand","fmt","fold","head","join","md5sum","nl","numfmt","od","paste","ptx","pr","sha1sum","sha224sum","sha256sum","sha384sum","sha512sum","shuf","sort","split","sum","tac","tail","tr","tsort","unexpand","uniq","wc","arch","basename","chroot","date","dirname","du","echo","env","expr","factor","groups","hostid","id","link","logname","nice","nohup","nproc","pathchk","pinky","printenv","printf","pwd","readlink","runcon","seq","sleep","stat","stdbuf","stty","tee","test","timeout","tty","uname","unlink","uptime","users","who","whoami","yes"];return{name:"Bash",aliases:["sh","zsh"],keywords:{$pattern:/\b[a-z][a-z0-9._-]+\b/,keyword:T,literal:A,built_in:[...O,...R,"set","shopt",...q,...Y]},contains:[v,t.SHEBANG(),S,x,u,c,w,h,g,p,b,l]}}function p2(t){const a=t.regex,l=t.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",o="[a-zA-Z_]\\w*::",c="("+r+"|"+a.optional(o)+"[a-zA-Z_]\\w*"+a.optional("<[^<>]+>")+")",h={className:"type",variants:[{begin:"\\b[a-z\\d_]*_t\\b"},{match:/\batomic_[a-z]{3,6}\b/}]},p={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[t.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},t.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},b={className:"number",variants:[{match:/\b(0b[01']+)/},{match:/(-?)\b([\d']+(\.[\d']*)?|\.[\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)/},{match:/(-?)\b(0[xX][a-fA-F0-9]+(?:'[a-fA-F0-9]+)*(?:\.[a-fA-F0-9]*(?:'[a-fA-F0-9]*)*)?(?:[pP][-+]?[0-9]+)?(l|L)?(u|U)?)/},{match:/(-?)\b\d+(?:'\d+)*(?:\.\d*(?:'\d*)*)?(?:[eE][-+]?\d+)?/}],relevance:0},x={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef elifdef elifndef include"},contains:[{begin:/\\\n/,relevance:0},t.inherit(p,{className:"string"}),{className:"string",begin:/<.*?>/},l,t.C_BLOCK_COMMENT_MODE]},_={className:"title",begin:a.optional(o)+t.IDENT_RE,relevance:0},v=a.optional(o)+t.IDENT_RE+"\\s*\\(",A={keyword:["asm","auto","break","case","continue","default","do","else","enum","extern","for","fortran","goto","if","inline","register","restrict","return","sizeof","typeof","typeof_unqual","struct","switch","typedef","union","volatile","while","_Alignas","_Alignof","_Atomic","_Generic","_Noreturn","_Static_assert","_Thread_local","alignas","alignof","noreturn","static_assert","thread_local","_Pragma"],type:["float","double","signed","unsigned","int","short","long","char","void","_Bool","_BitInt","_Complex","_Imaginary","_Decimal32","_Decimal64","_Decimal96","_Decimal128","_Decimal64x","_Decimal128x","_Float16","_Float32","_Float64","_Float128","_Float32x","_Float64x","_Float128x","const","static","constexpr","complex","bool","imaginary"],literal:"true false NULL",built_in:"std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr"},w=[x,h,l,t.C_BLOCK_COMMENT_MODE,b,p],O={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:A,contains:w.concat([{begin:/\(/,end:/\)/,keywords:A,contains:w.concat(["self"]),relevance:0}]),relevance:0},R={begin:"("+c+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:A,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:A,relevance:0},{begin:v,returnBegin:!0,contains:[t.inherit(_,{className:"title.function"})],relevance:0},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:A,relevance:0,contains:[l,t.C_BLOCK_COMMENT_MODE,p,b,h,{begin:/\(/,end:/\)/,keywords:A,relevance:0,contains:["self",l,t.C_BLOCK_COMMENT_MODE,p,b,h]}]},h,l,t.C_BLOCK_COMMENT_MODE,x]};return{name:"C",aliases:["h"],keywords:A,disableAutodetect:!0,illegal:"</",contains:[].concat(O,R,w,[x,{begin:t.IDENT_RE+"::",keywords:A},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},t.TITLE_MODE]}]),exports:{preprocessor:x,strings:p,keywords:A}}}function g2(t){const a=t.regex,l=t.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",o="[a-zA-Z_]\\w*::",c="(?!struct)("+r+"|"+a.optional(o)+"[a-zA-Z_]\\w*"+a.optional("<[^<>]+>")+")",h={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},p={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[t.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},t.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},b={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},x={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},t.inherit(p,{className:"string"}),{className:"string",begin:/<.*?>/},l,t.C_BLOCK_COMMENT_MODE]},_={className:"title",begin:a.optional(o)+t.IDENT_RE,relevance:0},v=a.optional(o)+t.IDENT_RE+"\\s*\\(",S=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],T=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],A=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],w=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],q={type:T,keyword:S,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:A},Y={className:"function.dispatch",relevance:0,keywords:{_hint:w},begin:a.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,t.IDENT_RE,a.lookahead(/(<[^<>]+>|)\s*\(/))},L=[Y,x,h,l,t.C_BLOCK_COMMENT_MODE,b,p],X={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:q,contains:L.concat([{begin:/\(/,end:/\)/,keywords:q,contains:L.concat(["self"]),relevance:0}]),relevance:0},oe={className:"function",begin:"("+c+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:q,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:q,relevance:0},{begin:v,returnBegin:!0,contains:[_],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[p,b]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:q,relevance:0,contains:[l,t.C_BLOCK_COMMENT_MODE,p,b,h,{begin:/\(/,end:/\)/,keywords:q,relevance:0,contains:["self",l,t.C_BLOCK_COMMENT_MODE,p,b,h]}]},h,l,t.C_BLOCK_COMMENT_MODE,x]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:q,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(X,oe,Y,L,[x,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:q,contains:["self",h]},{begin:t.IDENT_RE+"::",keywords:q},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function b2(t){const a=["bool","byte","char","decimal","delegate","double","dynamic","enum","float","int","long","nint","nuint","object","sbyte","short","string","ulong","uint","ushort"],l=["public","private","protected","static","internal","protected","abstract","async","extern","override","unsafe","virtual","new","sealed","partial"],r=["default","false","null","true"],o=["abstract","as","base","break","case","catch","class","const","continue","do","else","event","explicit","extern","finally","fixed","for","foreach","goto","if","implicit","in","interface","internal","is","lock","namespace","new","operator","out","override","params","private","protected","public","readonly","record","ref","return","scoped","sealed","sizeof","stackalloc","static","struct","switch","this","throw","try","typeof","unchecked","unsafe","using","virtual","void","volatile","while"],u=["add","alias","and","ascending","args","async","await","by","descending","dynamic","equals","file","from","get","global","group","init","into","join","let","nameof","not","notnull","on","or","orderby","partial","record","remove","required","scoped","select","set","unmanaged","value|0","var","when","where","with","yield"],c={keyword:o.concat(u),built_in:a,literal:r},h=t.inherit(t.TITLE_MODE,{begin:"[a-zA-Z](\\.?\\w)*"}),g={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},p={className:"string",begin:/"""("*)(?!")(.|\n)*?"""\1/,relevance:1},b={className:"string",begin:'@"',end:'"',contains:[{begin:'""'}]},x=t.inherit(b,{illegal:/\n/}),_={className:"subst",begin:/\{/,end:/\}/,keywords:c},v=t.inherit(_,{illegal:/\n/}),S={className:"string",begin:/\$"/,end:'"',illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},t.BACKSLASH_ESCAPE,v]},T={className:"string",begin:/\$@"/,end:'"',contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},_]},A=t.inherit(T,{illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},v]});_.contains=[T,S,b,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,g,t.C_BLOCK_COMMENT_MODE],v.contains=[A,S,x,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,g,t.inherit(t.C_BLOCK_COMMENT_MODE,{illegal:/\n/})];const w={variants:[p,T,S,b,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE]},O={begin:"<",end:">",contains:[{beginKeywords:"in out"},h]},R=t.IDENT_RE+"(<"+t.IDENT_RE+"(\\s*,\\s*"+t.IDENT_RE+")*>)?(\\[\\])?",q={begin:"@"+t.IDENT_RE,relevance:0};return{name:"C#",aliases:["cs","c#"],keywords:c,illegal:/::/,contains:[t.COMMENT("///","$",{returnBegin:!0,contains:[{className:"doctag",variants:[{begin:"///",relevance:0},{begin:"<!--|-->"},{begin:"</?",end:">"}]}]}),t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,{className:"meta",begin:"#",end:"$",keywords:{keyword:"if else elif endif define undef warning error line region endregion pragma checksum"}},w,g,{beginKeywords:"class interface",relevance:0,end:/[{;=]/,illegal:/[^\s:,]/,contains:[{beginKeywords:"where class"},h,O,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},{beginKeywords:"namespace",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[h,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},{beginKeywords:"record",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[h,O,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},{className:"meta",begin:"^\\s*\\[(?=[\\w])",excludeBegin:!0,end:"\\]",excludeEnd:!0,contains:[{className:"string",begin:/"/,end:/"/}]},{beginKeywords:"new return throw await else",relevance:0},{className:"function",begin:"("+R+"\\s+)+"+t.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,end:/\s*[{;=]/,excludeEnd:!0,keywords:c,contains:[{beginKeywords:l.join(" "),relevance:0},{begin:t.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,contains:[t.TITLE_MODE,O],relevance:0},{match:/\(\)/},{className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,relevance:0,contains:[w,g,t.C_BLOCK_COMMENT_MODE]},t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},q]}}const x2=t=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:t.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:t.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),y2=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],_2=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],v2=[...y2,..._2],E2=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),S2=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),N2=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),w2=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function k2(t){const a=t.regex,l=x2(t),r={begin:/-(webkit|moz|ms|o)-(?=[a-z])/},o="and or not only",u=/@-?\w[\w]*(-\w+)*/,c="[a-zA-Z-][a-zA-Z0-9_-]*",h=[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE];return{name:"CSS",case_insensitive:!0,illegal:/[=|'\$]/,keywords:{keyframePosition:"from to"},classNameAliases:{keyframePosition:"selector-tag"},contains:[l.BLOCK_COMMENT,r,l.CSS_NUMBER_MODE,{className:"selector-id",begin:/#[A-Za-z0-9_-]+/,relevance:0},{className:"selector-class",begin:"\\."+c,relevance:0},l.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",variants:[{begin:":("+S2.join("|")+")"},{begin:":(:)?("+N2.join("|")+")"}]},l.CSS_VARIABLE,{className:"attribute",begin:"\\b("+w2.join("|")+")\\b"},{begin:/:/,end:/[;}{]/,contains:[l.BLOCK_COMMENT,l.HEXCOLOR,l.IMPORTANT,l.CSS_NUMBER_MODE,...h,{begin:/(url|data-uri)\(/,end:/\)/,relevance:0,keywords:{built_in:"url data-uri"},contains:[...h,{className:"string",begin:/[^)]/,endsWithParent:!0,excludeEnd:!0}]},l.FUNCTION_DISPATCH]},{begin:a.lookahead(/@/),end:"[{;]",relevance:0,illegal:/:/,contains:[{className:"keyword",begin:u},{begin:/\s/,endsWithParent:!0,excludeEnd:!0,relevance:0,keywords:{$pattern:/[a-z-]+/,keyword:o,attribute:E2.join(" ")},contains:[{begin:/[a-z-]+(?=:)/,className:"attribute"},...h,l.CSS_NUMBER_MODE]}]},{className:"selector-tag",begin:"\\b("+v2.join("|")+")\\b"}]}}function T2(t){const a=t.regex;return{name:"Diff",aliases:["patch"],contains:[{className:"meta",relevance:10,match:a.either(/^@@ +-\d+,\d+ +\+\d+,\d+ +@@/,/^\*\*\* +\d+,\d+ +\*\*\*\*$/,/^--- +\d+,\d+ +----$/)},{className:"comment",variants:[{begin:a.either(/Index: /,/^index/,/={3,}/,/^-{3}/,/^\*{3} /,/^\+{3}/,/^diff --git/),end:/$/},{match:/^\*{15}$/}]},{className:"addition",begin:/^\+/,end:/$/},{className:"deletion",begin:/^-/,end:/$/},{className:"addition",begin:/^!/,end:/$/}]}}function A2(t){const u={keyword:["break","case","chan","const","continue","default","defer","else","fallthrough","for","func","go","goto","if","import","interface","map","package","range","return","select","struct","switch","type","var"],type:["bool","byte","complex64","complex128","error","float32","float64","int8","int16","int32","int64","string","uint8","uint16","uint32","uint64","int","uint","uintptr","rune"],literal:["true","false","iota","nil"],built_in:["append","cap","close","complex","copy","imag","len","make","new","panic","print","println","real","recover","delete"]};return{name:"Go",aliases:["golang"],keywords:u,illegal:"</",contains:[t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,{className:"string",variants:[t.QUOTE_STRING_MODE,t.APOS_STRING_MODE,{begin:"`",end:"`"}]},{className:"number",variants:[{match:/-?\b0[xX]\.[a-fA-F0-9](_?[a-fA-F0-9])*[pP][+-]?\d(_?\d)*i?/,relevance:0},{match:/-?\b0[xX](_?[a-fA-F0-9])+((\.([a-fA-F0-9](_?[a-fA-F0-9])*)?)?[pP][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b0[oO](_?[0-7])*i?/,relevance:0},{match:/-?\.\d(_?\d)*([eE][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b\d(_?\d)*(\.(\d(_?\d)*)?)?([eE][+-]?\d(_?\d)*)?i?/,relevance:0}]},{begin:/:=/},{className:"function",beginKeywords:"func",end:"\\s*(\\{|$)",excludeEnd:!0,contains:[t.TITLE_MODE,{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:u,illegal:/["']/}]}]}}function M2(t){const a=t.regex,l=/[_A-Za-z][_0-9A-Za-z]*/;return{name:"GraphQL",aliases:["gql"],case_insensitive:!0,disableAutodetect:!1,keywords:{keyword:["query","mutation","subscription","type","input","schema","directive","interface","union","scalar","fragment","enum","on"],literal:["true","false","null"]},contains:[t.HASH_COMMENT_MODE,t.QUOTE_STRING_MODE,t.NUMBER_MODE,{scope:"punctuation",match:/[.]{3}/,relevance:0},{scope:"punctuation",begin:/[\!\(\)\:\=\[\]\{\|\}]{1}/,relevance:0},{scope:"variable",begin:/\$/,end:/\W/,excludeEnd:!0,relevance:0},{scope:"meta",match:/@\w+/,excludeEnd:!0},{scope:"symbol",begin:a.concat(l,a.lookahead(/\s*:/)),relevance:0}],illegal:[/[;<']/,/BEGIN/]}}function C2(t){const a=t.regex,l={className:"number",relevance:0,variants:[{begin:/([+-]+)?[\d]+_[\d_]+/},{begin:t.NUMBER_RE}]},r=t.COMMENT();r.variants=[{begin:/;/,end:/$/},{begin:/#/,end:/$/}];const o={className:"variable",variants:[{begin:/\$[\w\d"][\w\d_]*/},{begin:/\$\{(.*?)\}/}]},u={className:"literal",begin:/\bon|off|true|false|yes|no\b/},c={className:"string",contains:[t.BACKSLASH_ESCAPE],variants:[{begin:"'''",end:"'''",relevance:10},{begin:'"""',end:'"""',relevance:10},{begin:'"',end:'"'},{begin:"'",end:"'"}]},h={begin:/\[/,end:/\]/,contains:[r,u,o,c,l,"self"],relevance:0},g=/[A-Za-z0-9_-]+/,p=/"(\\"|[^"])*"/,b=/'[^']*'/,x=a.either(g,p,b),_=a.concat(x,"(\\s*\\.\\s*",x,")*",a.lookahead(/\s*=\s*[^#\s]/));return{name:"TOML, also INI",aliases:["toml"],case_insensitive:!0,illegal:/\S/,contains:[r,{className:"section",begin:/\[+/,end:/\]+/},{begin:_,className:"attr",starts:{end:/$/,contains:[r,h,u,o,c,l]}}]}}var Cl="[0-9](_*[0-9])*",Mo=`\\.(${Cl})`,Co="[0-9a-fA-F](_*[0-9a-fA-F])*",N0={className:"number",variants:[{begin:`(\\b(${Cl})((${Mo})|\\.)?|(${Mo}))[eE][+-]?(${Cl})[fFdD]?\\b`},{begin:`\\b(${Cl})((${Mo})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${Mo})[fFdD]?\\b`},{begin:`\\b(${Cl})[fFdD]\\b`},{begin:`\\b0[xX]((${Co})\\.?|(${Co})?\\.(${Co}))[pP][+-]?(${Cl})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${Co})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function mx(t,a,l){return l===-1?"":t.replace(a,r=>mx(t,a,l-1))}function O2(t){const a=t.regex,l="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=l+mx("(?:<"+l+"~~~(?:\\s*,\\s*"+l+"~~~)*>)?",/~~~/g,2),g={keyword:["synchronized","abstract","private","var","static","if","const ","for","while","strictfp","finally","protected","import","native","final","void","enum","else","break","transient","catch","instanceof","volatile","case","assert","package","default","public","try","switch","continue","throws","protected","public","private","module","requires","exports","do","sealed","yield","permits","goto","when"],literal:["false","true","null"],type:["char","boolean","long","float","int","byte","short","double"],built_in:["super","this"]},p={className:"meta",begin:"@"+l,contains:[{begin:/\(/,end:/\)/,contains:["self"]}]},b={className:"params",begin:/\(/,end:/\)/,keywords:g,relevance:0,contains:[t.C_BLOCK_COMMENT_MODE],endsParent:!0};return{name:"Java",aliases:["jsp"],keywords:g,illegal:/<\/|#/,contains:[t.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{begin:/\w+@/,relevance:0},{className:"doctag",begin:"@[A-Za-z]+"}]}),{begin:/import java\.[a-z]+\./,keywords:"import",relevance:2},t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,{begin:/"""/,end:/"""/,className:"string",contains:[t.BACKSLASH_ESCAPE]},t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,{match:[/\b(?:class|interface|enum|extends|implements|new)/,/\s+/,l],className:{1:"keyword",3:"title.class"}},{match:/non-sealed/,scope:"keyword"},{begin:[a.concat(/(?!else)/,l),/\s+/,l,/\s+/,/=(?!=)/],className:{1:"type",3:"variable",5:"operator"}},{begin:[/record/,/\s+/,l],className:{1:"keyword",3:"title.class"},contains:[b,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},{beginKeywords:"new throw return else",relevance:0},{begin:["(?:"+r+"\\s+)",t.UNDERSCORE_IDENT_RE,/\s*(?=\()/],className:{2:"title.function"},keywords:g,contains:[{className:"params",begin:/\(/,end:/\)/,keywords:g,relevance:0,contains:[p,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,N0,t.C_BLOCK_COMMENT_MODE]},t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},N0,p]}}const w0="[A-Za-z$_][0-9A-Za-z$_]*",z2=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],R2=["true","false","null","undefined","NaN","Infinity"],hx=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],px=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],gx=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],D2=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],L2=[].concat(gx,hx,px);function j2(t){const a=t.regex,l=(ne,{after:ie})=>{const k="</"+ne[0].slice(1);return ne.input.indexOf(k,ie)!==-1},r=w0,o={begin:"<>",end:"</>"},u=/<[A-Za-z0-9\\._:-]+\s*\/>/,c={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(ne,ie)=>{const k=ne[0].length+ne.index,M=ne.input[k];if(M==="<"||M===","){ie.ignoreMatch();return}M===">"&&(l(ne,{after:k})||ie.ignoreMatch());let B;const N=ne.input.substring(k);if(B=N.match(/^\s*=/)){ie.ignoreMatch();return}if((B=N.match(/^\s+extends\s+/))&&B.index===0){ie.ignoreMatch();return}}},h={$pattern:w0,keyword:z2,literal:R2,built_in:L2,"variable.language":D2},g="[0-9](_?[0-9])*",p=`\\.(${g})`,b="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",x={className:"number",variants:[{begin:`(\\b(${b})((${p})|\\.)?|(${p}))[eE][+-]?(${g})\\b`},{begin:`\\b(${b})\\b((${p})\\b|\\.)?|(${p})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},_={className:"subst",begin:"\\$\\{",end:"\\}",keywords:h,contains:[]},v={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"xml"}},S={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"css"}},T={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"graphql"}},A={className:"string",begin:"`",end:"`",contains:[t.BACKSLASH_ESCAPE,_]},O={className:"comment",variants:[t.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),t.C_BLOCK_COMMENT_MODE,t.C_LINE_COMMENT_MODE]},R=[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,v,S,T,A,{match:/\$\d+/},x];_.contains=R.concat({begin:/\{/,end:/\}/,keywords:h,contains:["self"].concat(R)});const q=[].concat(O,_.contains),Y=q.concat([{begin:/(\s*)\(/,end:/\)/,keywords:h,contains:["self"].concat(q)}]),L={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:h,contains:Y},X={variants:[{match:[/class/,/\s+/,r,/\s+/,/extends/,/\s+/,a.concat(r,"(",a.concat(/\./,r),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,r],scope:{1:"keyword",3:"title.class"}}]},oe={relevance:0,match:a.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[...hx,...px]}},he={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},U={variants:[{match:[/function/,/\s+/,r,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[L],illegal:/%/},re={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function ae(ne){return a.concat("(?!",ne.join("|"),")")}const le={match:a.concat(/\b/,ae([...gx,"super","import"].map(ne=>`${ne}\\s*\\(`)),r,a.lookahead(/\s*\(/)),className:"title.function",relevance:0},W={begin:a.concat(/\./,a.lookahead(a.concat(r,/(?![0-9A-Za-z$_(])/))),end:r,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},H={match:[/get|set/,/\s+/,r,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},L]},C="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+t.UNDERSCORE_IDENT_RE+")\\s*=>",K={match:[/const|var|let/,/\s+/,r,/\s*/,/=\s*/,/(async\s*)?/,a.lookahead(C)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[L]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:h,exports:{PARAMS_CONTAINS:Y,CLASS_REFERENCE:oe},illegal:/#(?![$_A-z])/,contains:[t.SHEBANG({label:"shebang",binary:"node",relevance:5}),he,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,v,S,T,A,O,{match:/\$\d+/},x,oe,{scope:"attr",match:r+a.lookahead(":"),relevance:0},K,{begin:"("+t.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[O,t.REGEXP_MODE,{className:"function",begin:C,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:t.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:h,contains:Y}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:o.begin,end:o.end},{match:u},{begin:c.begin,"on:begin":c.isTrulyOpeningTag,end:c.end}],subLanguage:"xml",contains:[{begin:c.begin,end:c.end,skip:!0,contains:["self"]}]}]},U,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+t.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[L,t.inherit(t.TITLE_MODE,{begin:r,className:"title.function"})]},{match:/\.\.\./,relevance:0},W,{match:"\\$"+r,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[L]},le,re,X,H,{match:/\$[(.]/}]}}function B2(t){const a={className:"attr",begin:/"(\\.|[^\\"\r\n])*"(?=\s*:)/,relevance:1.01},l={match:/[{}[\],:]/,className:"punctuation",relevance:0},r=["true","false","null"],o={scope:"literal",beginKeywords:r.join(" ")};return{name:"JSON",aliases:["jsonc"],keywords:{literal:r},contains:[a,l,t.QUOTE_STRING_MODE,o,t.C_NUMBER_MODE,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE],illegal:"\\S"}}var Ol="[0-9](_*[0-9])*",Oo=`\\.(${Ol})`,zo="[0-9a-fA-F](_*[0-9a-fA-F])*",I2={className:"number",variants:[{begin:`(\\b(${Ol})((${Oo})|\\.)?|(${Oo}))[eE][+-]?(${Ol})[fFdD]?\\b`},{begin:`\\b(${Ol})((${Oo})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${Oo})[fFdD]?\\b`},{begin:`\\b(${Ol})[fFdD]\\b`},{begin:`\\b0[xX]((${zo})\\.?|(${zo})?\\.(${zo}))[pP][+-]?(${Ol})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${zo})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function U2(t){const a={keyword:"abstract as val var vararg get set class object open private protected public noinline crossinline dynamic final enum if else do while for when throw try catch finally import package is in fun override companion reified inline lateinit init interface annotation data sealed internal infix operator out by constructor super tailrec where const inner suspend typealias external expect actual",built_in:"Byte Short Char Int Long Boolean Float Double Void Unit Nothing",literal:"true false null"},l={className:"keyword",begin:/\b(break|continue|return|this)\b/,starts:{contains:[{className:"symbol",begin:/@\w+/}]}},r={className:"symbol",begin:t.UNDERSCORE_IDENT_RE+"@"},o={className:"subst",begin:/\$\{/,end:/\}/,contains:[t.C_NUMBER_MODE]},u={className:"variable",begin:"\\$"+t.UNDERSCORE_IDENT_RE},c={className:"string",variants:[{begin:'"""',end:'"""(?=[^"])',contains:[u,o]},{begin:"'",end:"'",illegal:/\n/,contains:[t.BACKSLASH_ESCAPE]},{begin:'"',end:'"',illegal:/\n/,contains:[t.BACKSLASH_ESCAPE,u,o]}]};o.contains.push(c);const h={className:"meta",begin:"@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*"+t.UNDERSCORE_IDENT_RE+")?"},g={className:"meta",begin:"@"+t.UNDERSCORE_IDENT_RE,contains:[{begin:/\(/,end:/\)/,contains:[t.inherit(c,{className:"string"}),"self"]}]},p=I2,b=t.COMMENT("/\\*","\\*/",{contains:[t.C_BLOCK_COMMENT_MODE]}),x={variants:[{className:"type",begin:t.UNDERSCORE_IDENT_RE},{begin:/\(/,end:/\)/,contains:[]}]},_=x;return _.variants[1].contains=[x],x.variants[1].contains=[_],{name:"Kotlin",aliases:["kt","kts"],keywords:a,contains:[t.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"}]}),t.C_LINE_COMMENT_MODE,b,l,r,h,g,{className:"function",beginKeywords:"fun",end:"[(]|$",returnBegin:!0,excludeEnd:!0,keywords:a,relevance:5,contains:[{begin:t.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,contains:[t.UNDERSCORE_TITLE_MODE]},{className:"type",begin:/</,end:/>/,keywords:"reified",relevance:0},{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:a,relevance:0,contains:[{begin:/:/,end:/[=,\/]/,endsWithParent:!0,contains:[x,t.C_LINE_COMMENT_MODE,b],relevance:0},t.C_LINE_COMMENT_MODE,b,h,g,c,t.C_NUMBER_MODE]},b]},{begin:[/class|interface|trait/,/\s+/,t.UNDERSCORE_IDENT_RE],beginScope:{3:"title.class"},keywords:"class interface trait",end:/[:\{(]|$/,excludeEnd:!0,illegal:"extends implements",contains:[{beginKeywords:"public protected internal private constructor"},t.UNDERSCORE_TITLE_MODE,{className:"type",begin:/</,end:/>/,excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:/[,:]\s*/,end:/[<\(,){\s]|$/,excludeBegin:!0,returnEnd:!0},h,g]},c,{className:"meta",begin:"^#!/usr/bin/env",end:"$",illegal:`
`},p]}}const H2=t=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:t.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:t.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),F2=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],$2=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],q2=[...F2,...$2],G2=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),bx=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),xx=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),P2=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse(),Y2=bx.concat(xx).sort().reverse();function V2(t){const a=H2(t),l=Y2,r="and or not only",o="[\\w-]+",u="("+o+"|@\\{"+o+"\\})",c=[],h=[],g=function(R){return{className:"string",begin:"~?"+R+".*?"+R}},p=function(R,q,Y){return{className:R,begin:q,relevance:Y}},b={$pattern:/[a-z-]+/,keyword:r,attribute:G2.join(" ")},x={begin:"\\(",end:"\\)",contains:h,keywords:b,relevance:0};h.push(t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,g("'"),g('"'),a.CSS_NUMBER_MODE,{begin:"(url|data-uri)\\(",starts:{className:"string",end:"[\\)\\n]",excludeEnd:!0}},a.HEXCOLOR,x,p("variable","@@?"+o,10),p("variable","@\\{"+o+"\\}"),p("built_in","~?`[^`]*?`"),{className:"attribute",begin:o+"\\s*:",end:":",returnBegin:!0,excludeEnd:!0},a.IMPORTANT,{beginKeywords:"and not"},a.FUNCTION_DISPATCH);const _=h.concat({begin:/\{/,end:/\}/,contains:c}),v={beginKeywords:"when",endsWithParent:!0,contains:[{beginKeywords:"and not"}].concat(h)},S={begin:u+"\\s*:",returnBegin:!0,end:/[;}]/,relevance:0,contains:[{begin:/-(webkit|moz|ms|o)-/},a.CSS_VARIABLE,{className:"attribute",begin:"\\b("+P2.join("|")+")\\b",end:/(?=:)/,starts:{endsWithParent:!0,illegal:"[<=$]",relevance:0,contains:h}}]},T={className:"keyword",begin:"@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",starts:{end:"[;{}]",keywords:b,returnEnd:!0,contains:h,relevance:0}},A={className:"variable",variants:[{begin:"@"+o+"\\s*:",relevance:15},{begin:"@"+o}],starts:{end:"[;}]",returnEnd:!0,contains:_}},w={variants:[{begin:"[\\.#:&\\[>]",end:"[;{}]"},{begin:u,end:/\{/}],returnBegin:!0,returnEnd:!0,illegal:`[<='$"]`,relevance:0,contains:[t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,v,p("keyword","all\\b"),p("variable","@\\{"+o+"\\}"),{begin:"\\b("+q2.join("|")+")\\b",className:"selector-tag"},a.CSS_NUMBER_MODE,p("selector-tag",u,0),p("selector-id","#"+u),p("selector-class","\\."+u,0),p("selector-tag","&",0),a.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",begin:":("+bx.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+xx.join("|")+")"},{begin:/\(/,end:/\)/,relevance:0,contains:_},{begin:"!important"},a.FUNCTION_DISPATCH]},O={begin:o+`:(:)?(${l.join("|")})`,returnBegin:!0,contains:[w]};return c.push(t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,T,A,O,S,w,v,a.FUNCTION_DISPATCH),{name:"Less",case_insensitive:!0,illegal:`[=>'/<($"]`,contains:c}}function K2(t){const a="\\[=*\\[",l="\\]=*\\]",r={begin:a,end:l,contains:["self"]},o=[t.COMMENT("--(?!"+a+")","$"),t.COMMENT("--"+a,l,{contains:[r],relevance:10})];return{name:"Lua",aliases:["pluto"],keywords:{$pattern:t.UNDERSCORE_IDENT_RE,literal:"true false nil",keyword:"and break do else elseif end for goto if in local not or repeat return then until while",built_in:"_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"},contains:o.concat([{className:"function",beginKeywords:"function",end:"\\)",contains:[t.inherit(t.TITLE_MODE,{begin:"([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*"}),{className:"params",begin:"\\(",endsWithParent:!0,contains:o}].concat(o)},t.C_NUMBER_MODE,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,{className:"string",begin:a,end:l,contains:[r],relevance:5}])}}function X2(t){const a={className:"variable",variants:[{begin:"\\$\\("+t.UNDERSCORE_IDENT_RE+"\\)",contains:[t.BACKSLASH_ESCAPE]},{begin:/\$[@%<?\^\+\*]/}]},l={className:"string",begin:/"/,end:/"/,contains:[t.BACKSLASH_ESCAPE,a]},r={className:"variable",begin:/\$\([\w-]+\s/,end:/\)/,keywords:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},contains:[a,l]},o={begin:"^"+t.UNDERSCORE_IDENT_RE+"\\s*(?=[:+?]?=)"},u={className:"meta",begin:/^\.PHONY:/,end:/$/,keywords:{$pattern:/[\.\w]+/,keyword:".PHONY"}},c={className:"section",begin:/^[^\s]+:/,end:/$/,contains:[a]};return{name:"Makefile",aliases:["mk","mak","make"],keywords:{$pattern:/[\w-]+/,keyword:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"},contains:[t.HASH_COMMENT_MODE,a,l,r,o,u,c]}}function Z2(t){const a=t.regex,l={begin:/<\/?[A-Za-z_]/,end:">",subLanguage:"xml",relevance:0},r={begin:"^[-\\*]{3,}",end:"$"},o={className:"code",variants:[{begin:"(`{3,})[^`](.|\\n)*?\\1`*[ ]*"},{begin:"(~{3,})[^~](.|\\n)*?\\1~*[ ]*"},{begin:"```",end:"```+[ ]*$"},{begin:"~~~",end:"~~~+[ ]*$"},{begin:"`.+?`"},{begin:"(?=^( {4}|\\t))",contains:[{begin:"^( {4}|\\t)",end:"(\\n)$"}],relevance:0}]},u={className:"bullet",begin:"^[ 	]*([*+-]|(\\d+\\.))(?=\\s+)",end:"\\s+",excludeEnd:!0},c={begin:/^\[[^\n]+\]:/,returnBegin:!0,contains:[{className:"symbol",begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0},{className:"link",begin:/:\s*/,end:/$/,excludeBegin:!0}]},h=/[A-Za-z][A-Za-z0-9+.-]*/,g={variants:[{begin:/\[.+?\]\[.*?\]/,relevance:0},{begin:/\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,relevance:2},{begin:a.concat(/\[.+?\]\(/,h,/:\/\/.*?\)/),relevance:2},{begin:/\[.+?\]\([./?&#].*?\)/,relevance:1},{begin:/\[.*?\]\(.*?\)/,relevance:0}],returnBegin:!0,contains:[{match:/\[(?=\])/},{className:"string",relevance:0,begin:"\\[",end:"\\]",excludeBegin:!0,returnEnd:!0},{className:"link",relevance:0,begin:"\\]\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0},{className:"symbol",relevance:0,begin:"\\]\\[",end:"\\]",excludeBegin:!0,excludeEnd:!0}]},p={className:"strong",contains:[],variants:[{begin:/_{2}(?!\s)/,end:/_{2}/},{begin:/\*{2}(?!\s)/,end:/\*{2}/}]},b={className:"emphasis",contains:[],variants:[{begin:/\*(?![*\s])/,end:/\*/},{begin:/_(?![_\s])/,end:/_/,relevance:0}]},x=t.inherit(p,{contains:[]}),_=t.inherit(b,{contains:[]});p.contains.push(_),b.contains.push(x);let v=[l,g];return[p,b,x,_].forEach(w=>{w.contains=w.contains.concat(v)}),v=v.concat(p,b),{name:"Markdown",aliases:["md","mkdown","mkd"],contains:[{className:"section",variants:[{begin:"^#{1,6}",end:"$",contains:v},{begin:"(?=^.+?\\n[=-]{2,}$)",contains:[{begin:"^[=-]*$"},{begin:"^",end:"\\n",contains:v}]}]},l,u,p,b,{className:"quote",begin:"^>\\s+",contains:v,end:"$"},o,r,g,c,{scope:"literal",match:/&([a-zA-Z0-9]+|#[0-9]{1,7}|#[Xx][0-9a-fA-F]{1,6});/}]}}function Q2(t){const a={className:"built_in",begin:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},l=/[a-zA-Z@][a-zA-Z0-9_]*/,h={"variable.language":["this","super"],$pattern:l,keyword:["while","export","sizeof","typedef","const","struct","for","union","volatile","static","mutable","if","do","return","goto","enum","else","break","extern","asm","case","default","register","explicit","typename","switch","continue","inline","readonly","assign","readwrite","self","@synchronized","id","typeof","nonatomic","IBOutlet","IBAction","strong","weak","copy","in","out","inout","bycopy","byref","oneway","__strong","__weak","__block","__autoreleasing","@private","@protected","@public","@try","@property","@end","@throw","@catch","@finally","@autoreleasepool","@synthesize","@dynamic","@selector","@optional","@required","@encode","@package","@import","@defs","@compatibility_alias","__bridge","__bridge_transfer","__bridge_retained","__bridge_retain","__covariant","__contravariant","__kindof","_Nonnull","_Nullable","_Null_unspecified","__FUNCTION__","__PRETTY_FUNCTION__","__attribute__","getter","setter","retain","unsafe_unretained","nonnull","nullable","null_unspecified","null_resettable","class","instancetype","NS_DESIGNATED_INITIALIZER","NS_UNAVAILABLE","NS_REQUIRES_SUPER","NS_RETURNS_INNER_POINTER","NS_INLINE","NS_AVAILABLE","NS_DEPRECATED","NS_ENUM","NS_OPTIONS","NS_SWIFT_UNAVAILABLE","NS_ASSUME_NONNULL_BEGIN","NS_ASSUME_NONNULL_END","NS_REFINED_FOR_SWIFT","NS_SWIFT_NAME","NS_SWIFT_NOTHROW","NS_DURING","NS_HANDLER","NS_ENDHANDLER","NS_VALUERETURN","NS_VOIDRETURN"],literal:["false","true","FALSE","TRUE","nil","YES","NO","NULL"],built_in:["dispatch_once_t","dispatch_queue_t","dispatch_sync","dispatch_async","dispatch_once"],type:["int","float","char","unsigned","signed","short","long","double","wchar_t","unichar","void","bool","BOOL","id|0","_Bool"]},g={$pattern:l,keyword:["@interface","@class","@protocol","@implementation"]};return{name:"Objective-C",aliases:["mm","objc","obj-c","obj-c++","objective-c++"],keywords:h,illegal:"</",contains:[a,t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,t.C_NUMBER_MODE,t.QUOTE_STRING_MODE,t.APOS_STRING_MODE,{className:"string",variants:[{begin:'@"',end:'"',illegal:"\\n",contains:[t.BACKSLASH_ESCAPE]}]},{className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},t.inherit(t.QUOTE_STRING_MODE,{className:"string"}),{className:"string",begin:/<.*?>/,end:/$/,illegal:"\\n"},t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE]},{className:"class",begin:"("+g.keyword.join("|")+")\\b",end:/(\{|$)/,excludeEnd:!0,keywords:g,contains:[t.UNDERSCORE_TITLE_MODE]},{begin:"\\."+t.UNDERSCORE_IDENT_RE,relevance:0}]}}function J2(t){const a=t.regex,l=["abs","accept","alarm","and","atan2","bind","binmode","bless","break","caller","chdir","chmod","chomp","chop","chown","chr","chroot","class","close","closedir","connect","continue","cos","crypt","dbmclose","dbmopen","defined","delete","die","do","dump","each","else","elsif","endgrent","endhostent","endnetent","endprotoent","endpwent","endservent","eof","eval","exec","exists","exit","exp","fcntl","field","fileno","flock","for","foreach","fork","format","formline","getc","getgrent","getgrgid","getgrnam","gethostbyaddr","gethostbyname","gethostent","getlogin","getnetbyaddr","getnetbyname","getnetent","getpeername","getpgrp","getpriority","getprotobyname","getprotobynumber","getprotoent","getpwent","getpwnam","getpwuid","getservbyname","getservbyport","getservent","getsockname","getsockopt","given","glob","gmtime","goto","grep","gt","hex","if","index","int","ioctl","join","keys","kill","last","lc","lcfirst","length","link","listen","local","localtime","log","lstat","lt","ma","map","method","mkdir","msgctl","msgget","msgrcv","msgsnd","my","ne","next","no","not","oct","open","opendir","or","ord","our","pack","package","pipe","pop","pos","print","printf","prototype","push","q|0","qq","quotemeta","qw","qx","rand","read","readdir","readline","readlink","readpipe","recv","redo","ref","rename","require","reset","return","reverse","rewinddir","rindex","rmdir","say","scalar","seek","seekdir","select","semctl","semget","semop","send","setgrent","sethostent","setnetent","setpgrp","setpriority","setprotoent","setpwent","setservent","setsockopt","shift","shmctl","shmget","shmread","shmwrite","shutdown","sin","sleep","socket","socketpair","sort","splice","split","sprintf","sqrt","srand","stat","state","study","sub","substr","symlink","syscall","sysopen","sysread","sysseek","system","syswrite","tell","telldir","tie","tied","time","times","tr","truncate","uc","ucfirst","umask","undef","unless","unlink","unpack","unshift","untie","until","use","utime","values","vec","wait","waitpid","wantarray","warn","when","while","write","x|0","xor","y|0"],r=/[dualxmsipngr]{0,12}/,o={$pattern:/[\w.]+/,keyword:l.join(" ")},u={className:"subst",begin:"[$@]\\{",end:"\\}",keywords:o},c={begin:/->\{/,end:/\}/},h={scope:"attr",match:/\s+:\s*\w+(\s*\(.*?\))?/},g={scope:"variable",variants:[{begin:/\$\d/},{begin:a.concat(/[$%@](?!")(\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,"(?![A-Za-z])(?![@$%])")},{begin:/[$%@](?!")[^\s\w{=]|\$=/,relevance:0}],contains:[h]},p={className:"number",variants:[{match:/0?\.[0-9][0-9_]+\b/},{match:/\bv?(0|[1-9][0-9_]*(\.[0-9_]+)?|[1-9][0-9_]*)\b/},{match:/\b0[0-7][0-7_]*\b/},{match:/\b0x[0-9a-fA-F][0-9a-fA-F_]*\b/},{match:/\b0b[0-1][0-1_]*\b/}],relevance:0},b=[t.BACKSLASH_ESCAPE,u,g],x=[/!/,/\//,/\|/,/\?/,/'/,/"/,/#/],_=(T,A,w="\\1")=>{const O=w==="\\1"?w:a.concat(w,A);return a.concat(a.concat("(?:",T,")"),A,/(?:\\.|[^\\\/])*?/,O,/(?:\\.|[^\\\/])*?/,w,r)},v=(T,A,w)=>a.concat(a.concat("(?:",T,")"),A,/(?:\\.|[^\\\/])*?/,w,r),S=[g,t.HASH_COMMENT_MODE,t.COMMENT(/^=\w/,/=cut/,{endsWithParent:!0}),c,{className:"string",contains:b,variants:[{begin:"q[qwxr]?\\s*\\(",end:"\\)",relevance:5},{begin:"q[qwxr]?\\s*\\[",end:"\\]",relevance:5},{begin:"q[qwxr]?\\s*\\{",end:"\\}",relevance:5},{begin:"q[qwxr]?\\s*\\|",end:"\\|",relevance:5},{begin:"q[qwxr]?\\s*<",end:">",relevance:5},{begin:"qw\\s+q",end:"q",relevance:5},{begin:"'",end:"'",contains:[t.BACKSLASH_ESCAPE]},{begin:'"',end:'"'},{begin:"`",end:"`",contains:[t.BACKSLASH_ESCAPE]},{begin:/\{\w+\}/,relevance:0},{begin:"-?\\w+\\s*=>",relevance:0}]},p,{begin:"(\\/\\/|"+t.RE_STARTERS_RE+"|\\b(split|return|print|reverse|grep)\\b)\\s*",keywords:"split return print reverse grep",relevance:0,contains:[t.HASH_COMMENT_MODE,{className:"regexp",variants:[{begin:_("s|tr|y",a.either(...x,{capture:!0}))},{begin:_("s|tr|y","\\(","\\)")},{begin:_("s|tr|y","\\[","\\]")},{begin:_("s|tr|y","\\{","\\}")}],relevance:2},{className:"regexp",variants:[{begin:/(m|qr)\/\//,relevance:0},{begin:v("(?:m|qr)?",/\//,/\//)},{begin:v("m|qr",a.either(...x,{capture:!0}),/\1/)},{begin:v("m|qr",/\(/,/\)/)},{begin:v("m|qr",/\[/,/\]/)},{begin:v("m|qr",/\{/,/\}/)}]}]},{className:"function",beginKeywords:"sub method",end:"(\\s*\\(.*?\\))?[;{]",excludeEnd:!0,relevance:5,contains:[t.TITLE_MODE,h]},{className:"class",beginKeywords:"class",end:"[;{]",excludeEnd:!0,relevance:5,contains:[t.TITLE_MODE,h,p]},{begin:"-\\w\\b",relevance:0},{begin:"^__DATA__$",end:"^__END__$",subLanguage:"mojolicious",contains:[{begin:"^@@.*",end:"$",className:"comment"}]}];return u.contains=S,c.contains=S,{name:"Perl",aliases:["pl","pm"],keywords:o,contains:S}}function W2(t){const a=t.regex,l=/(?![A-Za-z0-9])(?![$])/,r=a.concat(/[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,l),o=a.concat(/(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,l),u=a.concat(/[A-Z]+/,l),c={scope:"variable",match:"\\$+"+r},h={scope:"meta",variants:[{begin:/<\?php/,relevance:10},{begin:/<\?=/},{begin:/<\?/,relevance:.1},{begin:/\?>/}]},g={scope:"subst",variants:[{begin:/\$\w+/},{begin:/\{\$/,end:/\}/}]},p=t.inherit(t.APOS_STRING_MODE,{illegal:null}),b=t.inherit(t.QUOTE_STRING_MODE,{illegal:null,contains:t.QUOTE_STRING_MODE.contains.concat(g)}),x={begin:/<<<[ \t]*(?:(\w+)|"(\w+)")\n/,end:/[ \t]*(\w+)\b/,contains:t.QUOTE_STRING_MODE.contains.concat(g),"on:begin":(W,H)=>{H.data._beginMatch=W[1]||W[2]},"on:end":(W,H)=>{H.data._beginMatch!==W[1]&&H.ignoreMatch()}},_=t.END_SAME_AS_BEGIN({begin:/<<<[ \t]*'(\w+)'\n/,end:/[ \t]*(\w+)\b/}),v=`[ 	
]`,S={scope:"string",variants:[b,p,x,_]},T={scope:"number",variants:[{begin:"\\b0[bB][01]+(?:_[01]+)*\\b"},{begin:"\\b0[oO][0-7]+(?:_[0-7]+)*\\b"},{begin:"\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b"},{begin:"(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?"}],relevance:0},A=["false","null","true"],w=["__CLASS__","__DIR__","__FILE__","__FUNCTION__","__COMPILER_HALT_OFFSET__","__LINE__","__METHOD__","__NAMESPACE__","__TRAIT__","die","echo","exit","include","include_once","print","require","require_once","array","abstract","and","as","binary","bool","boolean","break","callable","case","catch","class","clone","const","continue","declare","default","do","double","else","elseif","empty","enddeclare","endfor","endforeach","endif","endswitch","endwhile","enum","eval","extends","final","finally","float","for","foreach","from","global","goto","if","implements","instanceof","insteadof","int","integer","interface","isset","iterable","list","match|0","mixed","new","never","object","or","private","protected","public","readonly","real","return","string","switch","throw","trait","try","unset","use","var","void","while","xor","yield"],O=["Error|0","AppendIterator","ArgumentCountError","ArithmeticError","ArrayIterator","ArrayObject","AssertionError","BadFunctionCallException","BadMethodCallException","CachingIterator","CallbackFilterIterator","CompileError","Countable","DirectoryIterator","DivisionByZeroError","DomainException","EmptyIterator","ErrorException","Exception","FilesystemIterator","FilterIterator","GlobIterator","InfiniteIterator","InvalidArgumentException","IteratorIterator","LengthException","LimitIterator","LogicException","MultipleIterator","NoRewindIterator","OutOfBoundsException","OutOfRangeException","OuterIterator","OverflowException","ParentIterator","ParseError","RangeException","RecursiveArrayIterator","RecursiveCachingIterator","RecursiveCallbackFilterIterator","RecursiveDirectoryIterator","RecursiveFilterIterator","RecursiveIterator","RecursiveIteratorIterator","RecursiveRegexIterator","RecursiveTreeIterator","RegexIterator","RuntimeException","SeekableIterator","SplDoublyLinkedList","SplFileInfo","SplFileObject","SplFixedArray","SplHeap","SplMaxHeap","SplMinHeap","SplObjectStorage","SplObserver","SplPriorityQueue","SplQueue","SplStack","SplSubject","SplTempFileObject","TypeError","UnderflowException","UnexpectedValueException","UnhandledMatchError","ArrayAccess","BackedEnum","Closure","Fiber","Generator","Iterator","IteratorAggregate","Serializable","Stringable","Throwable","Traversable","UnitEnum","WeakReference","WeakMap","Directory","__PHP_Incomplete_Class","parent","php_user_filter","self","static","stdClass"],q={keyword:w,literal:(W=>{const H=[];return W.forEach(C=>{H.push(C),C.toLowerCase()===C?H.push(C.toUpperCase()):H.push(C.toLowerCase())}),H})(A),built_in:O},Y=W=>W.map(H=>H.replace(/\|\d+$/,"")),L={variants:[{match:[/new/,a.concat(v,"+"),a.concat("(?!",Y(O).join("\\b|"),"\\b)"),o],scope:{1:"keyword",4:"title.class"}}]},X=a.concat(r,"\\b(?!\\()"),oe={variants:[{match:[a.concat(/::/,a.lookahead(/(?!class\b)/)),X],scope:{2:"variable.constant"}},{match:[/::/,/class/],scope:{2:"variable.language"}},{match:[o,a.concat(/::/,a.lookahead(/(?!class\b)/)),X],scope:{1:"title.class",3:"variable.constant"}},{match:[o,a.concat("::",a.lookahead(/(?!class\b)/))],scope:{1:"title.class"}},{match:[o,/::/,/class/],scope:{1:"title.class",3:"variable.language"}}]},he={scope:"attr",match:a.concat(r,a.lookahead(":"),a.lookahead(/(?!::)/))},U={relevance:0,begin:/\(/,end:/\)/,keywords:q,contains:[he,c,oe,t.C_BLOCK_COMMENT_MODE,S,T,L]},re={relevance:0,match:[/\b/,a.concat("(?!fn\\b|function\\b|",Y(w).join("\\b|"),"|",Y(O).join("\\b|"),"\\b)"),r,a.concat(v,"*"),a.lookahead(/(?=\()/)],scope:{3:"title.function.invoke"},contains:[U]};U.contains.push(re);const ae=[he,oe,t.C_BLOCK_COMMENT_MODE,S,T,L],le={begin:a.concat(/#\[\s*\\?/,a.either(o,u)),beginScope:"meta",end:/]/,endScope:"meta",keywords:{literal:A,keyword:["new","array"]},contains:[{begin:/\[/,end:/]/,keywords:{literal:A,keyword:["new","array"]},contains:["self",...ae]},...ae,{scope:"meta",variants:[{match:o},{match:u}]}]};return{case_insensitive:!1,keywords:q,contains:[le,t.HASH_COMMENT_MODE,t.COMMENT("//","$"),t.COMMENT("/\\*","\\*/",{contains:[{scope:"doctag",match:"@[A-Za-z]+"}]}),{match:/__halt_compiler\(\);/,keywords:"__halt_compiler",starts:{scope:"comment",end:t.MATCH_NOTHING_RE,contains:[{match:/\?>/,scope:"meta",endsParent:!0}]}},h,{scope:"variable.language",match:/\$this\b/},c,re,oe,{match:[/const/,/\s/,r],scope:{1:"keyword",3:"variable.constant"}},L,{scope:"function",relevance:0,beginKeywords:"fn function",end:/[;{]/,excludeEnd:!0,illegal:"[$%\\[]",contains:[{beginKeywords:"use"},t.UNDERSCORE_TITLE_MODE,{begin:"=>",endsParent:!0},{scope:"params",begin:"\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0,keywords:q,contains:["self",le,c,oe,t.C_BLOCK_COMMENT_MODE,S,T]}]},{scope:"class",variants:[{beginKeywords:"enum",illegal:/[($"]/},{beginKeywords:"class interface trait",illegal:/[:($"]/}],relevance:0,end:/\{/,excludeEnd:!0,contains:[{beginKeywords:"extends implements"},t.UNDERSCORE_TITLE_MODE]},{beginKeywords:"namespace",relevance:0,end:";",illegal:/[.']/,contains:[t.inherit(t.UNDERSCORE_TITLE_MODE,{scope:"title.class"})]},{beginKeywords:"use",relevance:0,end:";",contains:[{match:/\b(as|const|function)\b/,scope:"keyword"},t.UNDERSCORE_TITLE_MODE]},S,T]}}function eA(t){return{name:"PHP template",subLanguage:"xml",contains:[{begin:/<\?(php|=)?/,end:/\?>/,subLanguage:"php",contains:[{begin:"/\\*",end:"\\*/",skip:!0},{begin:'b"',end:'"',skip:!0},{begin:"b'",end:"'",skip:!0},t.inherit(t.APOS_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0}),t.inherit(t.QUOTE_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0})]}]}}function tA(t){return{name:"Plain text",aliases:["text","txt"],disableAutodetect:!0}}function nA(t){const a=t.regex,l=new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*","u"),r=["and","as","assert","async","await","break","case","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","match","nonlocal|10","not","or","pass","raise","return","try","while","with","yield"],h={$pattern:/[A-Za-z]\w+|__\w+__/,keyword:r,built_in:["__import__","abs","all","any","ascii","bin","bool","breakpoint","bytearray","bytes","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","exec","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","print","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip"],literal:["__debug__","Ellipsis","False","None","NotImplemented","True"],type:["Any","Callable","Coroutine","Dict","List","Literal","Generic","Optional","Sequence","Set","Tuple","Type","Union"]},g={className:"meta",begin:/^(>>>|\.\.\.) /},p={className:"subst",begin:/\{/,end:/\}/,keywords:h,illegal:/#/},b={begin:/\{\{/,relevance:0},x={className:"string",contains:[t.BACKSLASH_ESCAPE],variants:[{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,end:/'''/,contains:[t.BACKSLASH_ESCAPE,g],relevance:10},{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,end:/"""/,contains:[t.BACKSLASH_ESCAPE,g],relevance:10},{begin:/([fF][rR]|[rR][fF]|[fF])'''/,end:/'''/,contains:[t.BACKSLASH_ESCAPE,g,b,p]},{begin:/([fF][rR]|[rR][fF]|[fF])"""/,end:/"""/,contains:[t.BACKSLASH_ESCAPE,g,b,p]},{begin:/([uU]|[rR])'/,end:/'/,relevance:10},{begin:/([uU]|[rR])"/,end:/"/,relevance:10},{begin:/([bB]|[bB][rR]|[rR][bB])'/,end:/'/},{begin:/([bB]|[bB][rR]|[rR][bB])"/,end:/"/},{begin:/([fF][rR]|[rR][fF]|[fF])'/,end:/'/,contains:[t.BACKSLASH_ESCAPE,b,p]},{begin:/([fF][rR]|[rR][fF]|[fF])"/,end:/"/,contains:[t.BACKSLASH_ESCAPE,b,p]},t.APOS_STRING_MODE,t.QUOTE_STRING_MODE]},_="[0-9](_?[0-9])*",v=`(\\b(${_}))?\\.(${_})|\\b(${_})\\.`,S=`\\b|${r.join("|")}`,T={className:"number",relevance:0,variants:[{begin:`(\\b(${_})|(${v}))[eE][+-]?(${_})[jJ]?(?=${S})`},{begin:`(${v})[jJ]?`},{begin:`\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${S})`},{begin:`\\b0[bB](_?[01])+[lL]?(?=${S})`},{begin:`\\b0[oO](_?[0-7])+[lL]?(?=${S})`},{begin:`\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${S})`},{begin:`\\b(${_})[jJ](?=${S})`}]},A={className:"comment",begin:a.lookahead(/# type:/),end:/$/,keywords:h,contains:[{begin:/# type:/},{begin:/#/,end:/\b\B/,endsWithParent:!0}]},w={className:"params",variants:[{className:"",begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:h,contains:["self",g,T,x,t.HASH_COMMENT_MODE]}]};return p.contains=[x,T,g],{name:"Python",aliases:["py","gyp","ipython"],unicodeRegex:!0,keywords:h,illegal:/(<\/|\?)|=>/,contains:[g,T,{scope:"variable.language",match:/\bself\b/},{beginKeywords:"if",relevance:0},{match:/\bor\b/,scope:"keyword"},x,A,t.HASH_COMMENT_MODE,{match:[/\bdef/,/\s+/,l],scope:{1:"keyword",3:"title.function"},contains:[w]},{variants:[{match:[/\bclass/,/\s+/,l,/\s*/,/\(\s*/,l,/\s*\)/]},{match:[/\bclass/,/\s+/,l]}],scope:{1:"keyword",3:"title.class",6:"title.class.inherited"}},{className:"meta",begin:/^[\t ]*@/,end:/(?=#)|$/,contains:[T,w,x]}]}}function iA(t){return{aliases:["pycon"],contains:[{className:"meta.prompt",starts:{end:/ |$/,starts:{end:"$",subLanguage:"python"}},variants:[{begin:/^>>>(?=[ ]|$)/},{begin:/^\.\.\.(?=[ ]|$)/}]}]}}function aA(t){const a=t.regex,l=/(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/,r=a.either(/0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/,/0[xX][0-9a-fA-F]+(?:[pP][+-]?\d+)?[Li]?/,/(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?[Li]?/),o=/[=!<>:]=|\|\||&&|:::?|<-|<<-|->>|->|\|>|[-+*\/?!$&|:<=>@^~]|\*\*/,u=a.either(/[()]/,/[{}]/,/\[\[/,/[[\]]/,/\\/,/,/);return{name:"R",keywords:{$pattern:l,keyword:"function if in break next repeat else for while",literal:"NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",built_in:"LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"},contains:[t.COMMENT(/#'/,/$/,{contains:[{scope:"doctag",match:/@examples/,starts:{end:a.lookahead(a.either(/\n^#'\s*(?=@[a-zA-Z]+)/,/\n^(?!#')/)),endsParent:!0}},{scope:"doctag",begin:"@param",end:/$/,contains:[{scope:"variable",variants:[{match:l},{match:/`(?:\\.|[^`\\])+`/}],endsParent:!0}]},{scope:"doctag",match:/@[a-zA-Z]+/},{scope:"keyword",match:/\\[a-zA-Z]+/}]}),t.HASH_COMMENT_MODE,{scope:"string",contains:[t.BACKSLASH_ESCAPE],variants:[t.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\(/,end:/\)(-*)"/}),t.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\{/,end:/\}(-*)"/}),t.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\[/,end:/\](-*)"/}),t.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\(/,end:/\)(-*)'/}),t.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\{/,end:/\}(-*)'/}),t.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\[/,end:/\](-*)'/}),{begin:'"',end:'"',relevance:0},{begin:"'",end:"'",relevance:0}]},{relevance:0,variants:[{scope:{1:"operator",2:"number"},match:[o,r]},{scope:{1:"operator",2:"number"},match:[/%[^%]*%/,r]},{scope:{1:"punctuation",2:"number"},match:[u,r]},{scope:{2:"number"},match:[/[^a-zA-Z0-9._]|^/,r]}]},{scope:{3:"operator"},match:[l,/\s+/,/<-/,/\s+/]},{scope:"operator",relevance:0,variants:[{match:o},{match:/%[^%]*%/}]},{scope:"punctuation",relevance:0,match:u},{begin:"`",end:"`",contains:[{begin:/\\./}]}]}}function lA(t){const a=t.regex,l="([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)",r=a.either(/\b([A-Z]+[a-z0-9]+)+/,/\b([A-Z]+[a-z0-9]+)+[A-Z]+/),o=a.concat(r,/(::\w+)*/),c={"variable.constant":["__FILE__","__LINE__","__ENCODING__"],"variable.language":["self","super"],keyword:["alias","and","begin","BEGIN","break","case","class","defined","do","else","elsif","end","END","ensure","for","if","in","module","next","not","or","redo","require","rescue","retry","return","then","undef","unless","until","when","while","yield",...["include","extend","prepend","public","private","protected","raise","throw"]],built_in:["proc","lambda","attr_accessor","attr_reader","attr_writer","define_method","private_constant","module_function"],literal:["true","false","nil"]},h={className:"doctag",begin:"@[A-Za-z]+"},g={begin:"#<",end:">"},p=[t.COMMENT("#","$",{contains:[h]}),t.COMMENT("^=begin","^=end",{contains:[h],relevance:10}),t.COMMENT("^__END__",t.MATCH_NOTHING_RE)],b={className:"subst",begin:/#\{/,end:/\}/,keywords:c},x={className:"string",contains:[t.BACKSLASH_ESCAPE,b],variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/`/,end:/`/},{begin:/%[qQwWx]?\(/,end:/\)/},{begin:/%[qQwWx]?\[/,end:/\]/},{begin:/%[qQwWx]?\{/,end:/\}/},{begin:/%[qQwWx]?</,end:/>/},{begin:/%[qQwWx]?\//,end:/\//},{begin:/%[qQwWx]?%/,end:/%/},{begin:/%[qQwWx]?-/,end:/-/},{begin:/%[qQwWx]?\|/,end:/\|/},{begin:/\B\?(\\\d{1,3})/},{begin:/\B\?(\\x[A-Fa-f0-9]{1,2})/},{begin:/\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/},{begin:/\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/},{begin:/\B\?\\(c|C-)[\x20-\x7e]/},{begin:/\B\?\\?\S/},{begin:a.concat(/<<[-~]?'?/,a.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)),contains:[t.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,contains:[t.BACKSLASH_ESCAPE,b]})]}]},_="[1-9](_?[0-9])*|0",v="[0-9](_?[0-9])*",S={className:"number",relevance:0,variants:[{begin:`\\b(${_})(\\.(${v}))?([eE][+-]?(${v})|r)?i?\\b`},{begin:"\\b0[dD][0-9](_?[0-9])*r?i?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*r?i?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*r?i?\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b"},{begin:"\\b0(_?[0-7])+r?i?\\b"}]},T={variants:[{match:/\(\)/},{className:"params",begin:/\(/,end:/(?=\))/,excludeBegin:!0,endsParent:!0,keywords:c}]},L=[x,{variants:[{match:[/class\s+/,o,/\s+<\s+/,o]},{match:[/\b(class|module)\s+/,o]}],scope:{2:"title.class",4:"title.class.inherited"},keywords:c},{match:[/(include|extend)\s+/,o],scope:{2:"title.class"},keywords:c},{relevance:0,match:[o,/\.new[. (]/],scope:{1:"title.class"}},{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"},{relevance:0,match:r,scope:"title.class"},{match:[/def/,/\s+/,l],scope:{1:"keyword",3:"title.function"},contains:[T]},{begin:t.IDENT_RE+"::"},{className:"symbol",begin:t.UNDERSCORE_IDENT_RE+"(!|\\?)?:",relevance:0},{className:"symbol",begin:":(?!\\s)",contains:[x,{begin:l}],relevance:0},S,{className:"variable",begin:"(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"},{className:"params",begin:/\|(?!=)/,end:/\|/,excludeBegin:!0,excludeEnd:!0,relevance:0,keywords:c},{begin:"("+t.RE_STARTERS_RE+"|unless)\\s*",keywords:"unless",contains:[{className:"regexp",contains:[t.BACKSLASH_ESCAPE,b],illegal:/\n/,variants:[{begin:"/",end:"/[a-z]*"},{begin:/%r\{/,end:/\}[a-z]*/},{begin:"%r\\(",end:"\\)[a-z]*"},{begin:"%r!",end:"![a-z]*"},{begin:"%r\\[",end:"\\][a-z]*"}]}].concat(g,p),relevance:0}].concat(g,p);b.contains=L,T.contains=L;const U=[{begin:/^\s*=>/,starts:{end:"$",contains:L}},{className:"meta.prompt",begin:"^("+"[>?]>"+"|"+"[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]"+"|"+"(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>"+")(?=[ ])",starts:{end:"$",keywords:c,contains:L}}];return p.unshift(g),{name:"Ruby",aliases:["rb","gemspec","podspec","thor","irb"],keywords:c,illegal:/\/\*/,contains:[t.SHEBANG({binary:"ruby"})].concat(U).concat(p).concat(L)}}function rA(t){const a=t.regex,l=/(r#)?/,r=a.concat(l,t.UNDERSCORE_IDENT_RE),o=a.concat(l,t.IDENT_RE),u={className:"title.function.invoke",relevance:0,begin:a.concat(/\b/,/(?!let|for|while|if|else|match\b)/,o,a.lookahead(/\s*\(/))},c="([ui](8|16|32|64|128|size)|f(32|64))?",h=["abstract","as","async","await","become","box","break","const","continue","crate","do","dyn","else","enum","extern","false","final","fn","for","if","impl","in","let","loop","macro","match","mod","move","mut","override","priv","pub","ref","return","self","Self","static","struct","super","trait","true","try","type","typeof","union","unsafe","unsized","use","virtual","where","while","yield"],g=["true","false","Some","None","Ok","Err"],p=["drop ","Copy","Send","Sized","Sync","Drop","Fn","FnMut","FnOnce","ToOwned","Clone","Debug","PartialEq","PartialOrd","Eq","Ord","AsRef","AsMut","Into","From","Default","Iterator","Extend","IntoIterator","DoubleEndedIterator","ExactSizeIterator","SliceConcatExt","ToString","assert!","assert_eq!","bitflags!","bytes!","cfg!","col!","concat!","concat_idents!","debug_assert!","debug_assert_eq!","env!","eprintln!","panic!","file!","format!","format_args!","include_bytes!","include_str!","line!","local_data_key!","module_path!","option_env!","print!","println!","select!","stringify!","try!","unimplemented!","unreachable!","vec!","write!","writeln!","macro_rules!","assert_ne!","debug_assert_ne!"],b=["i8","i16","i32","i64","i128","isize","u8","u16","u32","u64","u128","usize","f32","f64","str","char","bool","Box","Option","Result","String","Vec"];return{name:"Rust",aliases:["rs"],keywords:{$pattern:t.IDENT_RE+"!?",type:b,keyword:h,literal:g,built_in:p},illegal:"</",contains:[t.C_LINE_COMMENT_MODE,t.COMMENT("/\\*","\\*/",{contains:["self"]}),t.inherit(t.QUOTE_STRING_MODE,{begin:/b?"/,illegal:null}),{className:"symbol",begin:/'[a-zA-Z_][a-zA-Z0-9_]*(?!')/},{scope:"string",variants:[{begin:/b?r(#*)"(.|\n)*?"\1(?!#)/},{begin:/b?'/,end:/'/,contains:[{scope:"char.escape",match:/\\('|\w|x\w{2}|u\w{4}|U\w{8})/}]}]},{className:"number",variants:[{begin:"\\b0b([01_]+)"+c},{begin:"\\b0o([0-7_]+)"+c},{begin:"\\b0x([A-Fa-f0-9_]+)"+c},{begin:"\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)"+c}],relevance:0},{begin:[/fn/,/\s+/,r],className:{1:"keyword",3:"title.function"}},{className:"meta",begin:"#!?\\[",end:"\\]",contains:[{className:"string",begin:/"/,end:/"/,contains:[t.BACKSLASH_ESCAPE]}]},{begin:[/let/,/\s+/,/(?:mut\s+)?/,r],className:{1:"keyword",3:"keyword",4:"variable"}},{begin:[/for/,/\s+/,r,/\s+/,/in/],className:{1:"keyword",3:"variable",5:"keyword"}},{begin:[/type/,/\s+/,r],className:{1:"keyword",3:"title.class"}},{begin:[/(?:trait|enum|struct|union|impl|for)/,/\s+/,r],className:{1:"keyword",3:"title.class"}},{begin:t.IDENT_RE+"::",keywords:{keyword:"Self",built_in:p,type:b}},{className:"punctuation",begin:"->"},u]}}const sA=t=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:t.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:t.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),oA=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],cA=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],uA=[...oA,...cA],fA=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),dA=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),mA=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),hA=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function pA(t){const a=sA(t),l=mA,r=dA,o="@[a-z-]+",u="and or not only",h={className:"variable",begin:"(\\$"+"[a-zA-Z-][a-zA-Z0-9_-]*"+")\\b",relevance:0};return{name:"SCSS",case_insensitive:!0,illegal:"[=/|']",contains:[t.C_LINE_COMMENT_MODE,t.C_BLOCK_COMMENT_MODE,a.CSS_NUMBER_MODE,{className:"selector-id",begin:"#[A-Za-z0-9_-]+",relevance:0},{className:"selector-class",begin:"\\.[A-Za-z0-9_-]+",relevance:0},a.ATTRIBUTE_SELECTOR_MODE,{className:"selector-tag",begin:"\\b("+uA.join("|")+")\\b",relevance:0},{className:"selector-pseudo",begin:":("+r.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+l.join("|")+")"},h,{begin:/\(/,end:/\)/,contains:[a.CSS_NUMBER_MODE]},a.CSS_VARIABLE,{className:"attribute",begin:"\\b("+hA.join("|")+")\\b"},{begin:"\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b"},{begin:/:/,end:/[;}{]/,relevance:0,contains:[a.BLOCK_COMMENT,h,a.HEXCOLOR,a.CSS_NUMBER_MODE,t.QUOTE_STRING_MODE,t.APOS_STRING_MODE,a.IMPORTANT,a.FUNCTION_DISPATCH]},{begin:"@(page|font-face)",keywords:{$pattern:o,keyword:"@page @font-face"}},{begin:"@",end:"[{;]",returnBegin:!0,keywords:{$pattern:/[a-z-]+/,keyword:u,attribute:fA.join(" ")},contains:[{begin:o,className:"keyword"},{begin:/[a-z-]+(?=:)/,className:"attribute"},h,t.QUOTE_STRING_MODE,t.APOS_STRING_MODE,a.HEXCOLOR,a.CSS_NUMBER_MODE]},a.FUNCTION_DISPATCH]}}function gA(t){return{name:"Shell Session",aliases:["console","shellsession"],contains:[{className:"meta.prompt",begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,starts:{end:/[^\\](?=\s*$)/,subLanguage:"bash"}}]}}function bA(t){const a=t.regex,l=t.COMMENT("--","$"),r={scope:"string",variants:[{begin:/'/,end:/'/,contains:[{match:/''/}]}]},o={begin:/"/,end:/"/,contains:[{match:/""/}]},u=["true","false","unknown"],c=["double precision","large object","with timezone","without timezone"],h=["bigint","binary","blob","boolean","char","character","clob","date","dec","decfloat","decimal","float","int","integer","interval","nchar","nclob","national","numeric","real","row","smallint","time","timestamp","varchar","varying","varbinary"],g=["add","asc","collation","desc","final","first","last","view"],p=["abs","acos","all","allocate","alter","and","any","are","array","array_agg","array_max_cardinality","as","asensitive","asin","asymmetric","at","atan","atomic","authorization","avg","begin","begin_frame","begin_partition","between","bigint","binary","blob","boolean","both","by","call","called","cardinality","cascaded","case","cast","ceil","ceiling","char","char_length","character","character_length","check","classifier","clob","close","coalesce","collate","collect","column","commit","condition","connect","constraint","contains","convert","copy","corr","corresponding","cos","cosh","count","covar_pop","covar_samp","create","cross","cube","cume_dist","current","current_catalog","current_date","current_default_transform_group","current_path","current_role","current_row","current_schema","current_time","current_timestamp","current_path","current_role","current_transform_group_for_type","current_user","cursor","cycle","date","day","deallocate","dec","decimal","decfloat","declare","default","define","delete","dense_rank","deref","describe","deterministic","disconnect","distinct","double","drop","dynamic","each","element","else","empty","end","end_frame","end_partition","end-exec","equals","escape","every","except","exec","execute","exists","exp","external","extract","false","fetch","filter","first_value","float","floor","for","foreign","frame_row","free","from","full","function","fusion","get","global","grant","group","grouping","groups","having","hold","hour","identity","in","indicator","initial","inner","inout","insensitive","insert","int","integer","intersect","intersection","interval","into","is","join","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","language","large","last_value","lateral","lead","leading","left","like","like_regex","listagg","ln","local","localtime","localtimestamp","log","log10","lower","match","match_number","match_recognize","matches","max","member","merge","method","min","minute","mod","modifies","module","month","multiset","national","natural","nchar","nclob","new","no","none","normalize","not","nth_value","ntile","null","nullif","numeric","octet_length","occurrences_regex","of","offset","old","omit","on","one","only","open","or","order","out","outer","over","overlaps","overlay","parameter","partition","pattern","per","percent","percent_rank","percentile_cont","percentile_disc","period","portion","position","position_regex","power","precedes","precision","prepare","primary","procedure","ptf","range","rank","reads","real","recursive","ref","references","referencing","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","release","result","return","returns","revoke","right","rollback","rollup","row","row_number","rows","running","savepoint","scope","scroll","search","second","seek","select","sensitive","session_user","set","show","similar","sin","sinh","skip","smallint","some","specific","specifictype","sql","sqlexception","sqlstate","sqlwarning","sqrt","start","static","stddev_pop","stddev_samp","submultiset","subset","substring","substring_regex","succeeds","sum","symmetric","system","system_time","system_user","table","tablesample","tan","tanh","then","time","timestamp","timezone_hour","timezone_minute","to","trailing","translate","translate_regex","translation","treat","trigger","trim","trim_array","true","truncate","uescape","union","unique","unknown","unnest","update","upper","user","using","value","values","value_of","var_pop","var_samp","varbinary","varchar","varying","versioning","when","whenever","where","width_bucket","window","with","within","without","year"],b=["abs","acos","array_agg","asin","atan","avg","cast","ceil","ceiling","coalesce","corr","cos","cosh","count","covar_pop","covar_samp","cume_dist","dense_rank","deref","element","exp","extract","first_value","floor","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","last_value","lead","listagg","ln","log","log10","lower","max","min","mod","nth_value","ntile","nullif","percent_rank","percentile_cont","percentile_disc","position","position_regex","power","rank","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","row_number","sin","sinh","sqrt","stddev_pop","stddev_samp","substring","substring_regex","sum","tan","tanh","translate","translate_regex","treat","trim","trim_array","unnest","upper","value_of","var_pop","var_samp","width_bucket"],x=["current_catalog","current_date","current_default_transform_group","current_path","current_role","current_schema","current_transform_group_for_type","current_user","session_user","system_time","system_user","current_time","localtime","current_timestamp","localtimestamp"],_=["create table","insert into","primary key","foreign key","not null","alter table","add constraint","grouping sets","on overflow","character set","respect nulls","ignore nulls","nulls first","nulls last","depth first","breadth first"],v=b,S=[...p,...g].filter(Y=>!b.includes(Y)),T={scope:"variable",match:/@[a-z0-9][a-z0-9_]*/},A={scope:"operator",match:/[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,relevance:0},w={match:a.concat(/\b/,a.either(...v),/\s*\(/),relevance:0,keywords:{built_in:v}};function O(Y){return a.concat(/\b/,a.either(...Y.map(L=>L.replace(/\s+/,"\\s+"))),/\b/)}const R={scope:"keyword",match:O(_),relevance:0};function q(Y,{exceptions:L,when:X}={}){const oe=X;return L=L||[],Y.map(he=>he.match(/\|\d+$/)||L.includes(he)?he:oe(he)?`${he}|0`:he)}return{name:"SQL",case_insensitive:!0,illegal:/[{}]|<\//,keywords:{$pattern:/\b[\w\.]+/,keyword:q(S,{when:Y=>Y.length<3}),literal:u,type:h,built_in:x},contains:[{scope:"type",match:O(c)},R,w,T,r,o,t.C_NUMBER_MODE,t.C_BLOCK_COMMENT_MODE,l,A]}}function yx(t){return t?typeof t=="string"?t:t.source:null}function Fr(t){return pt("(?=",t,")")}function pt(...t){return t.map(l=>yx(l)).join("")}function xA(t){const a=t[t.length-1];return typeof a=="object"&&a.constructor===Object?(t.splice(t.length-1,1),a):{}}function fn(...t){return"("+(xA(t).capture?"":"?:")+t.map(r=>yx(r)).join("|")+")"}const Cd=t=>pt(/\b/,t,/\w$/.test(t)?/\b/:/\B/),yA=["Protocol","Type"].map(Cd),k0=["init","self"].map(Cd),_A=["Any","Self"],Mf=["actor","any","associatedtype","async","await",/as\?/,/as!/,"as","borrowing","break","case","catch","class","consume","consuming","continue","convenience","copy","default","defer","deinit","didSet","distributed","do","dynamic","each","else","enum","extension","fallthrough",/fileprivate\(set\)/,"fileprivate","final","for","func","get","guard","if","import","indirect","infix",/init\?/,/init!/,"inout",/internal\(set\)/,"internal","in","is","isolated","nonisolated","lazy","let","macro","mutating","nonmutating",/open\(set\)/,"open","operator","optional","override","package","postfix","precedencegroup","prefix",/private\(set\)/,"private","protocol",/public\(set\)/,"public","repeat","required","rethrows","return","set","some","static","struct","subscript","super","switch","throws","throw",/try\?/,/try!/,"try","typealias",/unowned\(safe\)/,/unowned\(unsafe\)/,"unowned","var","weak","where","while","willSet"],T0=["false","nil","true"],vA=["assignment","associativity","higherThan","left","lowerThan","none","right"],EA=["#colorLiteral","#column","#dsohandle","#else","#elseif","#endif","#error","#file","#fileID","#fileLiteral","#filePath","#function","#if","#imageLiteral","#keyPath","#line","#selector","#sourceLocation","#warning"],A0=["abs","all","any","assert","assertionFailure","debugPrint","dump","fatalError","getVaList","isKnownUniquelyReferenced","max","min","numericCast","pointwiseMax","pointwiseMin","precondition","preconditionFailure","print","readLine","repeatElement","sequence","stride","swap","swift_unboxFromSwiftValueWithType","transcode","type","unsafeBitCast","unsafeDowncast","withExtendedLifetime","withUnsafeMutablePointer","withUnsafePointer","withVaList","withoutActuallyEscaping","zip"],_x=fn(/[/=\-+!*%<>&|^~?]/,/[\u00A1-\u00A7]/,/[\u00A9\u00AB]/,/[\u00AC\u00AE]/,/[\u00B0\u00B1]/,/[\u00B6\u00BB\u00BF\u00D7\u00F7]/,/[\u2016-\u2017]/,/[\u2020-\u2027]/,/[\u2030-\u203E]/,/[\u2041-\u2053]/,/[\u2055-\u205E]/,/[\u2190-\u23FF]/,/[\u2500-\u2775]/,/[\u2794-\u2BFF]/,/[\u2E00-\u2E7F]/,/[\u3001-\u3003]/,/[\u3008-\u3020]/,/[\u3030]/),vx=fn(_x,/[\u0300-\u036F]/,/[\u1DC0-\u1DFF]/,/[\u20D0-\u20FF]/,/[\uFE00-\uFE0F]/,/[\uFE20-\uFE2F]/),Cf=pt(_x,vx,"*"),Ex=fn(/[a-zA-Z_]/,/[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,/[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,/[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,/[\u1E00-\u1FFF]/,/[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,/[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,/[\u2C00-\u2DFF\u2E80-\u2FFF]/,/[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,/[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,/[\uFE47-\uFEFE\uFF00-\uFFFD]/),Vo=fn(Ex,/\d/,/[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/),oi=pt(Ex,Vo,"*"),Ro=pt(/[A-Z]/,Vo,"*"),SA=["attached","autoclosure",pt(/convention\(/,fn("swift","block","c"),/\)/),"discardableResult","dynamicCallable","dynamicMemberLookup","escaping","freestanding","frozen","GKInspectable","IBAction","IBDesignable","IBInspectable","IBOutlet","IBSegueAction","inlinable","main","nonobjc","NSApplicationMain","NSCopying","NSManaged",pt(/objc\(/,oi,/\)/),"objc","objcMembers","propertyWrapper","requires_stored_property_inits","resultBuilder","Sendable","testable","UIApplicationMain","unchecked","unknown","usableFromInline","warn_unqualified_access"],NA=["iOS","iOSApplicationExtension","macOS","macOSApplicationExtension","macCatalyst","macCatalystApplicationExtension","watchOS","watchOSApplicationExtension","tvOS","tvOSApplicationExtension","swift"];function wA(t){const a={match:/\s+/,relevance:0},l=t.COMMENT("/\\*","\\*/",{contains:["self"]}),r=[t.C_LINE_COMMENT_MODE,l],o={match:[/\./,fn(...yA,...k0)],className:{2:"keyword"}},u={match:pt(/\./,fn(...Mf)),relevance:0},c=Mf.filter(we=>typeof we=="string").concat(["_|0"]),h=Mf.filter(we=>typeof we!="string").concat(_A).map(Cd),g={variants:[{className:"keyword",match:fn(...h,...k0)}]},p={$pattern:fn(/\b\w+/,/#\w+/),keyword:c.concat(EA),literal:T0},b=[o,u,g],x={match:pt(/\./,fn(...A0)),relevance:0},_={className:"built_in",match:pt(/\b/,fn(...A0),/(?=\()/)},v=[x,_],S={match:/->/,relevance:0},T={className:"operator",relevance:0,variants:[{match:Cf},{match:`\\.(\\.|${vx})+`}]},A=[S,T],w="([0-9]_*)+",O="([0-9a-fA-F]_*)+",R={className:"number",relevance:0,variants:[{match:`\\b(${w})(\\.(${w}))?([eE][+-]?(${w}))?\\b`},{match:`\\b0x(${O})(\\.(${O}))?([pP][+-]?(${w}))?\\b`},{match:/\b0o([0-7]_*)+\b/},{match:/\b0b([01]_*)+\b/}]},q=(we="")=>({className:"subst",variants:[{match:pt(/\\/,we,/[0\\tnr"']/)},{match:pt(/\\/,we,/u\{[0-9a-fA-F]{1,8}\}/)}]}),Y=(we="")=>({className:"subst",match:pt(/\\/,we,/[\t ]*(?:[\r\n]|\r\n)/)}),L=(we="")=>({className:"subst",label:"interpol",begin:pt(/\\/,we,/\(/),end:/\)/}),X=(we="")=>({begin:pt(we,/"""/),end:pt(/"""/,we),contains:[q(we),Y(we),L(we)]}),oe=(we="")=>({begin:pt(we,/"/),end:pt(/"/,we),contains:[q(we),L(we)]}),he={className:"string",variants:[X(),X("#"),X("##"),X("###"),oe(),oe("#"),oe("##"),oe("###")]},U=[t.BACKSLASH_ESCAPE,{begin:/\[/,end:/\]/,relevance:0,contains:[t.BACKSLASH_ESCAPE]}],re={begin:/\/[^\s](?=[^/\n]*\/)/,end:/\//,contains:U},ae=we=>{const zt=pt(we,/\//),de=pt(/\//,we);return{begin:zt,end:de,contains:[...U,{scope:"comment",begin:`#(?!.*${de})`,end:/$/}]}},le={scope:"regexp",variants:[ae("###"),ae("##"),ae("#"),re]},W={match:pt(/`/,oi,/`/)},H={className:"variable",match:/\$\d+/},C={className:"variable",match:`\\$${Vo}+`},K=[W,H,C],ne={match:/(@|#(un)?)available/,scope:"keyword",starts:{contains:[{begin:/\(/,end:/\)/,keywords:NA,contains:[...A,R,he]}]}},ie={scope:"keyword",match:pt(/@/,fn(...SA),Fr(fn(/\(/,/\s+/)))},k={scope:"meta",match:pt(/@/,oi)},M=[ne,ie,k],B={match:Fr(/\b[A-Z]/),relevance:0,contains:[{className:"type",match:pt(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/,Vo,"+")},{className:"type",match:Ro,relevance:0},{match:/[?!]+/,relevance:0},{match:/\.\.\./,relevance:0},{match:pt(/\s+&\s+/,Fr(Ro)),relevance:0}]},N={begin:/</,end:/>/,keywords:p,contains:[...r,...b,...M,S,B]};B.contains.push(N);const ce={match:pt(oi,/\s*:/),keywords:"_|0",relevance:0},pe={begin:/\(/,end:/\)/,relevance:0,keywords:p,contains:["self",ce,...r,le,...b,...v,...A,R,he,...K,...M,B]},xe={begin:/</,end:/>/,keywords:"repeat each",contains:[...r,B]},Be={begin:fn(Fr(pt(oi,/\s*:/)),Fr(pt(oi,/\s+/,oi,/\s*:/))),end:/:/,relevance:0,contains:[{className:"keyword",match:/\b_\b/},{className:"params",match:oi}]},ve={begin:/\(/,end:/\)/,keywords:p,contains:[Be,...r,...b,...A,R,he,...M,B,pe],endsParent:!0,illegal:/["']/},qe={match:[/(func|macro)/,/\s+/,fn(W.match,oi,Cf)],className:{1:"keyword",3:"title.function"},contains:[xe,ve,a],illegal:[/\[/,/%/]},lt={match:[/\b(?:subscript|init[?!]?)/,/\s*(?=[<(])/],className:{1:"keyword"},contains:[xe,ve,a],illegal:/\[|%/},Yt={match:[/operator/,/\s+/,Cf],className:{1:"keyword",3:"title"}},mn={begin:[/precedencegroup/,/\s+/,Ro],className:{1:"keyword",3:"title"},contains:[B],keywords:[...vA,...T0],end:/}/},se={match:[/class\b/,/\s+/,/func\b/,/\s+/,/\b[A-Za-z_][A-Za-z0-9_]*\b/],scope:{1:"keyword",3:"keyword",5:"title.function"}},Me={match:[/class\b/,/\s+/,/var\b/],scope:{1:"keyword",3:"keyword"}},et={begin:[/(struct|protocol|class|extension|enum|actor)/,/\s+/,oi,/\s*/],beginScope:{1:"keyword",3:"title.class"},keywords:p,contains:[xe,...b,{begin:/:/,end:/\{/,keywords:p,contains:[{scope:"title.class.inherited",match:Ro},...b],relevance:0}]};for(const we of he.variants){const zt=we.contains.find(Re=>Re.label==="interpol");zt.keywords=p;const de=[...b,...v,...A,R,he,...K];zt.contains=[...de,{begin:/\(/,end:/\)/,contains:["self",...de]}]}return{name:"Swift",keywords:p,contains:[...r,qe,lt,se,Me,et,Yt,mn,{beginKeywords:"import",end:/$/,contains:[...r],relevance:0},le,...b,...v,...A,R,he,...K,...M,B,pe]}}const Ko="[A-Za-z$_][0-9A-Za-z$_]*",Sx=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],Nx=["true","false","null","undefined","NaN","Infinity"],wx=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],kx=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],Tx=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],Ax=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],Mx=[].concat(Tx,wx,kx);function kA(t){const a=t.regex,l=(ne,{after:ie})=>{const k="</"+ne[0].slice(1);return ne.input.indexOf(k,ie)!==-1},r=Ko,o={begin:"<>",end:"</>"},u=/<[A-Za-z0-9\\._:-]+\s*\/>/,c={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(ne,ie)=>{const k=ne[0].length+ne.index,M=ne.input[k];if(M==="<"||M===","){ie.ignoreMatch();return}M===">"&&(l(ne,{after:k})||ie.ignoreMatch());let B;const N=ne.input.substring(k);if(B=N.match(/^\s*=/)){ie.ignoreMatch();return}if((B=N.match(/^\s+extends\s+/))&&B.index===0){ie.ignoreMatch();return}}},h={$pattern:Ko,keyword:Sx,literal:Nx,built_in:Mx,"variable.language":Ax},g="[0-9](_?[0-9])*",p=`\\.(${g})`,b="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",x={className:"number",variants:[{begin:`(\\b(${b})((${p})|\\.)?|(${p}))[eE][+-]?(${g})\\b`},{begin:`\\b(${b})\\b((${p})\\b|\\.)?|(${p})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},_={className:"subst",begin:"\\$\\{",end:"\\}",keywords:h,contains:[]},v={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"xml"}},S={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"css"}},T={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[t.BACKSLASH_ESCAPE,_],subLanguage:"graphql"}},A={className:"string",begin:"`",end:"`",contains:[t.BACKSLASH_ESCAPE,_]},O={className:"comment",variants:[t.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),t.C_BLOCK_COMMENT_MODE,t.C_LINE_COMMENT_MODE]},R=[t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,v,S,T,A,{match:/\$\d+/},x];_.contains=R.concat({begin:/\{/,end:/\}/,keywords:h,contains:["self"].concat(R)});const q=[].concat(O,_.contains),Y=q.concat([{begin:/(\s*)\(/,end:/\)/,keywords:h,contains:["self"].concat(q)}]),L={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:h,contains:Y},X={variants:[{match:[/class/,/\s+/,r,/\s+/,/extends/,/\s+/,a.concat(r,"(",a.concat(/\./,r),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,r],scope:{1:"keyword",3:"title.class"}}]},oe={relevance:0,match:a.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[...wx,...kx]}},he={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},U={variants:[{match:[/function/,/\s+/,r,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[L],illegal:/%/},re={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function ae(ne){return a.concat("(?!",ne.join("|"),")")}const le={match:a.concat(/\b/,ae([...Tx,"super","import"].map(ne=>`${ne}\\s*\\(`)),r,a.lookahead(/\s*\(/)),className:"title.function",relevance:0},W={begin:a.concat(/\./,a.lookahead(a.concat(r,/(?![0-9A-Za-z$_(])/))),end:r,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},H={match:[/get|set/,/\s+/,r,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},L]},C="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+t.UNDERSCORE_IDENT_RE+")\\s*=>",K={match:[/const|var|let/,/\s+/,r,/\s*/,/=\s*/,/(async\s*)?/,a.lookahead(C)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[L]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:h,exports:{PARAMS_CONTAINS:Y,CLASS_REFERENCE:oe},illegal:/#(?![$_A-z])/,contains:[t.SHEBANG({label:"shebang",binary:"node",relevance:5}),he,t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,v,S,T,A,O,{match:/\$\d+/},x,oe,{scope:"attr",match:r+a.lookahead(":"),relevance:0},K,{begin:"("+t.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[O,t.REGEXP_MODE,{className:"function",begin:C,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:t.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:h,contains:Y}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:o.begin,end:o.end},{match:u},{begin:c.begin,"on:begin":c.isTrulyOpeningTag,end:c.end}],subLanguage:"xml",contains:[{begin:c.begin,end:c.end,skip:!0,contains:["self"]}]}]},U,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+t.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[L,t.inherit(t.TITLE_MODE,{begin:r,className:"title.function"})]},{match:/\.\.\./,relevance:0},W,{match:"\\$"+r,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[L]},le,re,X,H,{match:/\$[(.]/}]}}function TA(t){const a=t.regex,l=kA(t),r=Ko,o=["any","void","number","boolean","string","object","never","symbol","bigint","unknown"],u={begin:[/namespace/,/\s+/,t.IDENT_RE],beginScope:{1:"keyword",3:"title.class"}},c={beginKeywords:"interface",end:/\{/,excludeEnd:!0,keywords:{keyword:"interface extends",built_in:o},contains:[l.exports.CLASS_REFERENCE]},h={className:"meta",relevance:10,begin:/^\s*['"]use strict['"]/},g=["type","interface","public","private","protected","implements","declare","abstract","readonly","enum","override","satisfies"],p={$pattern:Ko,keyword:Sx.concat(g),literal:Nx,built_in:Mx.concat(o),"variable.language":Ax},b={className:"meta",begin:"@"+r},x=(T,A,w)=>{const O=T.contains.findIndex(R=>R.label===A);if(O===-1)throw new Error("can not find mode to replace");T.contains.splice(O,1,w)};Object.assign(l.keywords,p),l.exports.PARAMS_CONTAINS.push(b);const _=l.contains.find(T=>T.scope==="attr"),v=Object.assign({},_,{match:a.concat(r,a.lookahead(/\s*\?:/))});l.exports.PARAMS_CONTAINS.push([l.exports.CLASS_REFERENCE,_,v]),l.contains=l.contains.concat([b,u,c,v]),x(l,"shebang",t.SHEBANG()),x(l,"use_strict",h);const S=l.contains.find(T=>T.label==="func.def");return S.relevance=0,Object.assign(l,{name:"TypeScript",aliases:["ts","tsx","mts","cts"]}),l}function AA(t){const a=t.regex,l={className:"string",begin:/"(""|[^/n])"C\b/},r={className:"string",begin:/"/,end:/"/,illegal:/\n/,contains:[{begin:/""/}]},o=/\d{1,2}\/\d{1,2}\/\d{4}/,u=/\d{4}-\d{1,2}-\d{1,2}/,c=/(\d|1[012])(:\d+){0,2} *(AM|PM)/,h=/\d{1,2}(:\d{1,2}){1,2}/,g={className:"literal",variants:[{begin:a.concat(/# */,a.either(u,o),/ *#/)},{begin:a.concat(/# */,h,/ *#/)},{begin:a.concat(/# */,c,/ *#/)},{begin:a.concat(/# */,a.either(u,o),/ +/,a.either(c,h),/ *#/)}]},p={className:"number",relevance:0,variants:[{begin:/\b\d[\d_]*((\.[\d_]+(E[+-]?[\d_]+)?)|(E[+-]?[\d_]+))[RFD@!#]?/},{begin:/\b\d[\d_]*((U?[SIL])|[%&])?/},{begin:/&H[\dA-F_]+((U?[SIL])|[%&])?/},{begin:/&O[0-7_]+((U?[SIL])|[%&])?/},{begin:/&B[01_]+((U?[SIL])|[%&])?/}]},b={className:"label",begin:/^\w+:/},x=t.COMMENT(/'''/,/$/,{contains:[{className:"doctag",begin:/<\/?/,end:/>/}]}),_=t.COMMENT(null,/$/,{variants:[{begin:/'/},{begin:/([\t ]|^)REM(?=\s)/}]});return{name:"Visual Basic .NET",aliases:["vb"],case_insensitive:!0,classNameAliases:{label:"symbol"},keywords:{keyword:"addhandler alias aggregate ansi as async assembly auto binary by byref byval call case catch class compare const continue custom declare default delegate dim distinct do each equals else elseif end enum erase error event exit explicit finally for friend from function get global goto group handles if implements imports in inherits interface into iterator join key let lib loop me mid module mustinherit mustoverride mybase myclass namespace narrowing new next notinheritable notoverridable of off on operator option optional order overloads overridable overrides paramarray partial preserve private property protected public raiseevent readonly redim removehandler resume return select set shadows shared skip static step stop structure strict sub synclock take text then throw to try unicode until using when where while widening with withevents writeonly yield",built_in:"addressof and andalso await directcast gettype getxmlnamespace is isfalse isnot istrue like mod nameof new not or orelse trycast typeof xor cbool cbyte cchar cdate cdbl cdec cint clng cobj csbyte cshort csng cstr cuint culng cushort",type:"boolean byte char date decimal double integer long object sbyte short single string uinteger ulong ushort",literal:"true false nothing"},illegal:"//|\\{|\\}|endif|gosub|variant|wend|^\\$ ",contains:[l,r,g,p,b,x,_,{className:"meta",begin:/[\t ]*#(const|disable|else|elseif|enable|end|externalsource|if|region)\b/,end:/$/,keywords:{keyword:"const disable else elseif enable end externalsource if region then"},contains:[_]}]}}function MA(t){t.regex;const a=t.COMMENT(/\(;/,/;\)/);a.contains.push("self");const l=t.COMMENT(/;;/,/$/),r=["anyfunc","block","br","br_if","br_table","call","call_indirect","data","drop","elem","else","end","export","func","global.get","global.set","local.get","local.set","local.tee","get_global","get_local","global","if","import","local","loop","memory","memory.grow","memory.size","module","mut","nop","offset","param","result","return","select","set_global","set_local","start","table","tee_local","then","type","unreachable"],o={begin:[/(?:func|call|call_indirect)/,/\s+/,/\$[^\s)]+/],className:{1:"keyword",3:"title.function"}},u={className:"variable",begin:/\$[\w_]+/},c={match:/(\((?!;)|\))+/,className:"punctuation",relevance:0},h={className:"number",relevance:0,match:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/},g={match:/(i32|i64|f32|f64)(?!\.)/,className:"type"},p={className:"keyword",match:/\b(f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|nearest|neg?|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|store(?:8|16|32)?|sqrt|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))\b/};return{name:"WebAssembly",keywords:{$pattern:/[\w.]+/,keyword:r},contains:[l,a,{match:[/(?:offset|align)/,/\s*/,/=/],className:{1:"keyword",3:"operator"}},u,c,o,t.QUOTE_STRING_MODE,g,p,h]}}function CA(t){const a=t.regex,l=a.concat(/[\p{L}_]/u,a.optional(/[\p{L}0-9_.-]*:/u),/[\p{L}0-9_.-]*/u),r=/[\p{L}0-9._:-]+/u,o={className:"symbol",begin:/&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/},u={begin:/\s/,contains:[{className:"keyword",begin:/#?[a-z_][a-z1-9_-]+/,illegal:/\n/}]},c=t.inherit(u,{begin:/\(/,end:/\)/}),h=t.inherit(t.APOS_STRING_MODE,{className:"string"}),g=t.inherit(t.QUOTE_STRING_MODE,{className:"string"}),p={endsWithParent:!0,illegal:/</,relevance:0,contains:[{className:"attr",begin:r,relevance:0},{begin:/=\s*/,relevance:0,contains:[{className:"string",endsParent:!0,variants:[{begin:/"/,end:/"/,contains:[o]},{begin:/'/,end:/'/,contains:[o]},{begin:/[^\s"'=<>`]+/}]}]}]};return{name:"HTML, XML",aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist","wsf","svg"],case_insensitive:!0,unicodeRegex:!0,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,relevance:10,contains:[u,g,h,c,{begin:/\[/,end:/\]/,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,contains:[u,c,g,h]}]}]},t.COMMENT(/<!--/,/-->/,{relevance:10}),{begin:/<!\[CDATA\[/,end:/\]\]>/,relevance:10},o,{className:"meta",end:/\?>/,variants:[{begin:/<\?xml/,relevance:10,contains:[g]},{begin:/<\?[a-z][a-z0-9]+/}]},{className:"tag",begin:/<style(?=\s|>)/,end:/>/,keywords:{name:"style"},contains:[p],starts:{end:/<\/style>/,returnEnd:!0,subLanguage:["css","xml"]}},{className:"tag",begin:/<script(?=\s|>)/,end:/>/,keywords:{name:"script"},contains:[p],starts:{end:/<\/script>/,returnEnd:!0,subLanguage:["javascript","handlebars","xml"]}},{className:"tag",begin:/<>|<\/>/},{className:"tag",begin:a.concat(/</,a.lookahead(a.concat(l,a.either(/\/>/,/>/,/\s/)))),end:/\/?>/,contains:[{className:"name",begin:l,relevance:0,starts:p}]},{className:"tag",begin:a.concat(/<\//,a.lookahead(a.concat(l,/>/))),contains:[{className:"name",begin:l,relevance:0},{begin:/>/,relevance:0,endsParent:!0}]}]}}function OA(t){const a="true false yes no null",l="[\\w#;/?:@&=+$,.~*'()[\\]]+",r={className:"attr",variants:[{begin:/[\w*@][\w*@ :()\./-]*:(?=[ \t]|$)/},{begin:/"[\w*@][\w*@ :()\./-]*":(?=[ \t]|$)/},{begin:/'[\w*@][\w*@ :()\./-]*':(?=[ \t]|$)/}]},o={className:"template-variable",variants:[{begin:/\{\{/,end:/\}\}/},{begin:/%\{/,end:/\}/}]},u={className:"string",relevance:0,begin:/'/,end:/'/,contains:[{match:/''/,scope:"char.escape",relevance:0}]},c={className:"string",relevance:0,variants:[{begin:/"/,end:/"/},{begin:/\S+/}],contains:[t.BACKSLASH_ESCAPE,o]},h=t.inherit(c,{variants:[{begin:/'/,end:/'/,contains:[{begin:/''/,relevance:0}]},{begin:/"/,end:/"/},{begin:/[^\s,{}[\]]+/}]}),_={className:"number",begin:"\\b"+"[0-9]{4}(-[0-9][0-9]){0,2}"+"([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?"+"(\\.[0-9]*)?"+"([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?"+"\\b"},v={end:",",endsWithParent:!0,excludeEnd:!0,keywords:a,relevance:0},S={begin:/\{/,end:/\}/,contains:[v],illegal:"\\n",relevance:0},T={begin:"\\[",end:"\\]",contains:[v],illegal:"\\n",relevance:0},A=[r,{className:"meta",begin:"^---\\s*$",relevance:10},{className:"string",begin:"[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"},{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:"!\\w+!"+l},{className:"type",begin:"!<"+l+">"},{className:"type",begin:"!"+l},{className:"type",begin:"!!"+l},{className:"meta",begin:"&"+t.UNDERSCORE_IDENT_RE+"$"},{className:"meta",begin:"\\*"+t.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"-(?=[ ]|$)",relevance:0},t.HASH_COMMENT_MODE,{beginKeywords:a,keywords:{literal:a}},_,{className:"number",begin:t.C_NUMBER_RE+"\\b",relevance:0},S,T,u,c],w=[...A];return w.pop(),w.push(h),v.contains=w,{name:"YAML",case_insensitive:!0,aliases:["yml"],contains:A}}const zA={arduino:m2,bash:h2,c:p2,cpp:g2,csharp:b2,css:k2,diff:T2,go:A2,graphql:M2,ini:C2,java:O2,javascript:j2,json:B2,kotlin:U2,less:V2,lua:K2,makefile:X2,markdown:Z2,objectivec:Q2,perl:J2,php:W2,"php-template":eA,plaintext:tA,python:nA,"python-repl":iA,r:aA,ruby:lA,rust:rA,scss:pA,shell:gA,sql:bA,swift:wA,typescript:TA,vbnet:AA,wasm:MA,xml:CA,yaml:OA};var Of,M0;function RA(){if(M0)return Of;M0=1;function t(D){return D instanceof Map?D.clear=D.delete=D.set=function(){throw new Error("map is read-only")}:D instanceof Set&&(D.add=D.clear=D.delete=function(){throw new Error("set is read-only")}),Object.freeze(D),Object.getOwnPropertyNames(D).forEach(J=>{const be=D[J],je=typeof be;(je==="object"||je==="function")&&!Object.isFrozen(be)&&t(be)}),D}class a{constructor(J){J.data===void 0&&(J.data={}),this.data=J.data,this.isMatchIgnored=!1}ignoreMatch(){this.isMatchIgnored=!0}}function l(D){return D.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;")}function r(D,...J){const be=Object.create(null);for(const je in D)be[je]=D[je];return J.forEach(function(je){for(const vt in je)be[vt]=je[vt]}),be}const o="</span>",u=D=>!!D.scope,c=(D,{prefix:J})=>{if(D.startsWith("language:"))return D.replace("language:","language-");if(D.includes(".")){const be=D.split(".");return[`${J}${be.shift()}`,...be.map((je,vt)=>`${je}${"_".repeat(vt+1)}`)].join(" ")}return`${J}${D}`};class h{constructor(J,be){this.buffer="",this.classPrefix=be.classPrefix,J.walk(this)}addText(J){this.buffer+=l(J)}openNode(J){if(!u(J))return;const be=c(J.scope,{prefix:this.classPrefix});this.span(be)}closeNode(J){u(J)&&(this.buffer+=o)}value(){return this.buffer}span(J){this.buffer+=`<span class="${J}">`}}const g=(D={})=>{const J={children:[]};return Object.assign(J,D),J};class p{constructor(){this.rootNode=g(),this.stack=[this.rootNode]}get top(){return this.stack[this.stack.length-1]}get root(){return this.rootNode}add(J){this.top.children.push(J)}openNode(J){const be=g({scope:J});this.add(be),this.stack.push(be)}closeNode(){if(this.stack.length>1)return this.stack.pop()}closeAllNodes(){for(;this.closeNode(););}toJSON(){return JSON.stringify(this.rootNode,null,4)}walk(J){return this.constructor._walk(J,this.rootNode)}static _walk(J,be){return typeof be=="string"?J.addText(be):be.children&&(J.openNode(be),be.children.forEach(je=>this._walk(J,je)),J.closeNode(be)),J}static _collapse(J){typeof J!="string"&&J.children&&(J.children.every(be=>typeof be=="string")?J.children=[J.children.join("")]:J.children.forEach(be=>{p._collapse(be)}))}}class b extends p{constructor(J){super(),this.options=J}addText(J){J!==""&&this.add(J)}startScope(J){this.openNode(J)}endScope(){this.closeNode()}__addSublanguage(J,be){const je=J.root;be&&(je.scope=`language:${be}`),this.add(je)}toHTML(){return new h(this,this.options).value()}finalize(){return this.closeAllNodes(),!0}}function x(D){return D?typeof D=="string"?D:D.source:null}function _(D){return T("(?=",D,")")}function v(D){return T("(?:",D,")*")}function S(D){return T("(?:",D,")?")}function T(...D){return D.map(be=>x(be)).join("")}function A(D){const J=D[D.length-1];return typeof J=="object"&&J.constructor===Object?(D.splice(D.length-1,1),J):{}}function w(...D){return"("+(A(D).capture?"":"?:")+D.map(je=>x(je)).join("|")+")"}function O(D){return new RegExp(D.toString()+"|").exec("").length-1}function R(D,J){const be=D&&D.exec(J);return be&&be.index===0}const q=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;function Y(D,{joinWith:J}){let be=0;return D.map(je=>{be+=1;const vt=be;let gt=x(je),Ee="";for(;gt.length>0;){const ye=q.exec(gt);if(!ye){Ee+=gt;break}Ee+=gt.substring(0,ye.index),gt=gt.substring(ye.index+ye[0].length),ye[0][0]==="\\"&&ye[1]?Ee+="\\"+String(Number(ye[1])+vt):(Ee+=ye[0],ye[0]==="("&&be++)}return Ee}).map(je=>`(${je})`).join(J)}const L=/\b\B/,X="[a-zA-Z]\\w*",oe="[a-zA-Z_]\\w*",he="\\b\\d+(\\.\\d+)?",U="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",re="\\b(0b[01]+)",ae="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",le=(D={})=>{const J=/^#![ ]*\//;return D.binary&&(D.begin=T(J,/.*\b/,D.binary,/\b.*/)),r({scope:"meta",begin:J,end:/$/,relevance:0,"on:begin":(be,je)=>{be.index!==0&&je.ignoreMatch()}},D)},W={begin:"\\\\[\\s\\S]",relevance:0},H={scope:"string",begin:"'",end:"'",illegal:"\\n",contains:[W]},C={scope:"string",begin:'"',end:'"',illegal:"\\n",contains:[W]},K={begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},ne=function(D,J,be={}){const je=r({scope:"comment",begin:D,end:J,contains:[]},be);je.contains.push({scope:"doctag",begin:"[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)",end:/(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,excludeBegin:!0,relevance:0});const vt=w("I","a","is","so","us","to","at","if","in","it","on",/[A-Za-z]+['](d|ve|re|ll|t|s|n)/,/[A-Za-z]+[-][a-z]+/,/[A-Za-z][a-z]{2,}/);return je.contains.push({begin:T(/[ ]+/,"(",vt,/[.]?[:]?([.][ ]|[ ])/,"){3}")}),je},ie=ne("//","$"),k=ne("/\\*","\\*/"),M=ne("#","$"),B={scope:"number",begin:he,relevance:0},N={scope:"number",begin:U,relevance:0},ce={scope:"number",begin:re,relevance:0},pe={scope:"regexp",begin:/\/(?=[^/\n]*\/)/,end:/\/[gimuy]*/,contains:[W,{begin:/\[/,end:/\]/,relevance:0,contains:[W]}]},xe={scope:"title",begin:X,relevance:0},Be={scope:"title",begin:oe,relevance:0},ve={begin:"\\.\\s*"+oe,relevance:0};var lt=Object.freeze({__proto__:null,APOS_STRING_MODE:H,BACKSLASH_ESCAPE:W,BINARY_NUMBER_MODE:ce,BINARY_NUMBER_RE:re,COMMENT:ne,C_BLOCK_COMMENT_MODE:k,C_LINE_COMMENT_MODE:ie,C_NUMBER_MODE:N,C_NUMBER_RE:U,END_SAME_AS_BEGIN:function(D){return Object.assign(D,{"on:begin":(J,be)=>{be.data._beginMatch=J[1]},"on:end":(J,be)=>{be.data._beginMatch!==J[1]&&be.ignoreMatch()}})},HASH_COMMENT_MODE:M,IDENT_RE:X,MATCH_NOTHING_RE:L,METHOD_GUARD:ve,NUMBER_MODE:B,NUMBER_RE:he,PHRASAL_WORDS_MODE:K,QUOTE_STRING_MODE:C,REGEXP_MODE:pe,RE_STARTERS_RE:ae,SHEBANG:le,TITLE_MODE:xe,UNDERSCORE_IDENT_RE:oe,UNDERSCORE_TITLE_MODE:Be});function Yt(D,J){D.input[D.index-1]==="."&&J.ignoreMatch()}function mn(D,J){D.className!==void 0&&(D.scope=D.className,delete D.className)}function se(D,J){J&&D.beginKeywords&&(D.begin="\\b("+D.beginKeywords.split(" ").join("|")+")(?!\\.)(?=\\b|\\s)",D.__beforeBegin=Yt,D.keywords=D.keywords||D.beginKeywords,delete D.beginKeywords,D.relevance===void 0&&(D.relevance=0))}function Me(D,J){Array.isArray(D.illegal)&&(D.illegal=w(...D.illegal))}function et(D,J){if(D.match){if(D.begin||D.end)throw new Error("begin & end are not supported with match");D.begin=D.match,delete D.match}}function we(D,J){D.relevance===void 0&&(D.relevance=1)}const zt=(D,J)=>{if(!D.beforeMatch)return;if(D.starts)throw new Error("beforeMatch cannot be used with starts");const be=Object.assign({},D);Object.keys(D).forEach(je=>{delete D[je]}),D.keywords=be.keywords,D.begin=T(be.beforeMatch,_(be.begin)),D.starts={relevance:0,contains:[Object.assign(be,{endsParent:!0})]},D.relevance=0,delete be.beforeMatch},de=["of","and","for","in","not","or","if","then","parent","list","value"],Re="keyword";function rt(D,J,be=Re){const je=Object.create(null);return typeof D=="string"?vt(be,D.split(" ")):Array.isArray(D)?vt(be,D):Object.keys(D).forEach(function(gt){Object.assign(je,rt(D[gt],J,gt))}),je;function vt(gt,Ee){J&&(Ee=Ee.map(ye=>ye.toLowerCase())),Ee.forEach(function(ye){const De=ye.split("|");je[De[0]]=[gt,kt(De[0],De[1])]})}}function kt(D,J){return J?Number(J):Wn(D)?0:1}function Wn(D){return de.includes(D.toLowerCase())}const Fa={},Tt=D=>{console.error(D)},$a=(D,...J)=>{console.log(`WARN: ${D}`,...J)},Z=(D,J)=>{Fa[`${D}/${J}`]||(console.log(`Deprecated as of ${D}. ${J}`),Fa[`${D}/${J}`]=!0)},me=new Error;function Ce(D,J,{key:be}){let je=0;const vt=D[be],gt={},Ee={};for(let ye=1;ye<=J.length;ye++)Ee[ye+je]=vt[ye],gt[ye+je]=!0,je+=O(J[ye-1]);D[be]=Ee,D[be]._emit=gt,D[be]._multi=!0}function Ge(D){if(Array.isArray(D.begin)){if(D.skip||D.excludeBegin||D.returnBegin)throw Tt("skip, excludeBegin, returnBegin not compatible with beginScope: {}"),me;if(typeof D.beginScope!="object"||D.beginScope===null)throw Tt("beginScope must be object"),me;Ce(D,D.begin,{key:"beginScope"}),D.begin=Y(D.begin,{joinWith:""})}}function tt(D){if(Array.isArray(D.end)){if(D.skip||D.excludeEnd||D.returnEnd)throw Tt("skip, excludeEnd, returnEnd not compatible with endScope: {}"),me;if(typeof D.endScope!="object"||D.endScope===null)throw Tt("endScope must be object"),me;Ce(D,D.end,{key:"endScope"}),D.end=Y(D.end,{joinWith:""})}}function sn(D){D.scope&&typeof D.scope=="object"&&D.scope!==null&&(D.beginScope=D.scope,delete D.scope)}function Vn(D){sn(D),typeof D.beginScope=="string"&&(D.beginScope={_wrap:D.beginScope}),typeof D.endScope=="string"&&(D.endScope={_wrap:D.endScope}),Ge(D),tt(D)}function Kt(D){function J(Ee,ye){return new RegExp(x(Ee),"m"+(D.case_insensitive?"i":"")+(D.unicodeRegex?"u":"")+(ye?"g":""))}class be{constructor(){this.matchIndexes={},this.regexes=[],this.matchAt=1,this.position=0}addRule(ye,De){De.position=this.position++,this.matchIndexes[this.matchAt]=De,this.regexes.push([De,ye]),this.matchAt+=O(ye)+1}compile(){this.regexes.length===0&&(this.exec=()=>null);const ye=this.regexes.map(De=>De[1]);this.matcherRe=J(Y(ye,{joinWith:"|"}),!0),this.lastIndex=0}exec(ye){this.matcherRe.lastIndex=this.lastIndex;const De=this.matcherRe.exec(ye);if(!De)return null;const Rt=De.findIndex((di,Ga)=>Ga>0&&di!==void 0),Nt=this.matchIndexes[Rt];return De.splice(0,Rt),Object.assign(De,Nt)}}class je{constructor(){this.rules=[],this.multiRegexes=[],this.count=0,this.lastIndex=0,this.regexIndex=0}getMatcher(ye){if(this.multiRegexes[ye])return this.multiRegexes[ye];const De=new be;return this.rules.slice(ye).forEach(([Rt,Nt])=>De.addRule(Rt,Nt)),De.compile(),this.multiRegexes[ye]=De,De}resumingScanAtSamePosition(){return this.regexIndex!==0}considerAll(){this.regexIndex=0}addRule(ye,De){this.rules.push([ye,De]),De.type==="begin"&&this.count++}exec(ye){const De=this.getMatcher(this.regexIndex);De.lastIndex=this.lastIndex;let Rt=De.exec(ye);if(this.resumingScanAtSamePosition()&&!(Rt&&Rt.index===this.lastIndex)){const Nt=this.getMatcher(0);Nt.lastIndex=this.lastIndex+1,Rt=Nt.exec(ye)}return Rt&&(this.regexIndex+=Rt.position+1,this.regexIndex===this.count&&this.considerAll()),Rt}}function vt(Ee){const ye=new je;return Ee.contains.forEach(De=>ye.addRule(De.begin,{rule:De,type:"begin"})),Ee.terminatorEnd&&ye.addRule(Ee.terminatorEnd,{type:"end"}),Ee.illegal&&ye.addRule(Ee.illegal,{type:"illegal"}),ye}function gt(Ee,ye){const De=Ee;if(Ee.isCompiled)return De;[mn,et,Vn,zt].forEach(Nt=>Nt(Ee,ye)),D.compilerExtensions.forEach(Nt=>Nt(Ee,ye)),Ee.__beforeBegin=null,[se,Me,we].forEach(Nt=>Nt(Ee,ye)),Ee.isCompiled=!0;let Rt=null;return typeof Ee.keywords=="object"&&Ee.keywords.$pattern&&(Ee.keywords=Object.assign({},Ee.keywords),Rt=Ee.keywords.$pattern,delete Ee.keywords.$pattern),Rt=Rt||/\w+/,Ee.keywords&&(Ee.keywords=rt(Ee.keywords,D.case_insensitive)),De.keywordPatternRe=J(Rt,!0),ye&&(Ee.begin||(Ee.begin=/\B|\b/),De.beginRe=J(De.begin),!Ee.end&&!Ee.endsWithParent&&(Ee.end=/\B|\b/),Ee.end&&(De.endRe=J(De.end)),De.terminatorEnd=x(De.end)||"",Ee.endsWithParent&&ye.terminatorEnd&&(De.terminatorEnd+=(Ee.end?"|":"")+ye.terminatorEnd)),Ee.illegal&&(De.illegalRe=J(Ee.illegal)),Ee.contains||(Ee.contains=[]),Ee.contains=[].concat(...Ee.contains.map(function(Nt){return en(Nt==="self"?Ee:Nt)})),Ee.contains.forEach(function(Nt){gt(Nt,De)}),Ee.starts&&gt(Ee.starts,ye),De.matcher=vt(De),De}if(D.compilerExtensions||(D.compilerExtensions=[]),D.contains&&D.contains.includes("self"))throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");return D.classNameAliases=r(D.classNameAliases||{}),gt(D)}function Mt(D){return D?D.endsWithParent||Mt(D.starts):!1}function en(D){return D.variants&&!D.cachedVariants&&(D.cachedVariants=D.variants.map(function(J){return r(D,{variants:null},J)})),D.cachedVariants?D.cachedVariants:Mt(D)?r(D,{starts:D.starts?r(D.starts):null}):Object.isFrozen(D)?r(D):D}var st="11.11.1";class ei extends Error{constructor(J,be){super(J),this.name="HTMLInjectionError",this.html=be}}const on=l,os=r,ma=Symbol("nomatch"),qa=7,ha=function(D){const J=Object.create(null),be=Object.create(null),je=[];let vt=!0;const gt="Could not find the language '{}', did you forget to load/include a language module?",Ee={disableAutodetect:!0,name:"Plain text",contains:[]};let ye={ignoreUnescapedHTML:!1,throwUnescapedHTML:!1,noHighlightRe:/^(no-?highlight)$/i,languageDetectRe:/\blang(?:uage)?-([\w-]+)\b/i,classPrefix:"hljs-",cssSelector:"pre code",languages:null,__emitter:b};function De(ue){return ye.noHighlightRe.test(ue)}function Rt(ue){let ke=ue.className+" ";ke+=ue.parentNode?ue.parentNode.className:"";const Pe=ye.languageDetectRe.exec(ke);if(Pe){const ot=cn(Pe[1]);return ot||($a(gt.replace("{}",Pe[1])),$a("Falling back to no-highlight mode for this block.",ue)),ot?Pe[1]:"no-highlight"}return ke.split(/\s+/).find(ot=>De(ot)||cn(ot))}function Nt(ue,ke,Pe){let ot="",Lt="";typeof ke=="object"?(ot=ue,Pe=ke.ignoreIllegals,Lt=ke.language):(Z("10.7.0","highlight(lang, code, ...args) has been deprecated."),Z("10.7.0",`Please use highlight(code, options) instead.
https://github.com/highlightjs/highlight.js/issues/2277`),Lt=ue,ot=ke),Pe===void 0&&(Pe=!0);const nn={code:ot,language:Lt};ga("before:highlight",nn);const wn=nn.result?nn.result:di(nn.language,nn.code,Pe);return wn.code=nn.code,ga("after:highlight",wn),wn}function di(ue,ke,Pe,ot){const Lt=Object.create(null);function nn(ge,Se){return ge.keywords[Se]}function wn(){if(!ze.keywords){Ut.addText(ct);return}let ge=0;ze.keywordPatternRe.lastIndex=0;let Se=ze.keywordPatternRe.exec(ct),Ue="";for(;Se;){Ue+=ct.substring(ge,Se.index);const Xe=Xt.case_insensitive?Se[0].toLowerCase():Se[0],At=nn(ze,Xe);if(At){const[Bn,Vl]=At;if(Ut.addText(Ue),Ue="",Lt[Xe]=(Lt[Xe]||0)+1,Lt[Xe]<=qa&&(Ui+=Vl),Bn.startsWith("_"))Ue+=Se[0];else{const ps=Xt.classNameAliases[Bn]||Bn;kn(Se[0],ps)}}else Ue+=Se[0];ge=ze.keywordPatternRe.lastIndex,Se=ze.keywordPatternRe.exec(ct)}Ue+=ct.substring(ge),Ut.addText(Ue)}function pn(){if(ct==="")return;let ge=null;if(typeof ze.subLanguage=="string"){if(!J[ze.subLanguage]){Ut.addText(ct);return}ge=di(ze.subLanguage,ct,!0,hs[ze.subLanguage]),hs[ze.subLanguage]=ge._top}else ge=Pa(ct,ze.subLanguage.length?ze.subLanguage:null);ze.relevance>0&&(Ui+=ge.relevance),Ut.__addSublanguage(ge._emitter,ge.language)}function yt(){ze.subLanguage!=null?pn():wn(),ct=""}function kn(ge,Se){ge!==""&&(Ut.startScope(Se),Ut.addText(ge),Ut.endScope())}function ds(ge,Se){let Ue=1;const Xe=Se.length-1;for(;Ue<=Xe;){if(!ge._emit[Ue]){Ue++;continue}const At=Xt.classNameAliases[ge[Ue]]||ge[Ue],Bn=Se[Ue];At?kn(Bn,At):(ct=Bn,wn(),ct=""),Ue++}}function Va(ge,Se){return ge.scope&&typeof ge.scope=="string"&&Ut.openNode(Xt.classNameAliases[ge.scope]||ge.scope),ge.beginScope&&(ge.beginScope._wrap?(kn(ct,Xt.classNameAliases[ge.beginScope._wrap]||ge.beginScope._wrap),ct=""):ge.beginScope._multi&&(ds(ge.beginScope,Se),ct="")),ze=Object.create(ge,{parent:{value:ze}}),ze}function Gl(ge,Se,Ue){let Xe=R(ge.endRe,Ue);if(Xe){if(ge["on:end"]){const At=new a(ge);ge["on:end"](Se,At),At.isMatchIgnored&&(Xe=!1)}if(Xe){for(;ge.endsParent&&ge.parent;)ge=ge.parent;return ge}}if(ge.endsWithParent)return Gl(ge.parent,Se,Ue)}function Ka(ge){return ze.matcher.regexIndex===0?(ct+=ge[0],1):(Hi=!0,0)}function ic(ge){const Se=ge[0],Ue=ge.rule,Xe=new a(Ue),At=[Ue.__beforeBegin,Ue["on:begin"]];for(const Bn of At)if(Bn&&(Bn(ge,Xe),Xe.isMatchIgnored))return Ka(Se);return Ue.skip?ct+=Se:(Ue.excludeBegin&&(ct+=Se),yt(),!Ue.returnBegin&&!Ue.excludeBegin&&(ct=Se)),Va(Ue,ge),Ue.returnBegin?0:Se.length}function gn(ge){const Se=ge[0],Ue=ke.substring(ge.index),Xe=Gl(ze,ge,Ue);if(!Xe)return ma;const At=ze;ze.endScope&&ze.endScope._wrap?(yt(),kn(Se,ze.endScope._wrap)):ze.endScope&&ze.endScope._multi?(yt(),ds(ze.endScope,ge)):At.skip?ct+=Se:(At.returnEnd||At.excludeEnd||(ct+=Se),yt(),At.excludeEnd&&(ct=Se));do ze.scope&&Ut.closeNode(),!ze.skip&&!ze.subLanguage&&(Ui+=ze.relevance),ze=ze.parent;while(ze!==Xe.parent);return Xe.starts&&Va(Xe.starts,ge),At.returnEnd?0:Se.length}function Pl(){const ge=[];for(let Se=ze;Se!==Xt;Se=Se.parent)Se.scope&&ge.unshift(Se.scope);ge.forEach(Se=>Ut.openNode(Se))}let ba={};function Xa(ge,Se){const Ue=Se&&Se[0];if(ct+=ge,Ue==null)return yt(),0;if(ba.type==="begin"&&Se.type==="end"&&ba.index===Se.index&&Ue===""){if(ct+=ke.slice(Se.index,Se.index+1),!vt){const Xe=new Error(`0 width match regex (${ue})`);throw Xe.languageName=ue,Xe.badRule=ba.rule,Xe}return 1}if(ba=Se,Se.type==="begin")return ic(Se);if(Se.type==="illegal"&&!Pe){const Xe=new Error('Illegal lexeme "'+Ue+'" for mode "'+(ze.scope||"<unnamed>")+'"');throw Xe.mode=ze,Xe}else if(Se.type==="end"){const Xe=gn(Se);if(Xe!==ma)return Xe}if(Se.type==="illegal"&&Ue==="")return ct+=`
`,1;if(Yl>1e5&&Yl>Se.index*3)throw new Error("potential infinite loop, way more iterations than matches");return ct+=Ue,Ue.length}const Xt=cn(ue);if(!Xt)throw Tt(gt.replace("{}",ue)),new Error('Unknown language: "'+ue+'"');const ms=Kt(Xt);let Za="",ze=ot||ms;const hs={},Ut=new ye.__emitter(ye);Pl();let ct="",Ui=0,pi=0,Yl=0,Hi=!1;try{if(Xt.__emitTokens)Xt.__emitTokens(ke,Ut);else{for(ze.matcher.considerAll();;){Yl++,Hi?Hi=!1:ze.matcher.considerAll(),ze.matcher.lastIndex=pi;const ge=ze.matcher.exec(ke);if(!ge)break;const Se=ke.substring(pi,ge.index),Ue=Xa(Se,ge);pi=ge.index+Ue}Xa(ke.substring(pi))}return Ut.finalize(),Za=Ut.toHTML(),{language:ue,value:Za,relevance:Ui,illegal:!1,_emitter:Ut,_top:ze}}catch(ge){if(ge.message&&ge.message.includes("Illegal"))return{language:ue,value:on(ke),illegal:!0,relevance:0,_illegalBy:{message:ge.message,index:pi,context:ke.slice(pi-100,pi+100),mode:ge.mode,resultSoFar:Za},_emitter:Ut};if(vt)return{language:ue,value:on(ke),illegal:!1,relevance:0,errorRaised:ge,_emitter:Ut,_top:ze};throw ge}}function Ga(ue){const ke={value:on(ue),illegal:!1,relevance:0,_top:Ee,_emitter:new ye.__emitter(ye)};return ke._emitter.addText(ue),ke}function Pa(ue,ke){ke=ke||ye.languages||Object.keys(J);const Pe=Ga(ue),ot=ke.filter(cn).filter(Bi).map(yt=>di(yt,ue,!1));ot.unshift(Pe);const Lt=ot.sort((yt,kn)=>{if(yt.relevance!==kn.relevance)return kn.relevance-yt.relevance;if(yt.language&&kn.language){if(cn(yt.language).supersetOf===kn.language)return 1;if(cn(kn.language).supersetOf===yt.language)return-1}return 0}),[nn,wn]=Lt,pn=nn;return pn.secondBest=wn,pn}function ti(ue,ke,Pe){const ot=ke&&be[ke]||Pe;ue.classList.add("hljs"),ue.classList.add(`language-${ot}`)}function Dt(ue){let ke=null;const Pe=Rt(ue);if(De(Pe))return;if(ga("before:highlightElement",{el:ue,language:Pe}),ue.dataset.highlighted){console.log("Element previously highlighted. To highlight again, first unset `dataset.highlighted`.",ue);return}if(ue.children.length>0&&(ye.ignoreUnescapedHTML||(console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk."),console.warn("https://github.com/highlightjs/highlight.js/wiki/security"),console.warn("The element with unescaped HTML:"),console.warn(ue)),ye.throwUnescapedHTML))throw new ei("One of your code blocks includes unescaped HTML.",ue.innerHTML);ke=ue;const ot=ke.textContent,Lt=Pe?Nt(ot,{language:Pe,ignoreIllegals:!0}):Pa(ot);ue.innerHTML=Lt.value,ue.dataset.highlighted="yes",ti(ue,Pe,Lt.language),ue.result={language:Lt.language,re:Lt.relevance,relevance:Lt.relevance},Lt.secondBest&&(ue.secondBest={language:Lt.secondBest.language,relevance:Lt.secondBest.relevance}),ga("after:highlightElement",{el:ue,result:Lt,text:ot})}function tn(ue){ye=os(ye,ue)}const ji=()=>{Ya(),Z("10.6.0","initHighlighting() deprecated.  Use highlightAll() now.")};function $l(){Ya(),Z("10.6.0","initHighlightingOnLoad() deprecated.  Use highlightAll() now.")}let cs=!1;function Ya(){function ue(){Ya()}if(document.readyState==="loading"){cs||window.addEventListener("DOMContentLoaded",ue,!1),cs=!0;return}document.querySelectorAll(ye.cssSelector).forEach(Dt)}function us(ue,ke){let Pe=null;try{Pe=ke(D)}catch(ot){if(Tt("Language definition for '{}' could not be registered.".replace("{}",ue)),vt)Tt(ot);else throw ot;Pe=Ee}Pe.name||(Pe.name=ue),J[ue]=Pe,Pe.rawDefinition=ke.bind(null,D),Pe.aliases&&mi(Pe.aliases,{languageName:ue})}function pa(ue){delete J[ue];for(const ke of Object.keys(be))be[ke]===ue&&delete be[ke]}function ql(){return Object.keys(J)}function cn(ue){return ue=(ue||"").toLowerCase(),J[ue]||J[be[ue]]}function mi(ue,{languageName:ke}){typeof ue=="string"&&(ue=[ue]),ue.forEach(Pe=>{be[Pe.toLowerCase()]=ke})}function Bi(ue){const ke=cn(ue);return ke&&!ke.disableAutodetect}function Ii(ue){ue["before:highlightBlock"]&&!ue["before:highlightElement"]&&(ue["before:highlightElement"]=ke=>{ue["before:highlightBlock"](Object.assign({block:ke.el},ke))}),ue["after:highlightBlock"]&&!ue["after:highlightElement"]&&(ue["after:highlightElement"]=ke=>{ue["after:highlightBlock"](Object.assign({block:ke.el},ke))})}function It(ue){Ii(ue),je.push(ue)}function fs(ue){const ke=je.indexOf(ue);ke!==-1&&je.splice(ke,1)}function ga(ue,ke){const Pe=ue;je.forEach(function(ot){ot[Pe]&&ot[Pe](ke)})}function hi(ue){return Z("10.7.0","highlightBlock will be removed entirely in v12.0"),Z("10.7.0","Please use highlightElement now."),Dt(ue)}Object.assign(D,{highlight:Nt,highlightAuto:Pa,highlightAll:Ya,highlightElement:Dt,highlightBlock:hi,configure:tn,initHighlighting:ji,initHighlightingOnLoad:$l,registerLanguage:us,unregisterLanguage:pa,listLanguages:ql,getLanguage:cn,registerAliases:mi,autoDetection:Bi,inherit:os,addPlugin:It,removePlugin:fs}),D.debugMode=function(){vt=!1},D.safeMode=function(){vt=!0},D.versionString=st,D.regex={concat:T,lookahead:_,either:w,optional:S,anyNumberOfTimes:v};for(const ue in lt)typeof lt[ue]=="object"&&t(lt[ue]);return Object.assign(D,lt),D},hn=ha({});return hn.newInstance=()=>ha({}),Of=hn,hn.HighlightJS=hn,hn.default=hn,Of}var DA=RA();const LA=sd(DA),C0={},jA="hljs-";function BA(t){const a=LA.newInstance();return t&&u(t),{highlight:l,highlightAuto:r,listLanguages:o,register:u,registerAlias:c,registered:h};function l(g,p,b){const x=b||C0,_=typeof x.prefix=="string"?x.prefix:jA;if(!a.getLanguage(g))throw new Error("Unknown language: `"+g+"` is not registered");a.configure({__emitter:IA,classPrefix:_});const v=a.highlight(p,{ignoreIllegals:!0,language:g});if(v.errorRaised)throw new Error("Could not highlight with `Highlight.js`",{cause:v.errorRaised});const S=v._emitter.root,T=S.data;return T.language=v.language,T.relevance=v.relevance,S}function r(g,p){const x=(p||C0).subset||o();let _=-1,v=0,S;for(;++_<x.length;){const T=x[_];if(!a.getLanguage(T))continue;const A=l(T,g,p);A.data&&A.data.relevance!==void 0&&A.data.relevance>v&&(v=A.data.relevance,S=A)}return S||{type:"root",children:[],data:{language:void 0,relevance:v}}}function o(){return a.listLanguages()}function u(g,p){if(typeof g=="string")a.registerLanguage(g,p);else{let b;for(b in g)Object.hasOwn(g,b)&&a.registerLanguage(b,g[b])}}function c(g,p){if(typeof g=="string")a.registerAliases(typeof p=="string"?p:[...p],{languageName:g});else{let b;for(b in g)if(Object.hasOwn(g,b)){const x=g[b];a.registerAliases(typeof x=="string"?x:[...x],{languageName:b})}}}function h(g){return!!a.getLanguage(g)}}class IA{constructor(a){this.options=a,this.root={type:"root",children:[],data:{language:void 0,relevance:0}},this.stack=[this.root]}addText(a){if(a==="")return;const l=this.stack[this.stack.length-1],r=l.children[l.children.length-1];r&&r.type==="text"?r.value+=a:l.children.push({type:"text",value:a})}startScope(a){this.openNode(String(a))}endScope(){this.closeNode()}__addSublanguage(a,l){const r=this.stack[this.stack.length-1],o=a.root.children;l?r.children.push({type:"element",tagName:"span",properties:{className:[l]},children:o}):r.children.push(...o)}openNode(a){const l=this,r=a.split(".").map(function(c,h){return h?c+"_".repeat(h):l.options.classPrefix+c}),o=this.stack[this.stack.length-1],u={type:"element",tagName:"span",properties:{className:r},children:[]};o.children.push(u),this.stack.push(u)}closeNode(){this.stack.pop()}finalize(){}toHTML(){return""}}const UA={};function HA(t){const a=t||UA,l=a.aliases,r=a.detect||!1,o=a.languages||zA,u=a.plainText,c=a.prefix,h=a.subset;let g="hljs";const p=BA(o);if(l&&p.registerAlias(l),c){const b=c.indexOf("-");g=b===-1?c:c.slice(0,b)}return function(b,x){nc(b,"element",function(_,v,S){if(_.tagName!=="code"||!S||S.type!=="element"||S.tagName!=="pre")return;const T=FA(_);if(T===!1||!T&&!r||T&&u&&u.includes(T))return;Array.isArray(_.properties.className)||(_.properties.className=[]),_.properties.className.includes(g)||_.properties.className.unshift(g);const A=l2(_,{whitespace:"pre"});let w;try{w=T?p.highlight(T,A,{prefix:c}):p.highlightAuto(A,{prefix:c,subset:h})}catch(O){const R=O;if(T&&/Unknown language/.test(R.message)){x.message("Cannot highlight as `"+T+"`, it’s not registered",{ancestors:[S,_],cause:R,place:_.position,ruleId:"missing-language",source:"rehype-highlight"});return}throw R}!T&&w.data&&w.data.language&&_.properties.className.push("language-"+w.data.language),w.children.length>0&&(_.children=w.children)})}}function FA(t){const a=t.properties.className;let l=-1;if(!Array.isArray(a))return;let r;for(;++l<a.length;){const o=String(a[l]);if(o==="no-highlight"||o==="nohighlight")return!1;!r&&o.slice(0,5)==="lang-"&&(r=o.slice(5)),!r&&o.slice(0,9)==="language-"&&(r=o.slice(9))}return r}const $A=1500;function ls({text:t,className:a=""}){const[l,r]=F.useState(!1),o=F.useCallback(()=>{navigator.clipboard.writeText(t).then(()=>{r(!0),setTimeout(()=>r(!1),$A)})},[t]);return d.jsx("button",{onClick:o,className:`p-1 rounded hover:bg-zinc-700/50 transition-colors ${a}`,title:l?"Copied!":"Copy",children:l?d.jsx(cd,{className:"w-3.5 h-3.5 text-emerald-400"}):d.jsx(b_,{className:"w-3.5 h-3.5 text-zinc-400"})})}function O0(t){if(!t)return"";const a=t.match(/language-(\w+)/);return a?a[1]:""}function qA({content:t,className:a=""}){const l={h1:({children:r})=>d.jsx("h1",{className:"text-lg font-semibold text-zinc-100 mt-4 mb-2",children:r}),h2:({children:r})=>d.jsx("h2",{className:"text-base font-semibold text-zinc-100 mt-3 mb-1.5",children:r}),h3:({children:r})=>d.jsx("h3",{className:"text-sm font-semibold text-zinc-100 mt-2.5 mb-1",children:r}),h4:({children:r})=>d.jsx("h4",{className:"text-sm font-medium text-zinc-200 mt-2 mb-1",children:r}),h5:({children:r})=>d.jsx("h5",{className:"text-xs font-medium text-zinc-200 mt-1.5 mb-0.5",children:r}),h6:({children:r})=>d.jsx("h6",{className:"text-xs font-medium text-zinc-300 mt-1.5 mb-0.5",children:r}),p:({children:r})=>d.jsx("p",{className:"text-[13px] leading-relaxed text-zinc-200 my-1.5",children:r}),a:({href:r,children:o})=>d.jsx("a",{href:r,target:"_blank",rel:"noopener noreferrer",className:"text-cyan-400 hover:text-cyan-300 underline underline-offset-2",children:o}),strong:({children:r})=>d.jsx("strong",{className:"font-semibold text-zinc-50",children:r}),em:({children:r})=>d.jsx("em",{className:"italic text-zinc-300",children:r}),code:({className:r,children:o})=>{const u=O0(r),c=r==null?void 0:r.includes("hljs");return u||c?d.jsx("code",{className:`${r||""} text-[12px] font-mono`,children:o}):d.jsx("code",{className:"px-1.5 py-0.5 rounded bg-zinc-800/80 text-cyan-300 text-[12px] font-mono",children:o})},pre:({children:r})=>{var h;const o=r,u=O0((h=o==null?void 0:o.props)==null?void 0:h.className),c=GA(o);return d.jsxs("div",{className:"my-2 rounded-lg border border-zinc-700/60 overflow-hidden",children:[d.jsxs("div",{className:"flex items-center justify-between px-3 py-1.5 bg-zinc-800/80 border-b border-zinc-700/60",children:[d.jsx("span",{className:"text-[10px] font-medium text-zinc-400 uppercase tracking-wider",children:u||"code"}),d.jsx(ls,{text:c})]}),d.jsx("pre",{className:"p-3 overflow-x-auto bg-zinc-900/60 text-[12px] leading-relaxed !m-0",children:r})]})},ul:({children:r})=>d.jsx("ul",{className:"list-disc list-outside pl-5 space-y-0.5 my-1.5 text-[13px] text-zinc-200",children:r}),ol:({children:r})=>d.jsx("ol",{className:"list-decimal list-outside pl-5 space-y-0.5 my-1.5 text-[13px] text-zinc-200",children:r}),li:({children:r})=>d.jsx("li",{className:"leading-relaxed [&>p]:my-0 [&>p]:inline",children:r}),blockquote:({children:r})=>d.jsx("blockquote",{className:"border-l-2 border-zinc-600 pl-3 my-2 italic text-zinc-400",children:r}),table:({children:r})=>d.jsx("div",{className:"my-2 overflow-x-auto rounded-lg border border-zinc-700/60",children:d.jsx("table",{className:"w-full text-[12px]",children:r})}),thead:({children:r})=>d.jsx("thead",{className:"bg-zinc-900 text-zinc-300",children:r}),tr:({children:r})=>d.jsx("tr",{className:"border-b border-zinc-700/40",children:r}),th:({children:r})=>d.jsx("th",{className:"px-3 py-1.5 text-left font-medium text-zinc-300",children:r}),td:({children:r})=>d.jsx("td",{className:"px-3 py-1.5 text-zinc-400",children:r}),hr:()=>d.jsx("hr",{className:"border-zinc-700 my-3"})};return d.jsx("div",{className:a,children:d.jsx(Uw,{remarkPlugins:[JT],rehypePlugins:[HA],components:l,children:t})})}function GA(t){var l;if(!((l=t==null?void 0:t.props)!=null&&l.children))return"";const a=t.props.children;return typeof a=="string"?a.replace(/\n$/,""):Array.isArray(a)?a.map(String).join("").replace(/\n$/,""):String(a).replace(/\n$/,"")}const rs=F.memo(qA);function Od({content:t,className:a}){if(typeof t=="string"){const l=Qr(t);return l?d.jsx(rs,{content:l,className:a}):null}return t.length?d.jsx("div",{className:a,children:t.map((l,r)=>d.jsx(PA,{part:l},r))}):null}function PA({part:t}){if(t.type==="text"&&t.text){const a=Qr(t.text);return a?d.jsx(rs,{content:a}):null}return t.type==="image"&&t.source?d.jsx(YA,{source:t.source}):null}function YA({source:t}){const[a,l]=F.useState(!1),r=`data:${t.media_type};base64,${t.base64}`;return d.jsxs(d.Fragment,{children:[d.jsx("img",{src:r,alt:"Embedded image",className:"my-2 max-w-full max-h-80 rounded-lg border border-zinc-700/60 cursor-pointer hover:border-zinc-500 transition-colors",onClick:()=>l(!0)}),a&&d.jsx("div",{className:"fixed inset-0 z-50 flex items-center justify-center bg-black/80 cursor-pointer",onClick:()=>l(!1),children:d.jsx("img",{src:r,alt:"Expanded image",className:"max-w-[90vw] max-h-[90vh] rounded-lg"})})]})}const z0=8,R0=500,VA=20;function Cx({step:t}){var a;return t.source==="system"?d.jsx(XA,{step:t}):t.source==="user"?(a=t.extra)!=null&&a.is_skill_output?d.jsx(QA,{step:t}):d.jsx(KA,{step:t}):t.source==="agent"?d.jsx(JA,{step:t}):null}function KA({step:t}){const a=Bl(t.message);return!a&&typeof t.message=="string"||!a&&Array.isArray(t.message)&&t.message.length===0?null:d.jsx("div",{className:"flex justify-end",children:d.jsx("div",{className:"max-w-[85%] bg-gradient-to-br from-slate-600/70 to-slate-700/60 text-zinc-100 rounded-2xl rounded-br-md px-4 py-2.5 text-sm overflow-hidden break-words",children:d.jsx(Od,{content:t.message,className:"user-markdown"})})})}function XA({step:t}){const[a,l]=F.useState(!1),r=Bl(t.message);if(!r)return null;const o=r.split(`
`)[0].slice(0,80);return d.jsxs("div",{className:"max-w-[85%]",children:[d.jsxs("button",{onClick:()=>l(!a),className:"inline-flex items-center gap-1.5 px-2.5 py-1 rounded-lg text-[11px] border transition-colors bg-zinc-800/50 hover:bg-zinc-800/80 text-zinc-500 border-zinc-700",children:[a?d.jsx(ui,{className:"w-3 h-3"}):d.jsx(Di,{className:"w-3 h-3"}),d.jsx(G_,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"System"}),!a&&d.jsx("span",{className:"text-zinc-600 truncate max-w-[250px] ml-0.5",children:o})]}),a&&d.jsx("div",{className:"mt-1 bg-zinc-900/60 border border-zinc-700 rounded-lg p-3",children:d.jsx("pre",{className:"text-xs text-zinc-500 whitespace-pre-wrap break-words overflow-x-auto max-h-96 overflow-y-auto",children:r})})]})}function ZA(t){const a=t.match(/\/skills\/([^/\s]+)/);return a?a[1]:null}function QA({step:t}){const[a,l]=F.useState(!1),r=Bl(t.message);if(!r)return null;const o=ZA(r);return d.jsxs("div",{className:"max-w-[85%]",children:[d.jsxs("button",{onClick:()=>l(!a),className:"inline-flex items-center gap-1.5 px-2.5 py-1 rounded-lg text-[11px] border transition-colors bg-amber-500/10 hover:bg-amber-500/15 text-amber-300 border-amber-500/20",children:[a?d.jsx(ui,{className:"w-3 h-3"}):d.jsx(Di,{className:"w-3 h-3"}),d.jsx(nb,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"Skill"}),o&&d.jsxs("span",{className:"text-amber-400/70 ml-0.5",children:["/",o]})]}),a&&d.jsx("div",{className:"mt-1 bg-amber-500/5 border border-amber-500/20 rounded-lg p-3",children:d.jsx("pre",{className:"text-xs text-amber-200/70 whitespace-pre-wrap overflow-x-auto max-h-96 overflow-y-auto",children:r})})]})}function JA({step:t}){var o;const a=new Map;if(t.observation)for(const u of t.observation.results)u.source_call_id&&a.set(u.source_call_id,u);const l=((o=t.observation)==null?void 0:o.results.filter(u=>!u.source_call_id||!t.tool_calls.some(c=>c.tool_call_id===u.source_call_id)))??[],r=t.tool_calls.length>1;return d.jsxs("div",{className:"space-y-1",children:[t.message&&(typeof t.message!="string"||t.message.trim())&&d.jsx(eM,{content:t.message}),t.reasoning_content&&d.jsx(tM,{text:t.reasoning_content}),(t.tool_calls.length>0||l.length>0)&&d.jsxs("div",{className:"flex flex-col gap-1 mt-1.5",children:[r?d.jsx(WA,{toolCalls:t.tool_calls,obsMap:a}):t.tool_calls.map((u,c)=>{const h=a.get(u.tool_call_id);return d.jsxs("div",{children:[d.jsx(Ox,{toolCall:u}),h&&d.jsx(nd,{result:h})]},`tc-${c}`)}),l.map((u,c)=>d.jsx(nd,{result:u},`orphan-${c}`))]})]})}function WA({toolCalls:t,obsMap:a}){const[l,r]=F.useState(!0),o=t.map(h=>h.function_name||"unknown"),u=[...new Set(o)],c=u.length<=3?u.join(", "):`${u.slice(0,2).join(", ")} +${u.length-2}`;return d.jsxs("div",{className:"max-w-[85%] rounded-lg border bg-cyan-500/5 border-cyan-500/20 overflow-hidden",children:[d.jsxs("button",{onClick:()=>r(!l),className:"flex items-center gap-2 w-full px-3 py-2 text-xs text-cyan-300 hover:bg-white/5 transition-colors",children:[l?d.jsx(ui,{className:"w-3 h-3 shrink-0"}):d.jsx(Di,{className:"w-3 h-3 shrink-0"}),d.jsx(Q0,{className:"w-3.5 h-3.5"}),d.jsxs("span",{className:"font-medium",children:[t.length," parallel calls"]}),!l&&d.jsx("span",{className:"text-zinc-500 truncate ml-1",children:c})]}),l&&d.jsx("div",{className:"border-t border-cyan-500/20",children:d.jsx("div",{className:"border-l-2 border-cyan-500/30 ml-3 pl-3 py-2 space-y-1",children:t.map((h,g)=>{const p=a.get(h.tool_call_id);return d.jsxs("div",{children:[d.jsx(Ox,{toolCall:h}),p&&d.jsx(nd,{result:p})]},`tc-${g}`)})})})]})}function eM({content:t}){if(typeof t=="string"){const a=Qr(t);return a?d.jsx("div",{className:"max-w-[85%] text-zinc-100 text-sm break-words overflow-hidden",children:d.jsx(rs,{content:a})}):null}return d.jsx("div",{className:"max-w-[85%] text-zinc-100 text-sm break-words overflow-hidden",children:d.jsx(Od,{content:t})})}function tM({text:t}){const[a,l]=F.useState(!1);return t.trim()?d.jsxs("div",{className:"max-w-[85%]",children:[d.jsxs("button",{onClick:()=>l(!a),className:"inline-flex items-center gap-1.5 px-2.5 py-1 rounded-lg bg-amber-500/10 hover:bg-amber-500/15 text-[11px] text-amber-400/90 border border-amber-500/20 transition-colors",children:[a?d.jsx(ui,{className:"w-3 h-3"}):d.jsx(Di,{className:"w-3 h-3"}),d.jsx(J0,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"Thinking"})]}),a&&d.jsx("div",{className:"mt-1 bg-zinc-900/80 border border-zinc-800 rounded-lg p-3",children:d.jsx("pre",{className:"text-xs text-amber-200/80 whitespace-pre-wrap overflow-x-auto",children:t})})]}):null}function Ox({toolCall:t}){const[a,l]=F.useState(!1),r=t.function_name||"unknown",{icon:o,color:u}=oM(r),c=cM(r,t.arguments);return d.jsxs("div",{className:"max-w-[85%]",children:[d.jsxs("button",{onClick:()=>l(!a),className:`inline-flex items-center gap-1.5 px-2.5 py-1 rounded-lg text-[11px] border transition-colors ${u}`,children:[a?d.jsx(ui,{className:"w-3 h-3"}):d.jsx(Di,{className:"w-3 h-3"}),o,d.jsx("span",{className:"font-medium",children:r}),!a&&c&&d.jsx("span",{className:"text-zinc-500 truncate max-w-[200px] ml-0.5",children:c})]}),a&&d.jsx("div",{className:"mt-1",children:d.jsx(nM,{name:r,input:t.arguments})})]})}const D0="[ERROR] ";function nd({result:t}){const a=t.content;if(!a)return null;if(Array.isArray(a))return d.jsx("div",{className:"max-w-[85%] mt-1 bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden p-3",children:d.jsx(Od,{content:a})});const l=a.startsWith(D0),r=l?a.slice(D0.length):a;if(!r)return null;const u=r.split(`
`).length<=VA,[c,h]=F.useState(u);if(u)return d.jsx("div",{className:"max-w-[85%] mt-1 bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsx(L0,{text:r,isError:l})});const g=r.split(`
`)[0].slice(0,80);return d.jsxs("div",{className:"max-w-[85%]",children:[d.jsxs("button",{onClick:()=>h(!c),className:`inline-flex items-center gap-1.5 px-2.5 py-1 rounded-lg text-[11px] border transition-colors ${l?"bg-rose-500/10 hover:bg-rose-500/15 text-rose-300 border-rose-500/20":"bg-teal-500/10 hover:bg-teal-500/15 text-teal-300 border-teal-500/20"}`,children:[c?d.jsx(ui,{className:"w-3 h-3"}):d.jsx(Di,{className:"w-3 h-3"}),l?d.jsx(Ul,{className:"w-3.5 h-3.5"}):d.jsx(cd,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:l?"Error":"Result"}),!c&&d.jsx("span",{className:"text-zinc-500 truncate max-w-[250px] ml-0.5",children:g})]}),c&&d.jsx("div",{className:"mt-1 bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsx(L0,{text:r,isError:l})})]})}function nM({name:t,input:a}){const l=a;if(!l)return null;const r=t.toLowerCase();if(r==="bash")return d.jsx(iM,{command:String(l.command||"")});if(r==="edit")return d.jsx(aM,{filePath:String(l.file_path||""),oldString:String(l.old_string||""),newString:String(l.new_string||"")});if(r==="write")return d.jsx(rM,{filePath:String(l.file_path||""),content:String(l.content||"")});if(r==="read"){const u=String(l.file_path||""),c=u.split(".").pop()||"";return d.jsx("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsxs("div",{className:"flex items-center gap-2 px-3 py-1.5 bg-zinc-800/60 border-b border-zinc-700/40",children:[d.jsx(K0,{className:"w-3.5 h-3.5 text-sky-400"}),d.jsx("span",{className:"text-[11px] font-mono text-zinc-300 truncate flex-1",children:u}),c&&d.jsx("span",{className:"text-[9px] px-1.5 py-0.5 rounded bg-zinc-700/60 text-zinc-400 uppercase",children:c}),d.jsx(ls,{text:u})]})})}if(r==="grep")return d.jsx("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 bg-zinc-800/60",children:[d.jsx(fd,{className:"w-3.5 h-3.5 text-amber-400"}),d.jsxs("span",{className:"text-[11px] font-mono text-zinc-300",children:[!!l.pattern&&d.jsx("span",{className:"text-amber-300",children:String(l.pattern)}),!!l.path&&d.jsxs("span",{className:"text-zinc-500 ml-2",children:["in ",String(l.path)]})]})]})});if(r==="glob")return d.jsx("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 bg-zinc-800/60",children:[d.jsx(Ll,{className:"w-3.5 h-3.5 text-cyan-400"}),d.jsxs("span",{className:"text-[11px] font-mono text-zinc-300",children:[!!l.pattern&&d.jsx("span",{className:"text-cyan-300",children:String(l.pattern)}),!!l.path&&d.jsxs("span",{className:"text-zinc-500 ml-2",children:["in ",String(l.path)]})]})]})});const o=JSON.stringify(l,null,2);return d.jsx("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:d.jsx(rs,{content:`\`\`\`json
${o}
\`\`\``,className:"[&>div]:my-0 [&>div]:border-0 [&>div]:rounded-none"})})}function iM({command:t}){return d.jsxs("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:[d.jsxs("div",{className:"flex items-center justify-between px-3 py-1.5 bg-zinc-800/60 border-b border-zinc-700/40",children:[d.jsxs("div",{className:"flex items-center gap-1.5",children:[d.jsx(tb,{className:"w-3.5 h-3.5 text-green-400"}),d.jsx("span",{className:"text-[10px] font-medium text-zinc-400 uppercase tracking-wider",children:"Command"})]}),d.jsx(ls,{text:t})]}),d.jsxs("pre",{className:"p-3 overflow-x-auto text-[12px] font-mono text-green-300 leading-relaxed",children:[d.jsx("span",{className:"text-zinc-500",children:"$ "}),t]})]})}function aM({filePath:t,oldString:a,newString:l}){const r=t.split("/").pop()||t,o=l?l.split(`
`).length:0,u=a?a.split(`
`).length:0;let c=[];return(a||l)&&(c=Tv(r,r,a,l,"","",{context:3}).split(`
`).slice(4)),d.jsxs("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:[d.jsxs("div",{className:"flex items-center gap-2 px-3 py-1.5 bg-zinc-800/60 border-b border-zinc-700/40",children:[d.jsx(W0,{className:"w-3.5 h-3.5 text-blue-400"}),d.jsx("span",{className:"text-[11px] font-mono text-zinc-300 truncate flex-1",children:t}),o>0&&d.jsxs("span",{className:"text-[10px] text-emerald-400 font-mono",title:`${o} line${o!==1?"s":""} added`,children:["+",o]}),u>0&&d.jsxs("span",{className:"text-[10px] text-rose-400 font-mono",title:`${u} line${u!==1?"s":""} removed`,children:["-",u]})]}),c.length>0&&d.jsx("div",{className:"overflow-x-auto text-[11px] font-mono leading-[1.6]",children:c.map((h,g)=>d.jsx(lM,{line:h},g))})]})}function lM({line:t}){return t.startsWith("+")?d.jsx("div",{className:"px-3 bg-emerald-500/8 text-emerald-300 border-l-2 border-emerald-500/50",children:t}):t.startsWith("-")?d.jsx("div",{className:"px-3 bg-rose-500/8 text-rose-300 border-l-2 border-rose-500/50",children:t}):t.startsWith("@@")?d.jsx("div",{className:"px-3 text-zinc-500 bg-zinc-800/40",children:t}):d.jsx("div",{className:"px-3 text-zinc-400",children:t})}function rM({filePath:t,content:a}){const l=a?a.split(`
`).length:0,r=a.length>R0?a.slice(0,R0)+`
...`:a;return d.jsxs("div",{className:"bg-zinc-900/60 border border-zinc-800 rounded-lg overflow-hidden",children:[d.jsxs("div",{className:"flex items-center gap-2 px-3 py-1.5 bg-zinc-800/60 border-b border-zinc-700/40",children:[d.jsx(X0,{className:"w-3.5 h-3.5 text-emerald-400"}),d.jsx("span",{className:"text-[11px] font-mono text-zinc-300 truncate flex-1",children:t}),d.jsxs("span",{className:"text-[10px] text-zinc-500",children:[l," lines"]})]}),a&&d.jsx("pre",{className:"p-3 overflow-x-auto text-[11px] font-mono text-zinc-400 max-h-48 overflow-y-auto leading-relaxed",children:r})]})}function sM(t){const a=t.trim();if(!a.startsWith("{")&&!a.startsWith("["))return null;try{const l=JSON.parse(a);return JSON.stringify(l,null,2)}catch{return null}}function L0({text:t,isError:a}){const[l,r]=F.useState(!1),o=sM(t),u=o||t,c=u.split(`
`),h=c.length>z0,g=!l&&h?c.slice(0,z0).join(`
`)+`
...`:u;return o?d.jsxs("div",{className:"relative",children:[d.jsxs("div",{className:"flex items-center justify-between px-3 py-1 bg-zinc-800/60 border-b border-zinc-700/40",children:[d.jsx("span",{className:"text-[10px] font-medium text-zinc-500 uppercase tracking-wider",children:"json"}),d.jsx(ls,{text:o})]}),d.jsx(rs,{content:`\`\`\`json
${g}
\`\`\``,className:"tool-output-json [&>div]:my-0 [&>div]:border-0 [&>div]:rounded-none [&_pre]:max-h-96 [&_pre]:overflow-y-auto"}),h&&!l&&d.jsxs("button",{onClick:()=>r(!0),className:"text-[10px] text-zinc-400 hover:text-zinc-200 px-3 pb-2",children:["Show all (",c.length," lines)"]})]}):d.jsxs("div",{className:"relative",children:[d.jsx("pre",{className:`text-xs p-3 overflow-x-auto whitespace-pre-wrap break-words max-h-96 overflow-y-auto ${a?"text-rose-300":"text-teal-200/80"}`,children:g}),h&&!l&&d.jsxs("button",{onClick:()=>r(!0),className:"text-[10px] text-zinc-400 hover:text-zinc-200 px-3 pb-2",children:["Show all (",c.length," lines)"]})]})}function oM(t){const a=t.toLowerCase();return a==="bash"?{icon:d.jsx(tb,{className:"w-3.5 h-3.5 text-green-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="edit"?{icon:d.jsx(W0,{className:"w-3.5 h-3.5 text-blue-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="read"?{icon:d.jsx(K0,{className:"w-3.5 h-3.5 text-sky-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="write"?{icon:d.jsx(X0,{className:"w-3.5 h-3.5 text-emerald-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="grep"?{icon:d.jsx(fd,{className:"w-3.5 h-3.5 text-amber-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="glob"?{icon:d.jsx(Ll,{className:"w-3.5 h-3.5 text-cyan-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}:a==="agent"||a.includes("task")||a.includes("agent")?{icon:d.jsx(La,{className:"w-3.5 h-3.5 text-violet-400"}),color:"bg-violet-500/10 hover:bg-violet-500/15 text-violet-300 border-violet-500/20"}:{icon:d.jsx(Qo,{className:"w-3.5 h-3.5 text-zinc-400"}),color:"bg-slate-500/10 hover:bg-slate-500/15 text-slate-300 border-slate-500/20"}}function cM(t,a){const l=a;if(!l)return"";const r=t.toLowerCase();return r==="bash"?String(l.command||"").slice(0,60):r==="edit"||r==="read"||r==="write"?String(l.file_path||"").split("/").slice(-2).join("/"):r==="grep"||r==="glob"?String(l.pattern||"").slice(0,40):""}function uM({open:t,onToggle:a,icon:l,label:r,preview:o,className:u,children:c}){return d.jsxs("div",{className:`rounded-lg border ${u} overflow-hidden`,children:[d.jsxs("button",{onClick:a,className:"flex items-center gap-2 w-full px-3 py-2 text-xs hover:bg-white/5 transition-colors",children:[t?d.jsx(ui,{className:"w-3 h-3 shrink-0"}):d.jsx(Di,{className:"w-3 h-3 shrink-0"}),l,d.jsx("span",{className:"font-medium",children:r}),!t&&o&&d.jsx("span",{className:"text-zinc-500 truncate ml-1",children:o})]}),t&&d.jsx("div",{className:"border-t border-inherit",children:c})]})}function id({trajectory:t,allTrajectories:a}){const[l,r]=F.useState(!1),o=t.steps||[],u=o.length,c=o.reduce((b,x)=>{var _;return b+(((_=x.tool_calls)==null?void 0:_.length)||0)},0),h=F.useMemo(()=>a.filter(b=>{var x;return((x=b.parent_trajectory_ref)==null?void 0:x.session_id)===t.session_id}),[a,t.session_id]),g=t.session_id.slice(0,12),p=`${u} steps • ${c} tools`;return d.jsx(uM,{open:l,onToggle:()=>r(!l),icon:d.jsx(La,{className:"w-3.5 h-3.5"}),label:g,preview:p,className:"bg-violet-500/10 border-violet-500/30 text-violet-300",children:d.jsxs("div",{className:"border-l-2 border-violet-500/30 ml-3 pl-3 py-2 space-y-2",children:[d.jsxs("div",{className:"flex items-center gap-3 text-[10px] text-violet-400 px-1 pb-1",children:[d.jsxs("span",{className:"flex items-center gap-1",children:[d.jsx(Xr,{className:"w-3 h-3"}),u]}),d.jsxs("span",{className:"flex items-center gap-1",children:[d.jsx(Qo,{className:"w-3 h-3"}),c]})]}),o.filter(b=>b.source==="user"||b.source==="agent").map(b=>d.jsx(Cx,{step:b},b.step_id)),h.map(b=>d.jsx(id,{trajectory:b,allTrajectories:a},b.session_id))]})})}var fM=q0();const zf=52,zi=13,Al=3,Rf=28,Df=20,j0=12,dM=12,mM=["Mon","","Wed","","Fri","",""],hM=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],zl=["rgba(34,211,238,0.06)","rgba(34,211,238,0.25)","rgba(34,211,238,0.45)","rgba(34,211,238,0.65)","rgba(34,211,238,0.85)"],Do=["bg-blue-500","bg-amber-400","bg-rose-500","bg-emerald-500","bg-violet-500","bg-orange-500","bg-cyan-400","bg-fuchsia-500"],Lo=["bg-cyan-500","bg-teal-400","bg-sky-500","bg-indigo-400","bg-emerald-500","bg-amber-400","bg-violet-500","bg-rose-400","bg-orange-400","bg-lime-400","bg-pink-400","bg-blue-400"],pM=300,gM=480;function zd({state:t}){const a=F.useRef(null),[l,r]=F.useState({left:0,top:0}),o=t!=null&&typeof t.content!="string",u=o?gM:pM;return F.useEffect(()=>{if(!t)return;const c=a.current,h=c?c.offsetWidth:u,g=c?c.offsetHeight:40,p=window.innerWidth,b=window.innerHeight;let x=t.x+j0,_=t.y-8;x+h>p-8&&(x=t.x-h-j0),_+g>b-8&&(_=b-g-8),_<8&&(_=8),r({left:x,top:_})},[t,u]),t?fM.createPortal(d.jsx("div",{ref:a,className:`fixed z-[9999] pointer-events-none px-3 py-2.5 rounded-lg bg-zinc-800/95 border border-zinc-600 text-[13px] leading-relaxed text-zinc-100 shadow-2xl ${o?"whitespace-pre-wrap":"whitespace-pre-line"}`,style:{left:l.left,top:l.top,maxWidth:u},children:t.content}),document.body):null}function Rd(){const[t,a]=F.useState(null),l=F.useCallback((u,c)=>{a({x:u.clientX,y:u.clientY,content:c})},[]),r=F.useCallback(u=>{a(c=>c?{...c,x:u.clientX,y:u.clientY}:null)},[]),o=F.useCallback(()=>a(null),[]);return{tip:t,show:l,move:r,hide:o}}function bM({entries:t,sessionStartMs:a,sessionStartTimestamp:l}){const{tip:r,show:o,move:u,hide:c}=Rd();if(!t.some(p=>p.step.timestamp))return d.jsx(d.Fragment,{children:t.map(p=>d.jsx("div",{children:p.content},p.step.step_id))});const g=a??xM(t.map(p=>p.step));return d.jsxs(d.Fragment,{children:[d.jsx(zd,{state:r}),t.map((p,b)=>{var Y;const x=p.step.timestamp?new Date(p.step.timestamp).getTime():null,_=g!=null&&x!=null?Math.max(0,Math.floor((x-g)/1e3)):null,v=t[b-1],S=v!=null&&v.step.timestamp?new Date(v.step.timestamp).getTime():null,T=S!=null&&x!=null?Math.max(0,Math.floor((x-S)/1e3)):null,A=b<t.length-1,w=b===0,O=p.step.source==="user"?(Y=p.step.extra)!=null&&Y.is_skill_output?"bg-amber-500":"bg-indigo-500":p.step.source==="system"?"bg-zinc-500":"bg-cyan-500",R=p.step.timestamp?gv(p.step.timestamp,l):"",q=p.step.timestamp?bv(p.step.timestamp):"";return d.jsxs("div",{className:"flex gap-3",children:[d.jsxs("div",{className:"flex flex-col items-center w-5 shrink-0",children:[d.jsx("div",{className:`w-2 h-2 rounded-full ${O} mt-[7px] shrink-0`}),A&&d.jsx("div",{className:"w-0.5 flex-1 bg-zinc-600 min-h-[16px]"})]}),d.jsxs("div",{className:`flex-1 min-w-0 pb-5 ${w?"":"border-t border-zinc-600 pt-3"}`,children:[d.jsxs("div",{className:"flex items-baseline gap-1.5 mb-1.5 cursor-default",children:[_!=null&&d.jsx("span",{className:"text-xs font-mono text-zinc-300",onMouseEnter:L=>o(L,q),onMouseMove:u,onMouseLeave:c,children:ff(_)}),R&&d.jsxs(d.Fragment,{children:[d.jsx("span",{className:"text-zinc-500 text-[11px]",children:"·"}),d.jsx("span",{className:"text-[11px] font-mono text-zinc-400",onMouseEnter:L=>o(L,q),onMouseMove:u,onMouseLeave:c,children:R})]}),T!=null&&T>0&&d.jsxs("span",{className:"text-[10px] font-mono text-zinc-400 ml-auto",onMouseEnter:L=>o(L,`+${ff(T)} since previous step`),onMouseMove:u,onMouseLeave:c,children:["+",ff(T)]})]}),p.content]})]},p.step.step_id)})]})}function xM(t){for(const a of t)if(a.timestamp){const l=new Date(a.timestamp).getTime();if(!isNaN(l))return l}return null}const yM=80,_M=1,B0={exploration:{dot:"bg-blue-400",text:"text-blue-400"},implementation:{dot:"bg-emerald-400",text:"text-emerald-400"},debugging:{dot:"bg-red-400",text:"text-red-400"},verification:{dot:"bg-amber-400",text:"text-amber-400"},planning:{dot:"bg-violet-400",text:"text-violet-400"},mixed:{dot:"bg-zinc-500",text:"text-zinc-400"}},vM={file_read:"read",file_write:"write",shell:"shell",search:"search",web:"web",agent:"agent",task:"task",other:"other"};function EM(t){var r;const a=[];let l=0;for(let o=0;o<t.length;o++){const u=t[o];if(u.source!=="user"||(r=u.extra)!=null&&r.is_skill_output)continue;const c=$f(u);c&&(l++,a.push({turnNumber:l,stepId:u.step_id,preview:Fo(c.replace(/\n/g," "),yM)}))}return a}function SM({steps:t,subAgents:a,activeStepId:l,onNavigate:r,width:o,onResize:u,viewMode:c,flowPhases:h,activePhaseIdx:g,onPhaseNavigate:p}){const b=EM(t),x=b.length>=_M,_=a.length>0,v=c==="flow"&&h&&h.length>0,[S,T]=F.useState("prompts");if(!x&&!_&&!v)return null;const A=w=>{const O=document.getElementById(`subagent-${w}`);O&&O.scrollIntoView({behavior:"smooth",block:"start"})};return v?d.jsxs("div",{style:{width:o},className:"hidden xl:flex relative shrink-0 h-full flex-col border-l border-zinc-800 bg-zinc-900/50",children:[d.jsx(Ff,{side:"right",onResize:u}),d.jsx("div",{className:"shrink-0 px-3 pt-3 pb-2",children:d.jsxs("div",{className:"flex items-center gap-1.5 text-sm text-zinc-300",children:[d.jsx(Z0,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"Phases"}),d.jsxs("span",{className:"text-zinc-500",children:["(",h.length,")"]})]})}),d.jsx("div",{className:"flex-1 overflow-y-auto px-3 py-3",children:d.jsx("div",{className:"space-y-1",children:h.map((w,O)=>{const R=g===O,q=B0[w.phase]||B0.mixed,Y=vM[w.dominantCategory]||w.dominantCategory;return d.jsxs("button",{onClick:()=>p==null?void 0:p(O),className:`w-full text-left px-2 py-2 rounded-md transition-colors text-sm group ${R?"bg-cyan-500/15 border border-cyan-500/30":"hover:bg-zinc-800/60 border border-transparent"}`,children:[d.jsxs("div",{className:"flex items-center gap-2 mb-1",children:[d.jsx("span",{className:`w-2 h-2 rounded-full ${q.dot}`}),d.jsx("span",{className:`text-[11px] font-bold uppercase tracking-wider ${R?"text-cyan-300":q.text}`,children:w.phase})]}),d.jsxs("div",{className:"flex items-center gap-2 text-[11px] text-zinc-400 pl-4",children:[d.jsxs("span",{children:[w.cards.length," step",w.cards.length!==1?"s":""]}),d.jsx("span",{className:"text-zinc-600",children:"·"}),d.jsxs("span",{children:[w.toolCount," tool",w.toolCount!==1?"s":""]}),w.toolCount>0&&d.jsxs(d.Fragment,{children:[d.jsx("span",{className:"text-zinc-600",children:"·"}),d.jsx("span",{className:"text-zinc-500",children:Y})]})]})]},O)})})})]}):d.jsxs("div",{style:{width:o},className:"hidden xl:flex relative shrink-0 h-full flex-col border-l border-zinc-800 bg-zinc-900/50",children:[d.jsx(Ff,{side:"right",onResize:u}),x&&_&&d.jsx("div",{className:"shrink-0 px-3 pt-3 pb-2",children:d.jsxs("div",{className:ib,children:[d.jsxs("button",{onClick:()=>T("prompts"),className:`${$o} ${S==="prompts"?ja:Ba}`,children:[d.jsx(Xr,{className:"w-3 h-3"}),"Prompts"]}),d.jsxs("button",{onClick:()=>T("sub-agents"),className:`${$o} ${S==="sub-agents"?ja:Ba}`,children:[d.jsx(La,{className:"w-3 h-3"}),"Agents"]})]})}),d.jsxs("div",{className:"flex-1 overflow-y-auto px-3 py-3",children:[(S==="prompts"||!_)&&x&&d.jsxs("div",{children:[!_&&d.jsxs("div",{className:"flex items-center gap-1.5 text-sm text-zinc-300 mb-3",children:[d.jsx(Xr,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"Prompts"}),d.jsxs("span",{className:"text-zinc-500",children:["(",b.length,")"]})]}),d.jsx("div",{className:"space-y-1",children:b.map(w=>{const O=w.stepId===l;return d.jsxs("button",{onClick:()=>r(w.stepId),className:`w-full text-left px-2 py-1.5 rounded-md transition-colors text-sm group ${O?"bg-cyan-500/15 border border-cyan-500/30":"hover:bg-zinc-800/60 border border-transparent"}`,children:[d.jsx("div",{className:"flex items-center gap-1.5 mb-0.5",children:d.jsxs("span",{className:`font-mono font-semibold ${O?"text-cyan-400":"text-zinc-400 group-hover:text-zinc-300"}`,children:["#",w.turnNumber]})}),d.jsx("p",{className:`line-clamp-2 leading-snug ${O?"text-cyan-200/80":"text-zinc-400 group-hover:text-zinc-300"}`,children:w.preview})]},w.stepId)})})]}),S==="sub-agents"&&_&&d.jsx("div",{children:d.jsx("div",{className:"space-y-1",children:a.map((w,O)=>{var Y,L;const R=((Y=w.steps)==null?void 0:Y.length)??0,q=((L=w.final_metrics)==null?void 0:L.tool_call_count)??0;return d.jsxs("button",{onClick:()=>A(w.session_id),className:"w-full text-left px-2 py-1.5 rounded-md transition-colors text-sm group hover:bg-zinc-800/60 border border-transparent",children:[d.jsxs("div",{className:"flex items-center gap-1.5 mb-0.5",children:[d.jsxs("span",{className:"font-mono font-semibold text-violet-400",children:["#",O+1]}),d.jsx("span",{className:"text-zinc-400 truncate",children:w.session_id.slice(0,12)})]}),d.jsxs("p",{className:"text-zinc-400 group-hover:text-zinc-300 leading-snug",children:[R," steps · ",q," tools"]}),w.first_message&&d.jsx("p",{className:"text-zinc-500 group-hover:text-zinc-400 line-clamp-1 leading-snug mt-0.5",children:Fo(w.first_message,60)})]},w.session_id)})})}),!x&&_&&d.jsxs("div",{children:[d.jsxs("div",{className:"flex items-center gap-1.5 text-sm text-zinc-300 mb-3",children:[d.jsx(La,{className:"w-3.5 h-3.5"}),d.jsx("span",{className:"font-medium",children:"Sub-Agents"}),d.jsxs("span",{className:"text-zinc-500",children:["(",a.length,")"]})]}),d.jsx("div",{className:"space-y-1",children:a.map((w,O)=>{var Y,L;const R=((Y=w.steps)==null?void 0:Y.length)??0,q=((L=w.final_metrics)==null?void 0:L.tool_call_count)??0;return d.jsxs("button",{onClick:()=>A(w.session_id),className:"w-full text-left px-2 py-1.5 rounded-md transition-colors text-sm group hover:bg-zinc-800/60 border border-transparent",children:[d.jsxs("div",{className:"flex items-center gap-1.5 mb-0.5",children:[d.jsxs("span",{className:"font-mono font-semibold text-violet-400",children:["#",O+1]}),d.jsx("span",{className:"text-zinc-400 truncate",children:w.session_id.slice(0,12)})]}),d.jsxs("p",{className:"text-zinc-400 group-hover:text-zinc-300 leading-snug",children:[R," steps · ",q," tools"]}),w.first_message&&d.jsx("p",{className:"text-zinc-500 group-hover:text-zinc-400 line-clamp-1 leading-snug mt-0.5",children:Fo(w.first_message,60)})]},w.session_id)})})]})]})]})}const I0=120,NM={Read:"file_read",read_file:"file_read",cat:"file_read",Glob:"search",glob:"search",Grep:"search",grep:"search",find:"search",Edit:"file_write",Write:"file_write",write_file:"file_write",NotebookEdit:"file_write",MultiEdit:"file_write",apply_patch:"file_write","apply-patch":"file_write",Bash:"shell",bash:"shell",shell:"shell",execute_command:"shell",WebSearch:"web",WebFetch:"web",web_search:"web",Agent:"agent",Task:"agent",Skill:"agent",TaskCreate:"task",TaskUpdate:"task",TaskList:"task",TaskGet:"task"};function U0(t,a){return t.length<=a?t:t.slice(0,a-1)+"…"}function wM(t){if(!t)return"";if(typeof t=="string")return t.slice(0,300);try{return JSON.stringify(t,null,2).slice(0,400)}catch{return String(t).slice(0,300)}}function zx(t,a,l){const r=kM(t),o=TM(r,l),u=AM(a);return{phases:o,dependencies:u}}function kM(t){const a=[];let l=0;for(const r of t){const o=l++;if(r.source==="user"){const u=Bl(r.message);if(!u)continue;a.push({type:"user",data:{id:`user-${r.step_id}`,label:U0(u,I0),detail:u,stepIndex:o}})}if(r.source==="agent"){const u=Bl(r.message),c=r.tool_calls.length>0;if(!u&&!c)continue;const h=r.tool_calls.map(g=>({id:`tool-${g.tool_call_id}`,name:g.function_name,category:NM[g.function_name]||"other",detail:`${g.function_name}
${wM(g.arguments)}`,toolCallId:g.tool_call_id}));a.push({type:"agent",data:{id:`agent-${r.step_id}`,label:u?U0(u,I0):"Agent processing…",detail:u||"(tool calls only)",stepIndex:o,tools:h}})}}return a}function Lf(t){const a=new Map;let l=0;for(const u of t)if(u.type==="agent")for(const c of u.data.tools)l++,a.set(c.category,(a.get(c.category)||0)+1);let r="other",o=0;for(const[u,c]of a)c>o&&(o=c,r=u);return{toolCount:l,dominantCategory:r}}function TM(t,a){if(a.length===0){if(t.length===0)return[];const{toolCount:u,dominantCategory:c}=Lf(t);return[{phase:"mixed",cards:t,toolCount:u,dominantCategory:c}]}const l=[],r=new Set;for(const u of a){const c=t.filter(h=>{const g=h.data.stepIndex;return g>=u.start_index&&g<=u.end_index});if(c.length>0){const{toolCount:h,dominantCategory:g}=Lf(c);l.push({phase:u.phase,cards:c,toolCount:h,dominantCategory:g}),c.forEach(p=>r.add(p.data.stepIndex))}}const o=t.filter(u=>!r.has(u.data.stepIndex));if(o.length>0){const{toolCount:u,dominantCategory:c}=Lf(o);l.push({phase:"mixed",cards:o,toolCount:u,dominantCategory:c})}return l}function AM(t){const a=new Map;if(!t)return a;for(const l of t.edges){if(l.relation==="sequential")continue;const r=a.get(l.source_tool_call_id)||[];r.push({targetToolCallId:l.target_tool_call_id,relation:l.relation,sharedResource:l.shared_resource||void 0}),a.set(l.source_tool_call_id,r)}return a}const Xo={file_read:{bg:"bg-blue-500/20",ring:"ring-blue-400/60",text:"text-blue-300",label:"read"},file_write:{bg:"bg-emerald-500/20",ring:"ring-emerald-400/60",text:"text-emerald-300",label:"write"},shell:{bg:"bg-amber-500/20",ring:"ring-amber-400/60",text:"text-amber-300",label:"shell"},search:{bg:"bg-sky-500/20",ring:"ring-sky-400/60",text:"text-sky-300",label:"search"},web:{bg:"bg-orange-500/20",ring:"ring-orange-400/60",text:"text-orange-300",label:"web"},agent:{bg:"bg-violet-500/20",ring:"ring-violet-400/60",text:"text-violet-300",label:"agent"},task:{bg:"bg-rose-500/20",ring:"ring-rose-400/60",text:"text-rose-300",label:"task"},other:{bg:"bg-zinc-500/20",ring:"ring-zinc-400/60",text:"text-zinc-400",label:"other"}},H0={exploration:{border:"border-l-blue-400",label:"text-blue-400",dot:"bg-blue-400",bg:"bg-blue-500/[0.03]"},implementation:{border:"border-l-emerald-400",label:"text-emerald-400",dot:"bg-emerald-400",bg:"bg-emerald-500/[0.03]"},debugging:{border:"border-l-red-400",label:"text-red-400",dot:"bg-red-400",bg:"bg-red-500/[0.03]"},verification:{border:"border-l-amber-400",label:"text-amber-400",dot:"bg-amber-400",bg:"bg-amber-500/[0.03]"},planning:{border:"border-l-violet-400",label:"text-violet-400",dot:"bg-violet-400",bg:"bg-violet-500/[0.03]"},mixed:{border:"border-l-zinc-500",label:"text-zinc-400",dot:"bg-zinc-500",bg:"bg-zinc-500/[0.02]"}},MM={read_before_write:"read → write",search_then_read:"search → read",write_then_test:"edit → test",multi_edit:"re-edit",error_retry:"retry"};function CM({steps:t,flowData:a}){const{tip:l,show:r,move:o,hide:u}=Rd(),[c,h]=F.useState(null),g=F.useMemo(()=>zx(t,a.tool_graph,a.phase_segments),[t,a]),p=F.useMemo(()=>{const v=new Map;for(const[S,T]of g.dependencies)for(const A of T)v.has(S)||v.set(S,new Set),v.get(S).add(A.targetToolCallId),v.has(A.targetToolCallId)||v.set(A.targetToolCallId,new Set),v.get(A.targetToolCallId).add(S);return v},[g.dependencies]),b=F.useMemo(()=>{const v=new Map;for(const[S,T]of g.dependencies)for(const A of T){const w=MM[A.relation]||A.relation;v.set(`${S}->${A.targetToolCallId}`,w),v.set(`${A.targetToolCallId}->${S}`,w)}return v},[g.dependencies]),x=F.useCallback(v=>{var S;return c?v===c?!0:((S=p.get(c))==null?void 0:S.has(v))||!1:!1},[c,p]),_=F.useCallback(v=>!c||v===c?null:b.get(`${c}->${v}`)||null,[c,b]);return d.jsxs("div",{className:"max-w-3xl mx-auto pb-8",children:[g.phases.map((v,S)=>d.jsxs("div",{id:`flow-phase-${S}`,children:[d.jsx(OM,{phase:v,children:v.cards.map((T,A)=>d.jsxs("div",{children:[A>0&&d.jsx(zM,{}),T.type==="user"?d.jsx(RM,{label:T.data.label,detail:T.data.detail,onHover:r,onMove:o,onLeave:u}):d.jsx(DM,{label:T.data.label,detail:T.data.detail,tools:T.data.tools,hoveredToolId:c,onToolEnter:h,onToolLeave:()=>h(null),isHighlighted:x,getDepLabel:_,onHover:r,onMove:o,onLeave:u})]},T.data.id))}),S<g.phases.length-1&&d.jsx("div",{className:"flex items-center pl-6 py-1",children:d.jsxs("div",{className:"flex flex-col items-center",children:[d.jsx("div",{className:"w-px h-2 bg-zinc-700/30"}),d.jsx("div",{className:"w-1 h-1 rounded-full bg-zinc-600/40"}),d.jsx("div",{className:"w-px h-2 bg-zinc-700/30"})]})})]},S)),d.jsx(zd,{state:l})]})}function OM({phase:t,children:a}){const l=H0[t.phase]||H0.mixed;return d.jsx("div",{className:`rounded-lg ${l.bg}`,children:d.jsxs("div",{className:`border-l-[3px] ${l.border} pl-5 pr-3 py-4`,children:[d.jsxs("div",{className:"flex items-center gap-2.5 mb-4",children:[d.jsx("span",{className:`w-2.5 h-2.5 rounded-full ${l.dot} ring-2 ring-current/10`}),d.jsx("span",{className:`text-[11px] font-bold uppercase tracking-[0.14em] ${l.label}`,children:t.phase}),d.jsxs("span",{className:"text-[10px] text-zinc-500 font-medium",children:[t.cards.length," step",t.cards.length!==1?"s":""]})]}),d.jsx("div",{children:a})]})})}function zM(){return d.jsx("div",{className:"flex items-center justify-center py-1.5",children:d.jsxs("div",{className:"flex flex-col items-center",children:[d.jsx("div",{className:"w-px h-2.5 bg-zinc-700/40"}),d.jsx("div",{className:"w-[5px] h-[5px] rounded-full border border-zinc-600/60 bg-zinc-800"}),d.jsx("div",{className:"w-px h-2.5 bg-zinc-700/40"})]})})}function RM({label:t,detail:a,onHover:l,onMove:r,onLeave:o}){return d.jsx("div",{className:"group relative rounded-lg border border-indigo-500/30 bg-indigo-950/30 hover:border-indigo-400/50 hover:bg-indigo-950/40 transition-all",onMouseEnter:u=>l(u,a),onMouseMove:r,onMouseLeave:o,children:d.jsxs("div",{className:"px-4 py-3 flex items-start gap-3",children:[d.jsx("span",{className:"shrink-0 mt-0.5 w-6 h-6 rounded-md bg-indigo-500/25 border border-indigo-400/20 flex items-center justify-center",children:d.jsx("svg",{className:"w-3 h-3 text-indigo-300",viewBox:"0 0 16 16",fill:"currentColor",children:d.jsx("path",{d:"M8 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H3s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C11.516 10.68 10.289 10 8 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"})})}),d.jsx("p",{className:"text-[13px] leading-relaxed text-indigo-100 min-w-0 break-words",children:t})]})})}function DM({label:t,detail:a,tools:l,hoveredToolId:r,onToolEnter:o,onToolLeave:u,isHighlighted:c,getDepLabel:h,onHover:g,onMove:p,onLeave:b}){const x=F.useMemo(()=>{const _=new Map;for(const S of l){const T=_.get(S.category)||[];T.push(S),_.set(S.category,T)}const v=["file_read","search","file_write","shell","web","agent","task","other"];return[..._.entries()].sort(([S],[T])=>(v.indexOf(S)===-1?99:v.indexOf(S))-(v.indexOf(T)===-1?99:v.indexOf(T)))},[l]);return d.jsxs("div",{className:"rounded-lg border border-cyan-500/20 bg-cyan-950/20 hover:border-cyan-400/35 transition-colors",children:[d.jsxs("div",{className:"px-4 py-3 flex items-start gap-3",onMouseEnter:_=>g(_,a),onMouseMove:p,onMouseLeave:b,children:[d.jsx("span",{className:"shrink-0 mt-0.5 w-6 h-6 rounded-md bg-cyan-500/20 border border-cyan-400/15 flex items-center justify-center",children:d.jsxs("svg",{className:"w-3 h-3 text-cyan-300",viewBox:"0 0 16 16",fill:"currentColor",children:[d.jsx("path",{d:"M6 12.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zM3 8.062C3 6.76 4.235 5.765 5.53 5.886a26.58 26.58 0 0 0 4.94 0C11.765 5.765 13 6.76 13 8.062v1.157a.933.933 0 0 1-.765.935c-.845.147-2.34.346-4.235.346-1.895 0-3.39-.2-4.235-.346A.933.933 0 0 1 3 9.219V8.062zm4.542-.827a.25.25 0 0 0-.217.068l-.92.9a25.14 25.14 0 0 1-1.871-.183.25.25 0 0 0-.068.495c.55.076 1.232.149 2.02.193a.25.25 0 0 0 .189-.071l.754-.736.847 1.71a.25.25 0 0 0 .404.062l.932-.97a25.286 25.286 0 0 0 1.922-.188.25.25 0 0 0-.068-.495c-.538.074-1.207.145-1.98.189a.25.25 0 0 0-.166.076l-.754.785-.842-1.7a.25.25 0 0 0-.182-.135z"}),d.jsx("path",{d:"M8.5 1.866a1 1 0 1 0-1 0V3h-2A4.5 4.5 0 0 0 1 7.5V8a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1v1a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2v-1a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1v-.5A4.5 4.5 0 0 0 10.5 3h-2V1.866zM14 7.5V13a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V7.5A3.5 3.5 0 0 1 5.5 4h5A3.5 3.5 0 0 1 14 7.5z"})]})}),d.jsx("p",{className:"text-[13px] leading-relaxed text-cyan-100 min-w-0 break-words",children:t})]}),l.length>0&&d.jsxs("div",{className:"border-t border-cyan-500/10 mx-3 px-1 py-2.5",children:[d.jsxs("div",{className:"flex items-center gap-1.5 mb-2 px-1",children:[d.jsxs("span",{className:"text-[10px] font-semibold text-zinc-400 uppercase tracking-wider",children:[l.length," tool",l.length!==1?"s":""]}),d.jsx("span",{className:"text-zinc-700 text-[10px]",children:"·"}),d.jsx("div",{className:"flex gap-1.5",children:x.map(([_,v])=>{const S=Xo[_]||Xo.other;return d.jsxs("span",{className:`inline-flex items-center gap-1 text-[10px] ${S.text}`,title:`${v.length} ${_.replace(/_/g," ")}`,children:[d.jsx("span",{className:`w-2 h-2 rounded-sm ${S.bg} border border-current/20`}),d.jsx("span",{className:"opacity-80",children:S.label}),d.jsx("span",{className:"font-mono font-semibold",children:v.length})]},_)})})]}),d.jsx("div",{className:"flex flex-wrap gap-1.5 px-1",children:l.map(_=>d.jsx(LM,{tool:_,highlighted:c(_.toolCallId),depLabel:h(_.toolCallId),isAnyHovered:!!r,onEnter:()=>o(_.toolCallId),onLeave:u,onHover:g,onMove:p,onHoverLeave:b},_.id))})]})]})}function LM({tool:t,highlighted:a,depLabel:l,isAnyHovered:r,onEnter:o,onLeave:u,onHover:c,onMove:h,onHoverLeave:g}){const p=Xo[t.category]||Xo.other,b=r&&!a,x=F.useMemo(()=>{const _=t.detail.split(`
`),v=_[0]||t.name,S=_.slice(1).join(`
`).trim();return S?d.jsxs("div",{children:[d.jsx("div",{className:"font-mono text-[12px] font-semibold text-cyan-300 mb-1.5",children:v}),d.jsx("pre",{className:"font-mono text-[11px] text-zinc-300 leading-snug whitespace-pre-wrap break-all m-0",children:S})]}):d.jsx("span",{className:"font-mono text-[12px] text-cyan-300",children:v})},[t.detail,t.name]);return d.jsxs("span",{className:`
        relative inline-flex items-center gap-1.5 px-2.5 py-1 rounded-md text-[11px] font-mono
        border transition-all duration-150 cursor-default
        ${p.bg} ${p.text}
        ${a?`ring-2 ${p.ring} border-transparent brightness-125`:"border-transparent"}
        ${b?"opacity-25":"opacity-100"}
        hover:opacity-100 hover:brightness-125
      `,onMouseEnter:_=>{o(),c(_,x)},onMouseMove:h,onMouseLeave:()=>{u(),g()},children:[t.name,l&&d.jsx("span",{className:"absolute -top-2.5 left-1/2 -translate-x-1/2 px-1.5 py-px rounded-full text-[8px] font-sans font-bold bg-zinc-900 border border-zinc-500 text-zinc-200 whitespace-nowrap shadow-lg",children:l})]})}function Zo({label:t,sublabel:a}){return d.jsx("div",{className:"flex items-center justify-center h-full",children:d.jsxs("div",{className:"flex flex-col items-center gap-5",children:[d.jsxs("div",{className:"relative flex items-center justify-center w-20 h-20",children:[d.jsx("div",{className:"absolute w-28 h-28 bg-cyan-500/8 rounded-full blur-2xl animate-pulse"}),d.jsx("div",{className:"absolute w-20 h-20 rounded-full border-2 border-transparent border-t-cyan-400/40 border-r-cyan-400/10",style:{animation:"spin 3s linear infinite reverse"}}),d.jsx("div",{className:"absolute w-14 h-14 rounded-full border-2 border-transparent border-t-cyan-400/70 border-l-cyan-400/20",style:{animation:"spin 1.8s linear infinite"}}),d.jsx("div",{className:"absolute w-8 h-8 rounded-full border-2 border-transparent border-t-cyan-300 border-r-cyan-300/30",style:{animation:"spin 1s linear infinite"}}),d.jsx("div",{className:"w-2 h-2 rounded-full bg-cyan-400 animate-pulse"})]}),t&&d.jsxs("div",{className:"text-center space-y-1",children:[d.jsx("p",{className:"text-sm font-medium text-zinc-200",children:t}),a&&d.jsx("p",{className:"text-xs text-zinc-500",children:a})]})]})})}function Rx({sessionId:t,sharedTrajectories:a,shareToken:l}){const{fetchWithToken:r}=ss(),[o,u]=F.useState([]),[c,h]=F.useState(!0),[g,p]=F.useState(""),[b,x]=F.useState(null),[_,v]=F.useState(224),[S,T]=F.useState(null),[A,w]=F.useState("idle"),[O,R]=F.useState("timeline"),[q,Y]=F.useState(null),[L,X]=F.useState(!1),[oe,he]=F.useState(!0),U=F.useRef(null),re=F.useRef(!1),ae=!!a,le=160,W=400,H=F.useCallback(se=>{v(Me=>Math.min(W,Math.max(le,Me+se)))},[]);F.useEffect(()=>{if(x(null),T(null),Y(null),R("timeline"),a){u(a),h(!1);return}h(!0),p(""),u([]),r(`/api/sessions/${t}`).then(se=>{if(!se.ok)throw new Error(`Failed to load session: ${se.status}`);return se.json()}).then(se=>{u(se)}).catch(se=>p(se.message)).finally(()=>h(!1))},[t,r,a]),F.useEffect(()=>{!t||c||ae||r(`/api/analysis/sessions/${t}/stats`).then(se=>se.ok?se.json():null).then(se=>{(se==null?void 0:se.cost_usd)!=null&&T(se.cost_usd)}).catch(()=>{})},[t,c,r]),F.useEffect(()=>{if(O!=="flow"||q||L||!t)return;X(!0);const se=ae&&l?`/api/shares/${l}/flow`:`/api/sessions/${t}/flow`;r(se).then(Me=>Me.ok?Me.json():null).then(Me=>{Me&&Y(Me)}).catch(()=>{}).finally(()=>X(!1))},[O,q,L,t,r,ae,l]);const C=F.useMemo(()=>o.find(se=>!se.parent_trajectory_ref)??o[0]??null,[o]),K=F.useMemo(()=>o.filter(se=>!!se.parent_trajectory_ref).sort((se,Me)=>{const et=se.timestamp?new Date(se.timestamp).getTime():0,we=Me.timestamp?new Date(Me.timestamp).getTime():0;return et-we}),[o]),ne=F.useMemo(()=>{const se=new Map,Me=[],et=[];for(const we of K){let zt=!1;if(C!=null&&C.steps){for(const de of C.steps)if(de.observation){for(const Re of de.observation.results)if(Re.subagent_trajectory_ref){for(const rt of Re.subagent_trajectory_ref)if(rt.session_id===we.session_id){const kt=se.get(de.step_id)||[];kt.push(we),se.set(de.step_id,kt),zt=!0;break}if(zt)break}if(zt)break}}zt||et.push(we)}for(const we of et){const zt=we.timestamp?new Date(we.timestamp).getTime():NaN;if(!isNaN(zt)&&(C!=null&&C.steps)){let de=null;for(const Re of C.steps){if(!Re.timestamp)continue;if(new Date(Re.timestamp).getTime()<=zt)de=Re.step_id;else break}if(de){const Re=se.get(de)||[];Re.push(we),se.set(de,Re);continue}}Me.push(we)}return{map:se,orphans:Me}},[C,K]),ie=(C==null?void 0:C.steps)||[],k=F.useMemo(()=>ie.filter(se=>se.source==="user"&&$f(se)).map(se=>se.step_id),[ie]),M=F.useMemo(()=>!q||O!=="flow"?void 0:zx(ie,q.tool_graph,q.phase_segments).phases,[q,O,ie]),[B,N]=F.useState(null),ce=800,pe=F.useCallback(se=>{const Me=document.getElementById(`flow-phase-${se}`);Me&&(N(se),Me.scrollIntoView({behavior:"smooth",block:"start"}))},[]);F.useEffect(()=>{if(!U.current||k.length<2)return;const se=new IntersectionObserver(Me=>{if(re.current)return;let et=null;for(const we of Me)we.isIntersecting&&(!et||we.boundingClientRect.top<et.boundingClientRect.top)&&(et=we);et&&x(et.target.id.replace("step-",""))},{root:U.current,rootMargin:"-10% 0px -80% 0px",threshold:0});for(const Me of k){const et=document.getElementById(`step-${Me}`);et&&se.observe(et)}return()=>se.disconnect()},[k]);const xe=F.useCallback(se=>{const Me=document.getElementById(`step-${se}`);Me&&(re.current=!0,x(se),Me.scrollIntoView({behavior:"smooth",block:"start"}),setTimeout(()=>{re.current=!1},ce))},[]);if(c)return d.jsx(Zo,{label:"Loading session",sublabel:"Parsing trajectory data…"});if(g)return d.jsx("div",{className:"flex items-center justify-center h-full p-4",children:d.jsxs("div",{className:"text-center bg-rose-900/20 border border-rose-800 rounded-lg p-6 max-w-md",children:[d.jsx("p",{className:"text-sm font-semibold text-rose-300 mb-2",children:"Failed to load session"}),d.jsx("p",{className:"text-xs text-rose-400 mb-4 font-mono break-all",children:g}),d.jsx("button",{onClick:()=>window.location.reload(),className:"px-3 py-1 bg-rose-700/50 hover:bg-rose-700 rounded text-xs text-rose-200 transition",children:"Retry"})]})});const Be=async()=>{w("sharing");try{const se=await r("/api/shares",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({session_id:t})});if(!se.ok)throw new Error(`Failed to create share: ${se.status}`);const Me=await se.json();await navigator.clipboard.writeText(Me.url),w("copied"),setTimeout(()=>w("idle"),2e3)}catch(se){console.error("Share failed:",se),w("idle")}};if(!C)return null;const ve=C.final_metrics,qe=ie.filter(se=>{var Me;return se.source==="user"&&!((Me=se.extra)!=null&&Me.is_skill_output)&&$f(se)}).length,lt=ie.filter(se=>{var Me;return se.source==="user"&&((Me=se.extra)==null?void 0:Me.is_skill_output)}).length,Yt=((ve==null?void 0:ve.total_prompt_tokens)||0)+((ve==null?void 0:ve.total_completion_tokens)||0),mn=se=>se.source==="user"?typeof se.message=="string"?!!se.message.trim():se.message.length>0:se.source==="agent"||se.source==="system";return d.jsxs("div",{className:"h-full flex flex-col overflow-hidden",children:[d.jsx("div",{className:"shrink-0 bg-gradient-to-b from-zinc-900 to-zinc-900/80 border-b border-zinc-800 px-4 py-2",children:d.jsxs("div",{className:"max-w-7xl mx-auto",children:[d.jsxs("div",{className:"flex items-center justify-between mb-1 gap-3",children:[d.jsxs("div",{className:"flex items-center gap-2.5 min-w-0 flex-1",children:[d.jsx(ri,{icon:d.jsx(ud,{className:"w-3 h-3"}),label:C.session_id.slice(0,8),color:"text-zinc-300",tooltip:`Session ID: ${C.session_id}`}),d.jsx("h2",{className:"text-lg font-semibold text-zinc-100 truncate",title:C.first_message||"Session",children:C.first_message||"Session"})]}),d.jsxs("div",{className:"flex items-center gap-1 shrink-0 ml-3",children:[d.jsxs("div",{className:"flex rounded-md border border-zinc-700 mr-2",children:[d.jsxs("button",{onClick:()=>R("timeline"),className:`flex items-center gap-1 px-2.5 py-1.5 text-xs rounded-l-md transition ${O==="timeline"?ja:Ba}`,children:[d.jsx(I_,{className:"w-3 h-3"}),"Timeline"]}),d.jsxs("button",{onClick:()=>R("flow"),className:`flex items-center gap-1 px-2.5 py-1.5 text-xs rounded-r-md transition ${O==="flow"?ja:Ba}`,children:[d.jsx(Z0,{className:"w-3 h-3"}),"Flow"]})]}),!ae&&d.jsx("button",{onClick:Be,disabled:A==="sharing",className:"p-2 text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800 rounded transition text-xs disabled:opacity-50",title:A==="copied"?"Link copied!":"Share session",children:A==="copied"?d.jsx(cd,{className:"w-4 h-4 text-emerald-400"}):A==="sharing"?d.jsx(Pr,{className:"w-4 h-4 animate-spin"}):d.jsx(eb,{className:"w-4 h-4"})}),d.jsx("button",{onClick:()=>{const se=document.createElement("a");se.href=`/api/sessions/${t}/export`,se.download=`vibelens-${t.slice(0,8)}.json`,document.body.appendChild(se),se.click(),document.body.removeChild(se)},className:"p-2 text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800 rounded transition text-xs",title:"Download session",children:d.jsx(Ho,{className:"w-4 h-4"})}),d.jsx("button",{onClick:()=>he(se=>!se),className:"p-2 text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800 rounded transition text-xs",title:oe?"Collapse header":"Expand header",children:oe?d.jsx(P0,{className:"w-4 h-4"}):d.jsx(ui,{className:"w-4 h-4"})})]})]}),oe&&d.jsxs(d.Fragment,{children:[d.jsxs("div",{className:"flex flex-wrap items-center gap-1.5 mb-3",children:[C.agent.model_name&&d.jsx(ri,{icon:d.jsx(Y0,{className:"w-3 h-3"}),label:`${C.agent.name}@${C.agent.model_name}`,color:"text-amber-300",tooltip:"Agent model used for this session"}),C.timestamp&&d.jsx(ri,{icon:d.jsx(c_,{className:"w-3 h-3"}),label:BM(C.timestamp),color:"text-zinc-200",tooltip:"Session start time"}),ve&&d.jsx(ri,{icon:d.jsx(Uo,{className:"w-3 h-3"}),label:Ri(ve.duration),color:"text-cyan-400",tooltip:"Total wall-clock duration of this session"}),d.jsx(ri,{icon:d.jsx(Xr,{className:"w-3 h-3"}),label:`${qe} prompt${qe!==1?"s":""}`,color:"text-blue-400",tooltip:"User prompts — messages typed by the human operator"}),lt>0&&d.jsx(ri,{icon:d.jsx(nb,{className:"w-3 h-3"}),label:`${lt} skill${lt!==1?"s":""}`,color:"text-amber-300",tooltip:"Skill invocations — reusable prompts auto-injected by the agent"}),ve&&d.jsxs(d.Fragment,{children:[d.jsx(ri,{icon:d.jsx(Qo,{className:"w-3 h-3"}),label:`${ve.tool_call_count} tools`,color:"text-amber-400",tooltip:"Total tool calls made by the agent (Bash, Read, Edit, etc.)"}),ve.total_steps&&d.jsx(ri,{icon:d.jsx(Q0,{className:"w-3 h-3"}),label:`${ve.total_steps} steps`,color:"text-zinc-200",tooltip:"Total conversation steps including user, agent, and system turns"})]}),K.length>0&&d.jsx(ri,{icon:d.jsx(La,{className:"w-3 h-3"}),label:`${K.length} sub-agent${K.length!==1?"s":""}`,color:"text-violet-400",tooltip:"Sub-agent tasks spawned during this session"}),C.project_path&&d.jsx(ri,{icon:d.jsx(Ll,{className:"w-3 h-3"}),label:es(C.project_path),color:"text-zinc-200",tooltip:C.project_path})]}),ve&&(ve.total_prompt_tokens!=null||ve.total_completion_tokens!=null)&&d.jsxs("div",{className:`grid ${S!=null?"grid-cols-6":"grid-cols-5"} gap-2 text-xs`,children:[d.jsx($r,{icon:d.jsx(a_,{className:"w-3 h-3"}),label:"Input",value:ve.total_prompt_tokens||0,color:"text-cyan-300",tooltip:"Prompt tokens sent to the model"}),d.jsx($r,{icon:d.jsx(e_,{className:"w-3 h-3"}),label:"Output",value:ve.total_completion_tokens||0,color:"text-cyan-300",tooltip:"Completion tokens generated by the model"}),d.jsx($r,{icon:d.jsx(__,{className:"w-3 h-3"}),label:"Cache Read",value:ve.total_cache_read||0,color:"text-green-300",tooltip:"Tokens served from prompt cache (reduced cost)"}),d.jsx($r,{icon:d.jsx(O_,{className:"w-3 h-3"}),label:"Cache Write",value:ve.total_cache_write||0,color:"text-violet-300",tooltip:"Tokens written to prompt cache for future reuse"}),d.jsx($r,{icon:d.jsx(Io,{className:"w-3 h-3"}),label:"Total",value:Yt,color:"text-amber-300",tooltip:"Total tokens (input + output)"}),S!=null&&d.jsx(jM,{value:S})]})]})]})}),d.jsxs("div",{className:"flex-1 flex min-h-0",children:[d.jsx("div",{ref:U,className:"flex-1 overflow-y-auto",children:O==="timeline"?d.jsx("div",{className:"max-w-5xl mx-auto px-4 py-6 space-y-3",children:ie.length===0?d.jsxs("div",{className:"text-center text-zinc-500 text-sm py-8",children:[d.jsx(Io,{className:"w-8 h-8 mx-auto mb-2 opacity-50"}),d.jsx("p",{children:"No steps to display"})]}):d.jsxs(d.Fragment,{children:[d.jsx(bM,{entries:ie.filter(se=>{const Me=mn(se),et=ne.map.get(se.step_id);return Me||!!et}).map(se=>{const Me=mn(se),et=ne.map.get(se.step_id);return{step:se,content:d.jsxs("div",{id:`step-${se.step_id}`,style:{scrollMarginTop:"1rem"},children:[Me&&d.jsx(Cx,{step:se}),et==null?void 0:et.map(we=>d.jsx("div",{id:`subagent-${we.session_id}`,className:"mt-2",children:d.jsx(id,{trajectory:we,allTrajectories:o})},we.session_id))]})}}),sessionStartMs:C.timestamp?new Date(C.timestamp).getTime():null,sessionStartTimestamp:C.timestamp}),ne.orphans.map(se=>d.jsx("div",{id:`subagent-${se.session_id}`,children:d.jsx(id,{trajectory:se,allTrajectories:o})},se.session_id))]})}):L?d.jsx(Zo,{label:"Building flow diagram"}):q?d.jsx("div",{className:"max-w-5xl mx-auto px-4 py-6",children:d.jsx(CM,{steps:ie,flowData:q})}):d.jsx("div",{className:"flex items-center justify-center h-full",children:d.jsx("p",{className:"text-sm text-zinc-500",children:"Flow data unavailable"})})}),d.jsx(SM,{steps:ie,subAgents:K,activeStepId:b,onNavigate:xe,width:_,onResize:H,viewMode:O,flowPhases:M,activePhaseIdx:B,onPhaseNavigate:pe})]})]})}function ri({icon:t,label:a,color:l,tooltip:r}){const[o,u]=F.useState(!1),c=F.useRef(null);return d.jsxs("span",{ref:c,className:`relative inline-flex items-center gap-1 px-2 py-0.5 rounded-full bg-zinc-800 border border-zinc-700/50 text-[11px] hover:bg-zinc-700/80 transition-colors ${l}`,onMouseEnter:()=>u(!0),onMouseLeave:()=>u(!1),children:[t,d.jsx("span",{children:a}),r&&o&&d.jsx("span",{className:"absolute left-0 top-full mt-1.5 z-[100] px-2.5 py-1.5 rounded-md bg-zinc-950 border border-zinc-700 text-[11px] text-zinc-300 whitespace-nowrap shadow-lg pointer-events-none",children:r})]})}function $r({icon:t,label:a,value:l,color:r,tooltip:o}){const[u,c]=F.useState(!1);return d.jsxs("div",{className:"relative bg-zinc-800/50 rounded px-2 py-1.5",onMouseEnter:()=>c(!0),onMouseLeave:()=>c(!1),children:[d.jsxs("p",{className:`${ab} flex items-center gap-1`,children:[t,a]}),d.jsx("p",{className:`${r} font-mono`,children:fa(l)}),o&&u&&d.jsx("span",{className:"absolute left-1/2 -translate-x-1/2 top-full mt-1 z-[100] px-2.5 py-1.5 rounded-md bg-zinc-950 border border-zinc-700 text-[11px] text-zinc-300 whitespace-nowrap shadow-lg pointer-events-none",children:o})]})}function jM({value:t}){const[a,l]=F.useState(!1);return d.jsxs("div",{className:"relative bg-zinc-800/50 rounded px-2 py-1.5",onMouseEnter:()=>l(!0),onMouseLeave:()=>l(!1),children:[d.jsxs("p",{className:`${ab} flex items-center gap-1`,children:[d.jsx(V0,{className:"w-3 h-3"}),"Est. Cost"]}),d.jsx("p",{className:"text-emerald-300 font-mono",children:Ln(t)}),a&&d.jsx("span",{className:"absolute left-1/2 -translate-x-1/2 top-full mt-1 z-[100] px-2.5 py-1.5 rounded-md bg-zinc-950 border border-zinc-700 text-[11px] text-zinc-300 whitespace-nowrap shadow-lg pointer-events-none",children:"Estimated cost based on API pricing"})]})}function BM(t){const a=new Date(t);return isNaN(a.getTime())?t:a.toLocaleString(void 0,{month:"short",day:"numeric",hour:"2-digit",minute:"2-digit"})}function IM({shareToken:t}){const{fetchWithToken:a}=ss(),[l,r]=F.useState(null),[o,u]=F.useState(!0),[c,h]=F.useState("");if(F.useEffect(()=>{u(!0),h(""),a(`/api/shares/${t}`).then(p=>{if(!p.ok)throw new Error(p.status===404?"Share not found or has been revoked":`Failed to load: ${p.status}`);return p.json()}).then(p=>{if(!p.length)throw new Error("Share contains no session data");r(p)}).catch(p=>h(p.message)).finally(()=>u(!1))},[t,a]),o)return d.jsx(Zo,{label:"Loading shared session"});if(c)return d.jsx("div",{className:"flex items-center justify-center h-full p-4",children:d.jsxs("div",{className:"text-center bg-rose-900/20 border border-rose-800 rounded-lg p-6 max-w-md",children:[d.jsx("p",{className:"text-sm font-semibold text-rose-300 mb-2",children:"Failed to load shared session"}),d.jsx("p",{className:"text-xs text-rose-400 font-mono break-all",children:c})]})});if(!(l!=null&&l.length))return null;const g=l[0].session_id;return d.jsx(Rx,{sessionId:g,sharedTrajectories:l,shareToken:t})}const UM=[{type:"claude_code",label:"Claude Code"},{type:"codex",label:"Codex CLI"},{type:"gemini",label:"Gemini CLI"}],HM=[{platform:"macos",label:"macOS"},{platform:"linux",label:"Linux"},{platform:"windows",label:"Windows"}],FM="claude_code",$M="macos";function qM({onClose:t,onComplete:a}){const{fetchWithToken:l,sessionToken:r,maxZipBytes:o}=ss(),u=Math.round(o/(1024*1024)),[c,h]=F.useState("select"),[g,p]=F.useState(FM),[b,x]=F.useState($M),[_,v]=F.useState(null),[S,T]=F.useState(!1),[A,w]=F.useState(null),[O,R]=F.useState(!1),[q,Y]=F.useState(!1),[L,X]=F.useState(0),[oe,he]=F.useState("sending"),[U,re]=F.useState(null),ae=F.useRef(null);F.useEffect(()=>{c==="upload"&&(T(!0),l(`/api/upload/commands?agent_type=${g}&os_platform=${b}`).then(ie=>{if(!ie.ok)throw new Error(`HTTP ${ie.status}`);return ie.json()}).then(ie=>v(ie)).catch(()=>v({command:"# Failed to load command",description:""})).finally(()=>T(!1)))},[c,g,b,l]);const le=A?A.size>o:!1,W=F.useCallback(ie=>{ie.preventDefault(),R(!1),re(null);const k=ie.dataTransfer.files[0];k&&k.name.toLowerCase().endsWith(".zip")&&w(k)},[]),H=F.useCallback(ie=>{var M;re(null);const k=(M=ie.target.files)==null?void 0:M[0];k&&k.name.toLowerCase().endsWith(".zip")&&w(k),ie.target.value=""},[]),C=F.useCallback(()=>{if(!A)return;Y(!0),re(null),X(0),he("sending");const ie=new FormData;ie.append("file",A),ie.append("agent_type",g);const k=new XMLHttpRequest;k.open("POST","/api/upload/zip"),k.setRequestHeader("X-Session-Token",r),k.upload.onprogress=M=>{M.lengthComputable&&X(Math.round(M.loaded/M.total*100))},k.upload.onload=()=>{he("processing")},k.onload=()=>{try{const M=JSON.parse(k.responseText);k.status>=200&&k.status<300?re(M):re({files_received:1,sessions_parsed:0,steps_stored:0,skipped:0,errors:[{filename:A.name,error:M.detail||`HTTP ${k.status}`}]})}catch{re({files_received:1,sessions_parsed:0,steps_stored:0,skipped:0,errors:[{filename:A.name,error:k.responseText||`HTTP ${k.status}`}]})}Y(!1)},k.onerror=()=>{re({files_received:1,sessions_parsed:0,steps_stored:0,skipped:0,errors:[{filename:A.name,error:"Network error"}]}),Y(!1)},k.send(ie)},[A,g,r]),K=F.useCallback(()=>{U&&U.sessions_parsed>0&&a(),t()},[U,t,a]),ne=U!==null;return d.jsxs("div",{className:"fixed inset-0 z-50 flex items-center justify-center",children:[d.jsx("div",{className:"absolute inset-0 bg-black/60 backdrop-blur-sm",onClick:q?void 0:t}),d.jsxs("div",{className:"relative bg-zinc-900 border border-zinc-700 rounded-lg shadow-2xl w-full max-w-lg mx-4",children:[d.jsxs("div",{className:"flex items-center justify-between px-5 py-4 border-b border-zinc-800",children:[d.jsxs("div",{className:"flex items-center gap-2",children:[c==="upload"&&!q&&d.jsx("button",{onClick:()=>h("select"),className:"text-zinc-500 hover:text-zinc-300 transition",children:d.jsx(n_,{className:"w-4 h-4"})}),d.jsx("h2",{className:"text-sm font-semibold text-zinc-100",children:"Upload Conversation Data"})]}),d.jsx("button",{onClick:t,disabled:q,className:"text-zinc-500 hover:text-zinc-300 transition disabled:opacity-50",children:d.jsx(Ul,{className:"w-4 h-4"})})]}),d.jsxs("div",{className:"px-5 py-5",children:[c==="select"&&d.jsxs("div",{className:"space-y-5",children:[d.jsx("p",{className:"text-sm text-zinc-300",children:"Which agent and OS are you using?"}),d.jsx(F0,{label:"Agent",options:UM.map(ie=>({value:ie.type,label:ie.label})),selected:g,onSelect:ie=>p(ie)}),d.jsx(F0,{label:"Your OS",options:HM.map(ie=>({value:ie.platform,label:ie.label})),selected:b,onSelect:ie=>x(ie)}),d.jsx("div",{className:"flex justify-end pt-1",children:d.jsxs("button",{onClick:()=>h("upload"),className:"flex items-center gap-1.5 px-4 py-1.5 text-xs text-white bg-violet-600 hover:bg-violet-500 rounded transition",children:["Next",d.jsx(Di,{className:"w-3.5 h-3.5"})]})})]}),c==="upload"&&d.jsxs("div",{className:"space-y-4",children:[d.jsxs("div",{className:"space-y-1.5",children:[d.jsx("p",{className:"text-sm text-zinc-300",children:"Run this command in your terminal, then upload the zip."}),(_==null?void 0:_.description)&&d.jsx("p",{className:"text-xs text-zinc-500",children:_.description}),S?d.jsx("div",{className:"flex items-center justify-center py-4 bg-zinc-950 border border-zinc-800 rounded-lg",children:d.jsx(Pr,{className:"w-4 h-4 text-zinc-500 animate-spin"})}):d.jsxs("div",{className:"relative",children:[d.jsx("pre",{className:"bg-zinc-950 border border-zinc-800 rounded-lg p-3 pr-10 text-xs text-cyan-300 font-mono overflow-x-auto whitespace-pre-wrap break-all",children:(_==null?void 0:_.command)??""}),_&&d.jsx("div",{className:"absolute top-2 right-2",children:d.jsx(ls,{text:_.command})})]})]}),d.jsxs("div",{onDragOver:ie=>{ie.preventDefault(),R(!0)},onDragLeave:()=>R(!1),onDrop:W,onClick:()=>{var ie;return(ie=ae.current)==null?void 0:ie.click()},className:`flex flex-col items-center justify-center gap-2 p-6 border-2 border-dashed rounded-lg cursor-pointer transition ${O?"border-violet-400 bg-violet-500/10":"border-zinc-700 hover:border-zinc-500 bg-zinc-800/30"}`,children:[d.jsx(Eg,{className:`w-7 h-7 ${O?"text-violet-400":"text-zinc-500"}`}),d.jsx("p",{className:"text-sm text-zinc-300",children:"Drop .zip file here"}),d.jsxs("p",{className:"text-xs text-zinc-500",children:["or click to browse (max ",u," MB)"]}),d.jsx("input",{ref:ae,type:"file",accept:".zip",className:"hidden",onChange:H})]}),A&&d.jsxs("div",{className:"flex items-center justify-between gap-2",children:[d.jsxs("div",{className:"flex items-center gap-2 text-xs text-zinc-300 truncate min-w-0",children:[d.jsx(Eg,{className:"w-3.5 h-3.5 text-violet-400 shrink-0"}),d.jsx("span",{className:"truncate",children:A.name}),d.jsxs("span",{className:`shrink-0 ${le?"text-rose-400":"text-zinc-500"}`,children:["(",(A.size/(1024*1024)).toFixed(1)," MB)"]}),d.jsx("button",{onClick:ie=>{ie.stopPropagation(),w(null),re(null)},className:"text-zinc-500 hover:text-rose-400 transition shrink-0",children:d.jsx(sv,{className:"w-3.5 h-3.5"})})]}),d.jsx("button",{onClick:ne?K:C,disabled:q||le,className:"flex items-center gap-1.5 px-3 py-1.5 text-xs text-white bg-violet-600 hover:bg-violet-500 rounded transition disabled:opacity-40 disabled:cursor-not-allowed shrink-0",children:q?oe==="processing"?d.jsxs(d.Fragment,{children:[d.jsx(Pr,{className:"w-3.5 h-3.5 animate-spin"}),"Processing..."]}):d.jsxs(d.Fragment,{children:[d.jsx(Pr,{className:"w-3.5 h-3.5 animate-spin"}),L,"%"]}):ne?"Done":d.jsxs(d.Fragment,{children:[d.jsx(cv,{className:"w-3.5 h-3.5"}),"Upload"]})})]}),A&&le&&d.jsxs("p",{className:"text-xs text-rose-400",children:["File exceeds the ",u," MB limit. Try excluding large sessions or splitting the archive."]}),q&&d.jsxs("div",{className:"space-y-1.5",children:[d.jsx("div",{className:"w-full h-1.5 bg-zinc-800 rounded-full overflow-hidden",children:oe==="sending"?d.jsx("div",{className:"h-full bg-violet-500 rounded-full transition-all duration-300",style:{width:`${L}%`}}):d.jsx("div",{className:"h-full bg-violet-500 rounded-full animate-pulse w-full"})}),d.jsx("p",{className:"text-[10px] text-zinc-500 text-center",children:oe==="sending"?`Uploading — ${L}% of ${(((A==null?void 0:A.size)??0)/(1024*1024)).toFixed(0)} MB`:"Server is extracting and parsing sessions…"})]}),U&&d.jsx(GM,{result:U})]})]})]})]})}function F0({label:t,options:a,selected:l,onSelect:r}){return d.jsxs("div",{className:"flex items-center gap-3",children:[d.jsx("span",{className:"text-xs text-zinc-400 w-14 shrink-0",children:t}),d.jsx("div",{className:"flex gap-1.5",children:a.map(o=>d.jsx("button",{onClick:()=>r(o.value),className:`px-3 py-1 text-xs rounded-full transition ${l===o.value?"bg-violet-600 text-white":"bg-zinc-800 text-zinc-400 border border-zinc-700 hover:border-zinc-500 hover:text-zinc-200"}`,children:o.label},o.value))})]})}function GM({result:t}){const a=t.errors.length>0;return d.jsxs("div",{className:"space-y-2",children:[d.jsxs("div",{className:"grid grid-cols-3 gap-2 text-xs",children:[d.jsx(jf,{label:"Sessions",value:t.sessions_parsed}),d.jsx(jf,{label:"Steps",value:t.steps_stored}),d.jsx(jf,{label:"Skipped",value:t.skipped})]}),a&&d.jsxs("div",{className:"p-2.5 bg-rose-900/20 border border-rose-800/50 rounded text-xs text-rose-300 space-y-0.5",children:[d.jsx("p",{className:"font-medium",children:"Errors:"}),t.errors.slice(0,5).map((l,r)=>d.jsxs("p",{className:"text-rose-400",children:[l.filename?`${l.filename}: `:"",l.error]},r))]})]})}function jf({label:t,value:a}){return d.jsxs("div",{className:"bg-zinc-800/50 rounded px-2.5 py-1.5",children:[d.jsx("p",{className:"text-[10px] text-zinc-500",children:t}),d.jsx("p",{className:"text-zinc-200 font-mono text-sm",children:a})]})}function PM(t){if(t.length<2)return t;const a=[...t].sort((c,h)=>c.date.localeCompare(h.date)),l=[],r=new Date(a[0].date+"T00:00:00"),o=new Date(a[a.length-1].date+"T00:00:00"),u=new Map(a.map(c=>[c.date,c]));for(let c=new Date(r);c<=o;c.setDate(c.getDate()+1)){const h=c.toISOString().slice(0,10);l.push(u.get(h)||{date:h,session_count:0,total_messages:0,total_tokens:0,total_duration:0,total_duration_hours:0,total_cost_usd:0})}return l}function YM(t,a){if(a==="day")return t;const l=new Map;for(const r of t){const o=a==="month"?r.date.slice(0,7):r.date.slice(0,4),u=l.get(o);u?(u.session_count+=r.session_count,u.total_messages+=r.total_messages,u.total_tokens+=r.total_tokens,u.total_duration+=r.total_duration,u.total_duration_hours+=r.total_duration_hours,u.total_cost_usd+=r.total_cost_usd):l.set(o,{...r,date:o})}return[...l.values()].sort((r,o)=>r.date.localeCompare(o.date))}function jo(t){return t==="unknown"?"Unknown":t}function VM(t,a){if(t===0)return zl[0];const l=t/a;return l<=.25?zl[1]:l<=.5?zl[2]:l<=.75?zl[3]:zl[4]}function KM(t){const a=t.getFullYear(),l=String(t.getMonth()+1).padStart(2,"0"),r=String(t.getDate()).padStart(2,"0");return`${a}-${l}-${r}`}function XM({data:t,onHover:a,onMove:l,onLeave:r}){const{weeks:o,monthLabels:u,maxVal:c,yearTotal:h}=F.useMemo(()=>{const x=new Date,_=[],v=[],S=(x.getDay()+6)%7,T=new Date(x);T.setDate(x.getDate()-S-(zf-1)*7);let A=-1,w=0;for(let q=0;q<zf;q++){const Y=[];for(let L=0;L<7;L++){const X=new Date(T);if(X.setDate(T.getDate()+q*7+L),X>x){Y.push({date:"",count:0,dayOfWeek:L});continue}const oe=KM(X),he=t[oe]||0;w+=he,Y.push({date:oe,count:he,dayOfWeek:L}),L===0&&X.getMonth()!==A&&(A=X.getMonth(),v.push({month:hM[A],weekIndex:q}))}_.push(Y)}const O=Object.values(t),R=Math.max(1,...O);return{weeks:_,monthLabels:v,maxVal:R,yearTotal:w}},[t]),g=Rf+zf*(zi+Al)+10,p=Df+7*(zi+Al)+10,b=x=>{if(!x)return"";const _=new Date(x+"T00:00:00"),v=["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],S=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];return`${v[_.getDay()]}, ${S[_.getMonth()]} ${_.getDate()}, ${_.getFullYear()}`};return d.jsxs("div",{children:[d.jsxs("div",{className:"flex items-center justify-between mb-3",children:[d.jsxs("p",{className:"text-[13px] text-zinc-300 cursor-default",onMouseEnter:x=>a(x,"GitHub-style heatmap showing daily session activity over the past year"),onMouseMove:l,onMouseLeave:r,children:[d.jsx("span",{className:"text-cyan-400 font-semibold",children:h.toLocaleString()})," ","sessions in the last year"]}),d.jsxs("div",{className:"flex items-center gap-1.5 text-xs text-zinc-400",children:[d.jsx("span",{children:"Less"}),zl.slice(1).map((x,_)=>d.jsx("div",{className:"w-2.5 h-2.5 rounded-sm",style:{backgroundColor:x}},_)),d.jsx("span",{children:"More"})]})]}),d.jsx("div",{className:"overflow-x-auto",children:d.jsxs("svg",{width:g,height:p,className:"text-zinc-400",children:[u.map(({month:x,weekIndex:_},v)=>d.jsx("text",{x:Rf+_*(zi+Al),y:12,fill:"currentColor",fontSize:11,children:x},`${x}-${v}`)),mM.map((x,_)=>x&&d.jsx("text",{x:0,y:Df+_*(zi+Al)+zi/2+4,fill:"currentColor",fontSize:10,children:x},x)),o.map((x,_)=>x.map(v=>v.date?d.jsx("rect",{x:Rf+_*(zi+Al),y:Df+v.dayOfWeek*(zi+Al),width:zi,height:zi,rx:2,fill:VM(v.count,c),onMouseEnter:S=>a(S,`${b(v.date)}
${v.count} session${v.count!==1?"s":""}`),onMouseMove:l,onMouseLeave:r,className:"cursor-default"},v.date):null))]})})]})}function ZM({label:t,value:a,max:l,tooltipText:r,onClick:o,onHover:u,onMove:c,onLeave:h}){const g=l>0?a/l*100:0;return d.jsxs("button",{onClick:o,disabled:!o,className:"flex items-center gap-2.5 text-[13px] w-full text-left hover:bg-zinc-800/60 px-2.5 py-1.5 rounded-md transition disabled:cursor-default group",onMouseEnter:p=>u(p,r),onMouseMove:c,onMouseLeave:h,children:[d.jsx("span",{className:"w-32 truncate text-zinc-300 group-hover:text-zinc-100 transition-colors",title:t,children:t}),d.jsx("div",{className:"flex-1 h-5 bg-zinc-800/60 rounded-md overflow-hidden",children:d.jsx("div",{className:"h-full bg-gradient-to-r from-cyan-600 to-cyan-400 rounded-md transition-all",style:{width:`${g}%`}})}),d.jsx("span",{className:"w-10 text-right text-zinc-300 tabular-nums font-medium",children:a})]})}function QM({data:t,onHover:a,onMove:l,onLeave:r}){const o=F.useMemo(()=>Object.entries(t).sort(([,h],[,g])=>g-h),[t]),u=o.reduce((h,[,g])=>h+g,0),c=o.map(([h,g],p)=>({model:h,count:g,pct:u>0?g/u*100:0,color:Do[p%Do.length]}));return d.jsxs("div",{className:"space-y-3",children:[d.jsx("div",{className:"h-4 rounded-full overflow-hidden flex bg-zinc-800",children:c.map(h=>d.jsx("div",{className:`h-full ${h.color} cursor-default`,style:{width:`${h.pct}%`},onMouseEnter:g=>a(g,`${jo(h.model)}
${h.count} session${h.count!==1?"s":""} (${h.pct.toFixed(1)}%)`),onMouseMove:l,onMouseLeave:r},h.model))}),d.jsxs("div",{className:"space-y-1.5",children:[o.map(([h,g],p)=>{const b=u>0?(g/u*100).toFixed(1):"0";return d.jsxs("div",{className:"flex items-center gap-2.5 text-[13px] cursor-default",onMouseEnter:x=>a(x,`${jo(h)}
${g} session${g!==1?"s":""} (${b}%)`),onMouseMove:l,onMouseLeave:r,children:[d.jsx("span",{className:`w-3 h-3 rounded-sm shrink-0 ${Do[p%Do.length]}`}),d.jsx("span",{className:"flex-1 text-zinc-300 truncate",title:jo(h),children:jo(h)}),d.jsxs("span",{className:"text-zinc-400 tabular-nums",children:[g," (",b,"%)"]})]},h)}),o.length===0&&d.jsx("p",{className:"text-sm text-zinc-500",children:"No data"})]})]})}function JM({data:t,onHover:a,onMove:l,onLeave:r}){const o=F.useMemo(()=>Array.from({length:dM},(c,h)=>{const g=h*2,p=g+1,b=t[g]??t[String(g)]??0,x=t[p]??t[String(p)]??0;return{label:`${String(g).padStart(2,"0")}`,rangeLabel:`${String(g).padStart(2,"0")}:00 – ${String(p).padStart(2,"0")}:59`,count:b+x}}),[t]),u=Math.max(1,...o.map(c=>c.count));return d.jsxs("div",{children:[d.jsx("div",{className:"flex items-end gap-1.5 h-24",children:o.map(c=>{const h=c.count/u*100;return d.jsx("div",{className:"flex-1 flex flex-col items-center justify-end h-full cursor-default",onMouseEnter:g=>a(g,`${c.rangeLabel}
${c.count} session${c.count!==1?"s":""}`),onMouseMove:l,onMouseLeave:r,children:d.jsx("div",{className:"w-full bg-gradient-to-t from-cyan-600 to-cyan-400 rounded-t transition-all",style:{height:`${Math.max(h,c.count>0?4:0)}%`}})},c.label)})}),d.jsx("div",{className:"flex gap-1.5 mt-1.5",children:o.map((c,h)=>d.jsx("div",{className:"flex-1 text-center text-[10px] text-zinc-400",children:h%2===0?c.label:""},c.label))})]})}function qr({icon:t,label:a,description:l,value:r,rows:o,tooltipText:u,onHover:c,onMove:h,onLeave:g}){return d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 px-5 py-5 flex flex-col gap-3 hover:border-zinc-500/60 transition-colors cursor-default",onMouseEnter:p=>c(p,u),onMouseMove:h,onMouseLeave:g,children:[d.jsxs("div",{className:"flex items-center justify-between",children:[d.jsxs("div",{children:[d.jsx("span",{className:"text-xs font-semibold text-zinc-200 uppercase tracking-wider",children:a}),l&&d.jsx("p",{className:_v,children:l})]}),d.jsx("div",{className:"text-cyan-400/70",children:t})]}),d.jsx("div",{className:"text-3xl font-bold text-cyan-400 tabular-nums tracking-tight",children:r}),d.jsx("div",{className:"border-t border-zinc-700/40 pt-2.5 space-y-1.5",children:o.map(p=>d.jsxs("div",{className:"flex items-center justify-between text-[13px]",onMouseEnter:b=>{p.tooltipText&&(b.stopPropagation(),c(b,p.tooltipText))},onMouseMove:b=>{p.tooltipText&&(b.stopPropagation(),h(b))},onMouseLeave:b=>{p.tooltipText&&(b.stopPropagation(),g())},children:[d.jsx("span",{className:"text-zinc-400",children:p.label}),d.jsx("span",{className:"text-zinc-200 tabular-nums font-medium",children:p.value})]},p.label))})]})}const $0=12;function WM({data:t,totalCalls:a,onHover:l,onMove:r,onLeave:o}){const{visible:u,otherCount:c}=F.useMemo(()=>{const b=t.slice(0,$0),x=t.slice($0).reduce((_,v)=>_+v.call_count,0);return{visible:b,otherCount:x}},[t]),h=a||t.reduce((b,x)=>b+x.call_count,0),g=F.useMemo(()=>{const b=u.map((x,_)=>({name:x.tool_name,count:x.call_count,pct:h>0?x.call_count/h*100:0,avgPerSession:x.avg_per_session,errorRate:x.error_rate,color:Lo[_%Lo.length]}));return c>0&&b.push({name:"Other",count:c,pct:h>0?c/h*100:0,avgPerSession:0,errorRate:0,color:"bg-zinc-600"}),b},[u,c,h]),p=b=>{const x=[b.name,`${b.count.toLocaleString()} calls (${b.pct.toFixed(1)}%)`];return b.avgPerSession>0&&x.push(`Avg ${b.avgPerSession}/session`),b.errorRate>0&&x.push(`Error rate: ${(b.errorRate*100).toFixed(1)}%`),x.join(`
`)};return t.length===0?d.jsx("p",{className:"text-sm text-zinc-500",children:"No data"}):d.jsxs("div",{className:"space-y-3",children:[d.jsx("div",{className:"h-4 rounded-full overflow-hidden flex bg-zinc-800",children:g.map(b=>d.jsx("div",{className:`h-full ${b.color} cursor-default`,style:{width:`${b.pct}%`},onMouseEnter:x=>l(x,p(b)),onMouseMove:r,onMouseLeave:o},b.name))}),d.jsx("div",{className:"space-y-1.5",children:g.map((b,x)=>d.jsxs("div",{className:"flex items-center gap-2.5 text-[13px] cursor-default",onMouseEnter:_=>l(_,p(b)),onMouseMove:r,onMouseLeave:o,children:[d.jsx("span",{className:`w-3 h-3 rounded-sm shrink-0 ${b.name==="Other"?"bg-zinc-600":Lo[x%Lo.length]}`}),d.jsx("span",{className:"flex-1 text-zinc-300 truncate",title:b.name,children:b.name}),d.jsxs("span",{className:"text-zinc-400 tabular-nums",children:[b.count.toLocaleString()," (",b.pct.toFixed(1),"%)"]})]},b.name))})]})}const Gr=800,ad=200,Rl=55,ld=15,Qn=12,eC=28,Bf=Gr-Rl-ld,si=ad-Qn-eC;function tC({data:t,onHover:a,onMove:l,onLeave:r}){const[o,u]=F.useState("sessions"),[c,h]=F.useState("day"),[g,p]=F.useState(null),b=F.useRef(null),x=F.useMemo(()=>PM(t),[t]),_=F.useMemo(()=>YM(x,c),[x,c]),v=F.useMemo(()=>_.map(le=>{switch(o){case"sessions":return le.session_count;case"messages":return le.total_messages;case"tokens":return le.total_tokens;case"cost":return le.total_cost_usd}}),[_,o]),S=Math.max(1,...v),T=_.length===1,A=F.useMemo(()=>v.map((le,W)=>({x:Rl+(_.length>1?W/(_.length-1)*Bf:Bf/2),y:Qn+si-le/S*si})),[v,S,_.length]),w=A.map((le,W)=>`${W===0?"M":"L"}${le.x},${le.y}`).join(" "),O=w+` L${A[A.length-1].x},${Qn+si} L${A[0].x},${Qn+si} Z`,R=[.25,.5,.75,1],q=R.map(le=>Qn+si*(1-le)),Y=le=>o==="tokens"?fa(le):o==="cost"?Ln(le):String(Math.round(le)),L=Math.max(1,Math.ceil(_.length/7)),X=le=>c==="year"||c==="month"?le:le.slice(5),oe=F.useCallback(le=>{const W=b.current;if(!W||A.length===0)return null;const H=W.getBoundingClientRect(),C=(le-H.left)/H.width*Gr;let K=0,ne=Math.abs(C-A[0].x);for(let ie=1;ie<A.length;ie++){const k=Math.abs(C-A[ie].x);k<ne&&(ne=k,K=ie)}return K},[A]),he=F.useCallback(le=>{const W=oe(le.clientX);if(W===null)return;p(W);const H=_[W],C=[H.date,`Sessions: ${H.session_count}`,`Messages: ${H.total_messages.toLocaleString()}`,`Tokens: ${H.total_tokens.toLocaleString()}`,`Cost: ${Ln(H.total_cost_usd)}`];a(le,C.join(`
`)),l(le)},[oe,_,a,l]),U=F.useCallback(()=>{p(null),r()},[r]),re=[{key:"sessions",label:"Sessions"},{key:"messages",label:"Messages"},{key:"tokens",label:"Tokens"},{key:"cost",label:"Cost"}],ae=[{key:"day",label:"Day"},{key:"month",label:"Month"},{key:"year",label:"Year"}];return _.length<1?d.jsxs("div",{children:[d.jsx("h3",{className:"text-base font-medium text-zinc-200 mb-3",children:"Usage Over Time"}),d.jsx("p",{className:"text-sm text-zinc-400 py-8 text-center",children:"No data available"})]}):d.jsxs("div",{children:[d.jsxs("div",{className:"flex items-center justify-between mb-3",children:[d.jsx("h3",{className:"text-base font-medium text-zinc-200",children:"Usage Over Time"}),d.jsxs("div",{className:"flex items-center gap-3",children:[d.jsx("div",{className:"flex gap-1",children:ae.map(le=>d.jsx("button",{onClick:()=>h(le.key),className:`px-2 py-1 text-xs font-medium rounded-md transition ${c===le.key?ja:`${Ba} hover:bg-zinc-800`}`,children:le.label},le.key))}),d.jsx("div",{className:"w-px h-4 bg-zinc-700"}),d.jsx("div",{className:"flex gap-1",children:re.map(le=>d.jsx("button",{onClick:()=>u(le.key),className:`px-2.5 py-1 text-xs font-medium rounded-md transition ${o===le.key?"bg-cyan-600 text-white":"text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800"}`,children:le.label},le.key))})]})]}),d.jsxs("svg",{ref:b,viewBox:`0 0 ${Gr} ${ad}`,className:"w-full",preserveAspectRatio:"xMidYMid meet",children:[d.jsx("defs",{children:d.jsxs("linearGradient",{id:"areaGrad",x1:"0",y1:"0",x2:"0",y2:"1",children:[d.jsx("stop",{offset:"0%",stopColor:"rgba(34,211,238,0.3)"}),d.jsx("stop",{offset:"100%",stopColor:"rgba(34,211,238,0.02)"})]})}),q.map((le,W)=>d.jsxs("g",{children:[d.jsx("line",{x1:Rl,y1:le,x2:Gr-ld,y2:le,stroke:"rgba(255,255,255,0.06)"}),d.jsx("text",{x:Rl-8,y:le+4,fill:"#a1a1aa",fontSize:10,textAnchor:"end",children:Y(S*R[W])})]},W)),d.jsx("line",{x1:Rl,y1:Qn+si,x2:Gr-ld,y2:Qn+si,stroke:"rgba(255,255,255,0.08)"}),T?d.jsx("rect",{x:A[0].x-30,y:A[0].y,width:60,height:Qn+si-A[0].y,fill:"url(#areaGrad)",stroke:"rgb(34,211,238)",strokeWidth:2,rx:4}):d.jsxs(d.Fragment,{children:[d.jsx("path",{d:O,fill:"url(#areaGrad)"}),d.jsx("path",{d:w,fill:"none",stroke:"rgb(34,211,238)",strokeWidth:2})]}),!T&&A.map((le,W)=>d.jsx("circle",{cx:le.x,cy:le.y,r:g===W?5:3,fill:"rgb(34,211,238)",className:"pointer-events-none transition-all"},W)),g!==null&&A[g]&&d.jsx("line",{x1:A[g].x,y1:Qn,x2:A[g].x,y2:Qn+si,stroke:"rgba(34,211,238,0.4)",strokeWidth:1,strokeDasharray:"4 3",className:"pointer-events-none"}),d.jsx("rect",{x:Rl,y:Qn,width:Bf,height:si,fill:"transparent",className:"cursor-crosshair",onMouseMove:he,onMouseLeave:U}),_.map((le,W)=>W%L!==0&&W!==_.length-1?null:d.jsx("text",{x:A[W].x,y:ad-6,fill:"#a1a1aa",fontSize:10,textAnchor:"middle",children:X(le.date)},le.date))]})]})}function nC({cache:t}){var le,W;const{fetchWithToken:a}=ss(),[l,r]=F.useState((t==null?void 0:t.stats)??null),[o,u]=F.useState((t==null?void 0:t.toolUsage)??[]),[c,h]=F.useState(!t),[g,p]=F.useState(null),[b,x]=F.useState(null),[_,v]=F.useState(null),[S,T]=F.useState(!1),{tip:A,show:w,move:O,hide:R}=Rd();F.useEffect(()=>{t&&!l&&(r(t.stats),u(t.toolUsage),h(!1))},[t,l]),F.useEffect(()=>{t||l||b||Promise.all([a("/api/analysis/dashboard").then(H=>H.ok?H.json():null),a("/api/analysis/tool-usage").then(H=>H.ok?H.json():[]).catch(()=>[])]).then(([H,C])=>{H?(r(H),u(C)):p("Failed to load dashboard data")}).catch(H=>p(String(H))).finally(()=>h(!1))},[t,l,a,b]),F.useEffect(()=>{if(!b)return;h(!0),p(null);const H=new URLSearchParams;H.set("project_path",b),Promise.all([a(`/api/analysis/dashboard?${H}`).then(C=>{if(!C.ok)throw new Error(`HTTP ${C.status}`);return C.json()}),a(`/api/analysis/tool-usage?${H}`).then(C=>C.ok?C.json():[]).catch(()=>[])]).then(([C,K])=>{r(C),u(K)}).catch(C=>p(String(C))).finally(()=>h(!1))},[a,b]);const q=F.useCallback(()=>{x(null),t&&(r(t.stats),u(t.toolUsage))},[t]),Y=async H=>{v(H);const C=new URLSearchParams({format:H});b&&C.set("project_path",b);try{const K=await a(`/api/analysis/dashboard/export?${C}`);if(!K.ok)return;const ne=await K.blob(),ie=URL.createObjectURL(ne),k=document.createElement("a");k.href=ie,k.download=`vibelens-dashboard.${H}`,k.click(),URL.revokeObjectURL(ie)}catch(K){console.error("Export failed:",K)}finally{v(null)}};if(c)return d.jsx(Zo,{label:"Loading dashboard"});if(g||!l)return d.jsx("div",{className:"flex items-center justify-center h-full text-red-400",children:g||"Failed to load dashboard"});const L=10,X=Object.entries(l.project_distribution).sort(([,H],[,C])=>C-H),oe=S?X:X.slice(0,L),he=X.length>L,U=((le=X[0])==null?void 0:le[1])??0,re=Object.entries(l.agent_distribution).sort(([,H],[,C])=>C-H),ae=((W=re[0])==null?void 0:W[1])??0;return d.jsxs("div",{className:"h-full overflow-y-auto",children:[d.jsx(zd,{state:A}),d.jsxs("div",{className:"max-w-[1400px] mx-auto p-6 space-y-5",children:[d.jsxs("div",{className:"flex items-center justify-between",children:[d.jsx("div",{className:"flex items-center gap-3",children:b?d.jsxs(d.Fragment,{children:[d.jsx("button",{onClick:q,className:"text-sm text-cyan-400 hover:text-cyan-300 transition font-medium",children:"All Sessions"}),d.jsx("span",{className:"text-zinc-600",children:"/"}),d.jsx("span",{className:"text-sm text-zinc-200 font-medium",children:es(b)})]}):d.jsx("h2",{className:"text-xl font-semibold text-zinc-100",children:"Analytics Dashboard"})}),d.jsxs("div",{className:"flex items-center gap-1.5",children:[d.jsxs("button",{onClick:()=>Y("csv"),disabled:_!==null,className:"flex items-center gap-1.5 px-3 py-1.5 text-xs font-medium text-zinc-300 hover:text-zinc-100 bg-zinc-800/80 hover:bg-zinc-700 rounded-lg border border-zinc-700/50 transition disabled:opacity-50 disabled:cursor-not-allowed",onMouseEnter:H=>w(H,"Export all dashboard data as CSV"),onMouseMove:O,onMouseLeave:R,children:[_==="csv"?d.jsx("div",{className:"w-3.5 h-3.5 border-2 border-zinc-400/30 border-t-zinc-300 rounded-full animate-spin"}):d.jsx(Ho,{className:"w-3.5 h-3.5"}),_==="csv"?"Exporting...":"CSV"]}),d.jsxs("button",{onClick:()=>Y("json"),disabled:_!==null,className:"flex items-center gap-1.5 px-3 py-1.5 text-xs font-medium text-zinc-300 hover:text-zinc-100 bg-zinc-800/80 hover:bg-zinc-700 rounded-lg border border-zinc-700/50 transition disabled:opacity-50 disabled:cursor-not-allowed",onMouseEnter:H=>w(H,"Export all dashboard data as JSON"),onMouseMove:O,onMouseLeave:R,children:[_==="json"?d.jsx("div",{className:"w-3.5 h-3.5 border-2 border-zinc-400/30 border-t-zinc-300 rounded-full animate-spin"}):d.jsx(Ho,{className:"w-3.5 h-3.5"}),_==="json"?"Exporting...":"JSON"]})]})]}),d.jsxs("div",{className:"grid grid-cols-5 gap-4",children:[d.jsx(qr,{icon:d.jsx(Xr,{className:"w-4 h-4"}),label:"Sessions",description:"All agent sessions",value:l.total_sessions.toLocaleString(),rows:[{label:"This Year",value:l.this_year.sessions.toLocaleString()},{label:"This Month",value:l.this_month.sessions.toLocaleString()},{label:"This Week",value:l.this_week.sessions.toLocaleString()}],tooltipText:[`Total: ${l.total_sessions} sessions`,`${l.project_count} projects`,`This Year: ${l.this_year.sessions}`,`This Month: ${l.this_month.sessions}`,`This Week: ${l.this_week.sessions}`].join(`
`),onHover:w,onMove:O,onLeave:R}),d.jsx(qr,{icon:d.jsx(ud,{className:"w-4 h-4"}),label:"Messages",description:"User + agent turns",value:l.total_messages.toLocaleString(),rows:[{label:"This Year",value:l.this_year.messages.toLocaleString()},{label:"This Month",value:l.this_month.messages.toLocaleString()},{label:"Avg/Session",value:l.avg_messages_per_session.toFixed(1)}],tooltipText:[`Total: ${l.total_messages.toLocaleString()} messages`,`This Year: ${l.this_year.messages.toLocaleString()}`,`Avg: ${l.avg_messages_per_session.toFixed(1)} per session`].join(`
`),onHover:w,onMove:O,onLeave:R}),d.jsx(qr,{icon:d.jsx(Io,{className:"w-4 h-4"}),label:"Tokens",description:"Input + output tokens",value:fa(l.total_tokens),rows:[{label:"This Year",value:fa(l.this_year.tokens),tooltipText:[`This Year: ${l.this_year.tokens.toLocaleString()}`,`Input: ${l.this_year.input_tokens.toLocaleString()}`,`Output: ${l.this_year.output_tokens.toLocaleString()}`,`Cache Read: ${l.this_year.cache_read_tokens.toLocaleString()}`,`Cache Write: ${l.this_year.cache_creation_tokens.toLocaleString()}`].join(`
`)},{label:"This Month",value:fa(l.this_month.tokens),tooltipText:[`This Month: ${l.this_month.tokens.toLocaleString()}`,`Input: ${l.this_month.input_tokens.toLocaleString()}`,`Output: ${l.this_month.output_tokens.toLocaleString()}`,`Cache Read: ${l.this_month.cache_read_tokens.toLocaleString()}`,`Cache Write: ${l.this_month.cache_creation_tokens.toLocaleString()}`].join(`
`)},{label:"Avg/Session",value:fa(Math.round(l.avg_tokens_per_session)),tooltipText:[`Avg/Session: ${Math.round(l.avg_tokens_per_session).toLocaleString()}`,`Total Input: ${l.total_input_tokens.toLocaleString()}`,`Total Output: ${l.total_output_tokens.toLocaleString()}`,`Total Cache Read: ${l.total_cache_read_tokens.toLocaleString()}`,`Total Cache Write: ${l.total_cache_creation_tokens.toLocaleString()}`].join(`
`)}],tooltipText:[`Total: ${l.total_tokens.toLocaleString()}`,`Input: ${l.total_input_tokens.toLocaleString()}`,`Output: ${l.total_output_tokens.toLocaleString()}`,`Cache: ${l.total_cache_tokens.toLocaleString()}`].join(`
`),onHover:w,onMove:O,onLeave:R}),d.jsx(qr,{icon:d.jsx(Uo,{className:"w-4 h-4"}),label:"Duration",description:"Total session time",value:Ri(l.total_duration),rows:[{label:"This Year",value:Ri(l.this_year.duration)},{label:"This Month",value:Ri(l.this_month.duration)},{label:"Avg/Session",value:Ri(l.avg_duration_per_session)}],tooltipText:[`Total: ${Ri(l.total_duration)}`,`This Year: ${Ri(l.this_year.duration)}`,`This Month: ${Ri(l.this_month.duration)}`,`Avg/Session: ${Ri(l.avg_duration_per_session)}`].join(`
`),onHover:w,onMove:O,onLeave:R}),d.jsx(qr,{icon:d.jsx(V0,{className:"w-4 h-4"}),label:"Estimated Cost",description:"API pricing estimate",value:Ln(l.total_cost_usd),rows:[{label:"This Year",value:Ln(l.this_year.cost_usd)},{label:"This Month",value:Ln(l.this_month.cost_usd)},{label:"Avg/Session",value:Ln(l.avg_cost_per_session)}],tooltipText:[`Total: ${Ln(l.total_cost_usd)}`,`This Year: ${Ln(l.this_year.cost_usd)}`,`This Month: ${Ln(l.this_month.cost_usd)}`,`Avg/Session: ${Ln(l.avg_cost_per_session)}`].join(`
`),onHover:w,onMove:O,onLeave:R})]}),d.jsx("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:d.jsx(tC,{data:l.daily_stats,onHover:w,onMove:O,onLeave:R})}),d.jsx("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:d.jsx(XM,{data:l.daily_activity,onHover:w,onMove:O,onLeave:R})}),d.jsxs("div",{className:"grid grid-cols-2 gap-4",children:[d.jsxs("div",{className:"space-y-4",children:[d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:[d.jsxs("div",{className:"flex items-center gap-2 mb-3",children:[d.jsx(Uo,{className:"w-4 h-4 text-cyan-400"}),d.jsx("h3",{className:"text-base font-medium text-zinc-200 cursor-default",onMouseEnter:H=>w(H,"Distribution of session starts by hour of day"),onMouseMove:O,onMouseLeave:R,children:"Peak Hours"}),d.jsxs("span",{className:"text-xs text-zinc-500 cursor-default",onMouseEnter:H=>w(H,`All times shown in ${l.timezone} timezone`),onMouseMove:O,onMouseLeave:R,children:["(",l.timezone,")"]})]}),d.jsx(JM,{data:l.hourly_distribution,onHover:w,onMove:O,onLeave:R})]}),d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:[d.jsxs("div",{className:"flex items-center justify-between mb-4",children:[d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx(Ll,{className:"w-4 h-4 text-cyan-400"}),d.jsx("h3",{className:"text-base font-medium text-zinc-200 cursor-default",onMouseEnter:H=>w(H,`Per-project breakdown (${X.length} total). Click to filter.`),onMouseMove:O,onMouseLeave:R,children:"Project Activity"})]}),he&&d.jsx("button",{onClick:()=>T(H=>!H),className:"px-2.5 py-1 text-xs font-medium text-cyan-400 hover:text-cyan-300 bg-cyan-400/10 hover:bg-cyan-400/20 rounded-md border border-cyan-400/20 transition",children:S?"Top 10":`All ${X.length}`})]}),d.jsxs("div",{className:"space-y-1.5",children:[oe.map(([H,C])=>{var ne;const K=(ne=l.project_details)==null?void 0:ne[H];return d.jsx(iC,{project:H,count:C,detail:K,max:U,totalSessions:l.total_sessions,onClick:()=>x(H),onHover:w,onMove:O,onLeave:R},H)}),oe.length===0&&d.jsx("p",{className:"text-sm text-zinc-500",children:"No data"})]})]})]}),d.jsxs("div",{className:"space-y-4",children:[re.length>1&&d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:[d.jsxs("div",{className:"flex items-center gap-2 mb-4",children:[d.jsx(La,{className:"w-4 h-4 text-cyan-400"}),d.jsx("h3",{className:"text-base font-medium text-zinc-200 cursor-default",onMouseEnter:H=>w(H,"Session count breakdown by agent (Claude Code, Codex, Gemini)"),onMouseMove:O,onMouseLeave:R,children:"Agent Distribution"})]}),d.jsx("div",{className:"space-y-1",children:re.map(([H,C])=>d.jsx(ZM,{label:H,value:C,max:ae,tooltipText:[H,`${C} session${C!==1?"s":""}`,`${(C/l.total_sessions*100).toFixed(1)}% of total`].join(`
`),onHover:w,onMove:O,onLeave:R},H))})]}),d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:[d.jsxs("div",{className:"flex items-center gap-2 mb-4",children:[d.jsx(Y0,{className:"w-4 h-4 text-cyan-400"}),d.jsx("h3",{className:"text-base font-medium text-zinc-200 cursor-default",onMouseEnter:H=>w(H,"Session count breakdown by AI model"),onMouseMove:O,onMouseLeave:R,children:"Model Distribution"})]}),d.jsx(QM,{data:l.model_distribution,onHover:w,onMove:O,onLeave:R})]}),o.length>0&&d.jsxs("div",{className:"rounded-xl border border-zinc-700/60 bg-zinc-900/80 p-5",children:[d.jsxs("div",{className:"flex items-center justify-between mb-4",children:[d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx(Qo,{className:"w-4 h-4 text-cyan-400"}),d.jsx("h3",{className:"text-base font-medium text-zinc-200 cursor-default",onMouseEnter:H=>w(H,`Tool call distribution (${l.total_tool_calls.toLocaleString()} total, avg ${l.avg_tool_calls_per_session.toFixed(1)}/session)`),onMouseMove:O,onMouseLeave:R,children:"Tool Distribution"})]}),d.jsxs("span",{className:"text-xs text-zinc-500",children:[l.total_tool_calls.toLocaleString()," total"]})]}),d.jsx(WM,{data:o,totalCalls:l.total_tool_calls,onHover:w,onMove:O,onLeave:R})]})]})]})]})]})}function iC({project:t,count:a,detail:l,max:r,totalSessions:o,onClick:u,onHover:c,onMove:h,onLeave:g}){const p=r>0?a/r*100:0,b=es(t),x=[b,`${a} session${a!==1?"s":""}`,`${(a/o*100).toFixed(1)}% of total`];return l&&x.push(`${l.messages.toLocaleString()} messages`,`${fa(l.tokens)} tokens`,`${Ln(l.cost_usd)} est. cost`),d.jsxs("button",{onClick:u,className:"flex flex-col gap-1 w-full text-left hover:bg-zinc-800/60 px-3 py-2 rounded-lg transition group",onMouseEnter:_=>c(_,x.join(`
`)),onMouseMove:h,onMouseLeave:g,children:[d.jsxs("div",{className:"flex items-center justify-between w-full",children:[d.jsx("span",{className:"text-[13px] text-zinc-300 group-hover:text-zinc-100 transition-colors truncate max-w-[60%]",title:b,children:b}),d.jsxs("span",{className:"text-[13px] text-zinc-300 tabular-nums font-medium",children:[a," session",a!==1?"s":""]})]}),d.jsx("div",{className:"w-full h-1.5 bg-zinc-800/60 rounded-full overflow-hidden",children:d.jsx("div",{className:"h-full bg-gradient-to-r from-cyan-600 to-cyan-400 rounded-full transition-all",style:{width:`${p}%`}})}),l&&d.jsxs("div",{className:"flex items-center gap-3 text-[11px] text-zinc-500",children:[d.jsxs("span",{className:"inline-flex items-center gap-1",children:[d.jsx(ud,{className:"w-3 h-3"}),l.messages.toLocaleString()," msgs"]}),d.jsxs("span",{className:"inline-flex items-center gap-1",children:[d.jsx(Io,{className:"w-3 h-3"}),fa(l.tokens)]}),d.jsx("span",{className:"inline-flex items-center gap-1",children:Ln(l.cost_usd)})]})]})}const Dd=["90%","100%","110%","120%","130%"],Dx="vibelens-settings",Lx=F.createContext({fontScale:"100%",setFontScale:()=>{},fontScaleOptions:Dd});function aC(){return F.useContext(Lx)}function lC(){try{const t=localStorage.getItem(Dx);if(!t)return"100%";const a=JSON.parse(t);if(a.fontScale&&Dd.includes(a.fontScale))return a.fontScale}catch{}return"100%"}function rC(t){localStorage.setItem(Dx,JSON.stringify({fontScale:t}))}function sC({children:t}){const[a,l]=F.useState(lC),r=o=>{l(o),rC(o)};return F.useEffect(()=>{const o=document.getElementById("root");if(!o)return;const u=parseInt(a)/100;o.style.zoom=String(u),o.style.height=`${100/u}vh`,o.style.width=`${100/u}vw`},[a]),d.jsx(Lx.Provider,{value:{fontScale:a,setFontScale:r,fontScaleOptions:Dd},children:t})}const oC="https://github.com/yejh123/VibeLens/issues/new",cC={bug:{title:"[Bug] ",body:`## Description
Describe the bug clearly and concisely.

## Steps to Reproduce
1. Go to ...
2. Click on ...
3. See error

## Expected Behavior
What should have happened?

## Screenshots
If applicable, add screenshots.

## Environment
- Browser:
- OS:
- VibeLens version: `},enhancement:{title:"[Feature] ",body:`## Feature Description
Describe the feature you'd like to see.

## Use Case
Why would this feature be useful?

## Proposed Solution
How do you envision this working?

## Alternatives Considered
Any alternative solutions or workarounds?`},improvement:{title:"[Improvement] ",body:`## Current Behavior
What currently works but could be better?

## Suggested Improvement
How should it be improved?

## Motivation
Why would this improvement matter?`}};function If(t){const a=cC[t],l=new URLSearchParams({labels:t,title:(a==null?void 0:a.title)??"",body:(a==null?void 0:a.body)??""});window.open(`${oC}?${l}`,"_blank","noopener,noreferrer")}function uC({onClose:t}){const{fontScale:a,setFontScale:l,fontScaleOptions:r}=aC();return d.jsxs("div",{className:"fixed inset-0 z-50 flex items-center justify-center",children:[d.jsx("div",{className:"absolute inset-0 bg-black/60 backdrop-blur-sm",onClick:t}),d.jsxs("div",{className:"relative bg-zinc-900 border border-zinc-700 rounded-lg shadow-2xl w-full max-w-md mx-4",children:[d.jsxs("div",{className:"flex items-center justify-between px-5 py-4 border-b border-zinc-800",children:[d.jsx("h2",{className:"text-sm font-semibold text-zinc-100",children:"Settings"}),d.jsx("button",{onClick:t,className:"text-zinc-500 hover:text-zinc-300 transition",children:d.jsx(Ul,{className:"w-4 h-4"})})]}),d.jsxs("div",{className:"px-5 py-4 space-y-5",children:[d.jsxs("div",{children:[d.jsx("h3",{className:"text-xs font-semibold text-zinc-400 uppercase tracking-wider mb-3",children:"Display Scale"}),d.jsx("div",{className:"flex gap-2",children:r.map(o=>d.jsx("button",{onClick:()=>l(o),className:`flex-1 py-2 text-sm font-medium rounded-md border transition ${a===o?"bg-cyan-600/20 text-cyan-300 border-cyan-500/40":"text-zinc-400 border-zinc-700 hover:text-zinc-200 hover:border-zinc-600"}`,children:o},o))})]}),d.jsxs("div",{children:[d.jsx("h3",{className:"text-xs font-semibold text-zinc-400 uppercase tracking-wider mb-3",children:"Send Feedback"}),d.jsxs("div",{className:"grid grid-cols-3 gap-2",children:[d.jsxs("button",{onClick:()=>If("bug"),className:"flex flex-col items-center gap-1.5 py-3 text-xs font-medium text-zinc-300 hover:text-zinc-100 bg-zinc-800/80 hover:bg-zinc-700 rounded-lg border border-zinc-700/50 transition",children:[d.jsx(s_,{className:"w-4 h-4 text-red-400"}),"Bug Report"]}),d.jsxs("button",{onClick:()=>If("enhancement"),className:"flex flex-col items-center gap-1.5 py-3 text-xs font-medium text-zinc-300 hover:text-zinc-100 bg-zinc-800/80 hover:bg-zinc-700 rounded-lg border border-zinc-700/50 transition",children:[d.jsx(J0,{className:"w-4 h-4 text-yellow-400"}),"Feature Request"]}),d.jsxs("button",{onClick:()=>If("improvement"),className:"flex flex-col items-center gap-1.5 py-3 text-xs font-medium text-zinc-300 hover:text-zinc-100 bg-zinc-800/80 hover:bg-zinc-700 rounded-lg border border-zinc-700/50 transition",children:[d.jsx(tv,{className:"w-4 h-4 text-cyan-400"}),"Improvement"]})]})]})]})]})]})}const jx=500*1024*1024,rd=F.createContext({sessionToken:"",appMode:"self",maxZipBytes:jx,fetchWithToken:(t,a)=>fetch(t,a)});function ss(){return F.useContext(rd)}function fC(){const[t,a]=F.useState(!0),[l,r]=F.useState([]),[o,u]=F.useState([]),[c,h]=F.useState(null),[g,p]=F.useState(0),[b,x]=F.useState(!1),[_,v]=F.useState(new Set),[S,T]=F.useState({kind:"hidden"}),[A,w]=F.useState(!1),[O,R]=F.useState(0),[q,Y]=F.useState("project"),[L,X]=F.useState(320),[oe,he]=F.useState("self"),[U,re]=F.useState(jx),[ae,le]=F.useState("all"),[W,H]=F.useState(["all"]),[C,K]=F.useState("browse"),[ne,ie]=F.useState(!1),[k]=F.useState(()=>new URLSearchParams(window.location.search).get("share")),[M]=F.useState(()=>{var de;return((de=crypto.randomUUID)==null?void 0:de.call(crypto))??Array.from(crypto.getRandomValues(new Uint8Array(16)),Re=>Re.toString(16).padStart(2,"0")).join("")}),B=240,N=600,ce=100,pe=F.useCallback((de,Re)=>{const rt=new Headers(Re==null?void 0:Re.headers);return rt.set("X-Session-Token",M),fetch(de,{...Re,headers:rt})},[M]),xe={sessionToken:M,appMode:oe,maxZipBytes:U,fetchWithToken:pe},Be=F.useCallback(de=>{X(Re=>Math.min(N,Math.max(B,Re+de)))},[]);F.useEffect(()=>{pe("/api/settings").then(de=>de.json()).then(de=>{de.app_mode==="demo"&&he("demo"),de.max_zip_bytes&&re(de.max_zip_bytes),de.visible_agents&&H(de.visible_agents)}).catch(de=>console.error("Failed to load settings:",de))},[pe]),F.useEffect(()=>{pe("/api/projects").then(de=>de.json()).then(de=>u(de)).catch(de=>console.error("Failed to load projects:",de))},[pe,O]),F.useEffect(()=>{x(!0);const de=new URLSearchParams;q==="project"?(de.set("limit","9999"),de.set("offset","0")):(de.set("limit",String(ce)),de.set("offset",String(g*ce))),pe(`/api/sessions?${de}`).then(Re=>Re.json()).then(Re=>{r(Re),!c&&Re.length>0&&h(Re[0].session_id)}).catch(Re=>console.error("Failed to load sessions:",Re)).finally(()=>x(!1))},[g,O,pe,q]);const ve=F.useMemo(()=>{var kt;const de=new Set;for(const Wn of l)(kt=Wn.agent)!=null&&kt.name&&de.add(Wn.agent.name);const Re=[...de].sort();return W.length===1&&W[0]==="all"?Re:Re.filter(Wn=>W.includes(Wn))},[l,W]),[qe,lt]=F.useState(null),Yt=F.useRef(!1);F.useEffect(()=>{l.length===0||Yt.current||(Yt.current=!0,Promise.all([pe("/api/analysis/dashboard").then(de=>de.ok?de.json():null),pe("/api/analysis/tool-usage").then(de=>de.ok?de.json():[]).catch(()=>[])]).then(([de,Re])=>{de&&lt({stats:de,toolUsage:Re})}).catch(()=>{}))},[pe,l]);const mn=F.useCallback(de=>{h(de),de&&K("browse")},[]),se=async()=>{if(_.size!==0)try{const de=await pe("/api/sessions/download",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({session_ids:[..._]})});if(!de.ok)return;const Re=await de.blob(),rt=URL.createObjectURL(Re),kt=document.createElement("a");kt.href=rt,kt.download="vibelens-export.zip",kt.click(),URL.revokeObjectURL(rt)}catch(de){console.error("Download failed:",de)}},Me=()=>{_.size!==0&&T({kind:"donate-confirm"})},et=F.useCallback(async()=>{T({kind:"donating"});try{const de=await pe("/api/sessions/donate",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({session_ids:[..._]})});if(!de.ok){let rt=`HTTP ${de.status}`;try{const kt=await de.json();rt=kt.detail||JSON.stringify(kt)}catch{rt=await de.text().catch(()=>rt)}T({kind:"donate-result",result:{total:_.size,donated:0,errors:[{session_id:"",error:rt}]}});return}const Re=await de.json();T({kind:"donate-result",result:Re})}catch(de){T({kind:"donate-result",result:{total:_.size,donated:0,errors:[{session_id:"",error:String(de)}]}})}},[_,pe]),we=()=>{S.kind==="donate-result"&&S.result.donated>0&&v(new Set),T({kind:"hidden"})},zt=()=>{switch(S.kind){case"donate-confirm":return d.jsx(hv,{sessionCount:_.size,onConfirm:et,onCancel:we});case"donating":return d.jsx(Ng,{title:"Donating...",message:`Donating ${_.size} session${_.size!==1?"s":""}...`,onConfirm:()=>{},onCancel:()=>{},loading:!0});case"donate-result":{const de=S.result,Re=de.errors.length>0,rt=[`Donated: ${de.donated}`,`Total: ${de.total}`];if(Re){rt.push(""),rt.push(`Errors: ${de.errors.length}`);for(const kt of de.errors.slice(0,3))rt.push(`  ${kt.session_id||"—"}: ${kt.error}`)}return d.jsx(Ng,{title:Re?"Completed with errors":"Donation complete",message:rt.join(`
`),confirmLabel:"OK",cancelLabel:"Close",onConfirm:we,onCancel:we})}default:return null}};return k?d.jsx(rd.Provider,{value:xe,children:d.jsxs("div",{className:"flex flex-col h-full overflow-hidden bg-zinc-950 text-zinc-100",children:[d.jsxs("div",{className:"shrink-0 flex items-center justify-between px-4 py-2 bg-violet-900/30 border-b border-violet-700/50",children:[d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx(eb,{className:"w-4 h-4 text-violet-400"}),d.jsx("span",{className:"text-sm text-violet-300 font-medium",children:"Shared session"})]}),d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx("img",{src:"/icon.png",alt:"VibeLens",className:"w-6 h-6"}),d.jsx("span",{className:"text-sm font-bold text-cyan-400",children:"VibeLens"})]})]}),d.jsx("div",{className:"flex-1 min-h-0",children:d.jsx(IM,{shareToken:k})})]})}):d.jsx(rd.Provider,{value:xe,children:d.jsxs("div",{className:"flex h-full overflow-hidden bg-zinc-950 text-zinc-100",children:[t&&d.jsxs("aside",{style:{width:L},className:"relative border-r border-zinc-800 flex flex-col shrink-0 bg-zinc-900",children:[d.jsx(Ff,{side:"left",onResize:Be}),d.jsxs("div",{className:"flex items-center justify-between px-4 h-[75px] border-b border-zinc-800 sticky top-0",children:[d.jsxs("div",{className:"flex items-center gap-3",children:[d.jsx("img",{src:"/icon.png",alt:"VibeLens",className:"w-12 h-12"}),d.jsx("h1",{className:"text-2xl font-bold text-cyan-400",children:"VibeLens"})]}),d.jsx("button",{onClick:()=>a(!1),className:"text-zinc-500 hover:text-zinc-300 transition",title:"Collapse sidebar",children:d.jsx(Y_,{className:"w-4 h-4"})})]}),d.jsxs("div",{className:"shrink-0 border-b border-zinc-800 px-3 py-2.5 grid grid-cols-3 gap-2 text-xs text-zinc-400",children:[d.jsxs("button",{onClick:()=>w(!0),className:"flex items-center justify-center gap-1.5 py-1.5 text-xs font-medium bg-violet-600 hover:bg-violet-500 text-white rounded transition",title:"Upload conversation files",children:[d.jsx(T_,{className:"w-3.5 h-3.5"}),"Upload"]}),d.jsxs("button",{onClick:se,disabled:_.size===0,className:"flex items-center justify-center gap-1.5 py-1.5 text-xs font-medium bg-emerald-600 hover:bg-emerald-500 text-white rounded transition disabled:opacity-40 disabled:cursor-not-allowed",title:"Download selected sessions as zip",children:[d.jsx(Ho,{className:"w-3.5 h-3.5"}),"Download"]}),d.jsxs("button",{onClick:Me,disabled:_.size===0,className:"flex items-center justify-center gap-1.5 py-1.5 text-xs font-medium bg-rose-600 hover:bg-rose-500 text-white rounded transition disabled:opacity-40 disabled:cursor-not-allowed",title:"Donate selected sessions for research",children:[d.jsx(D_,{className:"w-3.5 h-3.5"}),"Donate"]})]}),d.jsx(vv,{sessions:l,selectedId:c,onSelect:mn,checkedIds:_,onCheckedChange:v,viewMode:q,onViewModeChange:Y,agentFilter:ae,onAgentFilterChange:le,availableAgents:ve}),d.jsxs("div",{className:"shrink-0 border-t border-zinc-800 px-3 py-2 flex items-center justify-between text-xs text-zinc-400",children:[d.jsxs("span",{children:[l.length," sessions"]}),q==="time"&&d.jsxs("div",{className:"flex items-center gap-1",children:[d.jsx("button",{onClick:()=>p(Math.max(0,g-1)),disabled:g===0||b,className:"p-1 hover:bg-zinc-800 disabled:opacity-50 disabled:cursor-not-allowed rounded transition",title:"Previous page",children:d.jsx(P0,{className:"w-4 h-4"})}),d.jsx("span",{className:"px-1 text-xs",children:g+1}),d.jsx("button",{onClick:()=>p(g+1),disabled:l.length<ce||b,className:"p-1 hover:bg-zinc-800 disabled:opacity-50 disabled:cursor-not-allowed rounded transition",title:"Next page",children:d.jsx(ui,{className:"w-4 h-4"})})]})]})]}),d.jsxs("main",{className:"flex-1 flex flex-col min-w-0 bg-zinc-950",children:[d.jsxs("div",{className:"flex items-center justify-between px-4 py-2 border-b border-zinc-800 bg-zinc-900/80",children:[d.jsxs("div",{className:"flex items-center gap-2",children:[!t&&d.jsx("button",{onClick:()=>a(!0),className:"p-1.5 mr-1 text-zinc-500 hover:text-zinc-300 bg-zinc-800 hover:bg-zinc-700 border border-zinc-700/50 rounded transition",title:"Expand sidebar",children:d.jsx(F_,{className:"w-4 h-4"})}),d.jsx("button",{onClick:()=>K("browse"),className:`px-4 py-1.5 text-sm font-semibold rounded-md transition ${C==="browse"?"bg-cyan-600/20 text-cyan-300 border border-cyan-500/30":"text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800"}`,children:"Conversation"}),d.jsx("button",{onClick:()=>K("analyze"),className:`px-4 py-1.5 text-sm font-semibold rounded-md transition ${C==="analyze"?"bg-cyan-600/20 text-cyan-300 border border-cyan-500/30":"text-zinc-400 hover:text-zinc-200 hover:bg-zinc-800"}`,children:"Dashboard"})]}),d.jsx("button",{onClick:()=>ie(!0),className:"p-1.5 text-zinc-500 hover:text-zinc-300 hover:bg-zinc-800 rounded transition",title:"Settings",children:d.jsx(Z_,{className:"w-6 h-6"})})]}),d.jsx("div",{className:"flex-1 min-h-0 relative",children:C==="analyze"?d.jsx(nC,{cache:qe}):c?d.jsx(Rx,{sessionId:c}):d.jsx("div",{className:"flex items-center justify-center h-full",children:d.jsxs("div",{className:"text-center",children:[d.jsx("div",{className:"text-5xl mb-4 opacity-50",children:"✨"}),d.jsx("p",{className:"text-lg font-medium text-zinc-300 mb-1",children:"Welcome to VibeLens"}),d.jsx("p",{className:"text-sm text-zinc-500 mb-6",children:"Select a session from the sidebar to explore agent conversations"}),d.jsxs("div",{className:"text-xs text-zinc-600",children:[d.jsxs("p",{children:[l.length," sessions loaded"]}),d.jsxs("p",{children:[o.length," projects available"]})]})]})})})]}),zt(),A&&d.jsx(qM,{onClose:()=>w(!1),onComplete:()=>R(de=>de+1)}),ne&&d.jsx(uC,{onClose:()=>ie(!1)})]})})}V1.createRoot(document.getElementById("root")).render(d.jsx(F.StrictMode,{children:d.jsx(sC,{children:d.jsx(fC,{})})}));
